import { UserData } from '..';
import RootStore from './RootStore';
import { LoginMethods } from '../types';
type AuthState = LoginState | RequestNewPasswordState | ChangePasswordState | InvitationExpiredState | WelcomeState | Register;
interface LoginState {
    type: 'LOGIN';
    error?: string;
    loginMethods?: LoginMethods;
    organizationId?: string;
    invitationId?: string;
    email?: string;
}
interface RequestNewPasswordState {
    type: 'REQUEST_NEW_PASSWORD';
    email: string;
}
interface ChangePasswordState {
    type: 'CHANGE_PASSWORD';
    token: string;
}
interface InvitationExpiredState {
    type: 'INVITATION_EXPIRED';
}
interface WelcomeState {
    type: 'WELCOME';
    isNewUser?: boolean;
    invitationId?: string;
    invitationOrgId?: string;
}
interface Register {
    type: 'REGISTER';
    loginMethods?: LoginMethods;
    invitationId?: string;
    email?: string;
    useOtp?: boolean;
}
export default class AuthorizationStore {
    private root;
    private _state?;
    private _nToken?;
    private _zToken?;
    private _zExpireBy?;
    private _loginState?;
    private _timeout?;
    constructor(root: RootStore);
    get zToken(): string | undefined;
    set zToken(zToken: string | undefined);
    get nToken(): string | undefined;
    get loginState(): "anon" | "simple" | "user" | undefined;
    showLogin(debug?: boolean, error?: boolean, organizationId?: string, invitationId?: string, email?: string): void;
    showRequestNewPassword(email: string): void;
    showChangePassword(token: string): void;
    showInvitationExpired(id: string): void;
    showWelcomeScreen(isNewUser: boolean, invitationId: string, invitationOrgId: string): Promise<void>;
    showRegister(invitationId?: string, email?: string, useOtp?: boolean): void;
    close(): void;
    get state(): AuthState | undefined;
    showExpiredLoginModal(): void;
    openOAuthLogin(provider: string, organizationId?: string, invitationId?: string): void;
    tokenChanged(): Generator<Generator<any, void, any> | Generator<any, string, any>, void, string>;
    autorize(organizationId?: string, nToken?: string): Generator<any, string, any>;
    register(email: string, password: string, name: string, familyName: string, invitationId: string, otp?: string): Generator<any, void, any>;
    login(email: string, password?: string, loginSimple?: boolean, organizationId?: string, invitationId?: string, otp?: string): Generator<any, void, any>;
    updateAuthorizationData(zToken: string, zExpireBy: number, type: 'anon' | 'simple' | 'user', organizationId: string, parentOrganizations?: string[], permissions?: string[], user?: UserData): Generator<Generator<any, void, any>, void, unknown>;
    logout(relogin?: boolean, skipApiLogout?: boolean, currentOrganization?: string, skipRedirect?: boolean): Generator<Promise<any>, void, {
        redirect: string;
    }>;
    private getRedirectUrl;
}
export {};
//# sourceMappingURL=AuthorizationStore.d.ts.map