import { Banner, Breadcrumb, Component } from '../types';
import RootStore from './RootStore';
export interface BrowserState {
    language?: string;
    organization?: string;
    component?: Component;
    breadcrumbs?: Breadcrumb;
    authdata?: string;
    debugLogin?: boolean;
}
export default class BrowserStateStore {
    private root;
    private _url;
    constructor(root: RootStore);
    /**
     * get the current state represented by the url
     * @returns the current state represented by the url
     */
    loadUrlState(): Promise<BrowserState>;
    /**
     * Stores the banner state into the local storage
     *
     * @param banner the banner state to be stored
     */
    setBannerState(banner: Banner): void;
    /**
     * Validates the current banner state against the the local storage
     * and removes expried states from the storage
     *
     * @param banner the current banner state
     */
    validateManipulateBannerLocalStorage(banner: Banner): void;
    /**
     * Check if the current banner state is in local storage
     *
     * @param banner the current banner state
     * @returns true if the current banner state is already in storage
     */
    bannerInLocalStorage(banner: Banner): boolean;
    /**
     * Get the currently stored ntoken token
     */
    getStoredNToken(): string | undefined;
    /**
     * Updates or removes ntoken in storage
     *
     * @param ntoken the new ntoken or undefined to remove it
     */
    setStoredNToken(ntoken?: string, expire?: number): void;
    /**
     * Get the currently stored organization
     */
    getStoredOrganization(): string | undefined;
    /**
     * Updates or removes organization in storage
     *
     * @param organization the new organization or undefined to remove it
     */
    setStoredOrganization(organization?: string): void;
    /**
     * Get the currently stored login method
     */
    getStoredLoginMethod(): string | undefined;
    /**
     * Updates or removes loginMethod in storage
     *
     * @param loginMethod the new loginMethod or undefined to remove it
     */
    setStoredLoginMethod(loginMethod?: string): void;
    /**
     * Get the currently stored language
     */
    getStoredLanguage(): string | undefined;
    /**
     * Updates or removes language in storage
     *
     * @param language the new language or undefined to remove it
     */
    setStoredLanguage(language?: string): void;
    /**
     * Applies the current state represented by the url to the application
     */
    private applyUrlStateChanges;
    /**
     * Updates the url when ever the state of the applicaton changes
     */
    private enableUrlSyncronization;
    /**
     * Returns true if the url should be syncronized
     */
    private get isUrlSyncEnabled();
    /**
     * action to set the internal copy of the url state
     */
    private setUrl;
    /**
     * Check if the localstorage contains a banner state for the current user
     *
     * @param localstoragevalue the full localstorage data for banners
     * @param userid the ID current user
     * @param banner the current bannter state
     * @returns true if the banner state already exists in localstorage
     */
    private bannerExistsInLocalStorage;
    /**
     * Adds a number of days to the current timestamp
     *
     * @param days a number of days
     * @returns the timestamp
     */
    private addDaysToCurrentDate;
}
//# sourceMappingURL=BrowserStateStore.d.ts.map