import type { ApiConfig, ApiConfigConfig, AuthenticationConfiguration, BaseNavigationConfiguration, Configuration, GoogleMapsConfig, CometChatConfig, OrganizationType } from '../types';
import RootStore from './RootStore';
export default class ConfigurationStore {
    private root;
    private identifier;
    private defaultApiConfig?;
    private domain?;
    private _configuration?;
    private configurationCache;
    contentBoxConfiguration?: {
        configParams: {
            showArQRCode: boolean;
        };
        identifier: string;
        type: string;
    };
    constructor(root: RootStore, identifier: string, defaultApiConfig?: Partial<ApiConfigConfig> | undefined, domain?: string | undefined);
    set configuration(config: Configuration);
    get configuration(): Configuration;
    get organizations(): string[];
    get validOrganizations(): string[] | undefined;
    get excludedOrganizations(): string[] | undefined;
    get components(): import("../types").ComponentConfiguration[];
    get defaultComponent(): import("../types").Component | undefined;
    get locales(): import("../types").Locales | undefined;
    get spinner(): import("../types").SpinnerData | undefined;
    get theme(): {
        palette: {
            primary: {
                main: string;
                light: string;
                dark: string;
                contrastText: string;
            };
            secondary: {
                main: string;
                light: string;
                dark: string;
                contrastText: string;
            };
            text: {
                primary: string;
                secondary: string;
            };
        };
        typography: {
            fontFamily: string;
        };
        components: any;
    };
    get navigation(): BaseNavigationConfiguration;
    get googleMapsconfig(): GoogleMapsConfig;
    get cometchatConfig(): CometChatConfig;
    get hasAuthentication(): boolean;
    get authentication(): AuthenticationConfiguration;
    get enableRouting(): boolean | undefined;
    get enableStorage(): boolean | undefined;
    get telemetrySettings(): {
        url: string;
        apm?: string | false;
        businessEvents?: boolean;
        apiKey: string;
        personalData: boolean;
        cookieBotCbid?: string;
    } | undefined;
    get enableModals(): boolean;
    get enableSupport(): boolean | undefined;
    get showInitWarnBanner(): boolean | undefined;
    get apiConfig(): ApiConfig;
    get applicationEnvironment(): "SELLER" | "WEB";
    get priceFormat(): any;
    get countryCodesFile(): string | undefined;
    get allowedOrganizationTypes(): OrganizationType[];
    resetConfigurationCache(): void;
    fetchConfiguration({ identifier, type, domain, organizationId, }: {
        identifier?: string;
        domain?: string;
        type: string;
        organizationId?: string;
    }): Promise<any>;
    updateConfiguration(): Generator<Promise<any>, void, Configuration>;
}
//# sourceMappingURL=ConfigurationStore.d.ts.map