import { LoginMode } from '..';
import RootStore from './RootStore';
import { OrganizationData, UserData, UserRole } from '../types';
export default class DataStore {
    private root;
    private _currentOrganizationId?;
    private _organization?;
    private _user?;
    private _isMobile;
    private _isFirefox;
    private _sessionGuids;
    private _permissions;
    private _parentOrganizations;
    constructor(root: RootStore);
    get isMobile(): boolean;
    get isFirefox(): boolean;
    get organization(): OrganizationData;
    get organizationId(): string;
    /**
     * Returns the full list of parent organizations including the current organization
     */
    get fullParentList(): string[];
    /**
     * Returns the list of parent organizations including the current organization, filtered by the valid organizations of the config and the permissions of the user
     * this is manly used for displaying the organization hirarchy in the header
     *
     * If you need the full parent list, use fullParentList
     */
    get organizationHirarchy(): ({
        type: string | undefined;
        _id: string;
        displayName: string;
        parentType?: string;
        crossOrganizationSetting?: "YES" | "NO";
        shopType: string;
    } | {
        _id: string;
        displayName: string;
        type: "SUPPLIER" | "RETAILER" | "ASSOCIATION" | undefined;
    })[];
    get user(): UserData | undefined;
    set user(user: UserData | undefined);
    set permissions(permission: string[]);
    set parentOrganizations(organizations: string[]);
    /**
     * Checks if the user has a certain permissions
     * @param permission the permission
     * @returns true if the user has the permission
     */
    userHasPermission(permission: string): boolean;
    updateOrganization(organizationId: string): Generator<any, void, any>;
    getSessionGuid(u: UserRole, m?: LoginMode, organizationId?: string, api2Location?: string): Promise<any>;
    getApi2AuthLoginData(u: UserRole, m?: LoginMode, organizationId?: string, api2Location?: string): Promise<any>;
    private getSessionGuidFlow;
    /**
     * clears all the current saved sessionGuids
     */
    clearSessionGuids(): void;
    /**
     * Update the currently selected organization and immediately load the organization data
     * @param organizationId the id of the new organization
     */
    updateOrganizationInternal(organizationId: string): Generator<any, void, any>;
}
//# sourceMappingURL=DataStore.d.ts.map