import ConfigurationStore from './ConfigurationStore';
import DataStore from './DataStore';
import ContentStore from './ContentStore';
import LoadingAndErrorStore from './LoadingAndErrorStore';
import BrowserStateStore from './BrowserStateStore';
import AuthorizationStore from './AuthorizationStore';
import { DivaCoreProps } from './';
import ApiHandler from '../handler/InternalApiHandler';
import { ApiConfig, Component, Event, OrganizationData, OrganizationType, UserData } from '../types';
import { ProductHandler, LoginMode } from '..';
import { OrganizationHandler } from '../handler/OrganizationHandler';
import { MediaHandler } from '../handler/MediaHandler';
import { AdminHandler } from '../handler/AdminHandler';
import { AnalyticsHandler } from '../handler/AnalyticsHandler';
import { ReportHandler } from '../handler/ReportHandler';
import { SupportHandler } from '../handler/SupportHandler';
import { AuthorizationHandler } from '../handler/AuthorizationHandler';
import { ClientArticleHandler } from '../handler/ClientArticleHandler';
export interface IRootStore {
    changeLanguage(lang: string): void;
    changeLoginMode(loginMode: LoginMode): void;
    onExternalEvent(event: Event): void;
    subscribeEvents(fn: (event: Event) => void): void;
    unSubscribeEvents(fn: (event: Event) => void): void;
    readonly language: string;
    readonly loginMode: LoginMode;
    readonly t: (key: string, options?: any) => string;
    readonly languages: string[];
    readonly onEvent: (event: Event) => void;
    readonly initializing: boolean;
    readonly apiHandler: ApiHandler;
    readonly productHandler: ProductHandler;
    readonly organizationHandler: OrganizationHandler;
    readonly mediaHandler: MediaHandler;
    readonly adminHandler: AdminHandler;
    readonly reportHandler: ReportHandler;
    readonly supportHandler: SupportHandler;
    readonly analyticsHandler: AnalyticsHandler;
    readonly clientArticleHandler: ClientArticleHandler;
    readonly authorizationHandler: AuthorizationHandler;
    readonly doShowInitWarnBanner: boolean;
    readonly apiConfig: ApiConfig;
    readonly jwt: string | undefined;
    readonly storedNToken: string | undefined;
    readonly user: UserData | undefined;
    readonly organization: OrganizationData | undefined;
    readonly allowedOrganizationTypes: OrganizationType[];
    readonly validOrganizations: string[] | undefined;
    readonly excludedOrganizations: string[] | undefined;
    readonly dataStore: DataStore;
}
export default class RootStore implements IRootStore {
    readonly contentStore: ContentStore;
    readonly configurationStore: ConfigurationStore;
    readonly dataStore: DataStore;
    readonly loadingAndErrorStore: LoadingAndErrorStore;
    readonly browserStateStore: BrowserStateStore;
    readonly authorizationStore: AuthorizationStore;
    private _onEvent?;
    private events;
    private _initializing;
    private _language;
    private _loginMode;
    private _apiHandler;
    private _productHandler;
    private _reportHandler;
    private _organizationHandler;
    private _mediaHandler;
    private _adminHandler;
    private _analyticsHandler;
    private _supportHandler;
    private _authorizationHandler;
    private _clientArticleHandler;
    private _initalComponent?;
    constructor({ components, spinnerClass, language, organizationId, domain, configUrl: configProvider, defaultApiConfig, currentComponent: component, identifier, telemetry, onEvent, }: DivaCoreProps);
    /**
     * Changes the current language of the application
     * @param lang the new language
     */
    changeLanguage(lang: string): void;
    /**
     * The current language of the application
     */
    get language(): string;
    /**
     * Changes the current userMode
     * @param mode the new mode
     */
    changeLoginMode(loginMode: LoginMode): void;
    /**
     * The current mode of the application
     */
    get loginMode(): LoginMode;
    /**
     * The i18n translation function
     */
    get t(): import("i18next").TFunction<["translation", ...string[]], undefined>;
    /**
     * The i18n languages
     */
    get languages(): string[];
    /**
     * The eventhandler register by the user of the application or a no-op if non was registered
     */
    get onEvent(): (event: Event) => void;
    /**
     * Is true if the application is currently initializing
     */
    get initializing(): boolean;
    /**
     * Triggers an event from outside of the application
     * @param event the event
     */
    onExternalEvent(event: Event): void;
    /**
     * Subscribe an eventhandler for external events
     * @param fn the eventhandler
     */
    subscribeEvents(fn: (event: Event) => void): void;
    /**
     * Unsubscribe an eventhandler from external events
     * @param fn the eventhandler
     */
    unSubscribeEvents(fn: (event: Event) => void): void;
    /**
     * get an ApiHandler instance with the current configuration
     */
    get apiHandler(): ApiHandler;
    /**
     * get the productHander instance with the current configuration
     */
    get productHandler(): ProductHandler;
    /**
     * get the organizationHandler instance with the current configuration
     */
    get organizationHandler(): OrganizationHandler;
    /**
     * get the mediaHandler instance with the current configuration
     */
    get mediaHandler(): MediaHandler;
    get adminHandler(): AdminHandler;
    get reportHandler(): ReportHandler;
    get supportHandler(): SupportHandler;
    get analyticsHandler(): AnalyticsHandler;
    get clientArticleHandler(): ClientArticleHandler;
    get authorizationHandler(): AuthorizationHandler;
    get doShowInitWarnBanner(): boolean;
    get apiConfig(): ApiConfig;
    get jwt(): string | undefined;
    get storedNToken(): string | undefined;
    get user(): UserData | undefined;
    get organization(): OrganizationData;
    get allowedOrganizationTypes(): OrganizationType[];
    get validOrganizations(): string[] | undefined;
    get excludedOrganizations(): string[] | undefined;
    /**
     * Initalizes the application
     *
     * @param organizationId the organizationId set via component property
     * @param domain the domain set via component property
     * @param identifier the identifier set via component property
     * @param language the language set via component property
     * @param component the inital component set via component property
     * @param telemetry the telemetry setting via component property
     */
    private initialize;
    initalizeView(): void;
    get initalComponent(): Component | undefined;
}
//# sourceMappingURL=RootStore.d.ts.map