import { PriceFormat } from '@crystaldesign/diva-utils';
import { Action, Theme } from './externalTypes';
export * from './externalTypes';
export interface Configuration {
    organizations: string[];
    components: Components;
    locales: Locales;
    spinner?: SpinnerData;
    theme?: Theme;
    loginLogoHeight?: number;
    navigation?: Partial<BaseNavigationConfiguration>;
    authentication?: AuthenticationConfiguration;
    enableRouting?: boolean;
    enableStorage?: boolean;
    disableModals?: boolean;
    enableSupport?: boolean;
    priceFormat?: PriceFormat;
    countryCodesFile?: string;
    cssCustomFile?: string;
    telemetry?: {
        url: string;
        apm?: string | false;
        businessEvents?: boolean;
        apiKey: string;
        personalData: boolean;
        cookieBotCbid?: string;
    };
    api?: Partial<ApiConfigConfig>;
    allowedOrganizationTypes?: OrganizationType | OrganizationType[];
    excludeOrganizations?: string[];
    applicationEnvironment?: 'SELLER' | 'WEB';
    showInitWarnBanner?: boolean;
    logOnlineState?: {
        log: boolean;
        intervalMS: number;
    };
    pwa?: {
        manifest?: string;
    };
    environment?: string;
    applicationName?: string;
    googleMapsConfig?: {
        id: string;
        googleMapsApiKey: string;
        language: string;
        region: string;
    };
    cometChatConfig?: {
        app_id: string;
        app_region: string;
        listener_id: string;
    };
    mailTo?: string;
    mailTemplate?: {
        kind: string;
        variant: string;
    };
    cssUrl?: string;
}
export interface ApiConfigConfig {
    analyticsService: string;
    authService: string;
    adminService: string;
    constructorService: string;
    messageService: string;
    catalogService: string;
    supportService: string;
    mediaService: string;
    basketService: string;
    reportService: string;
    clientArticleService: string;
    idmService: string;
    enricherService: string;
    baseUrl: string;
    host3d: string;
    diva3darchive: string;
    baseCdnUrl: string;
    useDebugUrl?: boolean;
    api2: string;
    baseSirvUrls?: string[];
    arViewerBaseUrl?: string;
    showInitWarnBanner?: string;
}
export type OrganizationType = 'SUPPLIER' | 'RETAILER';
export interface Components {
    default: Component;
    openSellerDefaultForRetailer?: boolean;
    available: ComponentConfiguration[];
}
export interface Component {
    type?: string;
    identifier?: string;
    route?: string;
    parameters?: {
        [param: string]: string | undefined;
    };
    internal?: {
        [key: string]: any | undefined;
    };
    openInNewTab?: boolean | string;
    openInFullscreen?: boolean;
    absoluteFullscreen?: boolean;
    absoluteFullscreenStyle?: FullscreenStyle;
    keepOldState?: boolean;
}
export interface FullscreenStyle {
    desktop?: React.CSSProperties;
    mobile?: React.CSSProperties;
}
export interface ComponentConfiguration {
    identifier: string;
    type: string;
    isPublic?: boolean | 'barrier';
    route?: string;
    openInNewTab?: boolean | string;
    permission?: string;
    showFooter?: boolean | 'hidden';
    settings?: {
        [key: string]: any;
    };
    barrier?: BarrierSetting;
}
export interface BarrierSetting {
    title?: string;
    text?: string;
    emailVariant?: string;
    excludeParams?: string[];
    skipVerify?: boolean;
}
export interface Locales {
    namespace?: string;
    url?: string;
    available?: string[];
}
export interface SpinnerData {
    className: string;
    file: string;
}
export interface BaseNavigationConfiguration {
    logoUrl?: string;
    logoAction?: Action;
    welcomeText?: string;
    showOrgName?: boolean;
    showUserName?: boolean;
    showDescription?: boolean;
    buttons: Button[];
    imprintUrl?: string;
    privacyUrl?: string;
    conditionsUrl?: string;
    tosUrl?: string;
    supportUrl?: string;
    feedbackUrl?: string;
    showFooter?: boolean | 'hidden';
    enableMobile?: boolean;
    hideHeader?: boolean;
    qrCodeScanner?: {
        product?: boolean;
        basket?: boolean;
    } | boolean;
    greetingsText?: string;
    showSnow?: boolean;
    pricePreviewActive?: boolean | string;
}
export interface GoogleMapsConfig {
    id?: string;
    googleMapsApiKey?: string;
    language?: string;
    region?: string;
}
export interface CometChatConfig {
    app_id?: string;
    app_region?: string;
    listener_id?: string;
}
export interface NavigationConfiguration extends BaseNavigationConfiguration {
    customLogo?: string;
    customHeaderElement?: () => JSX.Element;
    breadcrumbs?: Breadcrumbs;
    showFooter: boolean | 'hidden';
    allowHidePrices: boolean;
    showLogin: boolean;
    greetingsText?: string;
}
export interface AuthenticationConfiguration {
    loginMethods?: LoginMethods;
    allwaysShowLogin?: boolean;
    contentBox?: {
        config?: any;
        props: any;
    };
    resetPassword?: {
        returnToLogin?: boolean;
    };
}
export interface LoginMethods {
    standard?: boolean;
    google?: boolean;
    microsoft?: boolean;
    generic?: boolean | {
        logo?: string;
        backgroundColor?: string;
        color?: string;
    };
}
export interface Button {
    text: string;
    action: Action;
    permission?: string;
    isPublic?: boolean;
    inMenu?: boolean;
}
export interface Breadcrumbs {
    breadcrumbs: Breadcrumb;
    current: number;
}
export interface Breadcrumb {
    id: string;
    path: Path[];
}
interface Path {
    level: number;
    name: string;
    component: Component;
}
export interface AuthData {
    token: string;
    error?: string;
    path: 'confirmEmail' | 'resetPassword' | 'reactToInvite' | 'openIdCallback';
}
//# sourceMappingURL=types.d.ts.map