import './loadLoglevelSettings';
import { EventAction, EventModule, DivaError } from '@crystaldesign/diva-utils';
export declare class ApplicationLogger {
    private module;
    private component;
    private apiInitialized;
    private transactions;
    constructor(module: EventModule, component: string, apiInitialized?: boolean);
    /**
     * Start a new transaction and return the transaction id
     * @param event  The event type
     * @param message  The message to log
     * @param labels  Additional labels
     * @param eventId  An optional event ID, if not provided a new one will be generated
     * @param warningTime  An optional warning time, if the transaction takes longer than this time a warning will be logged
     * @param errorTime  An optional error time, if the transaction takes longer than this time an error will be logged
     * @returns The transaction ID
     */
    startTransaction({ event, message, labels, eventId, warningTime, errorTime, }: {
        event: string;
        message: string;
        labels?: {
            [label: string]: string | number | undefined;
        };
        eventId?: string;
        warningTime?: number;
        errorTime?: number;
    }): string;
    /**
     * End a transaction and log the duration
     * @param eventId The transaction ID
     * @param labels  Additional labels
     */
    successTransaction(eventId: string, labels?: {
        [label: string]: string | number | undefined;
    }): void;
    /** End a transaction and log the duration and an error message
     * @param eventId The transaction ID
     * @param code The error code
     * @param message The error message
     * @param labels  Additional labels
     * */
    errorTransaction(eventId: string, code: string, message: string, labels?: {
        [label: string]: string | number | undefined;
    }, dontLog?: boolean): void;
    /**
     * Log normal business event, without transaction
     * @param eventAction
     * @param module
     * @param message
     * @param labels
     */
    businessEvent(eventAction: EventAction, module: EventModule, message: string, labels?: {
        [key: string]: string | number | undefined | any;
    }): void;
    private timeoutTransation;
    /**
     * Close all open transactions and log them as errors
     */
    flush(): void;
    /**
     * After apm is initialized, send all transactions that were created before
     */
    apmInitalized(): void;
    debug(message: string, ...optionalParams: any[]): void;
    log(message: string, ...optionalParams: any[]): void;
    warn(message: string, ...optionalParams: any[]): void;
    error(error: DivaError): void;
    isValidLogLevel(loglevel: number): boolean;
    private getPrefix;
    private getApmTransationIdFormatted;
    private cleanLabels;
}
export declare function setOnErrorEvent(onEvent: (message: string, code?: string) => void): void;
export declare function getLogger(module: EventModule, component: string): ApplicationLogger;
export declare function flashLoggers(): void;
export declare function apmIsInitalized(): void;
//# sourceMappingURL=index.d.ts.map