import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { init as init$2 } from '@elastic/apm-rum';
import DivaUtils, { nanoid, DivaError, md5 } from '@crystaldesign/diva-utils';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import _inherits from '@babel/runtime/helpers/inherits';
import _wrapNativeSuper from '@babel/runtime/helpers/wrapNativeSuper';
import ReactDOM from 'react-dom';
import React, { forwardRef, useState, useEffect, useCallback, Suspense, createContext, useMemo, useImperativeHandle, useRef } from 'react';
import { observer } from 'mobx-react-lite';
import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import { makeAutoObservable, flow, flowResult, toJS, observable, computed, reaction, autorun, action, makeObservable, runInAction } from 'mobx';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import MobileDetect from 'mobile-detect';
import platform from 'platform';
import i18n from 'i18next';
import HttpApi from 'i18next-http-backend';
import * as CoreStyles from '@mui/material/styles';
import { StyledEngineProvider, ThemeProvider, createTheme } from '@mui/material/styles';
import { enUS, itIT, frFR, deDE } from '@mui/material/locale';
import { withTransaction } from '@elastic/apm-rum-react';
import Typography from '@mui/material/Typography';
import { useTranslation, Trans, I18nextProvider } from 'react-i18next';
import classnames from 'classnames';
import Button from '@mui/material/Button';
import { jsx, Fragment, jsxs } from 'react/jsx-runtime';
import { ArrowBack } from '@mui/icons-material';
import '@crystaldesign/basket-model';
import debounce from 'lodash/debounce';
import axios from 'axios';
import { ProductHandlerAbstract } from '@crystaldesign/product-handler';
import { useSwipeable } from 'react-swipeable';
import { ContentBoxComponent } from '@crystaldesign/content-box';
import { Button as Button$1, Snackbar, SnackbarContent, IconButton, Card, CardHeader, CardContent } from '@mui/material';
import { useTranslation as useTranslation$1, useDivaCore as useDivaCore$1 } from '@crystaldesign/diva-core';
import QRCode from 'react-qr-code';
import CloseIcon from '@mui/icons-material/Close';
import IconButton$1 from '@mui/material/IconButton';
import HelpOutline from '@mui/icons-material/HelpOutline';
import { actions } from '@storybook/addon-actions';
import * as Styles from '@mui/styles';

(function() {
    const env = {"STAGE":"production","VERSION":"25.7.5"};
    try {
        if (process) {
            process.env = Object.assign({}, process.env);
            Object.assign(process.env, env);
            return;
        }
    } catch (e) {} // avoid ReferenceError: process is not defined
    globalThis.process = { env:env };
})();

window.setDivaLogLevel = function (loglevel) {
  localStorage.setItem('DIVA_LOGGER', loglevel.toString());
};
window.setDivaModuleLogLevel = function (module, loglevel) {
  var moduleloglevel = {
    module: module,
    loglevel: loglevel
  };
  var valuesArray = [];
  var lsValue = localStorage.getItem('DIVA_LOGGER_MODULES');
  if (lsValue) {
    valuesArray = JSON.parse(lsValue);
    var index = valuesArray.findIndex(function (a) {
      return a.module === module;
    });
    if (index > -1) {
      valuesArray.splice(index);
    }
  }
  valuesArray.push(moduleloglevel);
  localStorage.setItem('DIVA_LOGGER_MODULES', JSON.stringify(valuesArray));
};
window.resetAllLogLevels = function () {
  localStorage.removeItem('DIVA_LOGGER');
  localStorage.removeItem('DIVA_LOGGER_MODULES');
};
var divaLogLevel = 2;
var lsDivaLogLevel = localStorage.getItem('DIVA_LOGGER');
if (lsDivaLogLevel) {
  divaLogLevel = parseInt(lsDivaLogLevel);
}
window.DIVA_LOGGER = divaLogLevel;
var divaLoggerModules = [];
var lsDivaLoggerModules = localStorage.getItem('DIVA_LOGGER_MODULES');
if (lsDivaLoggerModules) {
  divaLoggerModules = JSON.parse(lsDivaLoggerModules);
}
window.DIVA_LOGGER_MODULES = divaLoggerModules;

var apm = undefined;
function init$1(active, environment, serviceName, serviceUrl) {
  if (apm) {
    return;
  }
  apm = init$2({
    serviceName: serviceName !== null && serviceName !== void 0 ? serviceName : 'frontend',
    active: active,
    // && "production" != 'development' && isValidDomain(),
    serverUrl: serviceUrl !== null && serviceUrl !== void 0 ? serviceUrl : 'https://telemetry.diva-portal.com/apm/',
    environment: environment ,
    breakdownMetrics: true,
    distributedTracingOrigins: [/https?:\/\/.*\.diva-portal.(com|de).*/, new RegExp("https?:\\/\\/.*\\.".concat(baseUrl(), ".*"))],
    logLevel: 'error',
    pageLoadTransactionName: 'LoadPage',
    serviceVersion: window.DIVA_VERSION
  });
  DivaUtils.setAPM(apm);
}
function getApmInstance() {
  return apm;
}
function baseUrl() {
  var urlParts = window.location.host.split('.');
  return urlParts[urlParts.length - 2] + '.' + urlParts[urlParts.length - 1];
}

function ownKeys$h(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$h(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$h(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$h(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var _existingLogger = new Map();
var _apmInitialized = false;
var _onErrorEvent = function _onErrorEvent() {};
var ApplicationLogger = /*#__PURE__*/function () {
  function ApplicationLogger(module, component) {
    var apiInitialized = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    _classCallCheck(this, ApplicationLogger);
    this.module = module;
    this.component = component;
    this.apiInitialized = apiInitialized;
    _defineProperty(this, "transactions", new Map());
  }
  /**
   * Start a new transaction and return the transaction id
   * @param event  The event type
   * @param message  The message to log
   * @param labels  Additional labels
   * @param eventId  An optional event ID, if not provided a new one will be generated
   * @param warningTime  An optional warning time, if the transaction takes longer than this time a warning will be logged
   * @param errorTime  An optional error time, if the transaction takes longer than this time an error will be logged
   * @returns The transaction ID
   */
  return _createClass(ApplicationLogger, [{
    key: "startTransaction",
    value: function startTransaction(_ref) {
      var _this = this;
      var event = _ref.event,
        message = _ref.message,
        _ref$labels = _ref.labels,
        labels = _ref$labels === void 0 ? {} : _ref$labels,
        eventId = _ref.eventId,
        warningTime = _ref.warningTime,
        errorTime = _ref.errorTime;
      var start = performance.now();
      var span = DivaUtils.startSpanOfApmAndReturn(event);
      var id = eventId !== null && eventId !== void 0 ? eventId : nanoid();
      var warningTimeout;
      var errorTimeout;
      if (warningTime) {
        warningTimeout = setTimeout(function () {
          _this.timeoutTransation(id, 'warning');
        }, warningTime);
      }
      if (errorTime) {
        errorTimeout = setTimeout(function () {
          _this.timeoutTransation(id, 'error');
        }, errorTime);
      }
      this.transactions.set(id, {
        start: start,
        event: {
          type: event,
          message: message,
          labels: this.cleanLabels(labels),
          span: span,
          warningTimeout: warningTimeout,
          errorTimeout: errorTimeout
        }
      });
      return id;
    }

    /**
     * End a transaction and log the duration
     * @param eventId The transaction ID
     * @param labels  Additional labels
     */
  }, {
    key: "successTransaction",
    value: function successTransaction(eventId) {
      var labels = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var end = performance.now();
      var event = this.transactions.get(eventId);
      if (!event) {
        this.warn("Transaction ".concat(eventId, " not found"));
        return;
      }
      this.transactions["delete"](eventId);
      event.end = end;
      var cleanLabels = this.cleanLabels(labels);
      event.event.labels = _objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels);
      if (event.event.span) {
        event.event.span.addLabels(_objectSpread$h(_objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels), {}, {
          eventId: eventId
        }));
        event.event.span.end();
      }
      clearTimeout(event.event.warningTimeout);
      clearTimeout(event.event.errorTimeout);
      this.debug("Transaction ".concat(event.event.type, " (").concat(event.event.message, ") took ").concat(Math.floor(end - event.start), "ms"));
      DivaUtils.businessMetrics.logEvent(event.event.type, this.module, event.event.message, _objectSpread$h(_objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels), {}, {
        eventId: eventId,
        status: event.event.timeout ? 'TIMEOUT' : 'SUCCESS',
        eventDuration: Math.floor(end - event.start),
        timoutStatus: event.event.timeout
      }));
    }

    /** End a transaction and log the duration and an error message
     * @param eventId The transaction ID
     * @param code The error code
     * @param message The error message
     * @param labels  Additional labels
     * */
  }, {
    key: "errorTransaction",
    value: function errorTransaction(eventId, code, message) {
      var labels = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
      var dontLog = arguments.length > 4 ? arguments[4] : undefined;
      var end = performance.now();
      var event = this.transactions.get(eventId);
      this.transactions["delete"](eventId);
      if (!dontLog) {
        this.error(new DivaError(message, {
          code: code
        }));
      } else {
        this.debug(message, code);
      }
      if (!event) {
        this.warn("Transaction ".concat(eventId, " not found"));
        return;
      }
      event.end = end;
      var cleanLabels = this.cleanLabels(labels);
      event.event.labels = _objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels);
      if (event.event.span) {
        event.event.span.addLabels(_objectSpread$h(_objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels), {}, {
          eventId: eventId
        }));
        event.event.span.end();
      }
      clearTimeout(event.event.warningTimeout);
      clearTimeout(event.event.errorTimeout);
      this.debug("Transaction ".concat(event.event.type, " (").concat(event.event.message, ") failed after ").concat(Math.floor(end - event.start), "ms"));
      DivaUtils.businessMetrics.logEvent(event.event.type, this.module, event.event.message, _objectSpread$h(_objectSpread$h(_objectSpread$h({}, event.event.labels), cleanLabels), {}, {
        error: code,
        errorMessage: message,
        eventId: eventId,
        status: 'ERROR',
        eventDuration: Math.floor(end - event.start),
        timoutStatus: event.event.timeout
      }));
    }
    /**
     * Log normal business event, without transaction
     * @param eventAction
     * @param module
     * @param message
     * @param labels
     */
  }, {
    key: "businessEvent",
    value: function businessEvent(eventAction, module, message, labels) {
      DivaUtils.businessMetrics.logEvent(eventAction, module !== null && module !== void 0 ? module : this.module, message, labels);
    }
  }, {
    key: "timeoutTransation",
    value: function timeoutTransation(eventId, type) {
      var event = this.transactions.get(eventId);
      if (!event) {
        this.warn("Transaction ".concat(eventId, " not found"));
        return;
      }
      event.event.timeout = type;
      this.warn("Transaction ".concat(event.event.type, " (").concat(event.event.message, ") takes long and exeeded the ").concat(type, " threshold"));
    }

    /**
     * Close all open transactions and log them as errors
     */
  }, {
    key: "flush",
    value: function flush() {
      var _this2 = this;
      this.transactions.forEach(function (event, key) {
        _this2.errorTransaction(key, 'CORE_010', "Transaction ".concat(event.event.type, " (").concat(event.event.message, ") was forcefully closed, e.g. because of a page reload"), undefined, true);
      });
    }

    /**
     * After apm is initialized, send all transactions that were created before
     */
  }, {
    key: "apmInitalized",
    value: function apmInitalized() {
      if (!this.apiInitialized) {
        this.apiInitialized = true;
        this.transactions.forEach(function (transaction) {
          if (!transaction.event.span) {
            transaction.event.span = DivaUtils.startSpanOfApmAndReturn(transaction.event.type, transaction.start);
          }
        });
      }
    }
  }, {
    key: "debug",
    value: function debug(message) {
      var _console;
      if (!this.isValidLogLevel(0)) return;
      for (var _len = arguments.length, optionalParams = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        optionalParams[_key - 1] = arguments[_key];
      }
      (_console = console).debug.apply(_console, ["".concat(this.getPrefix('DEBUG')).concat(this.getApmTransationIdFormatted()).concat(message)].concat(optionalParams));
    }
  }, {
    key: "log",
    value: function log(message) {
      var _console2;
      if (!this.isValidLogLevel(1)) return;
      for (var _len2 = arguments.length, optionalParams = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        optionalParams[_key2 - 1] = arguments[_key2];
      }
      (_console2 = console).log.apply(_console2, ["".concat(this.getPrefix('INFO')).concat(this.getApmTransationIdFormatted()).concat(message)].concat(optionalParams));
    }
  }, {
    key: "warn",
    value: function warn(message) {
      var _console3;
      if (!this.isValidLogLevel(2)) return;
      for (var _len3 = arguments.length, optionalParams = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
        optionalParams[_key3 - 1] = arguments[_key3];
      }
      (_console3 = console).warn.apply(_console3, ["".concat(this.getPrefix('WARN')).concat(this.getApmTransationIdFormatted()).concat(message)].concat(optionalParams));
    }
  }, {
    key: "error",
    value: function error(_error) {
      var _error$custom, _getApmInstance;
      if (!this.isValidLogLevel(3)) return;
      console.error("".concat(this.getPrefix('ERROR', _error.name)).concat(this.getApmTransationIdFormatted()), _error, (_error$custom = _error.custom) !== null && _error$custom !== void 0 ? _error$custom : ' ');
      _onErrorEvent(_error.message, _error.name);

      //for apm we spread the custom object directly on the error object, so that the are added to APM as custom attributes
      var forApm = _objectSpread$h(_objectSpread$h({}, _error), _error.custom);
      (_getApmInstance = getApmInstance()) === null || _getApmInstance === void 0 || _getApmInstance.captureError(forApm);
    }
  }, {
    key: "isValidLogLevel",
    value: function isValidLogLevel(loglevel) {
      var _this3 = this;
      return window.DIVA_LOGGER <= loglevel || window.DIVA_LOGGER_MODULES.some(function (x) {
        return x.module === _this3.module && x.loglevel <= loglevel;
      });
    }
  }, {
    key: "getPrefix",
    value: function getPrefix(level, code) {
      return "[DIVA] [".concat(this.module, " (").concat(this.component, ")] [").concat(level, "]").concat(code ? "(".concat(code, ")") : '', " [").concat(DivaUtils.formatDate(new Date(), true, undefined, true), "] ");
    }
  }, {
    key: "getApmTransationIdFormatted",
    value: function getApmTransationIdFormatted() {
      var apmTransactionId = DivaUtils.getCurrentTraceId();
      return "".concat(apmTransactionId ? '[APM:' + apmTransactionId + '] ' : '');
    }
  }, {
    key: "cleanLabels",
    value: function cleanLabels(labels) {
      return Object.keys(labels).reduce(function (acc, key) {
        if (labels[key]) {
          acc[key] = labels[key];
        }
        return acc;
      }, {});
    }
  }]);
}();
function setOnErrorEvent(onEvent) {
  _onErrorEvent = onEvent;
}
function getLogger(module, component) {
  var key = "".concat(module, "-").concat(component);
  if (_existingLogger.has(key)) {
    return _existingLogger.get(key);
  }
  var logger = new ApplicationLogger(module, component, _apmInitialized);
  _existingLogger.set(key, logger);
  return logger;
}
DivaUtils.setLogger(getLogger);
function flashLoggers() {
  _existingLogger.forEach(function (logger) {
    return logger.flush();
  });
}
function apmIsInitalized() {
  _apmInitialized = true;
  _existingLogger.forEach(function (logger) {
    return logger.apmInitalized();
  });
}

if (typeof __webpack_public_path__ !== 'undefined') {
  var _document;
  //if __webpack_public_path__ is defiend, we are within a umd build, otherwise this workarround is not needed
  if (!__webpack_public_path__.startsWith('http') && (_document = document) !== null && _document !== void 0 && (_document = _document.currentScript) !== null && _document !== void 0 && _document.src.includes('.umd.')) {
    //if public_path is a relativ url script tag is present, load the chunks from same location as the main script
    //this is only present for backwards compatibility and can be removed if we are sure it is not needed any more
    var url = new URL(document.currentScript.src);
    var urlBase = url.href.slice(0, url.href.lastIndexOf('/') + 1);
    __webpack_public_path__ = urlBase;
    //if global var diva_source_location is set, load the chunks from that location
  } else if (window.diva_source_location) {
    __webpack_public_path__ = window.diva_source_location;
  }
}

function ownKeys$g(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$g(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$g(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$g(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _callSuper$2(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct$2() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _isNativeReflectConstruct$2() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct$2 = function _isNativeReflectConstruct() { return !!t; })(); }
var LOG$e = getLogger('Framework', 'webcomponent');
var DivaFramework = /*#__PURE__*/function (_HTMLElement) {
  function DivaFramework() {
    var _this;
    _classCallCheck(this, DivaFramework);
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _callSuper$2(this, DivaFramework, [].concat(args));
    _defineProperty(_this, "mountPoint", void 0);
    _defineProperty(_this, "ref", void 0);
    return _this;
  }
  _inherits(DivaFramework, _HTMLElement);
  return _createClass(DivaFramework, [{
    key: "organizationId",
    get: function get() {
      return this.getAttribute('organizationId') || '';
    },
    set: function set(val) {
      if (val) {
        this.setAttribute('organizationId', val);
      } else {
        this.removeAttribute('organizationId');
      }
    }
  }, {
    key: "identifier",
    get: function get() {
      return this.getAttribute('identifier') || 'COMPONENT';
    },
    set: function set(val) {
      if (val) {
        this.setAttribute('identifier', val);
      } else {
        this.removeAttribute('identifier');
      }
    }
  }, {
    key: "defaultApiConfig",
    get: function get() {
      var compAttr = this.getAttribute('defaultApiConfig') || undefined;
      if (compAttr) {
        return JSON.parse(compAttr);
      }
      return undefined;
    }

    /**
     * @deprecated
     */,
    set: function set(val) {
      if (val) {
        this.setAttribute('defaultApiConfig', JSON.stringify(val));
      } else this.removeAttribute('defaultApiConfig');
    }
  }, {
    key: "configUrl",
    get:
    /**
     * @deprecated
     */
    function get() {
      return this.getAttribute('configUrl') || undefined;
    },
    set: function set(val) {
      if (val) {
        this.setAttribute('configUrl', val);
      } else this.removeAttribute('configUrl');
    }
  }, {
    key: "language",
    get: function get() {
      return this.getAttribute('language') || undefined;
    },
    set: function set(val) {
      var _this$ref;
      if (val) {
        this.setAttribute('language', val);
      } else {
        this.removeAttribute('language');
      }
      if ((_this$ref = this.ref) !== null && _this$ref !== void 0 && _this$ref.current) {
        this.render();
      }
    }
  }, {
    key: "spinnerClass",
    get: function get() {
      return this.getAttribute('spinnerClass') || undefined;
    },
    set: function set(val) {
      if (val) {
        var _this$ref2;
        this.setAttribute('spinnerClass', val);
        if ((_this$ref2 = this.ref) !== null && _this$ref2 !== void 0 && _this$ref2.current) {
          this.render();
        }
      } else {
        this.removeAttribute('spinnerClass');
      }
    }
  }, {
    key: "telemetry",
    get: function get() {
      return this.getAttribute('telemetry') == null ? undefined : this.getAttribute('telemetry') == 'true';
    },
    set: function set(val) {
      if (val !== undefined) {
        var _this$ref3;
        this.setAttribute('telemetry', val == true || val == 'true' ? 'true' : 'false');
        if ((_this$ref3 = this.ref) !== null && _this$ref3 !== void 0 && _this$ref3.current) {
          this.render();
        }
      } else {
        this.removeAttribute('telemetry');
      }
    }
  }, {
    key: "currentComponent",
    get: function get() {
      var compAttr = this.getAttribute('currentComponent');
      if (compAttr) {
        return JSON.parse(compAttr);
      }
      return undefined;
    },
    set: function set(val) {
      if (val) {
        this.setAttribute('currentComponent', JSON.stringify(val));
      } else {
        this.removeAttribute('currentComponent');
      }
    }
  }, {
    key: "invokeEvent",
    value: function invokeEvent(event, params) {
      var _this$ref4;
      if ((_this$ref4 = this.ref) !== null && _this$ref4 !== void 0 && _this$ref4.current) {
        this.ref.current.invoke({
          type: event,
          data: params
        });
      }
    }
  }, {
    key: "attributeChangedCallback",
    value: function attributeChangedCallback(attrName, oldValue, newValue) {
      if (newValue !== oldValue) {
        var attr = this.getAttribute(attrName);
        if (attrName === 'currentComponent') {
          this[attrName] = attr ? JSON.parse(attr) : undefined;
        } else {
          this[attrName] = attr || undefined;
        }
      }
    }
  }, {
    key: "connectedCallback",
    value: function connectedCallback() {
      this.mountPoint = document.createElement('span');
      this.ref = /*#__PURE__*/React.createRef();
      this.appendChild(this.mountPoint);
      this.render();
    }
  }, {
    key: "onEvent",
    value: function onEvent(event) {
      this.dispatchEvent(new CustomEvent(event.type, {
        detail: event.data
      }));
    }
  }, {
    key: "render",
    value: function render() {
      if (this.mountPoint) {
        var framework = /*#__PURE__*/React.createElement(CoreWrapper, {
          currentComponent: this.currentComponent,
          configUrl: this.configUrl,
          defaultApiConfig: this.defaultApiConfig,
          spinnerClass: this.spinnerClass,
          language: this.language,
          organizationId: this.organizationId,
          identifier: this.identifier,
          telemetry: this.telemetry,
          onEvent: this.onEvent.bind(this),
          ref: this.ref
        });
        ReactDOM.render(framework, this.mountPoint);
      }
    }
  }], [{
    key: "observedAttributes",
    get: function get() {
      return ['currentComponent', 'language'];
    }
  }]);
}(/*#__PURE__*/_wrapNativeSuper(HTMLElement));
var CoreWrapper = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useState = useState(),
    _useState2 = _slicedToArray(_useState, 2),
    components = _useState2[0],
    setComponents = _useState2[1];
  useEffect(function () {
    //get all crystaldesign component that are mounted, add only if it is of the expected type
    var available = [];
    Object.keys(window).filter(function (key) {
      return key.startsWith('Crystaldesign');
    }).forEach(function (key) {
      var _key2;
      LOG$e.debug('Loading UMD Component', key, window[key]);
      var value = (_key2 = window[key]) === null || _key2 === void 0 ? void 0 : _key2["default"];
      if (value !== null && value !== void 0 && value.name) {
        available.push(value);
      }
    });
    setComponents(available);
  }, []);
  if (!components) {
    return /*#__PURE__*/jsx(Fragment, {});
  }
  return /*#__PURE__*/jsx(DivaCore, _objectSpread$g(_objectSpread$g({}, props), {}, {
    components: components,
    ref: ref
  }));
});

//we have to externalize the materialUI styling here, so that also in UMD the same instance is used
window.MaterialUIStyles = _objectSpread$g(_objectSpread$g({}, Styles), CoreStyles);
if (!window.customElements.get('diva-framework')) {
  window.customElements.define('diva-framework', DivaFramework);
}

function getUrl (serviceFallback, serviceConfig, serviceDefault, baseUrl) {
  if (serviceConfig) {
    return parseUrl(serviceConfig, baseUrl);
  }
  if (serviceDefault) {
    return parseUrl(serviceDefault, baseUrl);
  }
  return parseUrl(serviceFallback, baseUrl);
}
function parseUrl(service, baseUrl) {
  var url;
  if (service.startsWith('http')) {
    url = service;
  } else if (baseUrl) {
    url = "".concat(baseUrl, "/").concat(service);
  } else {
    throw new Error('No baseUrl specified');
  }
  if (url.endsWith('/')) {
    return url.slice(0, -1);
  } else {
    return url;
  }
}

function parseApiConfig (config, defaultApiConfig, organization) {
  var _ref, _config$baseUrl, _DIVA_GLOBAL_ENV, _window, _GLOBAL_ENV$analytics, _GLOBAL_ENV$authServi, _GLOBAL_ENV$adminServ, _GLOBAL_ENV$messageSe, _GLOBAL_ENV$catalogSe, _GLOBAL_ENV$supportSe, _GLOBAL_ENV$basketSer, _GLOBAL_ENV$mediaServ, _GLOBAL_ENV$construct, _GLOBAL_ENV$reportSer, _GLOBAL_ENV$clientArt, _GLOBAL_ENV$idmServic, _GLOBAL_ENV$enricherS, _config$useDebugUrl, _ref2, _organization$api2Loc, _organization$api2Loc2, _ref3, _ref4, _organization$api2Loc3, _organization$api2Loc4, _organization$api2Loc5, _ref5, _ref6, _organization$api2Loc6, _organization$api2Loc7, _organization$api2Loc8;
  var baseUrl = (_ref = (_config$baseUrl = config === null || config === void 0 ? void 0 : config.baseUrl) !== null && _config$baseUrl !== void 0 ? _config$baseUrl : defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.baseUrl) !== null && _ref !== void 0 ? _ref : 'https://api.diva-portal.com';
  var GLOBAL_ENV = (_DIVA_GLOBAL_ENV = (_window = window) === null || _window === void 0 ? void 0 : _window.DIVA_GLOBAL_ENV) !== null && _DIVA_GLOBAL_ENV !== void 0 ? _DIVA_GLOBAL_ENV : {};
  var c = {
    analyticsService: (_GLOBAL_ENV$analytics = GLOBAL_ENV.analyticsService) !== null && _GLOBAL_ENV$analytics !== void 0 ? _GLOBAL_ENV$analytics : getUrl('analytics', config === null || config === void 0 ? void 0 : config.analyticsService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.analyticsService, baseUrl),
    authService: (_GLOBAL_ENV$authServi = GLOBAL_ENV.authService) !== null && _GLOBAL_ENV$authServi !== void 0 ? _GLOBAL_ENV$authServi : getUrl('auth', config === null || config === void 0 ? void 0 : config.authService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.authService, baseUrl),
    adminService: (_GLOBAL_ENV$adminServ = GLOBAL_ENV.adminService) !== null && _GLOBAL_ENV$adminServ !== void 0 ? _GLOBAL_ENV$adminServ : getUrl('admin', config === null || config === void 0 ? void 0 : config.adminService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.adminService, baseUrl),
    messageService: (_GLOBAL_ENV$messageSe = GLOBAL_ENV.messageService) !== null && _GLOBAL_ENV$messageSe !== void 0 ? _GLOBAL_ENV$messageSe : getUrl('messages', config === null || config === void 0 ? void 0 : config.messageService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.messageService, baseUrl),
    catalogService: (_GLOBAL_ENV$catalogSe = GLOBAL_ENV.catalogService) !== null && _GLOBAL_ENV$catalogSe !== void 0 ? _GLOBAL_ENV$catalogSe : getUrl('catalog', config === null || config === void 0 ? void 0 : config.catalogService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.catalogService, baseUrl),
    supportService: (_GLOBAL_ENV$supportSe = GLOBAL_ENV.supportService) !== null && _GLOBAL_ENV$supportSe !== void 0 ? _GLOBAL_ENV$supportSe : getUrl('support', config === null || config === void 0 ? void 0 : config.supportService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.supportService, baseUrl),
    basketService: (_GLOBAL_ENV$basketSer = GLOBAL_ENV.basketService) !== null && _GLOBAL_ENV$basketSer !== void 0 ? _GLOBAL_ENV$basketSer : getUrl('basket', config === null || config === void 0 ? void 0 : config.basketService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.basketService, baseUrl),
    mediaService: (_GLOBAL_ENV$mediaServ = GLOBAL_ENV.mediaService) !== null && _GLOBAL_ENV$mediaServ !== void 0 ? _GLOBAL_ENV$mediaServ : getUrl('media', config === null || config === void 0 ? void 0 : config.mediaService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.mediaService, baseUrl),
    constructorService: (_GLOBAL_ENV$construct = GLOBAL_ENV.constructorService) !== null && _GLOBAL_ENV$construct !== void 0 ? _GLOBAL_ENV$construct : getUrl('constructor', config === null || config === void 0 ? void 0 : config.constructorService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.constructorService, baseUrl),
    reportService: (_GLOBAL_ENV$reportSer = GLOBAL_ENV.reportService) !== null && _GLOBAL_ENV$reportSer !== void 0 ? _GLOBAL_ENV$reportSer : getUrl('report', config === null || config === void 0 ? void 0 : config.reportService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.reportService, baseUrl),
    clientArticleService: (_GLOBAL_ENV$clientArt = GLOBAL_ENV.clientArticleService) !== null && _GLOBAL_ENV$clientArt !== void 0 ? _GLOBAL_ENV$clientArt : getUrl('pfister-article', config === null || config === void 0 ? void 0 : config.clientArticleService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.clientArticleService, baseUrl),
    idmService: (_GLOBAL_ENV$idmServic = GLOBAL_ENV.idmService) !== null && _GLOBAL_ENV$idmServic !== void 0 ? _GLOBAL_ENV$idmServic : getUrl('idm', config === null || config === void 0 ? void 0 : config.idmService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.idmService, baseUrl),
    enricherService: (_GLOBAL_ENV$enricherS = GLOBAL_ENV.enricherService) !== null && _GLOBAL_ENV$enricherS !== void 0 ? _GLOBAL_ENV$enricherS : getUrl('enricher', config === null || config === void 0 ? void 0 : config.enricherService, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.enricherService, baseUrl),
    baseUrl: baseUrl,
    baseSirvUrls: config === null || config === void 0 ? void 0 : config.baseSirvUrls,
    baseCdnUrl: getUrl('https://cdn.diva-portal.com', config === null || config === void 0 ? void 0 : config.baseCdnUrl, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.baseCdnUrl),
    host3d: getUrl('https://diva3dhost.diva-portal.com/diva3d/diva3dhost2', config === null || config === void 0 ? void 0 : config.host3d, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.host3d),
    diva3darchive: getUrl('https://diva3dhost.diva-portal.com/diva3d/diva3darchive', config === null || config === void 0 ? void 0 : config.diva3darchive, defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.diva3darchive),
    useDebugUrl: (_config$useDebugUrl = config === null || config === void 0 ? void 0 : config.useDebugUrl) !== null && _config$useDebugUrl !== void 0 ? _config$useDebugUrl : false,
    arViewerBaseUrl: config === null || config === void 0 ? void 0 : config.arViewerBaseUrl,
    api2: {
      "default": getUrl('https://retail.diva-portal.de/api2_retail/api.aspx', (_ref2 = (_organization$api2Loc = organization === null || organization === void 0 || (_organization$api2Loc2 = organization.api2Location) === null || _organization$api2Loc2 === void 0 || (_organization$api2Loc2 = _organization$api2Loc2.vk) === null || _organization$api2Loc2 === void 0 ? void 0 : _organization$api2Loc2.url) !== null && _organization$api2Loc !== void 0 ? _organization$api2Loc : config === null || config === void 0 ? void 0 : config.api2) !== null && _ref2 !== void 0 ? _ref2 : organization === null || organization === void 0 ? void 0 : organization.originEnvironmentUrl, //deprecated
      defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.api2),
      ek: getUrl('https://retail.diva-portal.de/api2_retail/api.aspx', (_ref3 = (_ref4 = (_organization$api2Loc3 = organization === null || organization === void 0 || (_organization$api2Loc4 = organization.api2Location) === null || _organization$api2Loc4 === void 0 || (_organization$api2Loc4 = _organization$api2Loc4.ek) === null || _organization$api2Loc4 === void 0 ? void 0 : _organization$api2Loc4.url) !== null && _organization$api2Loc3 !== void 0 ? _organization$api2Loc3 : organization === null || organization === void 0 || (_organization$api2Loc5 = organization.api2Location) === null || _organization$api2Loc5 === void 0 || (_organization$api2Loc5 = _organization$api2Loc5.vk) === null || _organization$api2Loc5 === void 0 ? void 0 : _organization$api2Loc5.url) !== null && _ref4 !== void 0 ? _ref4 : config === null || config === void 0 ? void 0 : config.api2) !== null && _ref3 !== void 0 ? _ref3 : organization === null || organization === void 0 ? void 0 : organization.originEnvironmentUrl, //deprecated
      defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.api2),
      web: getUrl('https://retail.diva-portal.de/api2_retail/api.aspx', (_ref5 = (_ref6 = (_organization$api2Loc6 = organization === null || organization === void 0 || (_organization$api2Loc7 = organization.api2Location) === null || _organization$api2Loc7 === void 0 || (_organization$api2Loc7 = _organization$api2Loc7.web) === null || _organization$api2Loc7 === void 0 ? void 0 : _organization$api2Loc7.url) !== null && _organization$api2Loc6 !== void 0 ? _organization$api2Loc6 : organization === null || organization === void 0 || (_organization$api2Loc8 = organization.api2Location) === null || _organization$api2Loc8 === void 0 || (_organization$api2Loc8 = _organization$api2Loc8.vk) === null || _organization$api2Loc8 === void 0 ? void 0 : _organization$api2Loc8.url) !== null && _ref6 !== void 0 ? _ref6 : config === null || config === void 0 ? void 0 : config.api2) !== null && _ref5 !== void 0 ? _ref5 : organization === null || organization === void 0 ? void 0 : organization.originEnvironmentUrl, //deprecated
      defaultApiConfig === null || defaultApiConfig === void 0 ? void 0 : defaultApiConfig.api2)
    }
  };
  return c;
}

var defaultTheme = {
  palette: {
    primary: {
      main: '#713434',
      light: '#e4b9b8',
      dark: '#42090e',
      contrastText: '#fff'
    },
    secondary: {
      main: '#474747',
      light: '#c3c3c3',
      dark: '#252525',
      contrastText: '#fff'
    },
    text: {
      primary: 'rgba(0, 0, 0, 0.87)',
      secondary: 'rgba(0, 0, 0, 0.54)'
    }
  },
  typography: {
    fontFamily: 'Roboto'
  },
  components: {
    MuiTextField: {
      defaultProps: {
        variant: 'standard' // Set default variant to 'standard'
      }
    },
    MuiSelect: {
      defaultProps: {
        variant: 'standard' // Set default variant to 'standard'
      }
    }
  }
};

function ownKeys$f(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$f(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$f(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$f(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$d = getLogger('Framework', 'ConfigurationStore');
var ConfigurationStore = /*#__PURE__*/function () {
  function ConfigurationStore(root, identifier, defaultApiConfig, domain) {
    _classCallCheck(this, ConfigurationStore);
    this.root = root;
    this.identifier = identifier;
    this.defaultApiConfig = defaultApiConfig;
    this.domain = domain;
    _defineProperty(this, "_configuration", undefined);
    _defineProperty(this, "configurationCache", new Map());
    _defineProperty(this, "contentBoxConfiguration", undefined);
    makeAutoObservable(this, {
      fetchConfiguration: false,
      configurationCache: false,
      updateConfiguration: flow
    });
  }
  return _createClass(ConfigurationStore, [{
    key: "configuration",
    get: function get() {
      return this._configuration;
    },
    set: function set(config) {
      //TODO validate configuration and fail gracefully
      this._configuration = config;
    }
  }, {
    key: "organizations",
    get: function get() {
      var _this$_configuration;
      return ((_this$_configuration = this._configuration) === null || _this$_configuration === void 0 ? void 0 : _this$_configuration.organizations) || [];
    }
  }, {
    key: "validOrganizations",
    get: function get() {
      var _this$_configuration2;
      var orgs = (_this$_configuration2 = this._configuration) === null || _this$_configuration2 === void 0 ? void 0 : _this$_configuration2.organizations;
      if (orgs && orgs.includes('*')) {
        return undefined;
      } else {
        return orgs || [];
      }
    }
  }, {
    key: "excludedOrganizations",
    get: function get() {
      var _this$_configuration3;
      return (_this$_configuration3 = this._configuration) === null || _this$_configuration3 === void 0 ? void 0 : _this$_configuration3.excludeOrganizations;
    }
  }, {
    key: "components",
    get: function get() {
      var _this$_configuration4;
      return ((_this$_configuration4 = this._configuration) === null || _this$_configuration4 === void 0 || (_this$_configuration4 = _this$_configuration4.components) === null || _this$_configuration4 === void 0 ? void 0 : _this$_configuration4.available) || [];
    }
  }, {
    key: "defaultComponent",
    get: function get() {
      var _this$_configuration5, _this$_configuration6;
      var dataStore = this.root.dataStore;
      if (dataStore && (_this$_configuration5 = this._configuration) !== null && _this$_configuration5 !== void 0 && _this$_configuration5.components.openSellerDefaultForRetailer) {
        if (dataStore.userHasPermission('retail') && !dataStore.userHasPermission('acquisition') && !dataStore.userHasPermission('category_manager')) {
          return {
            type: 'SELLER'
          };
        }
      }
      return (_this$_configuration6 = this._configuration) === null || _this$_configuration6 === void 0 ? void 0 : _this$_configuration6.components["default"];
    }
  }, {
    key: "locales",
    get: function get() {
      var _this$_configuration7;
      return (_this$_configuration7 = this._configuration) === null || _this$_configuration7 === void 0 ? void 0 : _this$_configuration7.locales;
    }
  }, {
    key: "spinner",
    get: function get() {
      var _this$_configuration8;
      return (_this$_configuration8 = this._configuration) === null || _this$_configuration8 === void 0 ? void 0 : _this$_configuration8.spinner;
    }
  }, {
    key: "theme",
    get: function get() {
      var _this$_configuration9, _theme$palette$primar, _theme$palette, _theme$palette$primar2, _theme$palette2, _theme$palette$primar3, _theme$palette3, _theme$palette$primar4, _theme$palette4, _ref, _theme$palette$second, _theme$palette5, _theme$palette6, _ref2, _theme$palette$second2, _theme$palette7, _theme$palette8, _ref3, _theme$palette$second3, _theme$palette9, _theme$palette10, _ref4, _theme$palette$second4, _theme$palette11, _theme$palette12, _theme$palette$text$p, _theme$palette13, _theme$palette$text$s, _theme$palette14, _theme$typography$fon, _theme$typography, _theme$components;
      var theme = (_this$_configuration9 = this._configuration) === null || _this$_configuration9 === void 0 ? void 0 : _this$_configuration9.theme;
      return {
        palette: {
          primary: {
            main: (_theme$palette$primar = theme === null || theme === void 0 || (_theme$palette = theme.palette) === null || _theme$palette === void 0 || (_theme$palette = _theme$palette.primary) === null || _theme$palette === void 0 ? void 0 : _theme$palette.main) !== null && _theme$palette$primar !== void 0 ? _theme$palette$primar : defaultTheme.palette.primary.main,
            light: (_theme$palette$primar2 = theme === null || theme === void 0 || (_theme$palette2 = theme.palette) === null || _theme$palette2 === void 0 || (_theme$palette2 = _theme$palette2.primary) === null || _theme$palette2 === void 0 ? void 0 : _theme$palette2.light) !== null && _theme$palette$primar2 !== void 0 ? _theme$palette$primar2 : defaultTheme.palette.primary.light,
            dark: (_theme$palette$primar3 = theme === null || theme === void 0 || (_theme$palette3 = theme.palette) === null || _theme$palette3 === void 0 || (_theme$palette3 = _theme$palette3.primary) === null || _theme$palette3 === void 0 ? void 0 : _theme$palette3.dark) !== null && _theme$palette$primar3 !== void 0 ? _theme$palette$primar3 : defaultTheme.palette.primary.dark,
            contrastText: (_theme$palette$primar4 = theme === null || theme === void 0 || (_theme$palette4 = theme.palette) === null || _theme$palette4 === void 0 || (_theme$palette4 = _theme$palette4.primary) === null || _theme$palette4 === void 0 ? void 0 : _theme$palette4.contrastText) !== null && _theme$palette$primar4 !== void 0 ? _theme$palette$primar4 : defaultTheme.palette.primary.contrastText
          },
          secondary: {
            main: (_ref = (_theme$palette$second = theme === null || theme === void 0 || (_theme$palette5 = theme.palette) === null || _theme$palette5 === void 0 || (_theme$palette5 = _theme$palette5.secondary) === null || _theme$palette5 === void 0 ? void 0 : _theme$palette5.main) !== null && _theme$palette$second !== void 0 ? _theme$palette$second : theme === null || theme === void 0 || (_theme$palette6 = theme.palette) === null || _theme$palette6 === void 0 || (_theme$palette6 = _theme$palette6.primary) === null || _theme$palette6 === void 0 ? void 0 : _theme$palette6.main) !== null && _ref !== void 0 ? _ref : defaultTheme.palette.secondary.main,
            light: (_ref2 = (_theme$palette$second2 = theme === null || theme === void 0 || (_theme$palette7 = theme.palette) === null || _theme$palette7 === void 0 || (_theme$palette7 = _theme$palette7.secondary) === null || _theme$palette7 === void 0 ? void 0 : _theme$palette7.light) !== null && _theme$palette$second2 !== void 0 ? _theme$palette$second2 : theme === null || theme === void 0 || (_theme$palette8 = theme.palette) === null || _theme$palette8 === void 0 || (_theme$palette8 = _theme$palette8.primary) === null || _theme$palette8 === void 0 ? void 0 : _theme$palette8.light) !== null && _ref2 !== void 0 ? _ref2 : defaultTheme.palette.secondary.light,
            dark: (_ref3 = (_theme$palette$second3 = theme === null || theme === void 0 || (_theme$palette9 = theme.palette) === null || _theme$palette9 === void 0 || (_theme$palette9 = _theme$palette9.secondary) === null || _theme$palette9 === void 0 ? void 0 : _theme$palette9.dark) !== null && _theme$palette$second3 !== void 0 ? _theme$palette$second3 : theme === null || theme === void 0 || (_theme$palette10 = theme.palette) === null || _theme$palette10 === void 0 || (_theme$palette10 = _theme$palette10.primary) === null || _theme$palette10 === void 0 ? void 0 : _theme$palette10.dark) !== null && _ref3 !== void 0 ? _ref3 : defaultTheme.palette.secondary.dark,
            contrastText: (_ref4 = (_theme$palette$second4 = theme === null || theme === void 0 || (_theme$palette11 = theme.palette) === null || _theme$palette11 === void 0 || (_theme$palette11 = _theme$palette11.secondary) === null || _theme$palette11 === void 0 ? void 0 : _theme$palette11.contrastText) !== null && _theme$palette$second4 !== void 0 ? _theme$palette$second4 : theme === null || theme === void 0 || (_theme$palette12 = theme.palette) === null || _theme$palette12 === void 0 || (_theme$palette12 = _theme$palette12.primary) === null || _theme$palette12 === void 0 ? void 0 : _theme$palette12.contrastText) !== null && _ref4 !== void 0 ? _ref4 : defaultTheme.palette.secondary.contrastText
          },
          text: {
            primary: (_theme$palette$text$p = theme === null || theme === void 0 || (_theme$palette13 = theme.palette) === null || _theme$palette13 === void 0 || (_theme$palette13 = _theme$palette13.text) === null || _theme$palette13 === void 0 ? void 0 : _theme$palette13.primary) !== null && _theme$palette$text$p !== void 0 ? _theme$palette$text$p : defaultTheme.palette.text.primary,
            secondary: (_theme$palette$text$s = theme === null || theme === void 0 || (_theme$palette14 = theme.palette) === null || _theme$palette14 === void 0 || (_theme$palette14 = _theme$palette14.text) === null || _theme$palette14 === void 0 ? void 0 : _theme$palette14.secondary) !== null && _theme$palette$text$s !== void 0 ? _theme$palette$text$s : defaultTheme.palette.text.secondary
          }
        },
        typography: {
          fontFamily: (_theme$typography$fon = theme === null || theme === void 0 || (_theme$typography = theme.typography) === null || _theme$typography === void 0 ? void 0 : _theme$typography.fontFamily) !== null && _theme$typography$fon !== void 0 ? _theme$typography$fon : defaultTheme.typography.fontFamily
        },
        components: (_theme$components = theme === null || theme === void 0 ? void 0 : theme.components) !== null && _theme$components !== void 0 ? _theme$components : defaultTheme.components
      };
    }
  }, {
    key: "navigation",
    get: function get() {
      var _this$_configuration10, _this$_configuration11, _this$_configuration12, _this$_configuration13, _this$_configuration14, _this$_configuration15, _this$_configuration16, _this$_configuration17, _this$_configuration18, _this$_configuration19, _this$_configuration20, _this$_configuration21, _this$_configuration22, _this$_configuration23, _this$_configuration24, _this$_configuration25, _this$_configuration26, _this$_configuration27, _this$root$dataStore$, _this$_configuration28;
      return {
        buttons: ((_this$_configuration10 = this._configuration) === null || _this$_configuration10 === void 0 || (_this$_configuration10 = _this$_configuration10.navigation) === null || _this$_configuration10 === void 0 ? void 0 : _this$_configuration10.buttons) || [],
        imprintUrl: (_this$_configuration11 = this._configuration) === null || _this$_configuration11 === void 0 || (_this$_configuration11 = _this$_configuration11.navigation) === null || _this$_configuration11 === void 0 ? void 0 : _this$_configuration11.imprintUrl,
        privacyUrl: (_this$_configuration12 = this._configuration) === null || _this$_configuration12 === void 0 || (_this$_configuration12 = _this$_configuration12.navigation) === null || _this$_configuration12 === void 0 ? void 0 : _this$_configuration12.privacyUrl,
        tosUrl: (_this$_configuration13 = this._configuration) === null || _this$_configuration13 === void 0 || (_this$_configuration13 = _this$_configuration13.navigation) === null || _this$_configuration13 === void 0 ? void 0 : _this$_configuration13.tosUrl,
        conditionsUrl: (_this$_configuration14 = this._configuration) === null || _this$_configuration14 === void 0 || (_this$_configuration14 = _this$_configuration14.navigation) === null || _this$_configuration14 === void 0 ? void 0 : _this$_configuration14.conditionsUrl,
        supportUrl: (_this$_configuration15 = this._configuration) === null || _this$_configuration15 === void 0 || (_this$_configuration15 = _this$_configuration15.navigation) === null || _this$_configuration15 === void 0 ? void 0 : _this$_configuration15.supportUrl,
        feedbackUrl: (_this$_configuration16 = this._configuration) === null || _this$_configuration16 === void 0 || (_this$_configuration16 = _this$_configuration16.navigation) === null || _this$_configuration16 === void 0 ? void 0 : _this$_configuration16.feedbackUrl,
        logoUrl: (_this$_configuration17 = this._configuration) === null || _this$_configuration17 === void 0 || (_this$_configuration17 = _this$_configuration17.navigation) === null || _this$_configuration17 === void 0 ? void 0 : _this$_configuration17.logoUrl,
        logoAction: (_this$_configuration18 = this._configuration) === null || _this$_configuration18 === void 0 || (_this$_configuration18 = _this$_configuration18.navigation) === null || _this$_configuration18 === void 0 ? void 0 : _this$_configuration18.logoAction,
        enableMobile: (_this$_configuration19 = this._configuration) === null || _this$_configuration19 === void 0 || (_this$_configuration19 = _this$_configuration19.navigation) === null || _this$_configuration19 === void 0 ? void 0 : _this$_configuration19.enableMobile,
        hideHeader: (_this$_configuration20 = this._configuration) === null || _this$_configuration20 === void 0 || (_this$_configuration20 = _this$_configuration20.navigation) === null || _this$_configuration20 === void 0 ? void 0 : _this$_configuration20.hideHeader,
        welcomeText: (_this$_configuration21 = this._configuration) === null || _this$_configuration21 === void 0 || (_this$_configuration21 = _this$_configuration21.navigation) === null || _this$_configuration21 === void 0 ? void 0 : _this$_configuration21.welcomeText,
        showOrgName: (_this$_configuration22 = this._configuration) === null || _this$_configuration22 === void 0 || (_this$_configuration22 = _this$_configuration22.navigation) === null || _this$_configuration22 === void 0 ? void 0 : _this$_configuration22.showOrgName,
        showUserName: (_this$_configuration23 = this._configuration) === null || _this$_configuration23 === void 0 || (_this$_configuration23 = _this$_configuration23.navigation) === null || _this$_configuration23 === void 0 ? void 0 : _this$_configuration23.showUserName,
        showDescription: (_this$_configuration24 = this._configuration) === null || _this$_configuration24 === void 0 || (_this$_configuration24 = _this$_configuration24.navigation) === null || _this$_configuration24 === void 0 ? void 0 : _this$_configuration24.showDescription,
        qrCodeScanner: (_this$_configuration25 = this._configuration) === null || _this$_configuration25 === void 0 || (_this$_configuration25 = _this$_configuration25.navigation) === null || _this$_configuration25 === void 0 ? void 0 : _this$_configuration25.qrCodeScanner,
        greetingsText: (_this$_configuration26 = this._configuration) === null || _this$_configuration26 === void 0 || (_this$_configuration26 = _this$_configuration26.navigation) === null || _this$_configuration26 === void 0 ? void 0 : _this$_configuration26.greetingsText,
        showSnow: (_this$_configuration27 = this._configuration) === null || _this$_configuration27 === void 0 || (_this$_configuration27 = _this$_configuration27.navigation) === null || _this$_configuration27 === void 0 ? void 0 : _this$_configuration27.showSnow,
        pricePreviewActive: ((_this$root$dataStore$ = this.root.dataStore.organization) === null || _this$root$dataStore$ === void 0 || (_this$root$dataStore$ = _this$root$dataStore$.settings) === null || _this$root$dataStore$ === void 0 ? void 0 : _this$root$dataStore$.pricePreview) && this.root.dataStore.organization.settings.pricePreview !== 'off' || ((_this$_configuration28 = this._configuration) === null || _this$_configuration28 === void 0 || (_this$_configuration28 = _this$_configuration28.components.available) === null || _this$_configuration28 === void 0 || (_this$_configuration28 = _this$_configuration28.find(function (c) {
          return c.type === 'DIVA_WEBPLANNER';
        })) === null || _this$_configuration28 === void 0 || (_this$_configuration28 = _this$_configuration28.settings) === null || _this$_configuration28 === void 0 || (_this$_configuration28 = _this$_configuration28.ViewConfig) === null || _this$_configuration28 === void 0 ? void 0 : _this$_configuration28.pricePreview)
      };
    }
  }, {
    key: "googleMapsconfig",
    get: function get() {
      var _this$_configuration29, _this$_configuration30, _this$_configuration31, _this$_configuration32;
      return {
        id: (_this$_configuration29 = this._configuration) === null || _this$_configuration29 === void 0 || (_this$_configuration29 = _this$_configuration29.googleMapsConfig) === null || _this$_configuration29 === void 0 ? void 0 : _this$_configuration29.id,
        googleMapsApiKey: (_this$_configuration30 = this._configuration) === null || _this$_configuration30 === void 0 || (_this$_configuration30 = _this$_configuration30.googleMapsConfig) === null || _this$_configuration30 === void 0 ? void 0 : _this$_configuration30.googleMapsApiKey,
        language: (_this$_configuration31 = this._configuration) === null || _this$_configuration31 === void 0 || (_this$_configuration31 = _this$_configuration31.googleMapsConfig) === null || _this$_configuration31 === void 0 ? void 0 : _this$_configuration31.language,
        region: (_this$_configuration32 = this._configuration) === null || _this$_configuration32 === void 0 || (_this$_configuration32 = _this$_configuration32.googleMapsConfig) === null || _this$_configuration32 === void 0 ? void 0 : _this$_configuration32.region
      };
    }
  }, {
    key: "cometchatConfig",
    get: function get() {
      var _this$_configuration33, _this$_configuration34, _this$_configuration35;
      return {
        app_id: (_this$_configuration33 = this._configuration) === null || _this$_configuration33 === void 0 || (_this$_configuration33 = _this$_configuration33.cometChatConfig) === null || _this$_configuration33 === void 0 ? void 0 : _this$_configuration33.app_id,
        app_region: (_this$_configuration34 = this._configuration) === null || _this$_configuration34 === void 0 || (_this$_configuration34 = _this$_configuration34.cometChatConfig) === null || _this$_configuration34 === void 0 ? void 0 : _this$_configuration34.app_region,
        listener_id: (_this$_configuration35 = this._configuration) === null || _this$_configuration35 === void 0 || (_this$_configuration35 = _this$_configuration35.cometChatConfig) === null || _this$_configuration35 === void 0 ? void 0 : _this$_configuration35.listener_id
      };
    }
  }, {
    key: "hasAuthentication",
    get: function get() {
      var _this$_configuration36;
      return !!((_this$_configuration36 = this._configuration) !== null && _this$_configuration36 !== void 0 && _this$_configuration36.authentication);
    }
  }, {
    key: "authentication",
    get: function get() {
      var _this$_configuration$, _this$_configuration37, _this$_configuration38, _this$_configuration39, _this$_configuration40, _this$_configuration41, _this$_configuration42, _this$_configuration43, _this$_configuration44, _this$_configuration45, _this$_configuration$2, _this$_configuration46;
      return _objectSpread$f(_objectSpread$f({}, (_this$_configuration$ = (_this$_configuration37 = this._configuration) === null || _this$_configuration37 === void 0 ? void 0 : _this$_configuration37.authentication) !== null && _this$_configuration$ !== void 0 ? _this$_configuration$ : {}), {}, {
        loginMethods: {
          google: (_this$_configuration38 = this._configuration) !== null && _this$_configuration38 !== void 0 && (_this$_configuration38 = _this$_configuration38.authentication) !== null && _this$_configuration38 !== void 0 && _this$_configuration38.loginMethods ? (_this$_configuration39 = this._configuration) === null || _this$_configuration39 === void 0 || (_this$_configuration39 = _this$_configuration39.authentication) === null || _this$_configuration39 === void 0 ? void 0 : _this$_configuration39.loginMethods.google : true,
          microsoft: (_this$_configuration40 = this._configuration) !== null && _this$_configuration40 !== void 0 && (_this$_configuration40 = _this$_configuration40.authentication) !== null && _this$_configuration40 !== void 0 && _this$_configuration40.loginMethods ? (_this$_configuration41 = this._configuration) === null || _this$_configuration41 === void 0 || (_this$_configuration41 = _this$_configuration41.authentication) === null || _this$_configuration41 === void 0 ? void 0 : _this$_configuration41.loginMethods.microsoft : true,
          standard: (_this$_configuration42 = this._configuration) !== null && _this$_configuration42 !== void 0 && (_this$_configuration42 = _this$_configuration42.authentication) !== null && _this$_configuration42 !== void 0 && _this$_configuration42.loginMethods ? (_this$_configuration43 = this._configuration) === null || _this$_configuration43 === void 0 || (_this$_configuration43 = _this$_configuration43.authentication) === null || _this$_configuration43 === void 0 ? void 0 : _this$_configuration43.loginMethods.standard : true,
          generic: (_this$_configuration44 = this._configuration) !== null && _this$_configuration44 !== void 0 && (_this$_configuration44 = _this$_configuration44.authentication) !== null && _this$_configuration44 !== void 0 && _this$_configuration44.loginMethods ? this._configuration.authentication.loginMethods.generic : false
        },
        contentBox: (_this$_configuration45 = this._configuration) === null || _this$_configuration45 === void 0 || (_this$_configuration45 = _this$_configuration45.authentication) === null || _this$_configuration45 === void 0 ? void 0 : _this$_configuration45.contentBox,
        resetPassword: {
          returnToLogin: (_this$_configuration$2 = (_this$_configuration46 = this._configuration) === null || _this$_configuration46 === void 0 || (_this$_configuration46 = _this$_configuration46.authentication) === null || _this$_configuration46 === void 0 || (_this$_configuration46 = _this$_configuration46.resetPassword) === null || _this$_configuration46 === void 0 ? void 0 : _this$_configuration46.returnToLogin) !== null && _this$_configuration$2 !== void 0 ? _this$_configuration$2 : true
        }
      });
    }
  }, {
    key: "enableRouting",
    get: function get() {
      var _this$_configuration47;
      return (_this$_configuration47 = this._configuration) === null || _this$_configuration47 === void 0 ? void 0 : _this$_configuration47.enableRouting;
    }
  }, {
    key: "enableStorage",
    get: function get() {
      var _this$_configuration48;
      return (_this$_configuration48 = this._configuration) === null || _this$_configuration48 === void 0 ? void 0 : _this$_configuration48.enableStorage;
    }
  }, {
    key: "telemetrySettings",
    get: function get() {
      var _this$_configuration49;
      return (_this$_configuration49 = this._configuration) === null || _this$_configuration49 === void 0 ? void 0 : _this$_configuration49.telemetry;
    }
  }, {
    key: "enableModals",
    get: function get() {
      var _this$_configuration50;
      return !((_this$_configuration50 = this._configuration) !== null && _this$_configuration50 !== void 0 && _this$_configuration50.disableModals);
    }
  }, {
    key: "enableSupport",
    get: function get() {
      var _this$_configuration51;
      return (_this$_configuration51 = this._configuration) === null || _this$_configuration51 === void 0 ? void 0 : _this$_configuration51.enableSupport;
    }
  }, {
    key: "showInitWarnBanner",
    get: function get() {
      var _this$defaultApiConfi, _this$defaultApiConfi2, _this$defaultApiConfi3, _this$_configuration52;
      if (!((_this$defaultApiConfi = this.defaultApiConfig) !== null && _this$defaultApiConfi !== void 0 && _this$defaultApiConfi.showInitWarnBanner) || ((_this$defaultApiConfi2 = this.defaultApiConfig) === null || _this$defaultApiConfi2 === void 0 ? void 0 : _this$defaultApiConfi2.showInitWarnBanner) === 'false') {
        localStorage.removeItem('bannerViews');
      }
      return ((_this$defaultApiConfi3 = this.defaultApiConfig) === null || _this$defaultApiConfi3 === void 0 ? void 0 : _this$defaultApiConfi3.showInitWarnBanner) === 'true' && ((_this$_configuration52 = this._configuration) === null || _this$_configuration52 === void 0 ? void 0 : _this$_configuration52.showInitWarnBanner);
    }
  }, {
    key: "apiConfig",
    get: function get() {
      var _this$_configuration53;
      return parseApiConfig((_this$_configuration53 = this._configuration) === null || _this$_configuration53 === void 0 ? void 0 : _this$_configuration53.api, this.defaultApiConfig, this.root.dataStore.organization);
    }
  }, {
    key: "applicationEnvironment",
    get: function get() {
      var _this$_configuration$3, _this$_configuration54;
      return (_this$_configuration$3 = (_this$_configuration54 = this._configuration) === null || _this$_configuration54 === void 0 ? void 0 : _this$_configuration54.applicationEnvironment) !== null && _this$_configuration$3 !== void 0 ? _this$_configuration$3 : 'SELLER';
    }
  }, {
    key: "priceFormat",
    get: function get() {
      var _this$_configuration55;
      if ((_this$_configuration55 = this._configuration) !== null && _this$_configuration55 !== void 0 && _this$_configuration55.priceFormat) {
        var _this$_configuration56, _this$root$dataStore$2, _this$root$dataStore$3, _this$_configuration57;
        return _objectSpread$f(_objectSpread$f({}, (_this$_configuration56 = this._configuration) === null || _this$_configuration56 === void 0 ? void 0 : _this$_configuration56.priceFormat), {}, {
          currency: (_this$root$dataStore$2 = (_this$root$dataStore$3 = this.root.dataStore.organization) === null || _this$root$dataStore$3 === void 0 ? void 0 : _this$root$dataStore$3.settings.defaultCurrency) !== null && _this$root$dataStore$2 !== void 0 ? _this$root$dataStore$2 : (_this$_configuration57 = this._configuration) === null || _this$_configuration57 === void 0 ? void 0 : _this$_configuration57.priceFormat.currency
        });
      } else {
        var _this$root$dataStore$4, _this$root$dataStore$5;
        return _objectSpread$f(_objectSpread$f({}, DivaUtils.defaultPriceFormat), {}, {
          currency: (_this$root$dataStore$4 = (_this$root$dataStore$5 = this.root.dataStore.organization) === null || _this$root$dataStore$5 === void 0 ? void 0 : _this$root$dataStore$5.settings.defaultCurrency) !== null && _this$root$dataStore$4 !== void 0 ? _this$root$dataStore$4 : DivaUtils.defaultPriceFormat.currency
        });
      }
    }
  }, {
    key: "countryCodesFile",
    get: function get() {
      var _this$_configuration58;
      return (_this$_configuration58 = this._configuration) === null || _this$_configuration58 === void 0 ? void 0 : _this$_configuration58.countryCodesFile;
    }
  }, {
    key: "allowedOrganizationTypes",
    get: function get() {
      var _this$_configuration59, _this$_configuration60, _this$_configuration61, _this$_configuration62;
      if (!((_this$_configuration59 = this._configuration) !== null && _this$_configuration59 !== void 0 && _this$_configuration59.allowedOrganizationTypes)) {
        return ['RETAILER'];
      }
      return Array.isArray((_this$_configuration60 = this._configuration) === null || _this$_configuration60 === void 0 ? void 0 : _this$_configuration60.allowedOrganizationTypes) ? (_this$_configuration61 = this._configuration) === null || _this$_configuration61 === void 0 ? void 0 : _this$_configuration61.allowedOrganizationTypes : [(_this$_configuration62 = this._configuration) === null || _this$_configuration62 === void 0 ? void 0 : _this$_configuration62.allowedOrganizationTypes];
    }
  }, {
    key: "resetConfigurationCache",
    value: function resetConfigurationCache() {
      this.configurationCache = new Map();
    }
  }, {
    key: "fetchConfiguration",
    value: function () {
      var _fetchConfiguration = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref5) {
        var identifier, type, domain, _ref5$organizationId, organizationId, configuration, types, settingsKeys, _i, _types, subType;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              identifier = _ref5.identifier, type = _ref5.type, domain = _ref5.domain, _ref5$organizationId = _ref5.organizationId, organizationId = _ref5$organizationId === void 0 ? this.root.dataStore.organizationId : _ref5$organizationId;
              LOG$d.debug("Fetching configuration for ".concat(type, " ").concat(identifier !== null && identifier !== void 0 ? identifier : '', " ").concat(domain !== null && domain !== void 0 ? domain : '', " ").concat(organizationId));
              configuration = this.configurationCache.get(type + identifier + organizationId);
              if (!configuration) {
                _context.next = 6;
                break;
              }
              LOG$d.debug("Found configuration in cache for ".concat(type, " ").concat(identifier !== null && identifier !== void 0 ? identifier : '', " ").concat(domain !== null && domain !== void 0 ? domain : '', " ").concat(organizationId));
              return _context.abrupt("return", configuration);
            case 6:
              _context.prev = 6;
              LOG$d.debug("Need to load configuration from service for ".concat(type, " ").concat(identifier !== null && identifier !== void 0 ? identifier : '', " ").concat(domain !== null && domain !== void 0 ? domain : '', " ").concat(organizationId));
              _context.next = 10;
              return this.root.apiHandler.fetchConfiguration({
                organizationId: organizationId,
                type: type,
                identifier: identifier,
                domain: domain
              });
            case 10:
              configuration = _context.sent;
              _context.next = 17;
              break;
            case 13:
              _context.prev = 13;
              _context.t0 = _context["catch"](6);
              LOG$d.error(new DivaError('Error while fetching configuration', {
                cause: _context.t0
              }));
              configuration = {};
            case 17:
              // If a component includes an other component that it self needs a configuration,
              // the convention is that there must be a field '{type}Identifer' (i.e. PRODUCTSIdentifier) and a field '{type}Settings' (i.e. PRODUCTSSettings).
              // If the settings fields is net set, the configuration is fetched from the server by using the indentifier field.
              types = [];
              settingsKeys = [];
              Object.keys(configuration).forEach(function (key) {
                if (key.includes('Identifier')) {
                  types.push(key.replace('Identifier', ''));
                }
                if (key.includes('Settings')) {
                  settingsKeys.push(key.replace('Settings', ''));
                }
              });
              _i = 0, _types = types;
            case 21:
              if (!(_i < _types.length)) {
                _context.next = 38;
                break;
              }
              subType = _types[_i];
              if (!settingsKeys.includes(subType)) {
                _context.next = 25;
                break;
              }
              return _context.abrupt("continue", 35);
            case 25:
              _context.prev = 25;
              _context.next = 28;
              return this.root.apiHandler.fetchConfiguration({
                organizationId: organizationId,
                identifier: configuration["".concat(subType, "Identifier")],
                type: subType
              });
            case 28:
              configuration["".concat(subType, "Settings")] = _context.sent;
              _context.next = 35;
              break;
            case 31:
              _context.prev = 31;
              _context.t1 = _context["catch"](25);
              LOG$d.error(new DivaError("Error while fetching configuration for ".concat(subType), {
                cause: _context.t1
              }));
              configuration["".concat(subType, "Settings")] = {};
            case 35:
              _i++;
              _context.next = 21;
              break;
            case 38:
              this.configurationCache.set(type + identifier + organizationId, configuration);
              LOG$d.debug("Loaded configuration from service ".concat(type, " ").concat(identifier !== null && identifier !== void 0 ? identifier : '', " ").concat(domain !== null && domain !== void 0 ? domain : '', " ").concat(organizationId));
              return _context.abrupt("return", configuration);
            case 41:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[6, 13], [25, 31]]);
      }));
      function fetchConfiguration(_x) {
        return _fetchConfiguration.apply(this, arguments);
      }
      return fetchConfiguration;
    }()
  }, {
    key: "updateConfiguration",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function updateConfiguration() {
      var _this$root$contentSto;
      var configuration, type, prevState;
      return _regeneratorRuntime.wrap(function updateConfiguration$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            this.root.loadingAndErrorStore.toggleLoading('updateConfiguration');
            _context2.next = 3;
            return this.fetchConfiguration({
              domain: this.domain,
              identifier: this.identifier,
              type: 'FRAMEWORK'
            });
          case 3:
            configuration = _context2.sent;
            this.configuration = configuration;
            type = (_this$root$contentSto = this.root.contentStore.currentComponent) === null || _this$root$contentSto === void 0 ? void 0 : _this$root$contentSto.type;
            if (type) {
              prevState = this.root.contentStore.getState(type);
              this.root.contentStore.openComponent({
                type: type,
                parameters: prevState.parameters,
                internal: prevState.internal
              });
            }
            this.root.loadingAndErrorStore.toggleLoading('updateConfiguration');
          case 8:
          case "end":
            return _context2.stop();
        }
      }, updateConfiguration, this);
    })
  }]);
}();

function getUserAgentInfo() {
  var _platformInfo$name, _platformInfo$os$fami, _platformInfo$os, _platformInfo$os$vers, _platformInfo$os2;
  var myAgent = {
    isMobile: false,
    family: 'Desktop',
    os: 'unknown',
    osVersion: 'unknown',
    deviceName: 'unknown',
    browser: 'unknown',
    screenWidth: window.innerWidth,
    screenHeight: window.innerHeight
  };
  var ua = window.navigator.userAgent;
  var md = new MobileDetect(ua);

  // Check if the device is a phone or tablet
  var phone = md.phone();
  var tablet = md.tablet();
  if (phone) {
    myAgent.deviceName = phone;
    myAgent.family = 'Phone';
    myAgent.isMobile = true;
  } else if (tablet) {
    myAgent.deviceName = tablet;
    myAgent.family = 'Tablet';
    myAgent.isMobile = true;
  }

  // Use platform.js for browser and OS detection
  var platformInfo = platform;

  // Browser name
  myAgent.browser = (_platformInfo$name = platformInfo.name) !== null && _platformInfo$name !== void 0 ? _platformInfo$name : 'unknown';

  // OS name and version
  myAgent.os = (_platformInfo$os$fami = (_platformInfo$os = platformInfo.os) === null || _platformInfo$os === void 0 ? void 0 : _platformInfo$os.family) !== null && _platformInfo$os$fami !== void 0 ? _platformInfo$os$fami : 'unknown';
  myAgent.osVersion = (_platformInfo$os$vers = (_platformInfo$os2 = platformInfo.os) === null || _platformInfo$os2 === void 0 ? void 0 : _platformInfo$os2.version) !== null && _platformInfo$os$vers !== void 0 ? _platformInfo$os$vers : 'unknown';
  return myAgent;
}
function userAgentIsMobile() {
  var md = new MobileDetect(window.navigator.userAgent);
  return !!md.mobile() || !!md.tablet() || !!isIpadOS();
}
function isIpadOS() {
  return navigator.maxTouchPoints && navigator.maxTouchPoints > 2 && /MacIntel/.test(navigator.platform);
}

function ownKeys$e(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$e(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$e(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$e(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$c = getLogger('Framework', 'DataStore');
var DataStore = /*#__PURE__*/function () {
  function DataStore(root) {
    _classCallCheck(this, DataStore);
    this.root = root;
    _defineProperty(this, "_currentOrganizationId", undefined);
    _defineProperty(this, "_organization", undefined);
    _defineProperty(this, "_user", undefined);
    _defineProperty(this, "_isMobile", void 0);
    _defineProperty(this, "_isFirefox", void 0);
    _defineProperty(this, "_sessionGuids", {});
    _defineProperty(this, "_permissions", []);
    _defineProperty(this, "_parentOrganizations", []);
    makeAutoObservable(this, {
      updateOrganizationInternal: flow,
      updateOrganization: flow,
      getSessionGuidFlow: flow
    });
    this._isMobile = userAgentIsMobile();
    var userAgent = navigator.userAgent.toLowerCase();
    var isFirefox = userAgent.includes('fxios') || userAgent.includes('firefox');
    this._isFirefox = isFirefox;
  }
  return _createClass(DataStore, [{
    key: "isMobile",
    get: function get() {
      return this._isMobile;
    }
  }, {
    key: "isFirefox",
    get: function get() {
      return this._isFirefox;
    }
  }, {
    key: "organization",
    get: function get() {
      var _settings$defaultCurr, _settings;
      return this._organization ? _objectSpread$e(_objectSpread$e({}, this._organization), {}, {
        settings: _objectSpread$e(_objectSpread$e({}, this._organization.settings), {}, {
          defaultCurrency: (_settings$defaultCurr = (_settings = this._organization.settings) === null || _settings === void 0 ? void 0 : _settings.defaultCurrency) !== null && _settings$defaultCurr !== void 0 ? _settings$defaultCurr : '€'
        })
      }) : this._organization;
    }
  }, {
    key: "organizationId",
    get: function get() {
      return this._currentOrganizationId || '';
    }

    /**
     * Returns the full list of parent organizations including the current organization
     */
  }, {
    key: "fullParentList",
    get: function get() {
      var _this$organization$pa, _this$organization$pa2;
      return [].concat(_toConsumableArray((_this$organization$pa = (_this$organization$pa2 = this.organization.parentOrganizations) === null || _this$organization$pa2 === void 0 ? void 0 : _this$organization$pa2.map(function (o) {
        return o._id;
      })) !== null && _this$organization$pa !== void 0 ? _this$organization$pa : []), [this.organizationId]);
    }

    /**
     * Returns the list of parent organizations including the current organization, filtered by the valid organizations of the config and the permissions of the user
     * this is manly used for displaying the organization hirarchy in the header
     *
     * If you need the full parent list, use fullParentList
     */
  }, {
    key: "organizationHirarchy",
    get: function get() {
      var _this$_organization$p,
        _this$_organization$p2,
        _this = this;
      if (!this._organization) {
        return [];
      }
      return [].concat(_toConsumableArray(((_this$_organization$p = (_this$_organization$p2 = this._organization.parentOrganizations) === null || _this$_organization$p2 === void 0 ? void 0 : _this$_organization$p2.filter(function (org) {
        return _this._parentOrganizations.includes(org._id);
      })) !== null && _this$_organization$p !== void 0 ? _this$_organization$p : []).map(function (org) {
        return _objectSpread$e(_objectSpread$e({}, org), {}, {
          type: org.type != 'SUPPLIER' ? org.parentType : undefined //supplier should not be accessed directly, only its children, so the simpliest solution is to remove here the type
        });
      }).reverse()), [{
        _id: this._organization._id,
        displayName: this._organization.displayName,
        type: this._organization.type != 'SUPPLIER' ? this._organization.parentType : undefined
      }]);
    }
  }, {
    key: "user",
    get: function get() {
      return this._user;
    },
    set: function set(user) {
      var _this$_user;
      if (user !== null && user !== void 0 && user._id && user._id == ((_this$_user = this._user) === null || _this$_user === void 0 ? void 0 : _this$_user._id)) {
        LOG$c.debug('User did not change');
      } else if (!user) {
        LOG$c.debug('User was removed');
      } else if (user._id) {
        var _this$_user2;
        LOG$c.debug("User changed from ".concat((_this$_user2 = this._user) === null || _this$_user2 === void 0 ? void 0 : _this$_user2._id, " to ").concat(user._id));
        DivaUtils.businessMetrics.setUser(user._id, user.mainEmail, user.name + ' ' + user.familyName); //Obsolete
      }
      this._user = user;
    }
  }, {
    key: "permissions",
    set: function set(permission) {
      this._permissions = permission;
    }
  }, {
    key: "parentOrganizations",
    set: function set(organizations) {
      this._parentOrganizations = organizations;
    }

    /**
     * Checks if the user has a certain permissions
     * @param permission the permission
     * @returns true if the user has the permission
     */
  }, {
    key: "userHasPermission",
    value: function userHasPermission(permission) {
      return this._permissions.includes(md5(permission.toLocaleLowerCase())) || false;
    }
  }, {
    key: "updateOrganization",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function updateOrganization(organizationId) {
      return _regeneratorRuntime.wrap(function updateOrganization$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            if (!(organizationId != this.organizationId)) {
              _context.next = 8;
              break;
            }
            _context.next = 4;
            return this.root.authorizationStore.autorize(organizationId);
          case 4:
            _context.next = 6;
            return this.updateOrganizationInternal(organizationId);
          case 6:
            _context.next = 8;
            return this.root.configurationStore.updateConfiguration();
          case 8:
            _context.next = 13;
            break;
          case 10:
            _context.prev = 10;
            _context.t0 = _context["catch"](0);
            this.root.loadingAndErrorStore.setError(_context.t0);
          case 13:
          case "end":
            return _context.stop();
        }
      }, updateOrganization, this, [[0, 10]]);
    })
  }, {
    key: "getSessionGuid",
    value: function () {
      var _getSessionGuid = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(u, m, organizationId, api2Location) {
        var result;
        return _regeneratorRuntime.wrap(function _callee$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return flowResult(this.getSessionGuidFlow(u, m, organizationId, api2Location));
            case 2:
              result = _context2.sent;
              return _context2.abrupt("return", result.sessionGuid);
            case 4:
            case "end":
              return _context2.stop();
          }
        }, _callee, this);
      }));
      function getSessionGuid(_x, _x2, _x3, _x4) {
        return _getSessionGuid.apply(this, arguments);
      }
      return getSessionGuid;
    }()
  }, {
    key: "getApi2AuthLoginData",
    value: function () {
      var _getApi2AuthLoginData = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(u, m, organizationId, api2Location) {
        return _regeneratorRuntime.wrap(function _callee2$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              return _context3.abrupt("return", flowResult(this.getSessionGuidFlow(u, m, organizationId, api2Location)));
            case 1:
            case "end":
              return _context3.stop();
          }
        }, _callee2, this);
      }));
      function getApi2AuthLoginData(_x5, _x6, _x7, _x8) {
        return _getApi2AuthLoginData.apply(this, arguments);
      }
      return getApi2AuthLoginData;
    }()
  }, {
    key: "getSessionGuidFlow",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function getSessionGuidFlow(u, m, organizationId, api2Location) {
      var _api2Url;
      var authToken, useNToken, api2Url, userRole, mode, organization, sessionKey, url, res;
      return _regeneratorRuntime.wrap(function getSessionGuidFlow$(_context4) {
        while (1) switch (_context4.prev = _context4.next) {
          case 0:
            authToken = this.root.authorizationStore.nToken;
            useNToken = true;
            if (!(organizationId && organizationId != this.organizationId && this.root.authorizationStore.nToken === undefined)) {
              _context4.next = 6;
              break;
            }
            throw new Error('Could not get sessionGuid! nToken is undefined');
          case 6:
            if (!(this.root.authorizationStore.zToken === undefined)) {
              _context4.next = 10;
              break;
            }
            throw new Error('Could not get sessionGuid! zToken is undefined');
          case 10:
            authToken = this.root.authorizationStore.zToken;
            useNToken = false;
          case 12:
            api2Url = api2Location;
            if (!api2Url) {
              api2Url = u == 'E' ? this.root.configurationStore.apiConfig.api2.ek : this.root.configurationStore.applicationEnvironment == 'WEB' ? this.root.configurationStore.apiConfig.api2.web : this.root.configurationStore.apiConfig.api2["default"];
            }
            if (api2Url) {
              _context4.next = 16;
              break;
            }
            throw new Error('Could not get sessionGuid! api2 is undefined');
          case 16:
            userRole = u.toLocaleUpperCase();
            mode = m === null || m === void 0 ? void 0 : m.toLocaleLowerCase();
            organization = organizationId !== null && organizationId !== void 0 ? organizationId : this.organizationId;
            sessionKey = organization + userRole + (mode !== null && mode !== void 0 ? mode : 'offline') + ((_api2Url = api2Url) !== null && _api2Url !== void 0 ? _api2Url : '');
            if (!(this._sessionGuids[sessionKey] !== undefined)) {
              _context4.next = 23;
              break;
            }
            LOG$c.debug("Found Session GUID in store for ".concat(sessionKey));
            return _context4.abrupt("return", this._sessionGuids[sessionKey]);
          case 23:
            LOG$c.debug("No Session GUID found in store for ".concat(sessionKey), toJS(this._sessionGuids));
            url = api2Url + '?function=JsonLoginByAuthToken' + ('&UserRole=' + userRole) + ('&organizationId=' + organization) + ('&mode=' + (mode !== null && mode !== void 0 ? mode : this.root.loginMode));
            _context4.next = 27;
            return fetch(url, {
              headers: useNToken ? {
                MainAuthToken: authToken
              } : {
                AuthToken: authToken
              }
            }).then(function (r) {
              return r.text();
            }).then(function (r) {
              var response = JSON.parse(r);
              if (response !== null && response !== void 0 && response.ErrMessage) {
                throw new Error('Get Session GUID: ' + response.ErrMessage);
              } else if (response) {
                return {
                  sessionGuid: response.SessionGUID,
                  supplierGuid: response.SupplierGuid
                };
              }
              throw new Error('Get Session GUID');
            })["catch"](function (e) {
              throw e;
            });
          case 27:
            res = _context4.sent;
            LOG$c.debug("Fetched new session GUID from api for ".concat(sessionKey));
            this._sessionGuids[sessionKey] = res;
            return _context4.abrupt("return", this._sessionGuids[sessionKey]);
          case 31:
          case "end":
            return _context4.stop();
        }
      }, getSessionGuidFlow, this);
    })
    /**
     * clears all the current saved sessionGuids
     */
  }, {
    key: "clearSessionGuids",
    value: function clearSessionGuids() {
      this._sessionGuids = {};
    }

    /**
     * Update the currently selected organization and immediately load the organization data
     * @param organizationId the id of the new organization
     */
  }, {
    key: "updateOrganizationInternal",
    value:
    /*#__PURE__*/
    _regeneratorRuntime.mark(function updateOrganizationInternal(organizationId) {
      var prevOrganization, organizationData, _organizationData$par, _organizationData$par2;
      return _regeneratorRuntime.wrap(function updateOrganizationInternal$(_context5) {
        while (1) switch (_context5.prev = _context5.next) {
          case 0:
            prevOrganization = this.organizationId;
            this.root.loadingAndErrorStore.toggleLoading('organization', false, true);
            _context5.prev = 2;
            organizationData = undefined;
            if (!(organizationId != prevOrganization)) {
              _context5.next = 18;
              break;
            }
            _context5.next = 7;
            return this.root.apiHandler.fetchOrganization(organizationId);
          case 7:
            organizationData = _context5.sent;
            if (organizationData) {
              _context5.next = 10;
              break;
            }
            throw new Error('Organization does not exist');
          case 10:
            DivaUtils.businessMetrics.setOrganizations({
              id: organizationData._id,
              name: organizationData.displayName
            }, (_organizationData$par = (_organizationData$par2 = organizationData.parentOrganizations) === null || _organizationData$par2 === void 0 ? void 0 : _organizationData$par2.map(function (data) {
              return {
                id: data._id,
                name: data.displayName
              };
            })) !== null && _organizationData$par !== void 0 ? _organizationData$par : []);
            this._currentOrganizationId = organizationId;
            this._organization = organizationData;
            this.root.authorizationStore.zToken ? DivaUtils.businessMetrics.jwtSetter = this.root.authorizationStore.zToken : undefined;
            if (this.root.authorizationStore.loginState == 'user') {
              this.root.browserStateStore.setStoredOrganization(organizationId);
            }
            LOG$c.debug("Organization changed from ".concat(prevOrganization, " to ").concat(organizationId));
            _context5.next = 19;
            break;
          case 18:
            LOG$c.debug("Organization did not change.");
          case 19:
            _context5.next = 24;
            break;
          case 21:
            _context5.prev = 21;
            _context5.t0 = _context5["catch"](2);
            throw new DivaError('Could not fetch organization data', {
              cause: _context5.t0,
              code: 'CORE_0002'
            });
          case 24:
            _context5.prev = 24;
            this.root.loadingAndErrorStore.toggleLoading('organization', false, false);
            return _context5.finish(24);
          case 27:
          case "end":
            return _context5.stop();
        }
      }, updateOrganizationInternal, this, [[2, 21, 24, 27]]);
    })
  }]);
}();

var instance = i18n.createInstance();
function init(_x) {
  return _init.apply(this, arguments);
}
function _init() {
  _init = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var url, namespace, available, defaultLng, apiConfig;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          url = _ref.url, namespace = _ref.namespace, available = _ref.available, defaultLng = _ref.defaultLng, apiConfig = _ref.apiConfig;
          return _context.abrupt("return", new Promise(function (resolve, reject) {
            var loadPath = "".concat(apiConfig.adminService, "/locales?lng={{lng}}&ns={{ns}}");
            if (url) {
              loadPath = url.includes('{{lng}}') ? url : "".concat(url, "?lng={{lng}}&ns={{ns}}");
            }
            var namespaces = ['default'];
            if (namespace) {
              namespaces.push(namespace);
            }
            var lang = defaultLng || (available === null || available === void 0 ? void 0 : available[0]) || 'de';
            var initOptions = {
              lng: lang,
              debug: false,
              defaultNS: namespace !== null && namespace !== void 0 ? namespace : 'default',
              fallbackNS: 'default',
              ns: namespaces,
              supportedLngs: available || [defaultLng || 'de'],
              interpolation: {
                escapeValue: false // not needed for react as it escapes by default
              },
              backend: {
                loadPath: loadPath,
                crossDomain: true
              }
            };
            instance.use(HttpApi).init(initOptions, function (error) {
              if (error) {
                reject(error);
              } else {
                resolve(lang);
              }
            });
          }));
        case 2:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return _init.apply(this, arguments);
}
function changeNamespace(_x2) {
  return _changeNamespace.apply(this, arguments);
}
function _changeNamespace() {
  _changeNamespace = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(namespace) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          instance.options.ns = [namespace, 'default'];
          instance.options.defaultNS = namespace;
          _context2.next = 4;
          return instance.reloadResources(undefined, namespace);
        case 4:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return _changeNamespace.apply(this, arguments);
}

function componentsEqual(c1, c2) {
  if (!c1 && !c2) {
    return true;
  }
  if (!c1 || !c2) {
    return false;
  }
  if (c1.type != c2.type) {
    return false;
  }
  if (!paramsEqual(c1.parameters, c2.parameters)) {
    return false;
  }
  if (!c1.identifier || !c2.identifier || c1.identifier === c2.identifier) {
    return true;
  }
  return false;
}
function paramsEqual(p1, p2) {
  if (empty(p1) && empty(p2)) {
    return true;
  }
  if (empty(p1) || empty(p2)) {
    return false;
  }
  if (Object.keys(p1).length !== Object.keys(p2).length) {
    return false;
  }
  return Object.keys(p1).every(function (k) {
    return decodeURIComponent(p1[k] || '') === decodeURIComponent(p2[k] || '');
  });
}
function empty(p) {
  return !p || Object.keys(p).length == 0;
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var titlecontainer = "titlecontainer-LeRMj";
var auth = "auth-y9j9-";
var loginBox = "login-box-Zu-QM";
var logoContainer = "logo-container-Gujpy";
var success = "success-7n9-D";
var error = "error-gJyOw";
var authButton = "auth-button-nvUhU";
var buttonDisabled = "button-disabled-GS-ox";
var socialButton = "social-button-p5pUa";
var google = "google-WhFJU";
var microsoft = "microsoft-e3GYR";
var separator = "separator-Hg6fH";
var input = "input--Dl8e";
var readonly = "readonly-uw66l";
var link = "link-s-Rcm";
var css_248z$6 = ".titlecontainer-LeRMj {\n  text-align: center;\n  color: #474747;\n}\n\n.auth-y9j9- {\n  height: 100%;\n  width: 100%;\n  display: flex;\n  background-color: rgba(255, 255, 255);\n  z-index: 3;\n  overflow: auto;\n  justify-content: center;\n  align-items: center;\n  position: absolute;\n}\n\n.login-box-Zu-QM {\n  padding: 20px;\n  width: 400px;\n  margin: 50px auto auto auto;\n  position: relative;\n}\n\n@media (max-height: 450px) {\n  .login-box-Zu-QM {\n    margin: auto;\n  }\n}\n\n.logo-container-Gujpy {\n  background-repeat: no-repeat;\n  background-position: center;\n  background-size: contain;\n  margin-bottom: 50px;\n}\n\n.success-7n9-D {\n  width: 100%;\n  padding: 12px;\n  border-radius: 4px;\n  margin: 15px 0;\n  box-sizing: border-box;\n  background-color: rgb(228, 244, 228);\n  color: rgb(17, 97, 73);\n  border: rgb(195, 231, 202) solid 1px;\n  border-left: solid 4px;\n  line-height: 20px;\n  font-size: 16px;\n  position: relative;\n}\n\n.success-7n9-D span {\n  width: 30px;\n  height: 100%;\n  float: left;\n  background-repeat: no-repeat;\n  background-image: url(\"data:image/svg+xml,%3Csvg fill%3D%22rgb(19%2C 170%2C 82)%22 xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22 height%3D%2230px%22 width%3D%2230px%22   viewBox%3D%220 0 24 24%22 %3E%3Cpath fill-rule%3D%22evenodd%22 clip-rule%3D%22evenodd%22 d%3D%22M8 15A7 7 0 108 1a7 7 0 000 14zm2.448-10.104a.997.997 0 111.508 1.306l-4.572 5.28a1 1 0 01-1.64-.07l-1.82-2.868a1 1 0 111.69-1.07l1.1 1.734 3.734-4.312z%22 fill%3D%22currentColor%22%3E%3C%2Fpath%3E%3C%2Fsvg%3E\");\n  position: absolute;\n}\n\n.success-7n9-D div {\n  text-align: justify;\n  margin-left: 30px;\n}\n\n[dir=\"ltr\"] .error-gJyOw {\n  text-align: left;\n}\n\n[dir=\"rtl\"] .error-gJyOw {\n  text-align: right;\n}\n\n.error-gJyOw {\n  border-left: 4px solid red !important;\n}\n\n.error-gJyOw {\n  border-radius: 4px;\n  padding: 10px;\n  display: flex;\n  align-items: center;\n}\n\n.auth-button-nvUhU {\n  width: 100%;\n  padding: 12px;\n  border-radius: 4px;\n  margin: 15px 0;\n  opacity: 0.85;\n  font-size: 17px;\n  line-height: 22px;\n  cursor: pointer;\n  box-sizing: border-box;\n  background-color: var(--diva-theme-palette-primary-main);\n  text-align: center;\n  color: var(--diva-theme-palette-primary-contrast-text);\n  text-transform: none;\n}\n\n.auth-button-nvUhU:hover {\n  opacity: 1;\n}\n\n.button-disabled-GS-ox {\n  opacity: 0.3;\n  cursor: auto;\n  cursor: initial;\n}\n.button-disabled-GS-ox:hover {\n  opacity: 0.3;\n}\n\n.social-button-p5pUa {\n  justify-content: space-around;\n  text-transform: none;\n}\n\n.social-button-p5pUa div {\n  width: 30px;\n  height: 22px;\n  float: left;\n  background-repeat: no-repeat;\n  background-size: contain;\n  background-position: center;\n}\n\n.google-WhFJU,\n.microsoft-e3GYR {\n  font-size: medium;\n  margin-top: 16px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  gap: 12px;\n  background-color: white;\n  color: #333;\n  border: 1px solid #ddd;\n  border-radius: 4px;\n  font-weight: 600;\n  padding: 12px;\n  transition: all 0.3s ease-in-out;\n  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);\n}\n\n.google-WhFJU:hover,\n.microsoft-e3GYR:hover {\n  background-color: #f8f9fa;\n  border-color: #bbb;\n  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15);\n}\n.google-WhFJU div {\n  background-image: url(\"data:image/svg+xml,%3C%3Fxml version%3D%221.0%22 encoding%3D%22utf-8%22%3F%3E%3C!-- Uploaded to%3A SVG Repo%2C www.svgrepo.com%2C Generator%3A SVG Repo Mixer Tools --%3E%3Csvg width%3D%22800px%22 height%3D%22800px%22 viewBox%3D%22-3 0 262 262%22 xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22 preserveAspectRatio%3D%22xMidYMid%22%3E%3Cpath d%3D%22M255.878 133.451c0-10.734-.871-18.567-2.756-26.69H130.55v48.448h71.947c-1.45 12.04-9.283 30.172-26.69 42.356l-.244 1.622 38.755 30.023 2.685.268c24.659-22.774 38.875-56.282 38.875-96.027%22 fill%3D%22%234285F4%22%2F%3E%3Cpath d%3D%22M130.55 261.1c35.248 0 64.839-11.605 86.453-31.622l-41.196-31.913c-11.024 7.688-25.82 13.055-45.257 13.055-34.523 0-63.824-22.773-74.269-54.25l-1.531.13-40.298 31.187-.527 1.465C35.393 231.798 79.49 261.1 130.55 261.1%22 fill%3D%22%2334A853%22%2F%3E%3Cpath d%3D%22M56.281 156.37c-2.756-8.123-4.351-16.827-4.351-25.82 0-8.994 1.595-17.697 4.206-25.82l-.073-1.73L15.26 71.312l-1.335.635C5.077 89.644 0 109.517 0 130.55s5.077 40.905 13.925 58.602l42.356-32.782%22 fill%3D%22%23FBBC05%22%2F%3E%3Cpath d%3D%22M130.55 50.479c24.514 0 41.05 10.589 50.479 19.438l36.844-35.974C195.245 12.91 165.798 0 130.55 0 79.49 0 35.393 29.301 13.925 71.947l42.211 32.783c10.59-31.477 39.891-54.251 74.414-54.251%22 fill%3D%22%23EB4335%22%2F%3E%3C%2Fsvg%3E\");\n}\n.microsoft-e3GYR div {\n  background-image: url(\"data:image/svg+xml,%3C%3Fxml version%3D%221.0%22 encoding%3D%22utf-8%22%3F%3E%3C!-- Uploaded to%3A SVG Repo%2C www.svgrepo.com%2C Generator%3A SVG Repo Mixer Tools --%3E%3Csvg xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22aria-label%3D%22Microsoft%22 role%3D%22img%22viewBox%3D%220 0 512 512%22%3E%3Crectwidth%3D%22512%22 height%3D%22512%22rx%3D%2215%25%22fill%3D%22%23ffffff%22%2F%3E%3Cpathd%3D%22M75 75v171h171v-171z%22 fill%3D%22%23f25022%22%2F%3E%3Cpathd%3D%22M266 75v171h171v-171z%22 fill%3D%22%237fba00%22%2F%3E%3Cpathd%3D%22M75 266v171h171v-171z%22 fill%3D%22%2300a4ef%22%2F%3E%3Cpathd%3D%22M266 266v171h171v-171z%22 fill%3D%22%23ffb900%22%2F%3E%3C%2Fsvg%3E\");\n}\n\n.separator-Hg6fH {\n  display: flex;\n  align-items: center;\n  text-align: center;\n  color: rgb(184, 196, 194);\n}\n\n.separator-Hg6fH::before,\n.separator-Hg6fH::after {\n  content: '';\n  flex: 1;\n  border-bottom: 1px solid rgb(184, 196, 194);\n}\n\n.separator-Hg6fH:not(:empty)::before {\n  margin-right: 0.25em;\n}\n\n.separator-Hg6fH:not(:empty)::after {\n  margin-left: 0.25em;\n}\n\n.input--Dl8e {\n  width: 100%;\n  padding: 1em;\n  border: solid 1px rgba(0, 0, 0, 0.1);\n  border-radius: 0.3em;\n  outline: none;\n  margin: 15px 0;\n  box-sizing: border-box;\n}\n\n.input--Dl8e:hover,\n.input--Dl8e:focus,\n.input--Dl8e:active {\n  border: solid 1px var(--diva-theme-palette-primary-main);\n}\n\n.input--Dl8e::-moz-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n\n.input--Dl8e::placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n\n.input--Dl8e.readonly-uw66l {\n  border: solid 1px rgba(0, 0, 0, 0.1);\n  color: rgba(0, 0, 0, 0.25);\n}\n\n.reset-input-ERpB4 {\n  position: relative;\n}\n\n.reset-input-ERpB4:after {\n  content: '';\n  position: absolute;\n  right: 10px;\n  top: 0;\n  bottom: 0;\n  width: 20px;\n  background: url(\"data:image/svg+xml,%3C%3Fxml version%3D%221.0%22 %3F%3E%3C!DOCTYPE svg  PUBLIC '-%2F%2FW3C%2F%2FDTD SVG 1.1%2F%2FEN'  'http%3A%2F%2Fwww.w3.org%2FGraphics%2FSVG%2F1.1%2FDTD%2Fsvg11.dtd'%3E%3Csvg  id%3D%22Layer_1%22 style%3D%22enable-background%3Anew 0 0 512 512%3B%22 version%3D%221.1%22 viewBox%3D%220 0 512 512%22 width%3D%22512px%22 xml%3Aspace%3D%22preserve%22 xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22 xmlns%3Axlink%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%22%3E%3Cg%3E%3Cpath d%3D%22M256%2C33C132.3%2C33%2C32%2C133.3%2C32%2C257c0%2C123.7%2C100.3%2C224%2C224%2C224c123.7%2C0%2C224-100.3%2C224-224C480%2C133.3%2C379.7%2C33%2C256%2C33z    M364.3%2C332.5c1.5%2C1.5%2C2.3%2C3.5%2C2.3%2C5.6c0%2C2.1-0.8%2C4.2-2.3%2C5.6l-21.6%2C21.7c-1.6%2C1.6-3.6%2C2.3-5.6%2C2.3c-2%2C0-4.1-0.8-5.6-2.3L256%2C289.8   l-75.4%2C75.7c-1.5%2C1.6-3.6%2C2.3-5.6%2C2.3c-2%2C0-4.1-0.8-5.6-2.3l-21.6-21.7c-1.5-1.5-2.3-3.5-2.3-5.6c0-2.1%2C0.8-4.2%2C2.3-5.6l75.7-76   l-75.9-75c-3.1-3.1-3.1-8.2%2C0-11.3l21.6-21.7c1.5-1.5%2C3.5-2.3%2C5.6-2.3c2.1%2C0%2C4.1%2C0.8%2C5.6%2C2.3l75.7%2C74.7l75.7-74.7   c1.5-1.5%2C3.5-2.3%2C5.6-2.3c2.1%2C0%2C4.1%2C0.8%2C5.6%2C2.3l21.6%2C21.7c3.1%2C3.1%2C3.1%2C8.2%2C0%2C11.3l-75.9%2C75L364.3%2C332.5z%22%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E\") center / contain no-repeat;\n  cursor: pointer;\n  opacity: 0.7;\n}\n\n.link-s-Rcm {\n  color: var(--diva-theme-palette-primary-main);\n  cursor: pointer;\n  display: inline-block;\n}\n";
styleInject(css_248z$6);

var _excluded$7 = ["className", "disabled", "children", "onClick", "style"];
function ownKeys$d(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$d(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$d(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$d(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function AuthButton(_ref) {
  var className = _ref.className,
    disabled = _ref.disabled,
    children = _ref.children,
    onClick = _ref.onClick,
    style = _ref.style,
    props = _objectWithoutProperties(_ref, _excluded$7);
  return /*#__PURE__*/jsx(Button, _objectSpread$d(_objectSpread$d({
    id: "submit",
    variant: "contained",
    disabled: disabled,
    onClick: onClick,
    className: classnames(authButton, className, disabled ? buttonDisabled : undefined),
    style: style
  }, props), {}, {
    children: children
  }));
}

var _excluded$6 = ["className", "readOnly", "resetInput"];
function ownKeys$c(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$c(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$c(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$c(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var Input = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var className = _ref.className,
    readOnly = _ref.readOnly,
    resetInput = _ref.resetInput,
    props = _objectWithoutProperties(_ref, _excluded$6);
  return /*#__PURE__*/jsxs("div", {
    style: {
      position: 'relative'
    },
    children: [/*#__PURE__*/jsx("input", _objectSpread$c({
      ref: ref,
      className: classnames(input, readOnly ? readonly : undefined, className),
      readOnly: readOnly,
      "data-test-id": "barrier-input-text",
      style: {
        paddingLeft: resetInput ? '40px' : undefined
      } // Platzierung des Pfeils
    }, props)), resetInput && /*#__PURE__*/jsx(ArrowBack, {
      onClick: function onClick() {
        return resetInput();
      },
      style: {
        position: 'absolute',
        left: '8px',
        // Platzierung des Pfeils
        top: '50%',
        transform: 'translateY(-50%)',
        // Vertikale Zentrierung
        cursor: 'pointer'
      }
    })]
  });
});

function SimpleLogin (_ref) {
  var email = _ref.email,
    setEmail = _ref.setEmail,
    tos = _ref.tos,
    setTos = _ref.setTos,
    showTos = _ref.showTos;
  var _useDivaCoreContext = useDivaCoreContext(),
    configurationStore = _useDivaCoreContext.configurationStore,
    contentStore = _useDivaCoreContext.contentStore;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  return /*#__PURE__*/jsxs(Fragment, {
    children: [/*#__PURE__*/jsx(Input, {
      placeholder: t('auth.input.email'),
      value: email,
      onChange: function onChange(e) {
        return setEmail(e.currentTarget.value);
      }
    }), showTos && /*#__PURE__*/jsxs("div", {
      style: {
        display: 'flex',
        cursor: 'pointer'
      },
      onClick: function onClick() {
        return setTos(!tos);
      },
      children: [/*#__PURE__*/jsx("input", {
        "data-test-id": "check-agb",
        type: "checkbox",
        style: {
          marginRight: '12px',
          cursor: 'pointer'
        },
        checked: tos,
        onChange: function onChange() {
          return setTos(!tos);
        }
      }), /*#__PURE__*/jsx("span", {
        children: /*#__PURE__*/jsx(Trans, {
          i18nKey: "barrier.tosconsent",
          components: {
            TOS: /*#__PURE__*/jsx("div", {
              className: link,
              onClick: function onClick() {
                return contentStore.openComponent({
                  url: configurationStore.navigation.tosUrl,
                  openInNewTab: true
                });
              }
            }),
            PRIVACY: /*#__PURE__*/jsx("div", {
              className: link,
              onClick: function onClick() {
                return contentStore.openComponent({
                  url: configurationStore.navigation.privacyUrl,
                  openInNewTab: true
                });
              }
            })
          }
        })
      })]
    })]
  });
}

function Barrier (_ref) {
  var actions = _ref.actions,
    _ref$currentEmail = _ref.currentEmail,
    currentEmail = _ref$currentEmail === void 0 ? '' : _ref$currentEmail,
    type = _ref.type;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _useState = useState(currentEmail),
    _useState2 = _slicedToArray(_useState, 2),
    email = _useState2[0],
    setEmail = _useState2[1];
  var _useState3 = useState(!!currentEmail),
    _useState4 = _slicedToArray(_useState3, 2),
    tosChecked = _useState4[0],
    setTosChecked = _useState4[1];
  var disabledActions = actions === null || actions === void 0 ? void 0 : actions.map(function (action) {
    return (!tosChecked || !email || !DivaUtils.validateEmail(email)) && action.loginType != 'NO_LOGIN';
  });
  return /*#__PURE__*/jsxs("form", {
    autoComplete: "off",
    onSubmit: function onSubmit(e) {
      var _actions$;
      e.preventDefault();
      if (disabledActions !== null && disabledActions !== void 0 && disabledActions[0]) return;
      actions === null || actions === void 0 || (_actions$ = actions[0]) === null || _actions$ === void 0 || _actions$.onClick(email);
    },
    "data-test-id": "barrier-action-form",
    children: [type != 'NO_LOGIN' && /*#__PURE__*/jsx(SimpleLogin, {
      setEmail: setEmail,
      email: email,
      showTos: !currentEmail,
      tos: tosChecked,
      setTos: setTosChecked
    }), actions === null || actions === void 0 ? void 0 : actions.map(function (a, index) {
      return /*#__PURE__*/jsx(AuthButton, {
        "data-test-id": "barrier-action-button",
        className: a.className,
        disabled: disabledActions === null || disabledActions === void 0 ? void 0 : disabledActions[index],
        onClick: disabledActions !== null && disabledActions !== void 0 && disabledActions[index] ? function () {} : function () {
          return a.onClick(email);
        },
        style: {
          justifyContent: 'flex-start'
        },
        children: t(a.text)
      }, a.text);
    })]
  });
}

function _callSuper$1(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct$1() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _isNativeReflectConstruct$1() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct$1 = function _isNativeReflectConstruct() { return !!t; })(); }
var LOG$b = getLogger('Framework', 'root');
var ErrorBoundary = /*#__PURE__*/function (_React$Component) {
  function ErrorBoundary(props) {
    var _this;
    _classCallCheck(this, ErrorBoundary);
    _this = _callSuper$1(this, ErrorBoundary, [props]);
    _defineProperty(_this, "root", void 0);
    _this.root = props.root;
    return _this;
  }
  _inherits(ErrorBoundary, _React$Component);
  return _createClass(ErrorBoundary, [{
    key: "componentDidCatch",
    value: function componentDidCatch(error) {
      LOG$b.error(new DivaError('Error while rendring in Core', {
        cause: error,
        custom: {
          code: 'CORE_0000'
        }
      }));
      this.root.loadingAndErrorStore.setError(error.message);
    }
  }, {
    key: "render",
    value: function render() {
      return this.props.children;
    }
  }], [{
    key: "getDerivedStateFromError",
    value: function getDerivedStateFromError() {
      // just to prevent warning
      return {};
    }
  }]);
}(React.Component);

function Fallback () {
  var _useDivaCoreContext = useDivaCoreContext(),
    loadingAndErrorStore = _useDivaCoreContext.loadingAndErrorStore;
  useEffect(function () {
    loadingAndErrorStore.toggleLoading('Fallback');
    return function () {
      return loadingAndErrorStore.toggleLoading('Fallback');
    };
  }, []);
  return /*#__PURE__*/jsx(Fragment, {});
}

var _excluded$5 = ["children"];
function ownKeys$b(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$b(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$b(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$b(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$a = getLogger('Framework', 'root');
var DivaCore = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded$5);
  useEffect(function () {
    LOG$a.successTransaction('UNTIL_RENDER');
  }, []);
  return /*#__PURE__*/jsx(DivaCoreProvider, _objectSpread$b(_objectSpread$b({}, props), {}, {
    ref: ref,
    children: /*#__PURE__*/jsx(ContentWrapper, {
      children: /*#__PURE__*/jsx(Fragment, {
        children: children !== null && children !== void 0 ? children : /*#__PURE__*/jsx(Content, {})
      })
    })
  }));
});
var ContentWrapper = observer(function (_ref2) {
  var children = _ref2.children;
  var context = useDivaCoreContext();
  var _context$contentStore = context.contentStore.containerDimensions,
    isMobile = _context$contentStore.isMobile,
    isPortrait = _context$contentStore.isPortrait;
  var ref = useCallback(function (node) {
    if (node !== null) {
      context.contentStore.setContainer(node);
    }
  }, []);
  return /*#__PURE__*/jsx(StyledEngineProvider, {
    injectFirst: true,
    children: /*#__PURE__*/jsx("div", {
      ref: ref,
      id: "DivaCore",
      style: {
        position: 'relative',
        height: '100%',
        overflow: 'hidden'
      },
      className: (isPortrait ? ' portrait' : '') + (isMobile ? '  mobile' : '') + (isMobile && !isPortrait ? '  landscape' : '') + (context.dataStore.isMobile ? ' actual-mobile' : ''),
      children: /*#__PURE__*/jsx(I18nextProvider, {
        i18n: instance,
        children: /*#__PURE__*/jsx(ErrorBoundary, {
          root: context,
          children: /*#__PURE__*/jsx(ThemeProvider, {
            theme: context.contentStore.materialUiTheme,
            children: /*#__PURE__*/jsx(Suspense, {
              fallback: /*#__PURE__*/jsx(Fallback, {}),
              children: children
            })
          })
        })
      })
    })
  });
});

function calculateDimensions(width, height) {
  var isPortrait = false;
  var isMobile = false;
  var isTablet = false;
  if (width < height) {
    isPortrait = true;
  }
  if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent) || width < 900) {
    isMobile = true;
  }
  if (/(tablet|ipad|playbook|silk)|(android(?!.*mobi))/i.test(navigator.userAgent) || navigator.userAgent.match(/Mac/) && navigator.maxTouchPoints && navigator.maxTouchPoints > 2) {
    isTablet = true;
  }
  return {
    isPortrait: isPortrait,
    isMobile: isMobile,
    isTablet: isTablet,
    width: Math.round(width),
    height: Math.round(height)
  };
}
function registerResizeObserver(_x, _x2) {
  return _registerResizeObserver.apply(this, arguments);
}
function _registerResizeObserver() {
  _registerResizeObserver = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(ref, onResize) {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          return _context.abrupt("return", new Promise(function (resolve) {
            if ('ResizeObserver' in self) {
              resolve(buildResizeObserver(ref, onResize));
            } else {
              DivaUtils.loadScript('https://cdn.jsdelivr.net/npm/resize-observer-polyfill@1.5.1/dist/ResizeObserver.min.js', function () {
                return resolve(buildResizeObserver(ref, onResize));
              });
            }
          }));
        case 1:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return _registerResizeObserver.apply(this, arguments);
}
function unregisterResizeObserver(observer) {
  observer.disconnect();
}
function buildResizeObserver(ref, onResize) {
  var resizeObserver = new ResizeObserver(debounce(function (entries) {
    if (entries.length === 0) return;
    var _entries$0$contentRec = entries[0].contentRect,
      width = _entries$0$contentRec.width,
      height = _entries$0$contentRec.height;
    onResize(width, height);
  }, 150));
  resizeObserver.observe(ref);
  return resizeObserver;
}

function updateCssThemeVariables (ref, theme) {
  ref.style.setProperty('--diva-theme-palette-primary-main', theme.palette.primary.main);
  ref.style.setProperty('--diva-theme-palette-primary-dark', theme.palette.primary.dark);
  ref.style.setProperty('--diva-theme-palette-primary-light', theme.palette.primary.light);
  ref.style.setProperty('--diva-theme-palette-primary-contrast-text', theme.palette.primary.contrastText);
  ref.style.setProperty('--diva-theme-palette-secondary-main', theme.palette.secondary.main);
  ref.style.setProperty('--diva-theme-palette-secondary-dark', theme.palette.secondary.dark);
  ref.style.setProperty('--diva-theme-palette-secondary-light', theme.palette.secondary.light);
  ref.style.setProperty('--diva-theme-palette-secondary-contrast-text', theme.palette.secondary.contrastText);
  ref.style.setProperty('--diva-theme-palette-text-primary', theme.palette.text.primary);
  ref.style.setProperty('--diva-theme-palette-text-secondary', theme.palette.text.secondary);
  ref.style.setProperty('--diva-typography-font-family', theme.typography.fontFamily);
  ref.style.setProperty('font-family', theme.typography.fontFamily);
}

var _excluded$4 = ["openFrom"],
  _excluded2$1 = ["onClose"];
function _createForOfIteratorHelper(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function ownKeys$a(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$a(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$a(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$a(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$9 = getLogger('Framework', 'ContentStore');
var ContentStore = /*#__PURE__*/function () {
  function ContentStore(components, root) {
    var _this = this;
    _classCallCheck(this, ContentStore);
    this.root = root;
    _defineProperty(this, "configuration", []);
    _defineProperty(this, "state", new Map());
    _defineProperty(this, "_modelViewerHasLoaded", false);
    _defineProperty(this, "_fullscreenComponent", undefined);
    _defineProperty(this, "_isAbsoluteComponent", false);
    _defineProperty(this, "_modal", undefined);
    _defineProperty(this, "_snackBars", []);
    _defineProperty(this, "_banner", undefined);
    _defineProperty(this, "_fullscreen", undefined);
    _defineProperty(this, "_sideMenu", undefined);
    _defineProperty(this, "_headerInfos", {
      visible: false
    });
    _defineProperty(this, "visible", undefined);
    _defineProperty(this, "customLogoMap", new Map());
    _defineProperty(this, "customHeaderComponentMap", new Map());
    _defineProperty(this, "_breadcrumbs", []);
    _defineProperty(this, "_hidePrices", getLocalStorageToggle('diva-price'));
    _defineProperty(this, "_hideConfigPricePreview", getLocalStorageToggle('diva-additional-price'));
    _defineProperty(this, "_hideSnow", getLocalStorageToggle('diva-snow'));
    _defineProperty(this, "_componentChange", undefined);
    _defineProperty(this, "_restrictedComponent", undefined);
    _defineProperty(this, "ref", undefined);
    _defineProperty(this, "resizeObserver", undefined);
    _defineProperty(this, "_dimensions", undefined);
    _defineProperty(this, "_currentlyRendered", []);
    _defineProperty(this, "mapTypeToModule", function (type) {
      switch (type) {
        case 'START_PAGE':
          return 'StartPage';
        case 'SELLER':
          return 'Seller';
        case 'ARCHIVE':
          return 'SellerArchiv';
        case 'CONTENTBOX':
          return 'ContentBox';
        case 'CLASSIFICATION':
          return 'Classification';
        case 'PRODUCTS':
          return 'Products';
        case 'PRODUCT_LIST':
          return 'Productlist';
        case 'DIVA_WEBPLANNER':
          return 'Planner';
        case 'DIVA_BACKOFFICE_NEW':
          return 'BackofficeNew';
        case 'AR_VIEWER':
          return 'ARViewer';
        case 'USER_MANAGER':
          return 'UserManager';
        case 'CATEGORY_MANAGER':
          return 'CategoryManager';
        case 'ASSORTMENT_MANAGER':
          return 'AssortmentManager';
        case 'TEST':
          return 'Test';
        case 'PRODUCT_GALLERY':
          return 'Productgallery';
        case 'DIVA_START_PAGE':
          return 'DivaStartPage';
        case 'ANALYTICS':
          return 'Analytics';
        default:
          return 'Undefined';
      }
    });
    this.root = root;
    this.configuration = components;
    if (window.customElements.get('model-viewer')) this._modelViewerHasLoaded = true;
    LOG$9.debug("Available Components: ".concat(components.map(function (c) {
      return c.name;
    })));
    makeAutoObservable(this, {
      state: observable.shallow,
      fullscreenModule: observable.shallow,
      configuration: observable.shallow,
      _fullscreenComponent: observable.shallow,
      _isAbsoluteComponent: observable,
      customHeaderComponentMap: observable.shallow,
      customLogoMap: observable.shallow,
      _snackBars: observable.shallow,
      isAbsoluteFullscreenComponent: computed,
      containerDimensions: computed,
      ref: observable.ref,
      _fullscreen: observable.ref,
      _banner: observable.ref,
      _sideMenu: observable.ref,
      resizeObserver: false,
      _currentlyRendered: false,
      openComponent: flow,
      openComponentInFullscreen: flow,
      sendEmail: flow,
      getState: false
    });
    reaction(function () {
      return _this.root.dataStore.user;
    }, function (newUser) {
      if (newUser) {
        _this.root.authorizationStore.close();
      }
      if (!newUser) {
        _this.updateStateAfterLogout();
      }
    }, {
      name: 'onUserChangedInContentStore'
    });
    autorun(function () {
      if (_this.ref && _this.root.configurationStore.theme) {
        _this.updateCssThemeVariables();
      }
    }, {
      name: 'updateCss'
    });
  }
  return _createClass(ContentStore, [{
    key: "loadModelViewer",
    value: function () {
      var _loadModelViewer = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (!(!this._modelViewerHasLoaded && !window.customElements.get('model-viewer'))) {
                _context.next = 4;
                break;
              }
              this._modelViewerHasLoaded = true;
              _context.next = 4;
              return import('@google/model-viewer');
            case 4:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function loadModelViewer() {
        return _loadModelViewer.apply(this, arguments);
      }
      return loadModelViewer;
    }()
  }, {
    key: "resolveComponent",
    value: function resolveComponent(action) {
      var _config$route, _config;
      if (action.url) {
        return action.url;
      }
      var config = undefined;
      var _ref = action,
        type = _ref.type,
        parameters = _ref.parameters,
        route = _ref.route;
      if (type) {
        config = this.availableComponents.find(function (c) {
          return c.type == type;
        });
      } else if (route) {
        config = this.availableComponents.find(function (c) {
          var _c$route;
          return (_c$route = c.route) === null || _c$route === void 0 ? void 0 : _c$route.startsWith(route);
        });
      }
      var url = new URL("".concat(window.location.origin).concat((_config$route = (_config = config) === null || _config === void 0 ? void 0 : _config.route) !== null && _config$route !== void 0 ? _config$route : ''));
      var params = url.searchParams;
      Object.entries(parameters || {}).forEach(function (param) {
        return param[1] ? params.append(param[0], param[1]) : false;
      });
      params.append('lang', this.root.language);
      params.append('organizationId', this.root.dataStore.organizationId);
      return url.href;
    }

    /**
     * Open a component or an external url.
     *
     * Checks against the configuration and opens in the expected way (e.g. new tab)
     * @param action the component or external url
     */
  }, {
    key: "openComponent",
    value:
    /*#__PURE__*/
    _regeneratorRuntime.mark(function openComponent(action) {
      var _this$componentChange,
        _config2,
        _config3,
        _this2 = this,
        _config6,
        _config8,
        _config9;
      var _this$componentChange2, _this$componentChange3, _this$openInNewTab, _this$openInNewTab2, link, _window, _ref2, type, parameters, internal, route, openInFullscreen, keepOldState, config, parent, _this$root$dataStore$, _this$root$dataStore$2, _config4, newTab, _config7, base, settings, openModuleLables, _parameters, otherPrams, module, prevType, prevState, currentState, componentState, _this$root$dataStore$3, _config$barrier, _parameters2;
      return _regeneratorRuntime.wrap(function openComponent$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            if (!((_this$componentChange = this.componentChange) !== null && _this$componentChange !== void 0 && _this$componentChange.isBlocked)) {
              _context2.next = 3;
              break;
            }
            (_this$componentChange2 = this.componentChange) === null || _this$componentChange2 === void 0 || (_this$componentChange3 = _this$componentChange2.callback) === null || _this$componentChange3 === void 0 || _this$componentChange3.call(_this$componentChange2);
            return _context2.abrupt("return");
          case 3:
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            LOG$9.debug('openComponent', toJS(action));
            if (!action.url) {
              _context2.next = 10;
              break;
            }
            LOG$9.businessEvent('onOpenModule', action.openInNewTab ? 'OpenUrlNewTab' : 'OpenUrl', "Open link ".concat(action.url), {
              url: action.url
            });
            if (action.openInNewTab) {
              _this$openInNewTab = this.openInNewTab(action), _this$openInNewTab2 = _slicedToArray(_this$openInNewTab, 2), link = _this$openInNewTab2[0], _window = _this$openInNewTab2[1];
              if (action.enableCorsCommunication) DivaUtils.createBridge(link, _window);
            } else {
              window.location.href = this.resoveUrl(action.url);
            }
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            return _context2.abrupt("return");
          case 10:
            _ref2 = action, type = _ref2.type, parameters = _ref2.parameters, internal = _ref2.internal, route = _ref2.route, openInFullscreen = _ref2.openInFullscreen, keepOldState = _ref2.keepOldState;
            config = undefined;
            if (!openInFullscreen) {
              _context2.next = 15;
              break;
            }
            this.openComponentInFullscreen(action);
            return _context2.abrupt("return");
          case 15:
            if (type) {
              config = this.availableComponents.find(function (c) {
                return c.type == type;
              });
            } else if (route) {
              config = this.availableComponents.find(function (c) {
                return c.route && (route === null || route === void 0 ? void 0 : route.startsWith(c.route));
              });
            }
            if (!(((_config2 = config) === null || _config2 === void 0 ? void 0 : _config2.type) == 'CATEGORY_MANAGER' || ((_config3 = config) === null || _config3 === void 0 ? void 0 : _config3.type) == 'ASSORTMENT_MANAGER')) {
              _context2.next = 23;
              break;
            }
            parent = undefined;
            if (this.root.dataStore.organization.type == undefined && this.root.dataStore.organization.parentType == 'RETAILER') {
              parent = (_this$root$dataStore$ = this.root.dataStore.organization.parentOrganizations) === null || _this$root$dataStore$ === void 0 ? void 0 : _this$root$dataStore$.find(function (o) {
                return o.type == 'RETAILER';
              });
            } else if (this.root.dataStore.organization.type == undefined && this.root.dataStore.organization.parentType == 'ASSOCIATION') {
              parent = (_this$root$dataStore$2 = this.root.dataStore.organization.parentOrganizations) === null || _this$root$dataStore$2 === void 0 ? void 0 : _this$root$dataStore$2.find(function (o) {
                return o.type == 'ASSOCIATION';
              });
            }
            if (!parent) {
              _context2.next = 23;
              break;
            }
            this.openModal({
              title: this.root.t('action.opencomponent.diva6.warning.title'),
              text: this.root.t('action.opencomponent.diva6.warning.text', {
                type: ((_config4 = config) === null || _config4 === void 0 ? void 0 : _config4.type) == 'CATEGORY_MANAGER' ? 'Category Manager' : 'Sortiments Manager',
                parent: parent.displayName
              }),
              accept: true,
              reject: true,
              rejectByIcon: true,
              callback: function callback(accept) {
                if (accept) {
                  var _config5;
                  var url = "".concat(window.location.origin).concat((_config5 = config) === null || _config5 === void 0 ? void 0 : _config5.route, "?lang=").concat(_this2.root.language, "&organizationId=").concat(parent._id);
                  _this2.openInNewTab({
                    url: url,
                    openInNewTab: true
                  });
                }
              }
            });
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            return _context2.abrupt("return");
          case 23:
            newTab = action.openInNewTab || ((_config6 = config) === null || _config6 === void 0 ? void 0 : _config6.openInNewTab);
            if (!newTab) {
              _context2.next = 29;
              break;
            }
            base = typeof action.openInNewTab == 'string' ? action.openInNewTab : window.origin;
            this.openInNewTab(action, "".concat(base).concat(((_config7 = config) === null || _config7 === void 0 ? void 0 : _config7.route) || ''));
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            return _context2.abrupt("return");
          case 29:
            if (!(!this.root.dataStore.user && !this.isPublic(action))) {
              _context2.next = 35;
              break;
            }
            LOG$9.debug("Component is restricted, open login form");
            this._restrictedComponent = action;
            this.root.authorizationStore.showLogin();
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            return _context2.abrupt("return");
          case 35:
            if (config) {
              _context2.next = 40;
              break;
            }
            this._restrictedComponent = action;
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            this.root.loadingAndErrorStore.setError(new DivaError("No component with the specified settings found", {
              code: 'CORE_0005',
              custom: {
                action: toJS(action)
              }
            }), 'CORE_0005');
            return _context2.abrupt("return");
          case 40:
            settings = undefined;
            if (config.settings) {
              settings = config.settings;
            } else {
              settings = {};
            }
            openModuleLables = undefined;
            if (parameters) {
              _parameters = parameters, _parameters.openFrom, otherPrams = _objectWithoutProperties(_parameters, _excluded$4);
              openModuleLables = parameters;
              parameters = otherPrams;
            }
            module = this.mapTypeToModule((_config8 = config) === null || _config8 === void 0 ? void 0 : _config8.type);
            LOG$9.businessEvent('onOpenModule', module, "Open module ".concat((_config9 = config) === null || _config9 === void 0 ? void 0 : _config9.type), openModuleLables);
            prevType = this.visible;
            prevState = this.state.get(this.visible || '');
            currentState = this.state.get(config.type);
            componentState = {};
            componentState.settings = toJS(settings);
            componentState.parameters = _objectSpread$a(_objectSpread$a({}, keepOldState && currentState ? currentState.parameters : {}), parameters);
            componentState.internal = _objectSpread$a(_objectSpread$a({}, keepOldState && currentState ? currentState.internal : {}), internal);
            componentState.path = route;
            this.state.set(config.type, componentState);
            this.visible = config.type;
            if (config.isPublic == 'barrier') {
              if (!this.root.dataStore.user || !((_this$root$dataStore$3 = this.root.dataStore.user) !== null && _this$root$dataStore$3 !== void 0 && _this$root$dataStore$3.isEmailVerified)) {
                if (!((_config$barrier = config.barrier) !== null && _config$barrier !== void 0 && _config$barrier.excludeParams) || !Object.keys((_parameters2 = parameters) !== null && _parameters2 !== void 0 ? _parameters2 : {}).find(function (p) {
                  return config.barrier.excludeParams.includes(p);
                })) this.loginBarrier(true, config.barrier);
              }
            }
            if (action.breadcrumb && prevType && prevState) {
              this.updateBreadcrumbs({
                type: 'update',
                param: {
                  groupId: 'AUTO',
                  component: {
                    parameters: prevState.parameters,
                    type: prevType
                  },
                  name: prevType
                }
              });
              this.updateBreadcrumbs({
                type: 'update',
                param: {
                  groupId: 'AUTO',
                  component: {
                    parameters: parameters,
                    type: config.type
                  },
                  name: config.type
                }
              });
            }
            this.setGlobalClass();
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
          case 60:
          case "end":
            return _context2.stop();
        }
      }, openComponent, this);
    })
  }, {
    key: "openComponentInFullscreen",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function openComponentInFullscreen(component) {
      var _config10, _config11;
      var type, parameters, internal, route, config, settings, module, componentState;
      return _regeneratorRuntime.wrap(function openComponentInFullscreen$(_context3) {
        while (1) switch (_context3.prev = _context3.next) {
          case 0:
            LOG$9.debug('openComponentInFullscreen', toJS(component));
            this.root.loadingAndErrorStore.setError(undefined);
            type = component.type, parameters = component.parameters, internal = component.internal, route = component.route;
            config = undefined;
            if (type) {
              config = this.availableComponents.find(function (c) {
                return c.type == type;
              });
            } else if (route) {
              config = this.availableComponents.find(function (c) {
                var _c$route2;
                return (_c$route2 = c.route) === null || _c$route2 === void 0 ? void 0 : _c$route2.startsWith(route);
              });
            }
            if (config) {
              _context3.next = 10;
              break;
            }
            this._restrictedComponent = component;
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
            this.root.loadingAndErrorStore.setError(new DivaError("No component with the specified settings found", {
              code: 'CORE_0005',
              custom: {
                component: toJS(component)
              }
            }), 'CORE_0005');
            return _context3.abrupt("return");
          case 10:
            settings = undefined;
            if (!config.settings) {
              _context3.next = 15;
              break;
            }
            settings = config.settings;
            _context3.next = 18;
            break;
          case 15:
            _context3.next = 17;
            return this.root.configurationStore.fetchConfiguration({
              identifier: config.identifier,
              type: config.type
            });
          case 17:
            settings = _context3.sent;
          case 18:
            module = this.mapTypeToModule((_config10 = config) === null || _config10 === void 0 ? void 0 : _config10.type);
            LOG$9.businessEvent('onOpenModule', module, "Open module ".concat((_config11 = config) === null || _config11 === void 0 ? void 0 : _config11.type));
            componentState = {
              key: config.type,
              parameters: parameters,
              settings: toJS(settings),
              internal: internal,
              absoluteFullscreen: component.absoluteFullscreen,
              absoluteFullscreenStyle: component.absoluteFullscreenStyle
            };
            this.setGlobalClass();
            this._fullscreenComponent = componentState;
            this.root.loadingAndErrorStore.toggleLoading('openComponent');
          case 24:
          case "end":
            return _context3.stop();
        }
      }, openComponentInFullscreen, this);
    })
  }, {
    key: "closeComponentInFullscreen",
    value: function closeComponentInFullscreen() {
      this._fullscreenComponent = undefined;
      this.root.onEvent({
        type: 'closeComponentInFullscreen'
      });
    }

    /**
     * this flag is for components that by their own go in absoulte fullscrennmode like eg: PDP.
     * this flag influences the dimension calculation
     * @param val new state
     */
  }, {
    key: "setAbsoluteFullScreen",
    value: function setAbsoluteFullScreen(val) {
      this._isAbsoluteComponent = val;
    }
  }, {
    key: "getSubConfiguration",
    value: function getSubConfiguration(type) {
      return this.findSubComponent(type, this.currentComponent);
    }
  }, {
    key: "findSubComponent",
    value: function findSubComponent(type, component) {
      var _component$settings;
      if ((component === null || component === void 0 ? void 0 : component.type) === type) {
        return component.settings;
      }
      if (component !== null && component !== void 0 && (_component$settings = component.settings) !== null && _component$settings !== void 0 && _component$settings.subComponents) {
        var _iterator = _createForOfIteratorHelper(component.settings.subComponents),
          _step;
        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var subComponent = _step.value;
            var found = this.findSubComponent(type, subComponent);
            if (found) return found;
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
      return undefined;
    }
  }, {
    key: "loginBarrier",
    value: function loginBarrier(anon, settings) {
      var _settings$title,
        _settings$text,
        _this3 = this;
      this.openBarrier({
        type: settings !== null && settings !== void 0 && settings.skipVerify ? 'SIMPLE' : 'GET_EMAIL',
        rejectable: false,
        anonOnly: anon,
        title: this.root.t((_settings$title = settings === null || settings === void 0 ? void 0 : settings.title) !== null && _settings$title !== void 0 ? _settings$title : 'loginbarrier.barrier.title'),
        text: this.root.t((_settings$text = settings === null || settings === void 0 ? void 0 : settings.text) !== null && _settings$text !== void 0 ? _settings$text : 'loginbarrier.barrier.text'),
        actions: [{
          text: this.root.t('loginbarrier.barrier.button'),
          onClick: function onClick(email) {
            var _settings$emailVarian;
            if (settings !== null && settings !== void 0 && settings.skipVerify) {
              return;
            }
            LOG$9.debug("Request email verification for ".concat(email));
            _this3.root.apiHandler.sendVerificationEmail({
              email: email,
              emailVariant: (_settings$emailVarian = settings === null || settings === void 0 ? void 0 : settings.emailVariant) !== null && _settings$emailVarian !== void 0 ? _settings$emailVarian : 'DEMO'
            });
            _this3.openModal({
              title: _this3.root.t('loginbarrier.verify.title'),
              text: _this3.root.t('loginbarrier.verify.text'),
              maxWidth: 500,
              actions: [{
                text: _this3.root.t('loginbarrier.verify.button'),
                variant: 'contained',
                id: 'verify',
                closeable: false
              }],
              callback: function callback() {
                _this3.loginBarrier(false, settings);
              }
            });
          }
        }]
      });
    }
  }, {
    key: "updateCustomLogo",
    value:
    /**
     * Update the custom logo for a list of components
     * @param components the list of components
     * @param logo the custom logo
     */
    function updateCustomLogo(components, logo) {
      var _this4 = this;
      components.forEach(function (c) {
        return logo ? _this4.customLogoMap.set(c, logo) : _this4.customLogoMap["delete"](c);
      });
    }

    /**
     * Update the custom headerelement for a list of components
     * @param components the list of components
     * @param element the custom header element
     */
  }, {
    key: "updateCustomHeaderElement",
    value: function updateCustomHeaderElement(components, element) {
      var _this5 = this;
      components.forEach(function (c) {
        return element ? _this5.customHeaderComponentMap.set(c, element) : _this5.customHeaderComponentMap["delete"](c);
      });
    }

    /**
     * Updates the breadcrumbs
     * If type is 'replace' a whole breadcrumb group gets replaces,
     * if the type is 'update' the group gets updated
     * @param params the update parameters for the breadcrumbs
     */
  }, {
    key: "updateBreadcrumbs",
    value: function updateBreadcrumbs(params) {
      if (params.type == 'replace') {
        var groupIndex = this._breadcrumbs.findIndex(function (g) {
          return g.id == params.groupId;
        });
        if (groupIndex >= 0) {
          this._breadcrumbs.splice(groupIndex, 1);
        }
        this._breadcrumbs.push({
          id: params.groupId,
          path: params.list.map(function (l) {
            return {
              level: l.level,
              name: l.name,
              component: l.component
            };
          })
        });
      } else if (params.type == 'update') {
        var _groupIndex = this._breadcrumbs.findIndex(function (g) {
          return g.id == params.param.groupId;
        });
        if (_groupIndex < 0) {
          _groupIndex = this._breadcrumbs.push({
            id: params.param.groupId,
            path: []
          }) - 1;
        } else {
          if (params.param.level !== undefined) {
            //if the same component on the same level exists already, do nothing
            var pathElement = this._breadcrumbs[_groupIndex].path.find(function (p) {
              return p.level === params.param.level;
            });
            if (pathElement && componentsEqual(pathElement.component, params.param.component)) {
              return;
            }
            //remove all levels greater than the new one
            this._breadcrumbs[_groupIndex].path = this._breadcrumbs[_groupIndex].path.filter(function (p) {
              return p.level < params.param.level;
            });
          } else {
            //if no level is defined, check if the same component already exists and remove all with higher level
            var _pathElement = this._breadcrumbs[_groupIndex].path.find(function (p) {
              return p.component.type == params.param.component.type;
            });
            if (_pathElement) {
              this._breadcrumbs[_groupIndex].path = this._breadcrumbs[_groupIndex].path.filter(function (p) {
                return p.level < _pathElement.level;
              });
            }
          }
        }
        var level = params.param.level !== undefined ? params.param.level : this._breadcrumbs[_groupIndex].path.length;
        this._breadcrumbs[_groupIndex].path.push({
          level: level,
          name: params.param.name,
          component: params.param.component
        });
      }
    }

    /**
     * Returns the current breadcrumbs the be rendered in the header
     */
  }, {
    key: "breadcrumbs",
    get: function get() {
      var _this6 = this;
      if (!this.visible) {
        return undefined;
      }
      var state = this.getState(this.visible);
      var _iterator2 = _createForOfIteratorHelper(this._breadcrumbs),
        _step2;
      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
          var group = _step2.value;
          var path = group.path.find(function (p) {
            return componentsEqual(p.component, {
              type: _this6.visible,
              parameters: state.parameters,
              internal: state.internal
            });
          });
          if (path) {
            return {
              breadcrumbs: group,
              current: path.level
            };
          }
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
      return undefined;
    }

    /**
     * Initialize the breadcrumb array
     * @param breadcrumbs the inital value
     */
  }, {
    key: "initBreadcrumbs",
    value: function initBreadcrumbs(breadcrumbs) {
      this._breadcrumbs = [breadcrumbs];
    }

    /**
     * Returns the custom logo that should be added to the logos in the header, if there is any
     */
  }, {
    key: "customLogo",
    get: function get() {
      return this.visible ? this.customLogoMap.get(this.visible) : undefined;
    }

    /**
     * Retruns the custom component that should be rendered in the header, if there is any
     */
  }, {
    key: "customHeaderComponent",
    get: function get() {
      return this.visible ? this.customHeaderComponentMap.get(this.visible) : undefined;
    }

    /**
     * Returns the component setting of the current component
     */
  }, {
    key: "currentComponent",
    get: function get() {
      var _this7 = this;
      return this.root.configurationStore.components.find(function (c) {
        return c.type == _this7.visible;
      });
    }

    /**
     * Returns the currently stored restricted component if there is one
     */
  }, {
    key: "restrictedComponent",
    get: function get() {
      return this._restrictedComponent;
    },
    set: function set(val) {
      this._restrictedComponent = val;
    }
    /**
     * States the status of the footer
     */
  }, {
    key: "showFooter",
    get: function get() {
      if (!this.visible) {
        return 'hidden';
      }
      var config = this.currentComponent;
      if (this.root.configurationStore.navigation.showFooter != undefined) {
        return this.root.configurationStore.navigation.showFooter;
      }
      return (config === null || config === void 0 ? void 0 : config.showFooter) != undefined ? config.showFooter : false;
    }

    /**
     * States the current status for the hide Price button
     */
  }, {
    key: "allowHidePrices",
    get: function get() {
      var _this$root$dataStore$4;
      if (!this.visible) {
        return false;
      }
      if (((_this$root$dataStore$4 = this.root.dataStore.organization) === null || _this$root$dataStore$4 === void 0 || (_this$root$dataStore$4 = _this$root$dataStore$4.settings) === null || _this$root$dataStore$4 === void 0 ? void 0 : _this$root$dataStore$4.hidePrices) !== undefined) {
        return this.root.dataStore.organization.settings.hidePrices.startsWith('DEFAULT');
      }
      return true;
    }

    /**
     * States if the prices should be hidden in the currently visible component
     * It gets the info from the current organization
     * when _hidePrices is undefined we use the default from the config in org
     */
  }, {
    key: "hidePrices",
    get: function get() {
      if (this._hidePrices === undefined) {
        var _this$root$dataStore$5;
        if ((_this$root$dataStore$5 = this.root.dataStore.organization) !== null && _this$root$dataStore$5 !== void 0 && (_this$root$dataStore$5 = _this$root$dataStore$5.settings) !== null && _this$root$dataStore$5 !== void 0 && _this$root$dataStore$5.hidePrices) {
          switch (this.root.dataStore.organization.settings.hidePrices) {
            case 'DEFAULT_HIDDEN':
            case 'ONLY_HIDDEN':
              return true;
            case 'DEFAULT_VISIBLE':
            case 'ONLY_VISIBLE':
              return false;
          }
        } else {
          return false;
        }
      }
      return this._hidePrices;
    }
  }, {
    key: "hideConfigPricePreview",
    get: function get() {
      if (this.hidePrices) return true;
      return !!this._hideConfigPricePreview;
    }

    /**
     * Hides or shows prices
     */
  }, {
    key: "toggleHidePrices",
    value: function toggleHidePrices() {
      this._hidePrices = !this.hidePrices;
      window.localStorage.setItem('diva-price', this._hidePrices ? '1' : '0');
    }
    /**
     * Hides or shows price preview in planner
     */
  }, {
    key: "toggleHideConfigPricePreview",
    value: function toggleHideConfigPricePreview() {
      this._hideConfigPricePreview = !this.hideConfigPricePreview;
      window.localStorage.setItem('diva-additional-price', this._hideConfigPricePreview ? '1' : '0');
    }
  }, {
    key: "hideSnow",
    get: function get() {
      return !!this._hideSnow;
    }
    /**
     * Hides or shows snow
     */
  }, {
    key: "toggleHideSnow",
    value: function toggleHideSnow() {
      this._hideSnow = !this._hideSnow;
      window.localStorage.setItem('diva-snow', this._hideSnow ? '1' : '0');
    }

    /**
     * States if the change of a component is blocked or not
     */
  }, {
    key: "componentChange",
    get: function get() {
      return this._componentChange;
    }
    /**
     * Block Component change
     */
  }, {
    key: "setComponentChange",
    value: function setComponentChange(value) {
      this._componentChange = value;
    }

    /**
     * Opens a modal
     * @param modal the settings for new modal
     */
  }, {
    key: "openModal",
    value: function openModal(modal) {
      this._modal = modal;
    }

    /**
     * Resets the modal state
     */
  }, {
    key: "closeModal",
    value: function closeModal() {
      this._modal = undefined;
    }

    /**
     * The settings for a modal, if one should be opened
     */
  }, {
    key: "modal",
    get: function get() {
      return this._modal;
    }
  }, {
    key: "openSnackBar",
    value: function openSnackBar(bar) {
      var _this$_snackBars;
      var key = nanoid();
      this._snackBars = []; //for now we don't support stacked snackbars
      (_this$_snackBars = this._snackBars) === null || _this$_snackBars === void 0 || _this$_snackBars.push({
        key: key,
        data: bar
      });
      return key;
    }
  }, {
    key: "closeSnackBar",
    value: function closeSnackBar(key) {
      var index = this._snackBars.findIndex(function (s) {
        return s.key == key;
      });
      if (index >= 0) this._snackBars.splice(index, 1);
    }
  }, {
    key: "snackBars",
    get: function get() {
      return this._snackBars;
    }

    /**
     * Open full screen modal
     * @param fullscreen the settings for the fullscreen
     */
  }, {
    key: "openFullscreen",
    value: function openFullscreen(fullscreen) {
      this._fullscreen = fullscreen;
    }

    /**
     * Resets the modal state
     */
  }, {
    key: "closeFullscreen",
    value: function closeFullscreen() {
      this._fullscreen = undefined;
    }

    /**
     * The settings of the fullscreen, if one should be opened
     */
  }, {
    key: "fullscreen",
    get: function get() {
      return this._fullscreen;
    }
  }, {
    key: "closeBanner",
    value: function closeBanner() {
      var _this$_banner;
      if ((_this$_banner = this._banner) !== null && _this$_banner !== void 0 && _this$_banner.useLocalStorage) this.root.browserStateStore.setBannerState(this._banner);
      this._banner = undefined;
    }
  }, {
    key: "banner",
    get: function get() {
      return this._banner;
    }

    /**
     * Open sideMenu screen modal
     * @param sideMenu the settings for the sideMenu
     */
  }, {
    key: "openSideMenu",
    value: function openSideMenu(_ref3) {
      var _this$_sideMenu$open, _this$_sideMenu;
      var _ref3$onClose = _ref3.onClose,
        onClose = _ref3$onClose === void 0 ? this.closeSideMenu.bind(this) : _ref3$onClose,
        sideMenu = _objectWithoutProperties(_ref3, _excluded2$1);
      if (sideMenu.open === undefined) sideMenu.open = (_this$_sideMenu$open = (_this$_sideMenu = this._sideMenu) === null || _this$_sideMenu === void 0 ? void 0 : _this$_sideMenu.open) !== null && _this$_sideMenu$open !== void 0 ? _this$_sideMenu$open : false;
      this._sideMenu = _objectSpread$a(_objectSpread$a({}, sideMenu), {}, {
        onClose: onClose
      });
    }

    /**
     * Resets the modal state
     */
  }, {
    key: "closeSideMenu",
    value: function closeSideMenu() {
      if (this._sideMenu) this._sideMenu = _objectSpread$a(_objectSpread$a({}, this._sideMenu), {}, {
        open: false
      });
    }

    /**
     * Updates HeaderInfos so other component know the state of the header
     */
  }, {
    key: "updateHeaderInfos",
    value: function updateHeaderInfos(headerInfos) {
      this._headerInfos = headerInfos;
    }
  }, {
    key: "headerInfos",
    get: function get() {
      return this._headerInfos;
    }

    /**
     * The settings of the sideMenu, if one should be opened
     */
  }, {
    key: "sideMenu",
    get: function get() {
      return this._sideMenu;
    }

    /**
     * Opens a berrier to request user infos
     *
     * @param barrier the settings for the barrier
     */
  }, {
    key: "openBarrier",
    value: function openBarrier(barrier) {
      var _this$root$dataStore$6,
        _this$root$dataStore$7,
        _barrier$actions,
        _this8 = this;
      if (barrier.anonOnly && (_this$root$dataStore$6 = this.root.dataStore.user) !== null && _this$root$dataStore$6 !== void 0 && _this$root$dataStore$6.mainEmail) {
        LOG$9.debug('Skip barrier because user is logged in');
        return;
      }
      this._modal = {
        text: barrier.text,
        title: barrier.title,
        rejectByIcon: barrier.rejectable != false,
        dontRenderForm: true,
        callback: function callback() {
          var _barrier$onClose;
          (_barrier$onClose = barrier.onClose) === null || _barrier$onClose === void 0 || _barrier$onClose.call(barrier);
        },
        content: /*#__PURE__*/React.createElement(Barrier, {
          type: barrier.type,
          currentEmail: (_this$root$dataStore$7 = this.root.dataStore.user) === null || _this$root$dataStore$7 === void 0 ? void 0 : _this$root$dataStore$7.mainEmail,
          actions: (_barrier$actions = barrier.actions) === null || _barrier$actions === void 0 ? void 0 : _barrier$actions.map(function (a) {
            return _objectSpread$a(_objectSpread$a({}, a), {}, {
              onClick: function () {
                var _onClick = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(email) {
                  var _this8$root$dataStore;
                  var doLogin;
                  return _regeneratorRuntime.wrap(function _callee2$(_context4) {
                    while (1) switch (_context4.prev = _context4.next) {
                      case 0:
                        _this8.closeModal();
                        doLogin = (a.loginType ? a.loginType : barrier.type) === 'SIMPLE';
                        if (!(doLogin && ((_this8$root$dataStore = _this8.root.dataStore.user) === null || _this8$root$dataStore === void 0 ? void 0 : _this8$root$dataStore.mainEmail) != email)) {
                          _context4.next = 11;
                          break;
                        }
                        _context4.prev = 3;
                        _context4.next = 6;
                        return flowResult(_this8.root.authorizationStore.login(email, undefined, true, _this8.root.dataStore.organizationId));
                      case 6:
                        _context4.next = 11;
                        break;
                      case 8:
                        _context4.prev = 8;
                        _context4.t0 = _context4["catch"](3);
                        LOG$9.error(new DivaError('Error while logging in', {
                          cause: _context4.t0
                        }));
                      case 11:
                        a.onClick(email);
                      case 12:
                      case "end":
                        return _context4.stop();
                    }
                  }, _callee2, null, [[3, 8]]);
                }));
                function onClick(_x) {
                  return _onClick.apply(this, arguments);
                }
                return onClick;
              }()
            });
          })
        })
      };
    }
  }, {
    key: "openBanner",
    value: function openBanner(banner) {
      this._banner = banner;
      if (banner.useLocalStorage) this.root.browserStateStore.validateManipulateBannerLocalStorage(banner);
    }
  }, {
    key: "bannerInLocalStorage",
    value: function bannerInLocalStorage(banner) {
      return this.root.browserStateStore.bannerInLocalStorage(banner);
    }

    /**
     * Sends an email and if specified opens an input dialog before sending
     */
  }, {
    key: "sendEmail",
    value: function sendEmail(_ref4) {
      var _this9 = this;
      var dialogText = _ref4.dialogText,
        showDialog = _ref4.showDialog,
        callback = _ref4.callback,
        content = _ref4.content;
      return /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
        var accepted, _content$language$toU, _content$language;
        return _regeneratorRuntime.wrap(function _callee3$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              accepted = showDialog === false;
              if (!(showDialog !== false)) {
                _context5.next = 4;
                break;
              }
              _context5.next = 4;
              return new Promise(function (resolve) {
                return _this9.openModal({
                  reject: true,
                  accept: true,
                  text: dialogText ? _this9.root.t(dialogText, {
                    to: content.to
                  }) : _this9.root.t('email.question.default', {
                    to: content.to
                  }),
                  callback: function callback(accept) {
                    accepted = !!accept;
                    resolve();
                  }
                });
              });
            case 4:
              if (accepted) {
                _context5.next = 6;
                break;
              }
              return _context5.abrupt("return");
            case 6:
              _this9.root.loadingAndErrorStore.toggleLoading('sendingEmail');
              _context5.prev = 7;
              content.language = (_content$language$toU = (_content$language = content.language) === null || _content$language === void 0 ? void 0 : _content$language.toUpperCase()) !== null && _content$language$toU !== void 0 ? _content$language$toU : _this9.root.language.toUpperCase();
              _context5.next = 11;
              return _this9.root.apiHandler.sendEmail({
                content: content,
                organizationIds: _this9.root.dataStore.fullParentList
              });
            case 11:
              if (callback) {
                callback(true);
              } else {
                _this9.openModal({
                  text: _this9.root.t('email.send.success'),
                  accept: true
                });
              }
              _context5.next = 18;
              break;
            case 14:
              _context5.prev = 14;
              _context5.t0 = _context5["catch"](7);
              LOG$9.error(_context5.t0);
              if (callback) {
                callback(false);
              } else {
                _this9.openModal({
                  text: _this9.root.t('email.send.error'),
                  accept: true
                });
              }
            case 18:
              _context5.prev = 18;
              _this9.root.loadingAndErrorStore.toggleLoading('sendingEmail');
              return _context5.finish(18);
            case 21:
            case "end":
              return _context5.stop();
          }
        }, _callee3, null, [[7, 14, 18, 21]]);
      })();
    }

    /**
     * Retruns the current state of the named component
     * @param type
     */
  }, {
    key: "getState",
    value: function getState(type) {
      var state = this.state.get(type);
      return state ? _objectSpread$a(_objectSpread$a({}, state), {}, {
        isVisible: this.isVisible(type)
      }) : {
        settings: {}
      };
    }

    /**
     * Returns true of the named component should be visible
     * @param type the
     */
  }, {
    key: "isVisible",
    value: function isVisible(type) {
      return type == this.visible && !this.root.loadingAndErrorStore.hideContent;
    }

    /**
     * Set the container ref, inorder to monitor the size
     * @param ref the current container
     */
  }, {
    key: "setContainer",
    value: (function () {
      var _setContainer = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(ref) {
        return _regeneratorRuntime.wrap(function _callee4$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              if (!(ref === this.ref)) {
                _context6.next = 2;
                break;
              }
              return _context6.abrupt("return");
            case 2:
              this.ref = ref;
              if (this.resizeObserver) {
                unregisterResizeObserver(this.resizeObserver);
              }
              _context6.next = 6;
              return registerResizeObserver(ref, this.onResize.bind(this));
            case 6:
              this.resizeObserver = _context6.sent;
            case 7:
            case "end":
              return _context6.stop();
          }
        }, _callee4, this);
      }));
      function setContainer(_x2) {
        return _setContainer.apply(this, arguments);
      }
      return setContainer;
    }())
  }, {
    key: "isPublic",
    value: function isPublic(component) {
      var comp;
      if (component.type) {
        comp = this.root.configurationStore.components.find(function (c) {
          return c.type == component.type;
        });
      }
      if (component.route) {
        comp = this.root.configurationStore.components.find(function (c) {
          var _c$route3;
          return (_c$route3 = c.route) === null || _c$route3 === void 0 ? void 0 : _c$route3.startsWith(component.route);
        });
      }
      return comp ? comp.isPublic : true;
    }

    /**
     * A list of all component settings that are currently available, based on the configuration and user permissions
     */
  }, {
    key: "availableComponents",
    get: function get() {
      var _this$root,
        _this10 = this;
      return (_this$root = this.root) === null || _this$root === void 0 ? void 0 : _this$root.configurationStore.components.filter(function (component) {
        //the component must be passed to diva core
        if (!_this10.configuration.find(function (config) {
          return config.name == component.type;
        })) {
          return false;
        }

        //if component is public it can be displayed
        if (component.isPublic) {
          return true;
        }
        //if the user is not logged in the component must be public
        if (!_this10.root.dataStore.user) {
          return false;
        }
        //if there is a permission specified, the user must have it
        return component.permission ? _this10.root.dataStore.userHasPermission(component.permission) : true;
      });
    }

    /**
     * All components that should be loaded, with there renderfunction
     */
  }, {
    key: "components",
    get: function get() {
      var _this11 = this;
      var componentDefinitionToRender = this.configuration.filter(function (config) {
        //there must be a state present in order for the component to be rendered
        if (!_this11.state.has(config.name)) {
          return false;
        }
        //the component must be contained in the available components list in order to be rendered
        return _this11.availableComponents.find(function (component) {
          return component.type == config.name;
        });
      });
      var componentsToRender = [];
      //when a new component is added we have to make sure that for the currently open components the existing instance is reused
      //withTransaction creates a new instance if APM is active, so we would loose the state of currently open components
      componentDefinitionToRender.forEach(function (cmp) {
        var toRender = _this11._currentlyRendered.find(function (c) {
          return c.name == cmp.name;
        });
        if (!toRender) {
          toRender = {
            name: cmp.name,
            component: withTransaction(cmp.name, 'Module')(cmp.renderFunction)
          };
        }
        componentsToRender.push(toRender);
      });
      this._currentlyRendered = componentsToRender;
      return componentsToRender;
    }

    /**
     * All components that should be loaded, with there renderfunction
     */
  }, {
    key: "fullscreenComponent",
    get: function get() {
      var _this12 = this;
      var component = this.availableComponents.find(function (component) {
        var _this12$_fullscreenCo;
        return component.type == ((_this12$_fullscreenCo = _this12._fullscreenComponent) === null || _this12$_fullscreenCo === void 0 ? void 0 : _this12$_fullscreenCo.key);
      });
      var cmp = this.configuration.find(function (config) {
        return (component === null || component === void 0 ? void 0 : component.type) == config.name;
      });
      if (!cmp || !component || !this._fullscreenComponent) throw new DivaError("No component with the specified settings found", {
        code: 'CORE_0005',
        custom: {
          key: this._fullscreenComponent.key
        }
      });
      return {
        name: cmp.name,
        component: withTransaction(this._fullscreenComponent.key, 'Module')(cmp.renderFunction),
        state: this._fullscreenComponent
      };
    }
  }, {
    key: "isFullscreenComponentDefined",
    get: function get() {
      return !!this._fullscreenComponent;
    }
  }, {
    key: "isAbsoluteFullscreenComponent",
    get: function get() {
      var _this$_fullscreenComp;
      return !!((_this$_fullscreenComp = this._fullscreenComponent) !== null && _this$_fullscreenComp !== void 0 && _this$_fullscreenComp.absoluteFullscreen) || this._isAbsoluteComponent;
    }

    /**
     * A list of all component types that are currently available, based on the configuration and user permissions
     */
  }, {
    key: "availableComponentList",
    get: function get() {
      return this.availableComponents.map(function (c) {
        return c.type;
      });
    }

    /**
     * The available buttons for the navigationbar, based on the configuration an user permissions
     */
  }, {
    key: "availableButtons",
    get: function get() {
      var _this$root$configurat,
        _this13 = this;
      return (_this$root$configurat = this.root.configurationStore.navigation) === null || _this$root$configurat === void 0 ? void 0 : _this$root$configurat.buttons.filter(function (button) {
        //if component is public it can be displayed
        if (button.isPublic) {
          return true;
        }
        //if the user is not logged in the component must be public
        if (!_this13.root.dataStore.user) {
          return false;
        }

        //if the button is opening a component, the component must be availalbe
        if (button.action.type && !_this13.availableComponentList.includes(button.action.type)) {
          return false;
        }

        //if there is a permission specified, the user must have it
        return button.permission ? _this13.root.dataStore.userHasPermission(button.permission) : true;
      });
    }

    /**
     * The material-ui theme based on the ccurrent configuration
     */
  }, {
    key: "materialUiTheme",
    get: function get() {
      var theme = this.root.configurationStore.theme;
      return createTheme(theme, this.getLang(this.root.language));
    }

    /**
     * Get the dimensions of the containing div (not the screen)
     */
  }, {
    key: "containerDimensions",
    get: function get() {
      var dimensions = this._dimensions || {
        isMobile: false,
        isPortrait: false,
        isTablet: false,
        width: 0,
        height: 0
      };
      if (this.isAbsoluteFullscreenComponent) {
        dimensions = calculateDimensions(window.innerWidth, window.innerHeight);
      }
      LOG$9.debug("Detected dimensions: ".concat(JSON.stringify(dimensions, null, 2), " "));
      return dimensions;
    }

    /**
     * Reset the state of the page, i.e. on organization data change
     * Remove all cached component states and reopen the current component
     */
  }, {
    key: "resetState",
    value: function resetState() {
      LOG$9.debug('Reset page state');
      var prevType = this.visible;
      var prevState = this.state.get(this.visible || '');
      this.root.dataStore.clearSessionGuids();
      DivaUtils.createNewSessionId();
      this.root.configurationStore.resetConfigurationCache();
      this.root.changeLoginMode('offline');
      this.state = new Map();
      this._breadcrumbs = [];
      if (prevType) {
        this.openComponent({
          type: prevType,
          parameters: prevState === null || prevState === void 0 ? void 0 : prevState.parameters,
          internal: prevState === null || prevState === void 0 ? void 0 : prevState.internal
        });
      } else if (this._restrictedComponent) {
        var restricted = this._restrictedComponent;
        this._restrictedComponent = undefined;
        this.openComponent(restricted);
      } else if (this.root.configurationStore.defaultComponent) {
        this.openComponent(this.root.configurationStore.defaultComponent);
      }
    }

    /**
     * Sets the theme as css variables
     */
  }, {
    key: "updateCssThemeVariables",
    value: function updateCssThemeVariables$1() {
      if (!this.ref) {
        return;
      }
      var theme = this.root.configurationStore.theme;
      updateCssThemeVariables(this.ref, theme);
    }

    /**
     * Updates the component state if the user is logged out.
     * Deletes states and changes the currently visible component if it is not public
     */
  }, {
    key: "updateStateAfterLogout",
    value: function updateStateAfterLogout() {
      var _this14 = this;
      var _iterator3 = _createForOfIteratorHelper(this.state.entries()),
        _step3;
      try {
        var _loop = function _loop() {
          var _step3$value = _slicedToArray(_step3.value, 2),
            type = _step3$value[0],
            component = _step3$value[1];
          var config = _this14.root.configurationStore.components.find(function (c) {
            return c.type == type;
          });
          if (!(config !== null && config !== void 0 && config.isPublic)) {
            _this14.state["delete"](type);
            if (_this14.visible == type) {
              _this14.visible = undefined;
              _this14._restrictedComponent = {
                type: type,
                parameters: component.parameters,
                internal: component.internal
              };
              _this14.root.authorizationStore.showLogin();
            }
          }
        };
        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
          _loop();
        }
      } catch (err) {
        _iterator3.e(err);
      } finally {
        _iterator3.f();
      }
    }
  }, {
    key: "resoveUrl",
    value: function resoveUrl(url) {
      var _this$root$authorizat;
      return url.replace('${zToken}', (_this$root$authorizat = this.root.authorizationStore.zToken) !== null && _this$root$authorizat !== void 0 ? _this$root$authorizat : '').replace('${organizationId}', this.root.dataStore.organizationId);
    }

    /**
     * Opens a component or an external url in a new tab
     *
     * @param action the action settings
     * @param baseUrl optional the base url for a component
     */
  }, {
    key: "openInNewTab",
    value: function openInNewTab(action, baseUrl) {
      var link;
      if (action.url) {
        link = this.resoveUrl(action.url);
      } else {
        var _this$root$dataStore$8;
        var _ref5 = action,
          parameters = _ref5.parameters;
        var url = new URL(baseUrl);
        var params = url.searchParams;
        Object.entries(parameters || {}).forEach(function (param) {
          return param[1] ? params.append(param[0], param[1]) : false;
        });
        if (this.root.language) {
          params.append('lang', this.root.language);
        }
        if ((_this$root$dataStore$8 = this.root.dataStore.organization) !== null && _this$root$dataStore$8 !== void 0 && _this$root$dataStore$8._id) {
          params.append('organizationId', this.root.dataStore.organization._id);
        }
        link = url.href;
      }
      var newWindow = window.open(link, '_blank');
      if (!newWindow || newWindow.closed || typeof newWindow.closed == 'undefined') {
        this.openModal({
          title: this.root.t('popupwarning.title'),
          accept: true,
          content: /*#__PURE__*/jsxs(Fragment, {
            children: [/*#__PURE__*/jsx(Typography, {
              children: this.root.t('popupwarning.paragraph1')
            }), /*#__PURE__*/jsxs(Typography, {
              children: [this.root.t('popupwarning.paragraph2'), /*#__PURE__*/jsx("br", {}), /*#__PURE__*/jsx("a", {
                href: link,
                target: "_blank",
                children: link
              })]
            })]
          })
        });
      }
      return [link, newWindow];
    }

    /**
     * Gets the material-ui language object
     *
     * @param lang the language string
     */
  }, {
    key: "getLang",
    value: function getLang(lang) {
      switch (lang) {
        case 'de':
          return deDE;
        case 'fr':
          return frFR;
        case 'it':
          return itIT;
        default:
          return enUS;
      }
    }

    /**
     * Callback for the resizeObserver
     * @param entries all registered entries
     */
  }, {
    key: "onResize",
    value: function onResize(width, height) {
      if (/iPhone|iPad|iPod/i.test(navigator.userAgent)) {
        this.ref.style.height = "".concat(width, " px");
      }
      this._dimensions = calculateDimensions(width, height);
    }
  }, {
    key: "setGlobalClass",
    value: function setGlobalClass() {
      var _this$currentComponen;
      var componentType = (_this$currentComponen = this.currentComponent) === null || _this$currentComponen === void 0 ? void 0 : _this$currentComponen.type;
      if (componentType) {
        var _element$, _element$3;
        var classname = 'diva-component-' + componentType;
        var element = document.getElementsByTagName('html');
        var toDelete = [];
        (_element$ = element[0]) === null || _element$ === void 0 || _element$.classList.forEach(function (classname) {
          if (classname.startsWith('diva-component-')) {
            toDelete.push(classname);
          }
        });
        toDelete.map(function (classname) {
          var _element$2;
          return (_element$2 = element[0]) === null || _element$2 === void 0 ? void 0 : _element$2.classList.remove(classname);
        });
        (_element$3 = element[0]) === null || _element$3 === void 0 || _element$3.classList.add(classname);
      }
    }
  }]);
}();
function getLocalStorageToggle(key) {
  return window.localStorage.getItem(key) !== null ? window.localStorage.getItem(key) == '1' : undefined;
}

var LOG$8 = getLogger('Framework', 'LoadingAndErrorStore');
var _default = /*#__PURE__*/function () {
  function _default(root, spinnerClass) {
    var _this = this;
    _classCallCheck(this, _default);
    this.root = root;
    _defineProperty(this, "loading", new Map());
    _defineProperty(this, "spinnerClass", undefined);
    _defineProperty(this, "cssFile", undefined);
    _defineProperty(this, "_errorMsg", undefined);
    _defineProperty(this, "span", void 0);
    _defineProperty(this, "_divaErrorCode", undefined);
    _defineProperty(this, "_fallbackModule", undefined);
    _defineProperty(this, "_userFriendlyErrorMsg", undefined);
    _defineProperty(this, "_validOrgId", undefined);
    _defineProperty(this, "_showLogout", false);
    _defineProperty(this, "_detailErrorMsg", undefined);
    this.spinnerClass = spinnerClass;
    makeAutoObservable(this, {
      span: false,
      setCustomLoader: action
    });
    autorun(function () {
      if (root.configurationStore.spinner) {
        _this.setCustomLoader(root.configurationStore.spinner.className, root.configurationStore.spinner.file);
      }
    }, {
      name: 'onSpinnerChanged'
    });
    autorun(function () {
      if (_this.isLoading) {
        _this.span = DivaUtils.startSpanOfApmAndReturn('Loading');
      } else if (_this.span) {
        _this.span.end();
      }
    }, {
      name: 'onLoading'
    });
  }
  return _createClass(_default, [{
    key: "setCustomLoader",
    value: function setCustomLoader(spinnerClass, cssFile) {
      this.spinnerClass = spinnerClass;
      this.cssFile = cssFile;
    }
  }, {
    key: "showLogout",
    get: function get() {
      return this._showLogout;
    }
  }, {
    key: "errorMsg",
    get: function get() {
      return this._errorMsg;
    }
  }, {
    key: "detailErrorMsg",
    get: function get() {
      return this._detailErrorMsg;
    }
  }, {
    key: "divaErrorCode",
    get: function get() {
      return this._divaErrorCode;
    }
  }, {
    key: "fallbackModule",
    get: function get() {
      return this._fallbackModule;
    }
  }, {
    key: "userFriendlyErrorMsg",
    get: function get() {
      return this._userFriendlyErrorMsg;
    }
  }, {
    key: "validOrgId",
    get: function get() {
      return this._validOrgId;
    }
  }, {
    key: "customLoader",
    get: function get() {
      return {
        spinnerClass: this.spinnerClass,
        cssFile: this.cssFile
      };
    }
  }, {
    key: "isLoading",
    get: function get() {
      return this.loading.size != 0;
    }
  }, {
    key: "error",
    get: function get() {
      return this._errorMsg;
    }
  }, {
    key: "setError",
    value: function setError(error, code, showLogout) {
      var _this$root$configurat, _this$root$configurat2;
      if (error == undefined) {
        this._errorMsg = undefined;
      } else if (typeof error == 'string') {
        this._errorMsg = error;
        LOG$8.error(new DivaError(error));
      } else if (error.name == 'CORE_0005') {
        LOG$8.error(error);
        this._errorMsg = this.root.t('core.error.page_not_found', {
          defaultValue: 'Die Seite existiert nicht oder Sie haben nicht die benötigten Berechtigungen. Bei Fragen wenden Sie sich bitte an den Support.'
        });
        var conf = this.root.configurationStore.components;
        console.log(conf);
      } else if (error.name == 'CORE_0002') {
        LOG$8.error(error);
        this._errorMsg = this.root.t('core.error.resource_not_found', {
          defaultValue: 'Eine oder mehrere der benötigten Resource existiert nicht oder konnte nicht gefunden werden. Bei Fragen wenden Sie sich bitte an den Support.'
        });
      } else {
        LOG$8.error(error);
        this._errorMsg = error.message;
      }
      if (this._errorMsg) {
        var apmTransactionId = DivaUtils.getCurrentTraceId();
        this._errorMsg = this._errorMsg + "[".concat(DivaUtils.formatDate(new Date(), true, undefined, true), "]") + "".concat(apmTransactionId ? '[APM:' + apmTransactionId + '] ' : '');
      }
      this._divaErrorCode = code;
      var defaultModule = (_this$root$configurat = (_this$root$configurat2 = this.root.configurationStore.defaultComponent) === null || _this$root$configurat2 === void 0 ? void 0 : _this$root$configurat2.type) !== null && _this$root$configurat !== void 0 ? _this$root$configurat : 'SELLER';
      var route = this.root.configurationStore.components.find(function (c) {
        return c.type == defaultModule;
      });
      if (error instanceof DivaError) {
        var _error$custom5;
        if (code == 'CORE_0002') {
          var _error$custom;
          if ((_error$custom = error.custom) !== null && _error$custom !== void 0 && _error$custom.requestedOrganizationId) {
            var _error$custom2, _error$custom3, _error$custom4;
            this._userFriendlyErrorMsg = this.root.t('portal.error.organization.notfoundnopermissions');
            this._detailErrorMsg = 'OrganizationId: ' + ((_error$custom2 = error.custom) === null || _error$custom2 === void 0 ? void 0 : _error$custom2.requestedOrganizationId);
            this._validOrgId = (_error$custom3 = error.custom) === null || _error$custom3 === void 0 ? void 0 : _error$custom3.organizationId;
            this._fallbackModule = {
              route: route === null || route === void 0 ? void 0 : route.route,
              organizationId: (_error$custom4 = error.custom) === null || _error$custom4 === void 0 ? void 0 : _error$custom4.organizationId,
              text: this.root.t('portal.error.organization.change')
            };
            this._showLogout = true;
          }
          this._showLogout = showLogout;
        } else if (code == 'CORE_0005') {
          this._userFriendlyErrorMsg = this.root.t('portal.error.module.notfoundnopermission');
          this._fallbackModule = {
            route: route === null || route === void 0 ? void 0 : route.route
          };
          this._showLogout = true;
        } else if (((_error$custom5 = error.custom) === null || _error$custom5 === void 0 ? void 0 : _error$custom5.httpStatus) == 403) {
          this._userFriendlyErrorMsg = this.root.t('portal.error.module.loginfailed');
          this._fallbackModule = {
            route: '/login',
            text: this.root.t('portal.error.invalidlogin.tologin')
          };
        }
      } else if (code == 'CORE_0005') {
        this._userFriendlyErrorMsg = this.root.t('portal.error.module.notfoundnopermission');
        this._fallbackModule = {
          route: route === null || route === void 0 ? void 0 : route.route
        };
        this._showLogout = true;
      }
    }
  }, {
    key: "hideContent",
    get: function get() {
      return this.isLoading && Array.from(this.loading.values()).some(function (hidden) {
        return hidden == true;
      }) || this.error;
    }
  }, {
    key: "toggleLoading",
    value: function toggleLoading(id, hidden, toggle) {
      if (this.loading.has(id) && toggle !== true) {
        this.loading["delete"](id);
        LOG$8.debug("End loading: ".concat(id, " [").concat(Array.from(this.loading.keys()), "]"));
      } else if (!this.loading.has(id) && toggle !== false) {
        LOG$8.debug("Start loading: ".concat(id));
        this.loading.set(id, hidden == undefined ? false : hidden);
      }
    }
  }]);
}();

var LOG$7 = getLogger('Framework', 'BrowserStateStore');
var BANNER_STATE_LOCALSTORAGE_KEY = 'diva-banner-state';
var NTOKEN_LOCALSTORAGE_KEY = 'diva-ntoken';
var LANGUAGE_LOCALSTORAGE_KEY = 'diva-language';
var ORGANIZATION_LOCALSTORAGE_KEY = 'diva-organization';
var LOGIN_METHOD_LOCALSTORAGE_KEY = 'diva-login-method';
var BrowserStateStore = /*#__PURE__*/function () {
  function BrowserStateStore(root) {
    var _this = this;
    _classCallCheck(this, BrowserStateStore);
    this.root = root;
    _defineProperty(this, "_url", '');
    makeObservable(this, {
      _url: observable,
      isUrlSyncEnabled: computed,
      setUrl: action,
      applyUrlStateChanges: action
    });
    window.addEventListener('popstate', function () {
      if (_this._url != location.href && _this.isUrlSyncEnabled) {
        _this.applyUrlStateChanges();
      }
    });
    window.addEventListener('storage', function (event) {
      if (event.key == NTOKEN_LOCALSTORAGE_KEY) _this.root.authorizationStore.tokenChanged();
    });
    this.enableUrlSyncronization();
  }

  /**
   * get the current state represented by the url
   * @returns the current state represented by the url
   */
  return _createClass(BrowserStateStore, [{
    key: "loadUrlState",
    value: (function () {
      var _loadUrlState = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var _route, _searchParams$get;
        var searchParams, currentUrl, state, route;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              searchParams = new URLSearchParams(window.location.search);
              currentUrl = new URL(window.location.href);
              state = {};
              route = currentUrl.pathname;
              route = (_route = route) !== null && _route !== void 0 && _route.endsWith('/') ? route.slice(0, -1) : route;
              if (route.endsWith('/login/debug')) {
                state.debugLogin = true;
                route = route.replace('/login/debug', '');
              } else if (route.endsWith('/login')) {
                route = route.replace('/login', '');
              }
              state.component = {
                parameters: {},
                route: route
              };
              state.organization = (_searchParams$get = searchParams.get('organizationId')) !== null && _searchParams$get !== void 0 ? _searchParams$get : undefined;
              searchParams["delete"]('organizationId');

              //for backwards compatibilty, if the channelId is set in the url, use that one as organization and update the url in the browser
              if (searchParams.get('channelId')) {
                state.organization = searchParams.get('channelId');
                searchParams["delete"]('channelId');
                currentUrl.searchParams.set('organizationId', state.organization);
                currentUrl.searchParams["delete"]('channelId');
              }
              state.language = searchParams.get('lang') || undefined;
              searchParams["delete"]('lang');
              state.authdata = searchParams.get('authdata') || undefined;
              searchParams["delete"]('authdata');
              searchParams.forEach(function (value, key) {
                state.component.parameters[key] = value;
              });
              state.component.internal = history.state;
              currentUrl.searchParams["delete"]('authdata');
              history.replaceState(null, '', currentUrl.href);
              return _context.abrupt("return", state);
            case 19:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function loadUrlState() {
        return _loadUrlState.apply(this, arguments);
      }
      return loadUrlState;
    }()
    /**
     * Stores the banner state into the local storage
     *
     * @param banner the banner state to be stored
     */
    )
  }, {
    key: "setBannerState",
    value: function setBannerState(banner) {
      var _this$root$dataStore$;
      var userid = (_this$root$dataStore$ = this.root.dataStore.user) === null || _this$root$dataStore$ === void 0 ? void 0 : _this$root$dataStore$._id;
      var localstoragevalue = {
        valuekey: banner === null || banner === void 0 ? void 0 : banner.key,
        userid: userid,
        expireTimestamp: this.addDaysToCurrentDate(1).valueOf() //unix timestamp
      };
      var valuesArray = [];
      var value = localStorage.getItem(BANNER_STATE_LOCALSTORAGE_KEY);
      if (value) {
        valuesArray = JSON.parse(value);
        if (!this.bannerExistsInLocalStorage(valuesArray, userid, banner)) {
          valuesArray.push(localstoragevalue);
          localStorage.setItem(BANNER_STATE_LOCALSTORAGE_KEY, JSON.stringify(valuesArray));
        }
      } else {
        valuesArray.push(localstoragevalue);
        localStorage.setItem(BANNER_STATE_LOCALSTORAGE_KEY, JSON.stringify(valuesArray));
      }
    }

    /**
     * Validates the current banner state against the the local storage
     * and removes expried states from the storage
     *
     * @param banner the current banner state
     */
  }, {
    key: "validateManipulateBannerLocalStorage",
    value: function validateManipulateBannerLocalStorage(banner) {
      var _this$root$dataStore$2;
      var userid = (_this$root$dataStore$2 = this.root.dataStore.user) === null || _this$root$dataStore$2 === void 0 ? void 0 : _this$root$dataStore$2._id;
      var value = localStorage.getItem(BANNER_STATE_LOCALSTORAGE_KEY);
      if (value && this.bannerExistsInLocalStorage(JSON.parse(value), userid, banner)) {
        var bannerViewValues = JSON.parse(value);
        var currentTimestamp = new Date().valueOf();
        var index = bannerViewValues.findIndex(function (x) {
          return x.valuekey === (banner === null || banner === void 0 ? void 0 : banner.key) && x.userid === userid && x.expireTimestamp < currentTimestamp;
        });
        if (index > -1) {
          bannerViewValues.splice(index);
          if (bannerViewValues.length < 1) {
            localStorage.removeItem(BANNER_STATE_LOCALSTORAGE_KEY);
          } else {
            localStorage.setItem(BANNER_STATE_LOCALSTORAGE_KEY, JSON.stringify(bannerViewValues));
          }
        }
      }
    }

    /**
     * Check if the current banner state is in local storage
     *
     * @param banner the current banner state
     * @returns true if the current banner state is already in storage
     */
  }, {
    key: "bannerInLocalStorage",
    value: function bannerInLocalStorage(banner) {
      var _this$root$dataStore$3;
      var value = localStorage.getItem(BANNER_STATE_LOCALSTORAGE_KEY);
      if (!value) return false;
      var valuesArray = JSON.parse(value);
      var userid = (_this$root$dataStore$3 = this.root.dataStore.user) === null || _this$root$dataStore$3 === void 0 ? void 0 : _this$root$dataStore$3._id;
      return this.bannerExistsInLocalStorage(valuesArray, userid, banner);
    }

    /**
     * Get the currently stored ntoken token
     */
  }, {
    key: "getStoredNToken",
    value: function getStoredNToken() {
      var _localStorage$getItem;
      var data = (_localStorage$getItem = localStorage.getItem(NTOKEN_LOCALSTORAGE_KEY)) === null || _localStorage$getItem === void 0 ? void 0 : _localStorage$getItem.split(';');
      var token = data === null || data === void 0 ? void 0 : data[0];
      var expire = data === null || data === void 0 ? void 0 : data[1];
      if (token && expire) {
        if (Number(expire) - 1000 * 60 * 5 > Date.now()) {
          //"expire" 5 min before actual expireDate
          return token;
        }
        //if token is expired, remove it
        this.setStoredNToken();
      }
      return undefined;
    }

    /**
     * Updates or removes ntoken in storage
     *
     * @param ntoken the new ntoken or undefined to remove it
     */
  }, {
    key: "setStoredNToken",
    value: function setStoredNToken(ntoken, expire) {
      if (ntoken && expire) {
        localStorage.setItem(NTOKEN_LOCALSTORAGE_KEY, ntoken + ';' + expire.toString());
      } else {
        localStorage.removeItem(NTOKEN_LOCALSTORAGE_KEY);
      }
    }

    /**
     * Get the currently stored organization
     */
  }, {
    key: "getStoredOrganization",
    value: function getStoredOrganization() {
      return localStorage.getItem(ORGANIZATION_LOCALSTORAGE_KEY) || undefined;
    }

    /**
     * Updates or removes organization in storage
     *
     * @param organization the new organization or undefined to remove it
     */
  }, {
    key: "setStoredOrganization",
    value: function setStoredOrganization(organization) {
      if (organization) {
        localStorage.setItem(ORGANIZATION_LOCALSTORAGE_KEY, organization);
      } else {
        localStorage.removeItem(ORGANIZATION_LOCALSTORAGE_KEY);
      }
    }

    /**
     * Get the currently stored login method
     */
  }, {
    key: "getStoredLoginMethod",
    value: function getStoredLoginMethod() {
      return localStorage.getItem(LOGIN_METHOD_LOCALSTORAGE_KEY) || undefined;
    }

    /**
     * Updates or removes loginMethod in storage
     *
     * @param loginMethod the new loginMethod or undefined to remove it
     */
  }, {
    key: "setStoredLoginMethod",
    value: function setStoredLoginMethod(loginMethod) {
      if (loginMethod) {
        localStorage.setItem(LOGIN_METHOD_LOCALSTORAGE_KEY, loginMethod);
      } else {
        localStorage.removeItem(LOGIN_METHOD_LOCALSTORAGE_KEY);
      }
    }

    /**
     * Get the currently stored language
     */
  }, {
    key: "getStoredLanguage",
    value: function getStoredLanguage() {
      return localStorage.getItem(LANGUAGE_LOCALSTORAGE_KEY) || undefined;
    }

    /**
     * Updates or removes language in storage
     *
     * @param language the new language or undefined to remove it
     */
  }, {
    key: "setStoredLanguage",
    value: function setStoredLanguage(language) {
      if (language) {
        localStorage.setItem(LANGUAGE_LOCALSTORAGE_KEY, language);
      } else {
        localStorage.removeItem(LANGUAGE_LOCALSTORAGE_KEY);
      }
    }

    /**
     * Applies the current state represented by the url to the application
     */
  }, {
    key: "applyUrlStateChanges",
    value: (function () {
      var _applyUrlStateChanges = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
        var state;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              this.setUrl(location.href);
              _context2.next = 3;
              return this.loadUrlState();
            case 3:
              state = _context2.sent;
              if (state.language) {
                this.root.changeLanguage(state.language);
              }
              if (state.organization) {
                this.root.dataStore.updateOrganization(state.organization);
              }
              if (state.component) {
                this.root.contentStore.openComponent(state.component);
              }
            case 7:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function applyUrlStateChanges() {
        return _applyUrlStateChanges.apply(this, arguments);
      }
      return applyUrlStateChanges;
    }()
    /**
     * Updates the url when ever the state of the applicaton changes
     */
    )
  }, {
    key: "enableUrlSyncronization",
    value: function enableUrlSyncronization() {
      var _this2 = this;
      autorun(function () {
        var _this2$root$authoriza;
        if (!_this2.isUrlSyncEnabled) {
          return;
        }
        var url;
        if (((_this2$root$authoriza = _this2.root.authorizationStore.state) === null || _this2$root$authoriza === void 0 ? void 0 : _this2$root$authoriza.type) == 'LOGIN') {
          url = new URL("".concat(location.origin, "/login"));
        } else {
          var _componentState$path;
          var componentConfig = _this2.root.contentStore.currentComponent;
          if (!componentConfig) {
            LOG$7.debug('No current component found, while updating url, do nothing');
            return;
          }
          var componentState = _this2.root.contentStore.getState(componentConfig === null || componentConfig === void 0 ? void 0 : componentConfig.type);
          url = new URL("".concat(location.origin).concat((_componentState$path = componentState.path) !== null && _componentState$path !== void 0 ? _componentState$path : componentConfig.route));
          url.searchParams.append('lang', _this2.root.language);
          url.searchParams.append('organizationId', _this2.root.dataStore.organizationId);
          Object.entries(componentState.parameters || {}).forEach(function (_ref) {
            var _ref2 = _slicedToArray(_ref, 2),
              key = _ref2[0],
              value = _ref2[1];
            return url.searchParams.append(key, value);
          });
        }
        if (_this2._url != url.href) {
          _this2.setUrl(url.href);
          history.pushState(null, '', url.href);
        }
      }, {
        name: 'onUrlChange'
      });
    }

    /**
     * Returns true if the url should be syncronized
     */
  }, {
    key: "isUrlSyncEnabled",
    get: function get() {
      return !!this.root.configurationStore.enableRouting;
    }

    /**
     * action to set the internal copy of the url state
     */
  }, {
    key: "setUrl",
    value: function setUrl(url) {
      this._url = url;
    }

    /**
     * Check if the localstorage contains a banner state for the current user
     *
     * @param localstoragevalue the full localstorage data for banners
     * @param userid the ID current user
     * @param banner the current bannter state
     * @returns true if the banner state already exists in localstorage
     */
  }, {
    key: "bannerExistsInLocalStorage",
    value: function bannerExistsInLocalStorage(localstoragevalue, userid, banner) {
      return !!localstoragevalue.find(function (x) {
        return x.valuekey === (banner === null || banner === void 0 ? void 0 : banner.key) && x.userid == userid;
      });
    }

    /**
     * Adds a number of days to the current timestamp
     *
     * @param days a number of days
     * @returns the timestamp
     */
  }, {
    key: "addDaysToCurrentDate",
    value: function addDaysToCurrentDate(days) {
      var date = new Date();
      return date.setDate(date.getDate() + days);
    }
  }]);
}();

function ownKeys$9(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$9(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$9(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$9(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$6 = getLogger('Framework', 'AuthorizationStore');
var AuthorizationStore = /*#__PURE__*/function () {
  function AuthorizationStore(root) {
    _classCallCheck(this, AuthorizationStore);
    this.root = root;
    _defineProperty(this, "_state", undefined);
    _defineProperty(this, "_nToken", undefined);
    _defineProperty(this, "_zToken", undefined);
    _defineProperty(this, "_zExpireBy", undefined);
    _defineProperty(this, "_loginState", void 0);
    _defineProperty(this, "_timeout", undefined);
    makeAutoObservable(this, {
      autorize: flow,
      tokenChanged: flow,
      login: flow,
      logout: flow
    });
  }
  return _createClass(AuthorizationStore, [{
    key: "zToken",
    get: function get() {
      if (this._zToken && this._zExpireBy) {
        if (Number(this._zExpireBy) > Date.now()) {
          return this._zToken;
        } else {
          this._zToken = undefined;
          this._zExpireBy = undefined;
        }
      }
      return undefined;
    },
    set: function set(zToken) {
      this._zToken = zToken;
    }
  }, {
    key: "nToken",
    get: function get() {
      return this._nToken;
    }
  }, {
    key: "loginState",
    get: function get() {
      return this._loginState;
    }
  }, {
    key: "showLogin",
    value: function showLogin(debug, error, organizationId, invitationId, email) {
      if (!this._state && !this.root.authorizationStore.nToken && this.root.configurationStore.hasAuthentication) {
        var _this$root$configurat;
        var storedLoginMethod = this.root.browserStateStore.getStoredLoginMethod();
        var loginMethods = (_this$root$configurat = this.root.configurationStore.authentication.loginMethods) !== null && _this$root$configurat !== void 0 ? _this$root$configurat : {};
        //if only one loginmethod is configured and it its an idp-login and this flag is off,
        //we skip the login window and go straight to the idp login
        var allwaysShowLogin = this.root.configurationStore.authentication.allwaysShowLogin;
        if (debug) {
          this._state = {
            type: 'LOGIN',
            loginMethods: _objectSpread$9(_objectSpread$9({}, loginMethods), {}, {
              standard: true
            }),
            organizationId: organizationId
          };
        } else if (error) {
          this._state = {
            type: 'LOGIN',
            error: 'auth.error.oauth'
          };
          this.root.browserStateStore.setStoredLoginMethod();
        } else if (storedLoginMethod == 'google' || !allwaysShowLogin && loginMethods !== null && loginMethods !== void 0 && loginMethods.google && !loginMethods.microsoft && !loginMethods.generic && !loginMethods.standard) {
          this.openOAuthLogin('google', organizationId);
        } else if (storedLoginMethod == 'microsoft' || !allwaysShowLogin && loginMethods !== null && loginMethods !== void 0 && loginMethods.microsoft && !loginMethods.google && !loginMethods.generic && !loginMethods.standard) {
          this.openOAuthLogin('microsoft', organizationId);
        } else if (storedLoginMethod == 'generic' || !allwaysShowLogin && loginMethods !== null && loginMethods !== void 0 && loginMethods.generic && !loginMethods.google && !loginMethods.microsoft && !loginMethods.standard) {
          this.openOAuthLogin('genericOpenId', organizationId);
        } else {
          this._state = {
            type: 'LOGIN',
            organizationId: organizationId,
            loginMethods: loginMethods,
            invitationId: invitationId,
            email: email
          };
        }
      }
    }
  }, {
    key: "showRequestNewPassword",
    value: function showRequestNewPassword(email) {
      this._state = {
        type: 'REQUEST_NEW_PASSWORD',
        email: email
      };
    }
  }, {
    key: "showChangePassword",
    value: function showChangePassword(token) {
      this._state = {
        type: 'CHANGE_PASSWORD',
        token: token
      };
    }
  }, {
    key: "showInvitationExpired",
    value: function showInvitationExpired(id) {
      this._state = {
        type: 'INVITATION_EXPIRED'
      };
    }
  }, {
    key: "showWelcomeScreen",
    value: function () {
      var _showWelcomeScreen = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(isNewUser, invitationId, invitationOrgId) {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              this._state = {
                type: 'WELCOME',
                isNewUser: isNewUser,
                invitationId: invitationId,
                invitationOrgId: invitationOrgId
              };
            case 1:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function showWelcomeScreen(_x, _x2, _x3) {
        return _showWelcomeScreen.apply(this, arguments);
      }
      return showWelcomeScreen;
    }()
  }, {
    key: "showRegister",
    value: function showRegister(invitationId, email, useOtp) {
      this._state = {
        type: 'REGISTER',
        invitationId: invitationId,
        loginMethods: this.root.configurationStore.authentication.loginMethods,
        email: email,
        useOtp: useOtp
      };
    }
  }, {
    key: "close",
    value: function close() {
      this._state = undefined;
    }
  }, {
    key: "state",
    get: function get() {
      return this._state;
    }
  }, {
    key: "showExpiredLoginModal",
    value: function showExpiredLoginModal() {
      var _this = this;
      this.root.contentStore.openModal({
        title: this.root.t('authorization.session.expired.title'),
        text: this.root.t('authorization.session.expired.text'),
        accept: true,
        callback: function callback() {
          return _this.logout(true, true);
        }
      });
    }
  }, {
    key: "openOAuthLogin",
    value: function openOAuthLogin(provider, organizationId, invitationId) {
      var url = "".concat(this.root.configurationStore.apiConfig.authService, "/openid/").concat(provider, "?callbackUri=").concat(encodeURIComponent(this.getRedirectUrl(organizationId, provider).toString()));
      if (organizationId) {
        url = url + "&organizationId=".concat(organizationId);
      }
      if (invitationId) {
        url = url + "&invitationId=".concat(invitationId);
      }
      this.root.contentStore.openComponent({
        url: url
      });
    }
  }, {
    key: "tokenChanged",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function tokenChanged() {
      var organizationId;
      return _regeneratorRuntime.wrap(function tokenChanged$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            if (this.root.browserStateStore.getStoredNToken()) {
              _context2.next = 6;
              break;
            }
            LOG$6.debug('NToken removed');
            _context2.next = 4;
            return this.root.authorizationStore.logout();
          case 4:
            _context2.next = 15;
            break;
          case 6:
            LOG$6.debug('NToken change detected, login');
            _context2.next = 9;
            return this.root.authorizationStore.autorize(this.root.dataStore.organizationId, this.root.browserStateStore.getStoredNToken());
          case 9:
            organizationId = _context2.sent;
            _context2.next = 12;
            return this.root.dataStore.updateOrganizationInternal(organizationId);
          case 12:
            _context2.next = 14;
            return this.root.configurationStore.updateConfiguration();
          case 14:
            this.root.initalizeView();
          case 15:
          case "end":
            return _context2.stop();
        }
      }, tokenChanged, this);
    })
  }, {
    key: "autorize",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function autorize(organizationId, nToken) {
      var _this$state, _this$state2;
      var _this$state3, authorizationData, _e$custom;
      return _regeneratorRuntime.wrap(function autorize$(_context3) {
        while (1) switch (_context3.prev = _context3.next) {
          case 0:
            this.root.loadingAndErrorStore.toggleLoading('autorize', false, true);
            if ((_this$state = this.state) !== null && _this$state !== void 0 && _this$state.invitationId && (_this$state2 = this.state) !== null && _this$state2 !== void 0 && _this$state2.invitationOrgId) {
              organizationId = (_this$state3 = this.state) === null || _this$state3 === void 0 ? void 0 : _this$state3.invitationOrgId;
            }
            _context3.prev = 2;
            _context3.next = 5;
            return this.root.authorizationHandler.authorize({
              organizationId: organizationId,
              nToken: nToken !== null && nToken !== void 0 ? nToken : this._nToken,
              validParents: this.root.configurationStore.organizations.includes('*') ? undefined : this.root.configurationStore.organizations,
              validOrganizationTypes: this.root.configurationStore.allowedOrganizationTypes,
              excludeOrganizations: this.root.configurationStore.excludedOrganizations
            });
          case 5:
            authorizationData = _context3.sent;
            this._nToken = nToken !== null && nToken !== void 0 ? nToken : this._nToken;
            _context3.next = 9;
            return this.updateAuthorizationData(authorizationData.zToken, authorizationData.zExpireBy, authorizationData.type, authorizationData.organizationId, authorizationData.parentOrganizations, authorizationData.permissions, authorizationData.user);
          case 9:
            return _context3.abrupt("return", authorizationData.organizationId);
          case 12:
            _context3.prev = 12;
            _context3.t0 = _context3["catch"](2);
            if (!(_context3.t0 instanceof DivaError && _context3.t0.name == 'AUTH_0007' && this.root.browserStateStore.getStoredOrganization() && organizationId == this.root.browserStateStore.getStoredOrganization())) {
              _context3.next = 21;
              break;
            }
            LOG$6.log('The stored organization is no longer valid, fallback to default organization');
            //for anonymous users, we fallback to the 'default' organization for ohter users we let the backend determine the right organization
            _context3.next = 18;
            return this.autorize(nToken ? undefined : this.root.configurationStore.organizations[0], nToken);
          case 18:
            return _context3.abrupt("return", _context3.sent);
          case 21:
            if (!(_context3.t0 instanceof DivaError && _context3.t0.name == 'CORE_0003' && !((_e$custom = _context3.t0.custom) !== null && _e$custom !== void 0 && _e$custom.requestedOrganizationId))) {
              _context3.next = 26;
              break;
            }
            LOG$6.log('Authentication expired or invalid, logging out.');
            _context3.next = 25;
            return this.logout(true, true, organizationId);
          case 25:
            return _context3.abrupt("return", _context3.sent);
          case 26:
            throw _context3.t0;
          case 27:
            _context3.prev = 27;
            this.root.loadingAndErrorStore.toggleLoading('autorize', false, false);
            return _context3.finish(27);
          case 30:
          case "end":
            return _context3.stop();
        }
      }, autorize, this, [[2, 12, 27, 30]]);
    })
  }, {
    key: "register",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function register(email, password, name, familyName, invitationId, otp) {
      var authorizationData;
      return _regeneratorRuntime.wrap(function register$(_context4) {
        while (1) switch (_context4.prev = _context4.next) {
          case 0:
            this.root.loadingAndErrorStore.toggleLoading('register');
            _context4.prev = 1;
            _context4.next = 4;
            return this.root.authorizationHandler.register({
              email: email,
              password: password,
              name: name,
              familyName: familyName,
              invitationId: invitationId,
              validParents: this.root.configurationStore.organizations.includes('*') ? undefined : this.root.configurationStore.organizations,
              validOrganizationTypes: this.root.configurationStore.allowedOrganizationTypes,
              excludeOrganizations: this.root.configurationStore.excludedOrganizations,
              otp: otp
            });
          case 4:
            authorizationData = _context4.sent;
            this.root.browserStateStore.setStoredNToken(authorizationData.nToken, authorizationData.nExpireBy);
            this._nToken = authorizationData.nToken;
            _context4.next = 9;
            return this.updateAuthorizationData(authorizationData.zToken, authorizationData.zExpireBy, authorizationData.type, authorizationData.organizationId, authorizationData.parentOrganizations, authorizationData.permissions, authorizationData.user);
          case 9:
            this.root.initalizeView();
            _context4.next = 15;
            break;
          case 12:
            _context4.prev = 12;
            _context4.t0 = _context4["catch"](1);
            throw _context4.t0;
          case 15:
            _context4.prev = 15;
            this.root.loadingAndErrorStore.toggleLoading('register');
            return _context4.finish(15);
          case 18:
          case "end":
            return _context4.stop();
        }
      }, register, this, [[1, 12, 15, 18]]);
    })
  }, {
    key: "login",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function login(email, password, loginSimple, organizationId, invitationId, otp) {
      var authorizationData;
      return _regeneratorRuntime.wrap(function login$(_context5) {
        while (1) switch (_context5.prev = _context5.next) {
          case 0:
            this.root.loadingAndErrorStore.toggleLoading('login');
            _context5.prev = 1;
            _context5.next = 4;
            return this.root.authorizationHandler.login({
              organizationId: organizationId,
              email: email,
              password: password,
              simple: loginSimple,
              validParents: this.root.configurationStore.organizations.includes('*') ? undefined : this.root.configurationStore.organizations,
              validOrganizationTypes: this.root.configurationStore.allowedOrganizationTypes,
              excludeOrganizations: this.root.configurationStore.excludedOrganizations,
              invitationId: invitationId,
              otp: otp
            });
          case 4:
            authorizationData = _context5.sent;
            this.root.browserStateStore.setStoredNToken(authorizationData.nToken, authorizationData.nExpireBy);
            this._nToken = authorizationData.nToken;
            _context5.next = 9;
            return this.updateAuthorizationData(authorizationData.zToken, authorizationData.zExpireBy, authorizationData.type, authorizationData.organizationId, authorizationData.parentOrganizations, authorizationData.permissions, authorizationData.user);
          case 9:
            this.root.initalizeView();
            _context5.next = 20;
            break;
          case 12:
            _context5.prev = 12;
            _context5.t0 = _context5["catch"](1);
            if (!((_context5.t0 === null || _context5.t0 === void 0 ? void 0 : _context5.t0.message) == 'No valid organization for this user' && this.root.browserStateStore.getStoredOrganization() && organizationId == this.root.browserStateStore.getStoredOrganization())) {
              _context5.next = 19;
              break;
            }
            LOG$6.log('The stored organization is no longer valid, fallback to default organization');
            _context5.next = 18;
            return this.login(email, password, loginSimple, undefined);
          case 18:
            return _context5.abrupt("return", _context5.sent);
          case 19:
            throw _context5.t0;
          case 20:
            _context5.prev = 20;
            this.root.loadingAndErrorStore.toggleLoading('login');
            return _context5.finish(20);
          case 23:
          case "end":
            return _context5.stop();
        }
      }, login, this, [[1, 12, 20, 23]]);
    })
  }, {
    key: "updateAuthorizationData",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function updateAuthorizationData(zToken, zExpireBy, type, organizationId, parentOrganizations, permissions, user) {
      var _this2 = this;
      var userExists, refreshTokenIn;
      return _regeneratorRuntime.wrap(function updateAuthorizationData$(_context6) {
        while (1) switch (_context6.prev = _context6.next) {
          case 0:
            userExists = this.root.dataStore.user;
            this._zExpireBy = zExpireBy;
            this.zToken = zToken;
            this._loginState = type;
            this.root.dataStore.user = user;
            this.root.dataStore.permissions = permissions !== null && permissions !== void 0 ? permissions : [];
            this.root.dataStore.parentOrganizations = parentOrganizations !== null && parentOrganizations !== void 0 ? parentOrganizations : [];
            if (!(this.root.dataStore.organizationId != organizationId)) {
              _context6.next = 12;
              break;
            }
            _context6.next = 10;
            return this.root.dataStore.updateOrganizationInternal(organizationId);
          case 10:
            _context6.next = 12;
            return this.root.configurationStore.updateConfiguration();
          case 12:
            if (this._loginState == 'user') {
              this.root.browserStateStore.setStoredOrganization(organizationId);
            }

            //clear token refresh timeout
            if (this._timeout) {
              clearTimeout(this._timeout);
              this._timeout = undefined;
            }
            refreshTokenIn = zExpireBy - 1000 * 60 * 5 - Date.now(); //refresh 5 minutes before expire
            LOG$6.debug("Set token refresh interval to ".concat(refreshTokenIn, " ms. Refresh at ").concat(new Date(Date.now() + refreshTokenIn)));

            //set the timout to refresh token
            this._timeout = setTimeout(function () {
              //as long as the nToken is valid, we auto-renew the zToken
              if (_this2.root.browserStateStore.getStoredNToken()) {
                _this2.autorize(organizationId);
              } else {
                _this2.showExpiredLoginModal();
                clearTimeout(_this2._timeout);
              }
            }, refreshTokenIn);
            if (userExists) {
              //reset State only if it's not the first authorization
              this.root.contentStore.resetState();
            }
          case 18:
          case "end":
            return _context6.stop();
        }
      }, updateAuthorizationData, this);
    })
  }, {
    key: "logout",
    value: /*#__PURE__*/_regeneratorRuntime.mark(function logout(relogin, skipApiLogout, currentOrganization, skipRedirect) {
      var redirectUrl, _logout$redirect, _logout;
      return _regeneratorRuntime.wrap(function logout$(_context7) {
        while (1) switch (_context7.prev = _context7.next) {
          case 0:
            redirectUrl = relogin ? this.getRedirectUrl(currentOrganization) : location.origin;
            if (skipApiLogout) {
              _context7.next = 6;
              break;
            }
            _context7.next = 4;
            return this.root.authorizationHandler.logout({
              callbackUri: redirectUrl
            });
          case 4:
            _logout = _context7.sent;
            redirectUrl = (_logout$redirect = _logout.redirect) !== null && _logout$redirect !== void 0 ? _logout$redirect : redirectUrl;
          case 6:
            this.root.browserStateStore.setStoredNToken();
            if (!relogin) {
              this.root.browserStateStore.setStoredLoginMethod();
            }
            if (!skipRedirect) window.location.replace(redirectUrl);
          case 9:
          case "end":
            return _context7.stop();
        }
      }, logout, this);
    })
  }, {
    key: "getRedirectUrl",
    value: function getRedirectUrl(currentOrganization, provider) {
      var _componentConfig, _this$root$contentSto, _componentConfig2, _componentConfig3, _componentConfig4;
      var componentConfig = this.root.contentStore.restrictedComponent;
      if (!componentConfig) {
        componentConfig = this.root.contentStore.currentComponent;
      }
      var parameters = (_componentConfig = componentConfig) !== null && _componentConfig !== void 0 && _componentConfig.type ? (_this$root$contentSto = this.root.contentStore.getState((_componentConfig2 = componentConfig) === null || _componentConfig2 === void 0 ? void 0 : _componentConfig2.type)) === null || _this$root$contentSto === void 0 ? void 0 : _this$root$contentSto.parameters : undefined;
      if (!parameters && (_componentConfig3 = componentConfig) !== null && _componentConfig3 !== void 0 && _componentConfig3.parameters) parameters = componentConfig.parameters;
      var redirectUrl = new URL("".concat(location.origin).concat((_componentConfig4 = componentConfig) !== null && _componentConfig4 !== void 0 && _componentConfig4.route ? componentConfig.route : ''));
      redirectUrl.searchParams.append('lang', this.root.language);
      redirectUrl.searchParams.append('organizationId', currentOrganization !== null && currentOrganization !== void 0 ? currentOrganization : this.root.dataStore.organizationId);
      if (provider) redirectUrl.searchParams.append('provider', provider);
      Object.entries(parameters || {}).forEach(function (_ref) {
        var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          value = _ref2[1];
        if (value !== undefined) redirectUrl.searchParams.append(key, value);
      });
      return redirectUrl.toString();
    }
  }]);
}();

var _excluded$3 = ["kind", "type"],
  _excluded2 = ["type"];
var ApiHandler = /*#__PURE__*/function () {
  function ApiHandler(root) {
    _classCallCheck(this, ApiHandler);
    this.root = root;
  }
  return _createClass(ApiHandler, [{
    key: "adminService",
    get: function get() {
      return this.root.apiConfig.adminService;
    }
  }, {
    key: "messageService",
    get: function get() {
      return this.root.apiConfig.messageService;
    }
  }, {
    key: "authService",
    get: function get() {
      return this.root.apiConfig.authService;
    }
  }, {
    key: "catalogService",
    get: function get() {
      return this.root.apiConfig.catalogService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "organizationId",
    get: function get() {
      return this.root.organization._id;
    }
  }, {
    key: "fetchConfiguration",
    value: function () {
      var _fetchConfiguration = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
        var identifier, domain, organizationId, type, fullUrl, response;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              identifier = _ref.identifier, domain = _ref.domain, organizationId = _ref.organizationId, type = _ref.type;
              fullUrl = this.adminService;
              if (fullUrl.includes('.json')) {
                //in case the configuration is loaded from a static file
                fullUrl = fullUrl.replace('{{type}}', type);
                if (identifier) {
                  fullUrl = fullUrl.replace('{{identifier}}', identifier);
                }
                if (domain) {
                  fullUrl = fullUrl.replace('{{domain}}', domain);
                }
                if (organizationId) {
                  fullUrl = fullUrl.replace('{{organizationId}}', organizationId);
                }
              } else {
                //in case the configuration is loaded from the service
                fullUrl = "".concat(fullUrl, "/v2/views/configs/load?type=").concat(type);
                if (identifier) {
                  fullUrl = "".concat(fullUrl, "&identifier=").concat(identifier);
                }
                if (domain) {
                  fullUrl = "".concat(fullUrl, "&domain=").concat(domain);
                }
                if (organizationId) {
                  fullUrl = "".concat(fullUrl, "&organizationId=").concat(organizationId);
                }
              }
              _context.prev = 3;
              _context.next = 6;
              return this.fetch({
                url: fullUrl
              });
            case 6:
              response = _context.sent;
              if (!response.ok) {
                _context.next = 9;
                break;
              }
              return _context.abrupt("return", response.json().then(function (json) {
                return json.configParams;
              }));
            case 9:
              if (!(response.status == 404)) {
                _context.next = 11;
                break;
              }
              throw new DivaError("Configuration ".concat(identifier || '', " of type ").concat(type, " not found"), {
                code: 'CORE_0002'
              });
            case 11:
              throw new DivaError("Error from server while loading configuration ".concat(identifier || '', " of type ").concat(type, ". HTTP status: ").concat(response.status), {
                code: 'CORE_0001'
              });
            case 14:
              _context.prev = 14;
              _context.t0 = _context["catch"](3);
              if (!(_context.t0 instanceof DivaError)) {
                _context.next = 18;
                break;
              }
              throw _context.t0;
            case 18:
              throw new DivaError("Error while loading configuration ".concat(identifier || '', " of type ").concat(type), {
                code: 'CORE_0001',
                cause: _context.t0
              });
            case 19:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[3, 14]]);
      }));
      function fetchConfiguration(_x2) {
        return _fetchConfiguration.apply(this, arguments);
      }
      return fetchConfiguration;
    }()
  }, {
    key: "sendEmail",
    value: function () {
      var _sendEmail = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref2) {
        var content, organizationIds, url, body, kind, rest, _rest, response;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              content = _ref2.content, organizationIds = _ref2.organizationIds;
              url = "".concat(this.messageService, "/mail/");
              if (content.type == 'other') {
                kind = content.kind, content.type, rest = _objectWithoutProperties(content, _excluded$3);
                url += kind;
                body = rest;
              } else {
                content.type, _rest = _objectWithoutProperties(content, _excluded2);
                url += 'basket';
                body = _rest;
              }
              body.organizationIds = organizationIds;
              _context2.prev = 4;
              _context2.next = 7;
              return this.fetch({
                url: url,
                method: 'POST',
                jwt: this.jwt,
                body: body
              });
            case 7:
              response = _context2.sent;
              if (!(response.status == 200)) {
                _context2.next = 10;
                break;
              }
              return _context2.abrupt("return");
            case 10:
              if (!response.ok) {
                _context2.next = 12;
                break;
              }
              return _context2.abrupt("return", response.json());
            case 12:
              if (!(response.status == 401)) {
                _context2.next = 14;
                break;
              }
              throw new DivaError('Not autorized to send email', {
                code: 'CORE_0004'
              });
            case 14:
              throw new DivaError("Error from server while sending email. HTTP status: ".concat(response.status), {
                code: 'CORE_0004'
              });
            case 17:
              _context2.prev = 17;
              _context2.t0 = _context2["catch"](4);
              if (!(_context2.t0 instanceof DivaError)) {
                _context2.next = 21;
                break;
              }
              throw _context2.t0;
            case 21:
              throw new DivaError('Error while sending email', {
                code: 'CORE_0004',
                cause: _context2.t0
              });
            case 22:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this, [[4, 17]]);
      }));
      function sendEmail(_x3) {
        return _sendEmail.apply(this, arguments);
      }
      return sendEmail;
    }()
  }, {
    key: "sendPasswordRecoveryMail",
    value: function () {
      var _sendPasswordRecoveryMail = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(_ref3) {
        var email, response;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              email = _ref3.email;
              _context3.prev = 1;
              _context3.next = 4;
              return this.fetch({
                url: "".concat(this.authService, "/v2/users/password/send"),
                method: 'POST',
                jwt: this.jwt,
                body: {
                  email: email,
                  redirectTo: window.location.href
                }
              });
            case 4:
              response = _context3.sent;
              if (!response.ok) {
                _context3.next = 7;
                break;
              }
              return _context3.abrupt("return");
            case 7:
              throw new DivaError("Error from server while requesting password recovery. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 10:
              _context3.prev = 10;
              _context3.t0 = _context3["catch"](1);
              if (!(_context3.t0 instanceof DivaError)) {
                _context3.next = 14;
                break;
              }
              throw _context3.t0;
            case 14:
              throw new DivaError('Error while requesting password recovery', {
                code: 'CORE_0001',
                cause: _context3.t0
              });
            case 15:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this, [[1, 10]]);
      }));
      function sendPasswordRecoveryMail(_x4) {
        return _sendPasswordRecoveryMail.apply(this, arguments);
      }
      return sendPasswordRecoveryMail;
    }()
  }, {
    key: "resetPassword",
    value: function () {
      var _resetPassword = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(data) {
        var response, json;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              _context4.prev = 0;
              _context4.next = 3;
              return this.fetch({
                url: "".concat(this.authService, "/v2/users/password/recover"),
                method: 'PATCH',
                jwt: this.jwt,
                body: data
              });
            case 3:
              response = _context4.sent;
              if (!response.ok) {
                _context4.next = 6;
                break;
              }
              return _context4.abrupt("return");
            case 6:
              _context4.prev = 6;
              _context4.next = 9;
              return response.json();
            case 9:
              json = _context4.sent;
              if (!json) {
                _context4.next = 12;
                break;
              }
              throw new DivaError("".concat(json.error, ". HTTP status: ").concat(response.status), {
                code: json.errorCode
              });
            case 12:
              _context4.next = 19;
              break;
            case 14:
              _context4.prev = 14;
              _context4.t0 = _context4["catch"](6);
              if (!(_context4.t0 instanceof DivaError)) {
                _context4.next = 18;
                break;
              }
              throw _context4.t0;
            case 18:
              throw new DivaError("Error from server while requesting password recovery. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 19:
              throw new DivaError("Error from server while requesting password recovery. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 22:
              _context4.prev = 22;
              _context4.t1 = _context4["catch"](0);
              if (!(_context4.t1 instanceof DivaError)) {
                _context4.next = 26;
                break;
              }
              throw _context4.t1;
            case 26:
              throw new DivaError('Error while requesting password recovery', {
                code: 'CORE_0001',
                cause: _context4.t1
              });
            case 27:
            case "end":
              return _context4.stop();
          }
        }, _callee4, this, [[0, 22], [6, 14]]);
      }));
      function resetPassword(_x5) {
        return _resetPassword.apply(this, arguments);
      }
      return resetPassword;
    }()
  }, {
    key: "sendVerificationEmail",
    value: function () {
      var _sendVerificationEmail = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(_ref4) {
        var email, emailVariant, response;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              email = _ref4.email, emailVariant = _ref4.emailVariant;
              _context5.prev = 1;
              _context5.next = 4;
              return this.fetch({
                url: "".concat(this.authService, "/v2/users/verification/send"),
                method: 'POST',
                jwt: this.jwt,
                body: {
                  email: email,
                  redirectTo: window.location.href,
                  emailVariant: emailVariant
                }
              });
            case 4:
              response = _context5.sent;
              if (!response.ok) {
                _context5.next = 7;
                break;
              }
              return _context5.abrupt("return");
            case 7:
              throw new DivaError("Error from server while requesting email verification. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 10:
              _context5.prev = 10;
              _context5.t0 = _context5["catch"](1);
              if (!(_context5.t0 instanceof DivaError)) {
                _context5.next = 14;
                break;
              }
              throw _context5.t0;
            case 14:
              throw new DivaError('Error while requesting email verification', {
                code: 'CORE_0001',
                cause: _context5.t0
              });
            case 15:
            case "end":
              return _context5.stop();
          }
        }, _callee5, this, [[1, 10]]);
      }));
      function sendVerificationEmail(_x6) {
        return _sendVerificationEmail.apply(this, arguments);
      }
      return sendVerificationEmail;
    }()
  }, {
    key: "verifyEmail",
    value: function () {
      var _verifyEmail = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(data) {
        var response, json;
        return _regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              _context6.prev = 0;
              _context6.next = 3;
              return this.fetch({
                url: "".concat(this.authService, "/v2/users/verification/verify"),
                method: 'PATCH',
                jwt: this.jwt,
                body: data
              });
            case 3:
              response = _context6.sent;
              _context6.prev = 4;
              _context6.next = 7;
              return response.json();
            case 7:
              json = _context6.sent;
              if (!response.ok) {
                _context6.next = 10;
                break;
              }
              return _context6.abrupt("return", json.email);
            case 10:
              if (!json) {
                _context6.next = 12;
                break;
              }
              throw new DivaError("".concat(json.error, ". HTTP status: ").concat(response.status), {
                code: json.errorCode
              });
            case 12:
              _context6.next = 19;
              break;
            case 14:
              _context6.prev = 14;
              _context6.t0 = _context6["catch"](4);
              if (!(_context6.t0 instanceof DivaError)) {
                _context6.next = 18;
                break;
              }
              throw _context6.t0;
            case 18:
              throw new DivaError("Error from server while email verification. HTTP status: ".concat(response.status, " "), {
                code: 'CORE_0001'
              });
            case 19:
              throw new DivaError("Error from server while requesting email verification. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 22:
              _context6.prev = 22;
              _context6.t1 = _context6["catch"](0);
              if (!(_context6.t1 instanceof DivaError)) {
                _context6.next = 26;
                break;
              }
              throw _context6.t1;
            case 26:
              throw new DivaError('Error while requesting email verification', {
                code: 'CORE_0001',
                cause: _context6.t1
              });
            case 27:
            case "end":
              return _context6.stop();
          }
        }, _callee6, this, [[0, 22], [4, 14]]);
      }));
      function verifyEmail(_x7) {
        return _verifyEmail.apply(this, arguments);
      }
      return verifyEmail;
    }()
  }, {
    key: "fetchOrganization",
    value: function () {
      var _fetchOrganization = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee7(organizationId) {
        var url, response;
        return _regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) switch (_context7.prev = _context7.next) {
            case 0:
              url = new URL("".concat(this.authService, "/v2/organizations/").concat(organizationId));
              _context7.prev = 1;
              _context7.next = 4;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 4:
              response = _context7.sent;
              if (!response.ok) {
                _context7.next = 7;
                break;
              }
              return _context7.abrupt("return", response.json());
            case 7:
              if (!(response.status == 404)) {
                _context7.next = 9;
                break;
              }
              return _context7.abrupt("return", undefined);
            case 9:
              if (!(response.status == 403)) {
                _context7.next = 11;
                break;
              }
              return _context7.abrupt("return", 'FORBIDDEN');
            case 11:
              throw new DivaError("Error from server while loading organization. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 14:
              _context7.prev = 14;
              _context7.t0 = _context7["catch"](1);
              throw new DivaError('Error while loading organization', {
                code: 'CORE_0001',
                cause: _context7.t0
              });
            case 17:
            case "end":
              return _context7.stop();
          }
        }, _callee7, this, [[1, 14]]);
      }));
      function fetchOrganization(_x8) {
        return _fetchOrganization.apply(this, arguments);
      }
      return fetchOrganization;
    }()
  }, {
    key: "fetchProduct",
    value: function () {
      var _fetchProduct = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee8(_ref5) {
        var divaNr, _this$root$organizati, variantId, variantStart, filter, response, result;
        return _regeneratorRuntime.wrap(function _callee8$(_context8) {
          while (1) switch (_context8.prev = _context8.next) {
            case 0:
              divaNr = _ref5.divaNr;
              _context8.prev = 1;
              variantId = null;
              variantStart = divaNr.lastIndexOf('V');
              if (variantStart > 4) {
                variantId = divaNr.substring(variantStart + 1);
                divaNr = divaNr.substring(0, variantStart);
              }
              filter = "{availableForOrganizations,eq,".concat((_this$root$organizati = this.root.organization) === null || _this$root$organizati === void 0 ? void 0 : _this$root$organizati._id, "},{divaNr,eq,") + divaNr.substring(1) + '}';
              if (variantId) {
                filter += ',{variantId,eq,' + variantId + '}';
              }
              _context8.next = 9;
              return this.fetch({
                url: this.catalogService + '/v1/products' + '?organizationIds=' + this.organizationId + '&limit=1' + '&sort=' + encodeURIComponent('{-created}') + '&fields=' + encodeURIComponent('{_id,organizationId,modelName}') + '&search=' + encodeURIComponent('[' + filter + ']')
              });
            case 9:
              response = _context8.sent;
              if (!response.ok) {
                _context8.next = 17;
                break;
              }
              _context8.next = 13;
              return response.json();
            case 13:
              result = _context8.sent;
              if (!(result.data && result.data.length > 0)) {
                _context8.next = 16;
                break;
              }
              return _context8.abrupt("return", {
                organizationId: result.data[0].organizationId ? result.data[0].organizationId : null,
                productId: result.data[0]._id ? result.data[0]._id : null,
                modelName: result.data[0].modelName ? result.data[0].modelName : null
              });
            case 16:
              return _context8.abrupt("return", undefined);
            case 17:
              if (!(response.status == 404)) {
                _context8.next = 19;
                break;
              }
              return _context8.abrupt("return", undefined);
            case 19:
              throw new DivaError("Error from server while loading product. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 22:
              _context8.prev = 22;
              _context8.t0 = _context8["catch"](1);
              if (!(_context8.t0 instanceof DivaError)) {
                _context8.next = 26;
                break;
              }
              throw _context8.t0;
            case 26:
              throw new DivaError('Error while loading product', {
                code: 'CORE_0001',
                cause: _context8.t0
              });
            case 27:
            case "end":
              return _context8.stop();
          }
        }, _callee8, this, [[1, 22]]);
      }));
      function fetchProduct(_x9) {
        return _fetchProduct.apply(this, arguments);
      }
      return fetchProduct;
    }()
  }, {
    key: "getRootOrganization",
    value: function () {
      var _getRootOrganization = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee9(userId) {
        var url, response;
        return _regeneratorRuntime.wrap(function _callee9$(_context9) {
          while (1) switch (_context9.prev = _context9.next) {
            case 0:
              url = new URL("".concat(this.authService, "/v2/organizations/root?userId=").concat(userId));
              url.searchParams.append('fields', '{_id,displayName}');
              _context9.prev = 2;
              _context9.next = 5;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 5:
              response = _context9.sent;
              if (!response.ok) {
                _context9.next = 8;
                break;
              }
              return _context9.abrupt("return", response.json());
            case 8:
              throw new DivaError("Error from server while searching organizations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 11:
              _context9.prev = 11;
              _context9.t0 = _context9["catch"](2);
              if (!(_context9.t0 instanceof DivaError)) {
                _context9.next = 15;
                break;
              }
              throw _context9.t0;
            case 15:
              throw new DivaError('Error while searching organizations', {
                code: 'CORE_0001',
                cause: _context9.t0
              });
            case 16:
            case "end":
              return _context9.stop();
          }
        }, _callee9, this, [[2, 11]]);
      }));
      function getRootOrganization(_x10) {
        return _getRootOrganization.apply(this, arguments);
      }
      return getRootOrganization;
    }()
  }, {
    key: "getOrganizationsChildren",
    value: function () {
      var _getOrganizationsChildren = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee10(userId, allowedOrganizationTypes) {
        var organizationId,
          skip,
          allowed,
          excluded,
          limit,
          filterText,
          url,
          response,
          _args10 = arguments;
        return _regeneratorRuntime.wrap(function _callee10$(_context10) {
          while (1) switch (_context10.prev = _context10.next) {
            case 0:
              organizationId = _args10.length > 2 && _args10[2] !== undefined ? _args10[2] : 'ROOT';
              skip = _args10.length > 3 ? _args10[3] : undefined;
              allowed = _args10.length > 4 ? _args10[4] : undefined;
              excluded = _args10.length > 5 ? _args10[5] : undefined;
              limit = _args10.length > 6 ? _args10[6] : undefined;
              filterText = _args10.length > 7 ? _args10[7] : undefined;
              url = new URL("".concat(this.authService, "/v2/users/").concat(userId, "/organizations/").concat(organizationId, "/children"));
              url.searchParams.append('organizationTypes', allowedOrganizationTypes.join(','));
              if (allowed) url.searchParams.append('validParents', allowed.join(','));
              if (excluded) url.searchParams.append('excluded', excluded.join(','));
              if (skip) url.searchParams.append('skip', skip.toString());
              if (limit) url.searchParams.append('limit', limit.toString());
              if (filterText) url.searchParams.append('filterText', encodeURIComponent(filterText.toString()));
              _context10.prev = 13;
              _context10.next = 16;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 16:
              response = _context10.sent;
              if (!response.ok) {
                _context10.next = 19;
                break;
              }
              return _context10.abrupt("return", response.json());
            case 19:
              throw new DivaError("Error from server while searching organizations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 22:
              _context10.prev = 22;
              _context10.t0 = _context10["catch"](13);
              if (!(_context10.t0 instanceof DivaError)) {
                _context10.next = 26;
                break;
              }
              throw _context10.t0;
            case 26:
              throw new DivaError('Error while searching organizations', {
                code: 'CORE_0001',
                cause: _context10.t0
              });
            case 27:
            case "end":
              return _context10.stop();
          }
        }, _callee10, this, [[13, 22]]);
      }));
      function getOrganizationsChildren(_x11, _x12) {
        return _getOrganizationsChildren.apply(this, arguments);
      }
      return getOrganizationsChildren;
    }()
  }, {
    key: "getOrganizationRelatives",
    value: function () {
      var _getOrganizationRelatives = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee11(userId, allowedOrganizationTypes, organizationId) {
        var skip,
          allowed,
          excluded,
          limit,
          url,
          response,
          _args11 = arguments;
        return _regeneratorRuntime.wrap(function _callee11$(_context11) {
          while (1) switch (_context11.prev = _context11.next) {
            case 0:
              skip = _args11.length > 3 && _args11[3] !== undefined ? _args11[3] : 0;
              allowed = _args11.length > 4 ? _args11[4] : undefined;
              excluded = _args11.length > 5 ? _args11[5] : undefined;
              limit = _args11.length > 6 ? _args11[6] : undefined;
              url = new URL("".concat(this.authService, "/v2/users/").concat(userId, "/organizations/relatives"));
              url.searchParams.append('organizationTypes', allowedOrganizationTypes.join(','));
              url.searchParams.append('skip', skip.toString());
              if (organizationId) url.searchParams.append('organizationId', organizationId);
              if (limit) url.searchParams.append('limit', limit.toString());
              if (allowed) url.searchParams.append('allowed', allowed.join());
              if (excluded) url.searchParams.append('excluded', excluded.join());
              _context11.prev = 11;
              _context11.next = 14;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 14:
              response = _context11.sent;
              if (!response.ok) {
                _context11.next = 17;
                break;
              }
              return _context11.abrupt("return", response.json());
            case 17:
              throw new DivaError("Error from server while searching organizations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 20:
              _context11.prev = 20;
              _context11.t0 = _context11["catch"](11);
              if (!(_context11.t0 instanceof DivaError)) {
                _context11.next = 24;
                break;
              }
              throw _context11.t0;
            case 24:
              throw new DivaError('Error while searching organizations', {
                code: 'CORE_0001',
                cause: _context11.t0
              });
            case 25:
            case "end":
              return _context11.stop();
          }
        }, _callee11, this, [[11, 20]]);
      }));
      function getOrganizationRelatives(_x13, _x14, _x15) {
        return _getOrganizationRelatives.apply(this, arguments);
      }
      return getOrganizationRelatives;
    }()
  }, {
    key: "getOrganizationBySearch",
    value: function () {
      var _getOrganizationBySearch = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee12(userId, allowedOrganizationTypes, allowed, excluded, query) {
        var skip,
          url,
          response,
          _args12 = arguments;
        return _regeneratorRuntime.wrap(function _callee12$(_context12) {
          while (1) switch (_context12.prev = _context12.next) {
            case 0:
              skip = _args12.length > 5 && _args12[5] !== undefined ? _args12[5] : 0;
              url = new URL("".concat(this.authService, "/v2/users/").concat(userId, "/organizations/hirachy"));
              url.searchParams.append('limit', '20');
              url.searchParams.append('fields', '{_id,displayName,parentOrganizations}');
              url.searchParams.append('organizationTypes', allowedOrganizationTypes.join(','));
              url.searchParams.append('skip', skip.toString());
              if (query) {
                url.searchParams.append('filter', encodeURIComponent("[+[{displayName,contains,".concat(query, "},{_id,eq,").concat(query, "}]]")));
              }
              if (allowed) {
                url.searchParams.append('allowed', allowed.join());
              }
              if (excluded) {
                url.searchParams.append('excluded', excluded.join());
              }
              _context12.prev = 9;
              _context12.next = 12;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 12:
              response = _context12.sent;
              if (!response.ok) {
                _context12.next = 15;
                break;
              }
              return _context12.abrupt("return", response.json());
            case 15:
              throw new DivaError("Error from server while searching organizations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 18:
              _context12.prev = 18;
              _context12.t0 = _context12["catch"](9);
              if (!(_context12.t0 instanceof DivaError)) {
                _context12.next = 22;
                break;
              }
              throw _context12.t0;
            case 22:
              throw new DivaError('Error while searching organizations', {
                code: 'CORE_0001',
                cause: _context12.t0
              });
            case 23:
            case "end":
              return _context12.stop();
          }
        }, _callee12, this, [[9, 18]]);
      }));
      function getOrganizationBySearch(_x16, _x17, _x18, _x19, _x20) {
        return _getOrganizationBySearch.apply(this, arguments);
      }
      return getOrganizationBySearch;
    }()
  }, {
    key: "getOrganizationParentByType",
    value: function () {
      var _getOrganizationParentByType = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee13(organizationId, type) {
        var url, response, _data$data, data;
        return _regeneratorRuntime.wrap(function _callee13$(_context13) {
          while (1) switch (_context13.prev = _context13.next) {
            case 0:
              url = new URL("".concat(this.authService, "/v2/organizations/").concat(organizationId, "/parents/").concat(type.toLocaleLowerCase()));
              _context13.prev = 1;
              _context13.next = 4;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 4:
              response = _context13.sent;
              if (!response.ok) {
                _context13.next = 10;
                break;
              }
              _context13.next = 8;
              return response.json();
            case 8:
              data = _context13.sent;
              return _context13.abrupt("return", (_data$data = data.data) === null || _data$data === void 0 ? void 0 : _data$data[0]);
            case 10:
              throw new DivaError("Error from server while searching organizations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 13:
              _context13.prev = 13;
              _context13.t0 = _context13["catch"](1);
              if (!(_context13.t0 instanceof DivaError)) {
                _context13.next = 17;
                break;
              }
              throw _context13.t0;
            case 17:
              throw new DivaError('Error while getting organization', {
                code: 'CORE_0001',
                cause: _context13.t0
              });
            case 18:
            case "end":
              return _context13.stop();
          }
        }, _callee13, this, [[1, 13]]);
      }));
      function getOrganizationParentByType(_x21, _x22) {
        return _getOrganizationParentByType.apply(this, arguments);
      }
      return getOrganizationParentByType;
    }()
  }, {
    key: "getRetailerLocationsForArea",
    value: function () {
      var _getRetailerLocationsForArea = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee14(organizationId, location, radius) {
        var url, response;
        return _regeneratorRuntime.wrap(function _callee14$(_context14) {
          while (1) switch (_context14.prev = _context14.next) {
            case 0:
              url = new URL("".concat(this.authService, "/organizations/").concat(organizationId, "/retailer-locations"));
              if (location) {
                url.searchParams.append('lat', String(location.lat()));
                url.searchParams.append('lng', String(location.lng()));
              }
              url.searchParams.append('radius', radius);
              _context14.prev = 3;
              _context14.next = 6;
              return this.fetch({
                url: url.toString(),
                jwt: this.jwt
              });
            case 6:
              response = _context14.sent;
              if (!response.ok) {
                _context14.next = 9;
                break;
              }
              return _context14.abrupt("return", response.json());
            case 9:
              throw new DivaError("Error from server while searching retailer locations. HTTP status: ".concat(response.status), {
                code: 'CORE_0001'
              });
            case 12:
              _context14.prev = 12;
              _context14.t0 = _context14["catch"](3);
              if (!(_context14.t0 instanceof DivaError)) {
                _context14.next = 16;
                break;
              }
              throw _context14.t0;
            case 16:
              throw new DivaError('Error while getting retailer locations', {
                code: 'CORE_0001',
                cause: _context14.t0
              });
            case 17:
            case "end":
              return _context14.stop();
          }
        }, _callee14, this, [[3, 12]]);
      }));
      function getRetailerLocationsForArea(_x23, _x24, _x25) {
        return _getRetailerLocationsForArea.apply(this, arguments);
      }
      return getRetailerLocationsForArea;
    }()
  }, {
    key: "fetch",
    value: function (_fetch) {
      function fetch(_x) {
        return _fetch.apply(this, arguments);
      }
      fetch.toString = function () {
        return _fetch.toString();
      };
      return fetch;
    }(/*#__PURE__*/function () {
      var _ref7 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee15(_ref6) {
        var url, _ref6$method, method, jwt, body, headers;
        return _regeneratorRuntime.wrap(function _callee15$(_context15) {
          while (1) switch (_context15.prev = _context15.next) {
            case 0:
              url = _ref6.url, _ref6$method = _ref6.method, method = _ref6$method === void 0 ? 'GET' : _ref6$method, jwt = _ref6.jwt, body = _ref6.body;
              headers = {
                'Content-Type': 'application/json',
                'X-Session-Id': DivaUtils.SessionId
              };
              if (jwt) {
                headers.Authorization = "Bearer ".concat(jwt);
              }
              _context15.next = 5;
              return fetch(url, {
                method: method,
                headers: headers,
                body: body ? JSON.stringify(body) : undefined
              });
            case 5:
              return _context15.abrupt("return", _context15.sent);
            case 6:
            case "end":
              return _context15.stop();
          }
        }, _callee15);
      }));
      return function (_x26) {
        return _ref7.apply(this, arguments);
      };
    }())
  }]);
}();

var OrganizationHandler = /*#__PURE__*/function () {
  function OrganizationHandler(root) {
    _classCallCheck(this, OrganizationHandler);
    this.root = root;
  }
  return _createClass(OrganizationHandler, [{
    key: "apiHandler",
    get: function get() {
      return this.root.apiHandler;
    }
  }, {
    key: "organization",
    get: function get() {
      return this.root.organization;
    }
  }, {
    key: "user",
    get: function get() {
      return this.root.user;
    }
  }, {
    key: "allowedOrganizationTypes",
    get: function get() {
      return this.root.allowedOrganizationTypes;
    }
  }, {
    key: "validOrganizations",
    get: function get() {
      return this.root.validOrganizations;
    }
  }, {
    key: "excludedOrganizations",
    get: function get() {
      return this.root.excludedOrganizations;
    }
  }, {
    key: "getOrganizationsChildren",
    value: function () {
      var _getOrganizationsChildren = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(organizationId, skip, limit, filterText) {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (!this.user) {
                _context.next = 4;
                break;
              }
              _context.next = 3;
              return this.apiHandler.getOrganizationsChildren(this.user._id, this.allowedOrganizationTypes, organizationId, skip, this.validOrganizations, this.excludedOrganizations, limit, filterText);
            case 3:
              return _context.abrupt("return", _context.sent);
            case 4:
              return _context.abrupt("return", {
                data: [],
                total: 0,
                flatTotal: 0
              });
            case 5:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function getOrganizationsChildren(_x, _x2, _x3, _x4) {
        return _getOrganizationsChildren.apply(this, arguments);
      }
      return getOrganizationsChildren;
    }()
  }, {
    key: "getOrganizationRelatives",
    value: function () {
      var _getOrganizationRelatives = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(organizationId, skip, limit) {
        var result;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              if (!this.user) {
                _context2.next = 5;
                break;
              }
              _context2.next = 3;
              return this.apiHandler.getOrganizationRelatives(this.user._id, this.allowedOrganizationTypes, organizationId, skip, this.validOrganizations, this.excludedOrganizations, limit);
            case 3:
              result = _context2.sent;
              return _context2.abrupt("return", {
                parentOrganizations: result.parentOrganizations,
                brotherOrganizations: result.brotherOrganizations,
                childrenOrganizations: result.childrenOrganizations
              });
            case 5:
              return _context2.abrupt("return", {
                data: [],
                total: 0
              });
            case 6:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function getOrganizationRelatives(_x5, _x6, _x7) {
        return _getOrganizationRelatives.apply(this, arguments);
      }
      return getOrganizationRelatives;
    }()
  }, {
    key: "getOrganizationBySearch",
    value: function () {
      var _getOrganizationBySearch = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(query, skip) {
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              if (!this.user) {
                _context3.next = 2;
                break;
              }
              return _context3.abrupt("return", this.apiHandler.getOrganizationBySearch(this.user._id, this.allowedOrganizationTypes, this.validOrganizations, this.excludedOrganizations, query, skip));
            case 2:
              return _context3.abrupt("return", {
                data: [],
                total: 0
              });
            case 3:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this);
      }));
      function getOrganizationBySearch(_x8, _x9) {
        return _getOrganizationBySearch.apply(this, arguments);
      }
      return getOrganizationBySearch;
    }()
  }, {
    key: "getOrganizationDataById",
    value: function () {
      var _getOrganizationDataById = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(organizationId) {
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              return _context4.abrupt("return", this.apiHandler.fetchOrganization(organizationId));
            case 1:
            case "end":
              return _context4.stop();
          }
        }, _callee4, this);
      }));
      function getOrganizationDataById(_x10) {
        return _getOrganizationDataById.apply(this, arguments);
      }
      return getOrganizationDataById;
    }()
  }, {
    key: "getOrganizationParentByType",
    value: function () {
      var _getOrganizationParentByType = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(organizationId, type) {
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              return _context5.abrupt("return", this.apiHandler.getOrganizationParentByType(organizationId, type));
            case 1:
            case "end":
              return _context5.stop();
          }
        }, _callee5, this);
      }));
      function getOrganizationParentByType(_x11, _x12) {
        return _getOrganizationParentByType.apply(this, arguments);
      }
      return getOrganizationParentByType;
    }()
  }, {
    key: "getRetailerLocationsForArea",
    value: function () {
      var _getRetailerLocationsForArea = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(organizationId, location, radius) {
        return _regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              if (!this.user) {
                _context6.next = 2;
                break;
              }
              return _context6.abrupt("return", this.apiHandler.getRetailerLocationsForArea(organizationId ? organizationId : this.organization._id, location, radius));
            case 2:
              return _context6.abrupt("return", {
                data: [],
                area: null
              });
            case 3:
            case "end":
              return _context6.stop();
          }
        }, _callee6, this);
      }));
      function getRetailerLocationsForArea(_x13, _x14, _x15) {
        return _getRetailerLocationsForArea.apply(this, arguments);
      }
      return getRetailerLocationsForArea;
    }()
  }]);
}();

var COOKIEBOT_LOAD_TIMEOUT_MS = 10000; // 10 seconds
var COOKIEBOT_SCRIPT_ID = 'Cookiebot';

/*
/**
 * Initializes the Cookiebot script.
 * @param cbid The Cookiebot domain group ID.
 * @param onConsentReady Callback function triggered when Cookiebot consent is ready.
 * @param onCookieBotError Optional callback function triggered if Cookiebot fails to initialize.
 */
function initCookieBot(cbid, onConsentReady, onCookieBotError) {
  var consentReadyFired = false;
  var errorCallbackCalled = false;
  var handleError = function handleError(reason) {
    if (errorCallbackCalled) return;
    errorCallbackCalled = true;
    if (onCookieBotError) {
      onCookieBotError(reason);
    }
  };
  var _consentReadyListener = function consentReadyListener() {
    if (consentReadyFired || errorCallbackCalled) return;
    if (window.Cookiebot && window.Cookiebot.consent) {
      consentReadyFired = true;
      if (timeoutId) clearTimeout(timeoutId);
      window.removeEventListener('CookiebotOnConsentReady', _consentReadyListener);
      onConsentReady(window.Cookiebot.consent);
    } else {
      handleError('CookiebotOnConsentReady fired, but window.Cookiebot.consent was not available.');
    }
  };
  window.addEventListener('CookiebotOnConsentReady', _consentReadyListener);
  var cookieBotScript = document.createElement('script');
  cookieBotScript.setAttribute('id', COOKIEBOT_SCRIPT_ID);
  cookieBotScript.setAttribute('src', 'https://consent.cookiebot.com/uc.js');
  cookieBotScript.setAttribute('data-cbid', cbid);
  cookieBotScript.setAttribute('async', ''); // Asynchronous loading

  cookieBotScript.onerror = function () {
    if (timeoutId) clearTimeout(timeoutId);
    window.removeEventListener('CookiebotOnConsentReady', _consentReadyListener);
    handleError('Script loading failed (e.g., network issue, ad blocker, CSP).');
  };
  document.head.appendChild(cookieBotScript);
  var timeoutId = setTimeout(function () {
    if (!consentReadyFired && !errorCallbackCalled) {
      window.removeEventListener('CookiebotOnConsentReady', _consentReadyListener);
      handleError("Timeout reached (".concat(COOKIEBOT_LOAD_TIMEOUT_MS, "ms). 'CookiebotOnConsentReady' event did not fire. ") + "This may indicate an issue with the Cookiebot configuration (CBID: ".concat(cbid, ") or script execution. Check browser console for Cookiebot messages."));
    }
  }, COOKIEBOT_LOAD_TIMEOUT_MS);
}

var MediaHandler = /*#__PURE__*/function () {
  function MediaHandler(root) {
    _classCallCheck(this, MediaHandler);
    this.root = root;
  }
  return _createClass(MediaHandler, [{
    key: "mediaService",
    get: function get() {
      return this.root.apiConfig.mediaService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "getMediaByIds",
    value: function () {
      var _getMediaByIds = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(ids) {
        var resultPromsies, i, result, finalRes;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              resultPromsies = [];
              for (i = 0; i < ids.length; i++) {
                resultPromsies.push(this.getMediaById(ids[i]));
              }
              _context.next = 4;
              return Promise.all(resultPromsies);
            case 4:
              result = _context.sent;
              finalRes = [];
              result.forEach(function (res) {
                res.data.forEach(function (rData) {
                  finalRes.push(rData);
                });
              });
              return _context.abrupt("return", finalRes);
            case 8:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function getMediaByIds(_x) {
        return _getMediaByIds.apply(this, arguments);
      }
      return getMediaByIds;
    }()
  }, {
    key: "getMediaById",
    value: function () {
      var _getMediaById = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(id) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              fullUrl = this.mediaService + '/v1/mediaitems';
              _context2.prev = 1;
              _context2.next = 4;
              return fetch("".concat(fullUrl, "?filter=%5B%7B_id%2Ceq%2C").concat(id, "%7D%5D"), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              res = _context2.sent;
              _context2.next = 7;
              return res.json();
            case 7:
              resData = _context2.sent;
              _context2.next = 13;
              break;
            case 10:
              _context2.prev = 10;
              _context2.t0 = _context2["catch"](1);
              throw new Error('Could not fetch mediaItem');
            case 13:
              if (!res.ok) {
                _context2.next = 15;
                break;
              }
              return _context2.abrupt("return", resData);
            case 15:
              throw new Error(resData.error);
            case 16:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this, [[1, 10]]);
      }));
      function getMediaById(_x2) {
        return _getMediaById.apply(this, arguments);
      }
      return getMediaById;
    }()
  }, {
    key: "getMediaItemByRefId",
    value: function () {
      var _getMediaItemByRefId = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(refid) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              fullUrl = this.mediaService + '/v1/mediaitemref/' + refid + '/mediaitem';
              _context3.prev = 1;
              _context3.next = 4;
              return fetch(fullUrl, {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              res = _context3.sent;
              _context3.next = 7;
              return res.json();
            case 7:
              resData = _context3.sent;
              if (!res.ok) {
                _context3.next = 10;
                break;
              }
              return _context3.abrupt("return", resData);
            case 10:
              throw new Error(resData.error || 'Could not fetch mediaItem');
            case 13:
              _context3.prev = 13;
              _context3.t0 = _context3["catch"](1);
              throw new Error("Could not fetch mediaItem: ".concat(_context3.t0.message));
            case 16:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this, [[1, 13]]);
      }));
      function getMediaItemByRefId(_x3) {
        return _getMediaItemByRefId.apply(this, arguments);
      }
      return getMediaItemByRefId;
    }()
  }, {
    key: "getHQRenderScriptById",
    value: function () {
      var _getHQRenderScriptById = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(id) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              fullUrl = this.mediaService + '/hqrenderscripts';
              _context4.prev = 1;
              _context4.next = 4;
              return fetch("".concat(fullUrl, "/").concat(id), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              res = _context4.sent;
              _context4.next = 7;
              return res.json();
            case 7:
              resData = _context4.sent;
              _context4.next = 13;
              break;
            case 10:
              _context4.prev = 10;
              _context4.t0 = _context4["catch"](1);
              throw new Error('Could not fetch mediaItem');
            case 13:
              if (!res.ok) {
                _context4.next = 15;
                break;
              }
              return _context4.abrupt("return", resData);
            case 15:
              throw new Error(resData.error);
            case 16:
            case "end":
              return _context4.stop();
          }
        }, _callee4, this, [[1, 10]]);
      }));
      function getHQRenderScriptById(_x4) {
        return _getHQRenderScriptById.apply(this, arguments);
      }
      return getHQRenderScriptById;
    }()
  }, {
    key: "getRooms",
    value: function () {
      var _getRooms = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(id, mainCategory, style, name) {
        var fullUrl, filterParts, filter, res, resData;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              fullUrl = new URL(this.mediaService + '/rooms');
              fullUrl.searchParams.append('limit', '20');
              fullUrl.searchParams.append('skip', '0');
              filterParts = [];
              if (id) {
                filterParts.push("{_id,eq,".concat(id, "}"));
              } else {
                if (mainCategory) {
                  filterParts.push("{mainCategory,eq,".concat(mainCategory, "}"));
                }
                if (style) {
                  filterParts.push("{style,eq,".concat(style, "}"));
                }
                if (name) {
                  filterParts.push("{name,eq,".concat(name, "}"));
                }
              }
              filter = filterParts.length > 0 ? "[".concat(filterParts.join(','), "]") : undefined;
              if (filter) {
                fullUrl.searchParams.append('filter', encodeURIComponent(filter));
              }
              _context5.prev = 7;
              _context5.next = 10;
              return fetch(fullUrl.toString(), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 10:
              res = _context5.sent;
              _context5.next = 13;
              return res.json();
            case 13:
              resData = _context5.sent;
              _context5.next = 19;
              break;
            case 16:
              _context5.prev = 16;
              _context5.t0 = _context5["catch"](7);
              throw new Error('Could not get rooms');
            case 19:
              if (!res.ok) {
                _context5.next = 21;
                break;
              }
              return _context5.abrupt("return", resData.data);
            case 21:
              throw new Error(resData.error);
            case 22:
            case "end":
              return _context5.stop();
          }
        }, _callee5, this, [[7, 16]]);
      }));
      function getRooms(_x5, _x6, _x7, _x8) {
        return _getRooms.apply(this, arguments);
      }
      return getRooms;
    }()
  }, {
    key: "getRoomsNew",
    value: function () {
      var _getRoomsNew = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(id, mainCategory, organizationId) {
        var fullUrl, filterParts, filter, res, resData;
        return _regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              fullUrl = new URL(this.mediaService + '/rooms');
              fullUrl.searchParams.append('limit', '1000');
              fullUrl.searchParams.append('skip', '0');
              if (organizationId) {
                fullUrl.searchParams.append('organizationId', organizationId);
              }
              filterParts = [];
              if (id) {
                filterParts.push("+[{_id,eq,".concat(id, "},{variants.id,eq,").concat(id, "}]"));
              } else {
                if (mainCategory) {
                  filterParts.push("{mainCategory,eq,".concat(mainCategory, "}"));
                }
              }
              filter = filterParts.length > 0 ? "[".concat(filterParts.join(','), "]") : undefined;
              if (filter) {
                fullUrl.searchParams.append('filter', encodeURIComponent(filter));
              }
              _context6.prev = 8;
              _context6.next = 11;
              return fetch(fullUrl.toString(), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 11:
              res = _context6.sent;
              _context6.next = 14;
              return res.json();
            case 14:
              resData = _context6.sent;
              _context6.next = 20;
              break;
            case 17:
              _context6.prev = 17;
              _context6.t0 = _context6["catch"](8);
              throw new Error('Could not get rooms');
            case 20:
              if (!res.ok) {
                _context6.next = 22;
                break;
              }
              return _context6.abrupt("return", resData.data);
            case 22:
              throw new Error(resData.error);
            case 23:
            case "end":
              return _context6.stop();
          }
        }, _callee6, this, [[8, 17]]);
      }));
      function getRoomsNew(_x9, _x10, _x11) {
        return _getRoomsNew.apply(this, arguments);
      }
      return getRoomsNew;
    }()
  }, {
    key: "getRoomsGrouped",
    value: function () {
      var _getRoomsGrouped = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee7(id, mainCategory, style, organizationId) {
        var fullUrl, filterParts, filter, res, resData;
        return _regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) switch (_context7.prev = _context7.next) {
            case 0:
              fullUrl = new URL(this.mediaService + '/rooms');
              if (organizationId) {
                fullUrl = new URL(this.mediaService + "/rooms/".concat(organizationId, "/grouped"));
              }
              fullUrl.searchParams.append('limit', '20');
              fullUrl.searchParams.append('skip', '0');
              filterParts = [];
              if (id) {
                filterParts.push("{_id,eq,".concat(id, "}"));
              } else {
                if (mainCategory) {
                  filterParts.push("{mainCategory,eq,".concat(mainCategory, "}"));
                }
                if (style) {
                  filterParts.push("{style,eq,".concat(style, "}"));
                }
              }
              filter = filterParts.length > 0 ? "[".concat(filterParts.join(','), "]") : undefined;
              if (filter) {
                fullUrl.searchParams.append('filter', encodeURIComponent(filter));
              }
              _context7.prev = 8;
              _context7.next = 11;
              return fetch(fullUrl.toString(), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 11:
              res = _context7.sent;
              _context7.next = 14;
              return res.json();
            case 14:
              resData = _context7.sent;
              _context7.next = 20;
              break;
            case 17:
              _context7.prev = 17;
              _context7.t0 = _context7["catch"](8);
              throw new Error('Could not get rooms');
            case 20:
              if (!res.ok) {
                _context7.next = 22;
                break;
              }
              return _context7.abrupt("return", organizationId ? resData : resData.data);
            case 22:
              throw new Error(resData.error);
            case 23:
            case "end":
              return _context7.stop();
          }
        }, _callee7, this, [[8, 17]]);
      }));
      function getRoomsGrouped(_x12, _x13, _x14, _x15) {
        return _getRoomsGrouped.apply(this, arguments);
      }
      return getRoomsGrouped;
    }()
  }, {
    key: "getRoomColors",
    value: function () {
      var _getRoomColors = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee8(name) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee8$(_context8) {
          while (1) switch (_context8.prev = _context8.next) {
            case 0:
              fullUrl = this.mediaService + '/rooms/' + name + '/colors';
              resData = [];
              _context8.prev = 2;
              _context8.next = 5;
              return fetch(fullUrl, {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 5:
              res = _context8.sent;
              _context8.next = 8;
              return res.json();
            case 8:
              resData = _context8.sent;
              _context8.next = 14;
              break;
            case 11:
              _context8.prev = 11;
              _context8.t0 = _context8["catch"](2);
              throw new Error('Could not get room variants');
            case 14:
              if (!res.ok) {
                _context8.next = 16;
                break;
              }
              return _context8.abrupt("return", resData);
            case 16:
              throw new Error(resData.error);
            case 17:
            case "end":
              return _context8.stop();
          }
        }, _callee8, this, [[2, 11]]);
      }));
      function getRoomColors(_x16) {
        return _getRoomColors.apply(this, arguments);
      }
      return getRoomColors;
    }()
  }, {
    key: "getRoomVariants",
    value: function () {
      var _getRoomVariants = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee9(id) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee9$(_context9) {
          while (1) switch (_context9.prev = _context9.next) {
            case 0:
              fullUrl = this.mediaService + '/rooms/' + id + '/variants';
              resData = [];
              _context9.prev = 2;
              _context9.next = 5;
              return fetch(fullUrl, {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 5:
              res = _context9.sent;
              _context9.next = 8;
              return res.json();
            case 8:
              resData = _context9.sent;
              _context9.next = 14;
              break;
            case 11:
              _context9.prev = 11;
              _context9.t0 = _context9["catch"](2);
              throw new Error('Could not get room variants');
            case 14:
              if (!res.ok) {
                _context9.next = 16;
                break;
              }
              return _context9.abrupt("return", resData);
            case 16:
              throw new Error(resData.error);
            case 17:
            case "end":
              return _context9.stop();
          }
        }, _callee9, this, [[2, 11]]);
      }));
      function getRoomVariants(_x17) {
        return _getRoomVariants.apply(this, arguments);
      }
      return getRoomVariants;
    }()
  }, {
    key: "getRenderPackages",
    value: function () {
      var _getRenderPackages = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee10(organizationId) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee10$(_context10) {
          while (1) switch (_context10.prev = _context10.next) {
            case 0:
              fullUrl = new URL(this.mediaService + '/renderpackages');
              if (organizationId) fullUrl.searchParams.append('organizationId', organizationId);
              fullUrl.searchParams.append('sort', encodeURIComponent('{position}'));
              _context10.prev = 3;
              _context10.next = 6;
              return fetch(fullUrl, {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 6:
              res = _context10.sent;
              _context10.next = 9;
              return res.json();
            case 9:
              resData = _context10.sent;
              _context10.next = 15;
              break;
            case 12:
              _context10.prev = 12;
              _context10.t0 = _context10["catch"](3);
              throw new Error('Could not get render packages');
            case 15:
              if (!res.ok) {
                _context10.next = 17;
                break;
              }
              return _context10.abrupt("return", resData);
            case 17:
              throw new Error(resData.error);
            case 18:
            case "end":
              return _context10.stop();
          }
        }, _callee10, this, [[3, 12]]);
      }));
      function getRenderPackages(_x18) {
        return _getRenderPackages.apply(this, arguments);
      }
      return getRenderPackages;
    }()
  }]);
}();

var AdminHandler = /*#__PURE__*/function () {
  function AdminHandler(root) {
    _classCallCheck(this, AdminHandler);
    this.root = root;
  }
  return _createClass(AdminHandler, [{
    key: "adminService",
    get: function get() {
      return this.root.apiConfig.adminService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "getViewConfigsLoad",
    value: function () {
      var _getViewConfigsLoad = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(identifier, type, adminService) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              fullUrl = '';
              if (adminService) fullUrl = adminService + '/v2/views/configs/load';else fullUrl = this.adminService + '/v2/views/configs/load';
              _context.prev = 2;
              _context.next = 5;
              return fetch("".concat(fullUrl, "?identifier=").concat(identifier, "&type=").concat(type), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 5:
              res = _context.sent;
              _context.next = 8;
              return res.json();
            case 8:
              resData = _context.sent;
              _context.next = 14;
              break;
            case 11:
              _context.prev = 11;
              _context.t0 = _context["catch"](2);
              throw new Error('Could not fetch ViewConfig ' + _context.t0.message);
            case 14:
              if (!res.ok) {
                _context.next = 16;
                break;
              }
              return _context.abrupt("return", resData);
            case 16:
              throw new Error(resData.error);
            case 17:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[2, 11]]);
      }));
      function getViewConfigsLoad(_x, _x2, _x3) {
        return _getViewConfigsLoad.apply(this, arguments);
      }
      return getViewConfigsLoad;
    }()
  }]);
}();

var _excluded$2 = ["path"];
var ONE_DAY_UNIX = 86400000;
var AnalyticsHandler = /*#__PURE__*/function () {
  function AnalyticsHandler(root) {
    _classCallCheck(this, AnalyticsHandler);
    this.root = root;
  }
  return _createClass(AnalyticsHandler, [{
    key: "analyticsService",
    get: function get() {
      return this.root.apiConfig.analyticsService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "getAnalyticsData",
    value: function () {
      var _getAnalyticsData = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
        var path, props, url, res, resData;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              path = _ref.path, props = _objectWithoutProperties(_ref, _excluded$2);
              url = new URL(this.analyticsService + path);
              this.addBaseParamsToUrl(url, props);
              _context.prev = 3;
              _context.next = 6;
              return fetch(url.toString(), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 6:
              res = _context.sent;
              _context.next = 9;
              return res.json();
            case 9:
              resData = _context.sent;
              _context.next = 15;
              break;
            case 12:
              _context.prev = 12;
              _context.t0 = _context["catch"](3);
              throw new Error('Could not fetch User History from AnaylticsService');
            case 15:
              if (!res.ok) {
                _context.next = 17;
                break;
              }
              return _context.abrupt("return", resData.data);
            case 17:
              throw new Error(resData.error);
            case 18:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[3, 12]]);
      }));
      function getAnalyticsData(_x) {
        return _getAnalyticsData.apply(this, arguments);
      }
      return getAnalyticsData;
    }()
  }, {
    key: "processHistroyData",
    value: function processHistroyData(data, endPoint, keyMapping, interval, fromTimeStamp, toTimeStamp) {
      for (var i = 0; i < data.length; i++) {
        var dataSet = data[i];
        while (fromTimeStamp < dataSet.time[0].timeStamp) {
          dataSet.time.unshift({
            count: 0,
            timeStamp: dataSet.time[0].timeStamp - interval
          });
        }
        while (toTimeStamp > dataSet.time[dataSet.time.length - 1].timeStamp + interval) {
          dataSet.time.push({
            count: 0,
            timeStamp: dataSet.time[dataSet.time.length - 1].timeStamp + interval
          });
        }
      }
      var labels = [];
      var intervalInUnix = getIntervalInUnixTimestamp(interval.toString());
      var count = (toTimeStamp - fromTimeStamp) / intervalInUnix;
      for (var _i = 0; _i < count; _i++) {
        var time = new Date(fromTimeStamp + intervalInUnix * _i);
        labels.push(time.getDate() + '/' + (time.getMonth() + 1));
      }
      var result = data.map(function (dataSet) {
        return {
          label: dataSet[endPoint.key],
          data: dataSet.time.map(function (time) {
            return time.count;
          }),
          valueLabels: labels
        };
      });
      return this.mapKeys(result, keyMapping);
    }
  }, {
    key: "processData",
    value: function processData(data, endPoint, keyMapping) {
      var _this = this;
      var result = data.map(function (dataSet) {
        return {
          label: dataSet.filteredField ? _this.root.t('Analytics.' + dataSet.filteredField) : dataSet[endPoint.key],
          key: dataSet[endPoint.key],
          data: dataSet[endPoint.valueKey].map(function (value) {
            return value.count;
          }),
          valueLabels: dataSet[endPoint.valueKey].map(function (value) {
            return value.codex;
          })
        };
      });
      return this.mapKeys(result, keyMapping);
    }
  }, {
    key: "mapKeys",
    value: function mapKeys(result, keyMapping) {
      if (keyMapping) result.map(function (item) {
        if (keyMapping[item.label]) item.label = keyMapping[item.label];
        item.valueLabels = item.valueLabels.map(function (label) {
          if (keyMapping[label]) return keyMapping[label];
          return label;
        });
      });
      return result;
    }
  }, {
    key: "addBaseParamsToUrl",
    value: function addBaseParamsToUrl(url, props) {
      var _loop = function _loop(key) {
        var value;
        if (typeof props[key] === 'number') {
          value = props[key].toString();
        } else if (Array.isArray(props[key])) {
          if (!props[key].length) return 1; // continue
          value = props[key];
        } else {
          value = props[key];
        }
        if (Array.isArray(value)) {
          value.map(function (val) {
            return url.searchParams.append(key, val);
          });
        } else {
          url.searchParams.append(key, value);
        }
      };
      for (var key in props) {
        if (_loop(key)) continue;
      }
    }
  }, {
    key: "getCatalogHistorypath",
    value: function getCatalogHistorypath() {
      return '/catalogs/sessions/history';
    }
  }, {
    key: "getSupplierHistorypath",
    value: function getSupplierHistorypath() {
      return '//supplier/session/history';
    }
  }, {
    key: "getProductsHistorypath",
    value: function getProductsHistorypath() {
      return '/products/sessions/history';
    }
  }, {
    key: "getUserHistorypath",
    value: function getUserHistorypath() {
      return '/users/sessions/history';
    }
  }, {
    key: "getSupplierOptionCodexPath",
    value: function getSupplierOptionCodexPath() {
      return '/supplier/option';
    }
  }, {
    key: "createLead",
    value: function () {
      var _createLead = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(data) {
        var url, response;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              url = "".concat(this.analyticsService, "/lead?organizationId=").concat(encodeURIComponent(data.organizationId));
              _context2.next = 3;
              return fetch(url, {
                method: 'POST',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify(data)
              });
            case 3:
              response = _context2.sent;
              if (!response.ok) {
                _context2.next = 8;
                break;
              }
              _context2.next = 7;
              return response.json();
            case 7:
              return _context2.abrupt("return", _context2.sent);
            case 8:
              throw new Error("Error from server while creating lead. HTTP status: ".concat(response.status));
            case 9:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function createLead(_x2) {
        return _createLead.apply(this, arguments);
      }
      return createLead;
    }()
  }]);
}();
var getIntervalInUnixTimestamp = function getIntervalInUnixTimestamp(interval) {
  if (interval.includes('d')) {
    return Number(interval.replace('d', '')) * 86400000;
  } else if (interval.includes('h')) {
    return Number(interval.replace('h', '')) * 3600000;
  }
  throw new Error('interval: ' + interval + ' not implemented yet');
};

var ReportHandler = /*#__PURE__*/function () {
  function ReportHandler(root) {
    _classCallCheck(this, ReportHandler);
    this.root = root;
    _defineProperty(this, "errorAccoured", function (e) {
      throw new Error('Could not create report ' + (e ? e.message : '') + " [".concat(DivaUtils.formatDate(new Date(), true, undefined, true), "] ").concat(DivaUtils.getCurrentTraceId() ? '[APM:' + DivaUtils.getCurrentTraceId() + '] ' : ''));
    });
  }
  return _createClass(ReportHandler, [{
    key: "reportService",
    get: function get() {
      return this.root.apiConfig.reportService;
    }
  }, {
    key: "basketService",
    get: function get() {
      return this.root.apiConfig.basketService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "createReport",
    value: function () {
      var _createReport = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(basketId, type, useDefaultPdfField) {
        var fullUrl, res, resData, patch, val;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              fullUrl = this.reportService + '/Report';
              _context.prev = 1;
              _context.next = 4;
              return fetch("".concat(fullUrl), {
                method: 'POST',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                  basketId: basketId,
                  type: type,
                  savePDF: true
                })
              });
            case 4:
              res = _context.sent;
              _context.next = 7;
              return res.json();
            case 7:
              resData = _context.sent;
              if (!res.ok) {
                _context.next = 15;
                break;
              }
              patch = [{
                path: '/PDFDocumentURL',
                value: resData.url,
                op: 'replace'
              }];
              if (!useDefaultPdfField) {
                val = {};
                val[type] = resData.url;
                patch = [{
                  path: '/pdfs',
                  value: val,
                  op: 'replace'
                }];
              }
              fetch("".concat(this.basketService, "/baskets/").concat(basketId), {
                method: 'PATCH',
                body: JSON.stringify({
                  patch: patch
                }),
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
              return _context.abrupt("return", resData);
            case 15:
              this.errorAccoured();
            case 16:
              _context.next = 21;
              break;
            case 18:
              _context.prev = 18;
              _context.t0 = _context["catch"](1);
              this.errorAccoured(_context.t0);
            case 21:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[1, 18]]);
      }));
      function createReport(_x, _x2, _x3) {
        return _createReport.apply(this, arguments);
      }
      return createReport;
    }()
  }, {
    key: "shortenUrl",
    value: function () {
      var _shortenUrl = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(url) {
        var fullUrl, res, resData;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              fullUrl = this.reportService + '/Url/Shorten';
              _context2.prev = 1;
              _context2.next = 4;
              return fetch("".concat(fullUrl, "?url=").concat(url), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              res = _context2.sent;
              _context2.next = 7;
              return res.text();
            case 7:
              resData = _context2.sent;
              if (!res.ok) {
                _context2.next = 12;
                break;
              }
              return _context2.abrupt("return", resData);
            case 12:
              return _context2.abrupt("return", url);
            case 13:
              _context2.next = 18;
              break;
            case 15:
              _context2.prev = 15;
              _context2.t0 = _context2["catch"](1);
              throw new Error('Could not get short url ' + _context2.t0.message);
            case 18:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this, [[1, 15]]);
      }));
      function shortenUrl(_x4) {
        return _shortenUrl.apply(this, arguments);
      }
      return shortenUrl;
    }()
  }]);
}();

var RequestStatus = /*#__PURE__*/function (RequestStatus) {
  RequestStatus["OPEN"] = "OPEN";
  RequestStatus["IN_PROGRESS"] = "IN_PROGRESS";
  RequestStatus["CLOSED"] = "CLOSED";
  return RequestStatus;
}({});

function ownKeys$8(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$8(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$8(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$8(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var SupportHandler = /*#__PURE__*/function () {
  function SupportHandler(root) {
    _classCallCheck(this, SupportHandler);
    this.root = root;
  }
  return _createClass(SupportHandler, [{
    key: "supportService",
    get: function get() {
      return this.root.apiConfig.supportService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "getCometChatApiToken",
    value: function () {
      var _getCometChatApiToken = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return fetch("".concat(this.supportService, "/chat/auth-token"), {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context.sent;
              _context.next = 6;
              return response.json();
            case 6:
              resData = _context.sent;
              if (!response.ok) {
                _context.next = 11;
                break;
              }
              return _context.abrupt("return", resData);
            case 11:
              return _context.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 12:
              _context.next = 17;
              break;
            case 14:
              _context.prev = 14;
              _context.t0 = _context["catch"](0);
              return _context.abrupt("return", Promise.reject(_context.t0));
            case 17:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[0, 14]]);
      }));
      function getCometChatApiToken() {
        return _getCometChatApiToken.apply(this, arguments);
      }
      return getCometChatApiToken;
    }()
  }, {
    key: "createCometChatGroup",
    value: function () {
      var _createCometChatGroup = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(divaNr) {
        var participantEmail,
          response,
          _args2 = arguments;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              participantEmail = _args2.length > 1 && _args2[1] !== undefined ? _args2[1] : undefined;
              _context2.prev = 1;
              _context2.next = 4;
              return fetch("".concat(this.supportService, "/chat/group"), {
                method: 'POST',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify(_objectSpread$8({
                  divaNr: divaNr
                }, participantEmail && {
                  participantEmail: participantEmail
                }))
              });
            case 4:
              response = _context2.sent;
              if (response.ok) {
                _context2.next = 7;
                break;
              }
              return _context2.abrupt("return", Promise.reject(null));
            case 7:
              _context2.next = 12;
              break;
            case 9:
              _context2.prev = 9;
              _context2.t0 = _context2["catch"](1);
              return _context2.abrupt("return", Promise.reject(_context2.t0));
            case 12:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this, [[1, 9]]);
      }));
      function createCometChatGroup(_x) {
        return _createCometChatGroup.apply(this, arguments);
      }
      return createCometChatGroup;
    }()
  }, {
    key: "joinCometChatGroup",
    value: function () {
      var _joinCometChatGroup = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(guid) {
        var response;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              _context3.prev = 0;
              _context3.next = 3;
              return fetch("".concat(this.supportService, "/chat/group/").concat(guid, "/join"), {
                method: 'PUT',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context3.sent;
              if (response.ok) {
                _context3.next = 6;
                break;
              }
              return _context3.abrupt("return", Promise.reject(null));
            case 6:
              _context3.next = 11;
              break;
            case 8:
              _context3.prev = 8;
              _context3.t0 = _context3["catch"](0);
              return _context3.abrupt("return", Promise.reject(_context3.t0));
            case 11:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this, [[0, 8]]);
      }));
      function joinCometChatGroup(_x2) {
        return _joinCometChatGroup.apply(this, arguments);
      }
      return joinCometChatGroup;
    }()
  }, {
    key: "listCometChatConversations",
    value: function () {
      var _listCometChatConversations = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              _context4.prev = 0;
              _context4.next = 3;
              return fetch("".concat(this.supportService, "/chat/conversations"), {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context4.sent;
              _context4.next = 6;
              return response.json();
            case 6:
              resData = _context4.sent;
              if (!response.ok) {
                _context4.next = 11;
                break;
              }
              return _context4.abrupt("return", resData.conversations);
            case 11:
              return _context4.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 12:
              _context4.next = 17;
              break;
            case 14:
              _context4.prev = 14;
              _context4.t0 = _context4["catch"](0);
              return _context4.abrupt("return", Promise.reject(_context4.t0));
            case 17:
            case "end":
              return _context4.stop();
          }
        }, _callee4, this, [[0, 14]]);
      }));
      function listCometChatConversations() {
        return _listCometChatConversations.apply(this, arguments);
      }
      return listCometChatConversations;
    }()
  }, {
    key: "sendCometChatMessage",
    value: function () {
      var _sendCometChatMessage = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(guid, message) {
        var response;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              _context5.prev = 0;
              _context5.next = 3;
              return fetch("".concat(this.supportService, "/chat/send-message"), {
                method: 'POST',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                  guid: guid,
                  message: message
                })
              });
            case 3:
              response = _context5.sent;
              if (response.ok) {
                _context5.next = 6;
                break;
              }
              return _context5.abrupt("return", Promise.reject(null));
            case 6:
              _context5.next = 11;
              break;
            case 8:
              _context5.prev = 8;
              _context5.t0 = _context5["catch"](0);
              return _context5.abrupt("return", Promise.reject(_context5.t0));
            case 11:
            case "end":
              return _context5.stop();
          }
        }, _callee5, this, [[0, 8]]);
      }));
      function sendCometChatMessage(_x3, _x4) {
        return _sendCometChatMessage.apply(this, arguments);
      }
      return sendCometChatMessage;
    }()
  }, {
    key: "sendCometChatImage",
    value: function () {
      var _sendCometChatImage = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(guid, imageUrl) {
        var response;
        return _regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              _context6.prev = 0;
              _context6.next = 3;
              return fetch("".concat(this.supportService, "/chat/send-image"), {
                method: 'POST',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                  guid: guid,
                  imageUrl: imageUrl
                })
              });
            case 3:
              response = _context6.sent;
              if (response.ok) {
                _context6.next = 6;
                break;
              }
              return _context6.abrupt("return", Promise.reject(null));
            case 6:
              _context6.next = 11;
              break;
            case 8:
              _context6.prev = 8;
              _context6.t0 = _context6["catch"](0);
              return _context6.abrupt("return", Promise.reject(_context6.t0));
            case 11:
            case "end":
              return _context6.stop();
          }
        }, _callee6, this, [[0, 8]]);
      }));
      function sendCometChatImage(_x5, _x6) {
        return _sendCometChatImage.apply(this, arguments);
      }
      return sendCometChatImage;
    }()
  }, {
    key: "listFriends",
    value: function () {
      var _listFriends = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) switch (_context7.prev = _context7.next) {
            case 0:
              _context7.prev = 0;
              _context7.next = 3;
              return fetch("".concat(this.supportService, "/chat/list-friends"), {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context7.sent;
              _context7.next = 6;
              return response.json();
            case 6:
              resData = _context7.sent;
              if (!response.ok) {
                _context7.next = 11;
                break;
              }
              return _context7.abrupt("return", resData.friends);
            case 11:
              return _context7.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 12:
              _context7.next = 17;
              break;
            case 14:
              _context7.prev = 14;
              _context7.t0 = _context7["catch"](0);
              return _context7.abrupt("return", Promise.reject(_context7.t0));
            case 17:
            case "end":
              return _context7.stop();
          }
        }, _callee7, this, [[0, 14]]);
      }));
      function listFriends() {
        return _listFriends.apply(this, arguments);
      }
      return listFriends;
    }()
  }, {
    key: "createClientRequest",
    value: function () {
      var _createClientRequest = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee8(clientRequest) {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee8$(_context8) {
          while (1) switch (_context8.prev = _context8.next) {
            case 0:
              _context8.prev = 0;
              _context8.next = 3;
              return fetch("".concat(this.supportService, "/client-requests"), {
                method: 'POST',
                body: JSON.stringify(clientRequest),
                headers: {
                  authorization: "Bearer ".concat(this.jwt),
                  'content-type': 'application/json'
                }
              });
            case 3:
              response = _context8.sent;
              _context8.next = 6;
              return response.json();
            case 6:
              resData = _context8.sent;
              return _context8.abrupt("return", resData);
            case 10:
              _context8.prev = 10;
              _context8.t0 = _context8["catch"](0);
              return _context8.abrupt("return", Promise.reject(_context8.t0));
            case 13:
            case "end":
              return _context8.stop();
          }
        }, _callee8, this, [[0, 10]]);
      }));
      function createClientRequest(_x7) {
        return _createClientRequest.apply(this, arguments);
      }
      return createClientRequest;
    }()
  }, {
    key: "updateClientRequest",
    value: function () {
      var _updateClientRequest = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee9(id, state) {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee9$(_context9) {
          while (1) switch (_context9.prev = _context9.next) {
            case 0:
              _context9.prev = 0;
              _context9.next = 3;
              return fetch("".concat(this.supportService, "/client-requests/").concat(id), {
                method: 'PATCH',
                body: JSON.stringify({
                  state: state
                }),
                headers: {
                  authorization: "Bearer ".concat(this.jwt),
                  'content-type': 'application/json'
                }
              });
            case 3:
              response = _context9.sent;
              _context9.next = 6;
              return response.json();
            case 6:
              resData = _context9.sent;
              return _context9.abrupt("return", resData);
            case 10:
              _context9.prev = 10;
              _context9.t0 = _context9["catch"](0);
              return _context9.abrupt("return", Promise.reject(_context9.t0));
            case 13:
            case "end":
              return _context9.stop();
          }
        }, _callee9, this, [[0, 10]]);
      }));
      function updateClientRequest(_x8, _x9) {
        return _updateClientRequest.apply(this, arguments);
      }
      return updateClientRequest;
    }()
  }, {
    key: "listClientRequests",
    value: function () {
      var _listClientRequests = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee10$(_context10) {
          while (1) switch (_context10.prev = _context10.next) {
            case 0:
              _context10.prev = 0;
              _context10.next = 3;
              return fetch("".concat(this.supportService, "/client-requests"), {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context10.sent;
              _context10.next = 6;
              return response.json();
            case 6:
              resData = _context10.sent;
              if (!response.ok) {
                _context10.next = 11;
                break;
              }
              return _context10.abrupt("return", resData.clientRequests);
            case 11:
              return _context10.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 12:
              _context10.next = 17;
              break;
            case 14:
              _context10.prev = 14;
              _context10.t0 = _context10["catch"](0);
              return _context10.abrupt("return", Promise.reject(_context10.t0));
            case 17:
            case "end":
              return _context10.stop();
          }
        }, _callee10, this, [[0, 14]]);
      }));
      function listClientRequests() {
        return _listClientRequests.apply(this, arguments);
      }
      return listClientRequests;
    }()
  }, {
    key: "listActivePlannings",
    value: function () {
      var _listActivePlannings = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
        var response, resData;
        return _regeneratorRuntime.wrap(function _callee11$(_context11) {
          while (1) switch (_context11.prev = _context11.next) {
            case 0:
              _context11.prev = 0;
              _context11.next = 3;
              return fetch("".concat(this.supportService, "/planner/active"), {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 3:
              response = _context11.sent;
              _context11.next = 6;
              return response.json();
            case 6:
              resData = _context11.sent;
              if (!response.ok) {
                _context11.next = 11;
                break;
              }
              return _context11.abrupt("return", resData.data);
            case 11:
              return _context11.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 12:
              _context11.next = 17;
              break;
            case 14:
              _context11.prev = 14;
              _context11.t0 = _context11["catch"](0);
              return _context11.abrupt("return", Promise.reject(_context11.t0));
            case 17:
            case "end":
              return _context11.stop();
          }
        }, _callee11, this, [[0, 14]]);
      }));
      function listActivePlannings() {
        return _listActivePlannings.apply(this, arguments);
      }
      return listActivePlannings;
    }()
  }]);
}();

var LOG$5 = getLogger('Framework', 'AuthorizationHandler');
var AuthorizationHandler = /*#__PURE__*/function () {
  function AuthorizationHandler(root) {
    _classCallCheck(this, AuthorizationHandler);
    this.root = root;
  }
  return _createClass(AuthorizationHandler, [{
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "userID",
    get: function get() {
      var _this$root$user;
      return (_this$root$user = this.root.user) === null || _this$root$user === void 0 ? void 0 : _this$root$user._id;
    }
  }, {
    key: "authService",
    get: function get() {
      return this.root.apiConfig.authService;
    }
  }, {
    key: "setOnlineState",
    value: function () {
      var _setOnlineState = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(interval) {
        var url, requestBody;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (!this.userID) {
                _context.next = 12;
                break;
              }
              url = this.authService + '/users/online/' + this.userID;
              requestBody = {
                interval: interval
              };
              _context.prev = 3;
              _context.next = 6;
              return fetch(url, {
                method: 'PATCH',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify(requestBody)
              }).then(function (res) {
                if (res.status !== 200) {
                  throw new Error('Error updating online state');
                }
                LOG$5.debug('Updating online state.');
              });
            case 6:
              _context.sent;
              _context.next = 12;
              break;
            case 9:
              _context.prev = 9;
              _context.t0 = _context["catch"](3);
              LOG$5.error(new DivaError('Error updating online state', {
                cause: _context.t0
              }));
            case 12:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[3, 9]]);
      }));
      function setOnlineState(_x2) {
        return _setOnlineState.apply(this, arguments);
      }
      return setOnlineState;
    }()
  }, {
    key: "getOnlineStates",
    value: function () {
      var _getOnlineStates = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(userIds) {
        var userIdString, url, response, resData;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              _context2.prev = 0;
              userIdString = userIds.join(',');
              url = "".concat(this.authService, "/users/online/").concat(userIdString);
              _context2.next = 5;
              return fetch(url, {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 5:
              response = _context2.sent;
              _context2.next = 8;
              return response.json();
            case 8:
              resData = _context2.sent;
              if (!response.ok) {
                _context2.next = 13;
                break;
              }
              return _context2.abrupt("return", resData.data);
            case 13:
              return _context2.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 14:
              _context2.next = 19;
              break;
            case 16:
              _context2.prev = 16;
              _context2.t0 = _context2["catch"](0);
              return _context2.abrupt("return", Promise.reject(_context2.t0));
            case 19:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this, [[0, 16]]);
      }));
      function getOnlineStates(_x3) {
        return _getOnlineStates.apply(this, arguments);
      }
      return getOnlineStates;
    }()
  }, {
    key: "authorize",
    value: function () {
      var _authorize = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(_ref) {
        var _errorCode;
        var organizationId, nToken, validParents, validOrganizationTypes, excludeOrganizations, force, url, response, result, error, errorCode, errorResponse;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              organizationId = _ref.organizationId, nToken = _ref.nToken, validParents = _ref.validParents, validOrganizationTypes = _ref.validOrganizationTypes, excludeOrganizations = _ref.excludeOrganizations, force = _ref.force;
              url = new URL("".concat(this.authService, "/v2/authorization/users"));
              if (organizationId) {
                url.searchParams.append('organizationId', organizationId);
              }
              if (force) {
                url.searchParams.append('force', 'true');
              }
              _context3.next = 6;
              return this.fetch({
                url: url.toString(),
                method: 'POST',
                jwt: nToken,
                body: {
                  validParents: validParents,
                  validOrganizationTypes: validOrganizationTypes,
                  excludeOrganizations: excludeOrganizations
                }
              });
            case 6:
              response = _context3.sent;
              if (!response.ok) {
                _context3.next = 14;
                break;
              }
              _context3.next = 10;
              return response.json();
            case 10:
              result = _context3.sent;
              if (!result.requestedOrganizationId) {
                _context3.next = 13;
                break;
              }
              throw new DivaError('Invalid Organization', {
                code: 'CORE_0003',
                custom: {
                  requestedOrganizationId: result.requestedOrganizationId,
                  organizationId: result.organizationId
                }
              });
            case 13:
              return _context3.abrupt("return", result);
            case 14:
              error = undefined;
              errorCode = undefined;
              _context3.prev = 16;
              _context3.next = 19;
              return response.json();
            case 19:
              errorResponse = _context3.sent;
              error = errorResponse.error;
              errorCode = errorResponse.errorCode;
              _context3.next = 26;
              break;
            case 24:
              _context3.prev = 24;
              _context3.t0 = _context3["catch"](16);
            case 26:
              if (!(response.status == 401)) {
                _context3.next = 28;
                break;
              }
              throw new DivaError('Authorization Failed', {
                code: 'CORE_0003'
              });
            case 28:
              throw new DivaError("Error from server while authorizing user. HTTP status: ".concat(response.status), {
                code: (_errorCode = errorCode) !== null && _errorCode !== void 0 ? _errorCode : 'CORE_0001',
                cause: error,
                custom: {
                  httpStatus: response.status
                }
              });
            case 29:
            case "end":
              return _context3.stop();
          }
        }, _callee3, this, [[16, 24]]);
      }));
      function authorize(_x4) {
        return _authorize.apply(this, arguments);
      }
      return authorize;
    }()
  }, {
    key: "register",
    value: function () {
      var _register = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(_ref2) {
        var email, password, name, familyName, invitationId, validParents, validOrganizationTypes, excludeOrganizations, otp, url, response, error;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              email = _ref2.email, password = _ref2.password, name = _ref2.name, familyName = _ref2.familyName, invitationId = _ref2.invitationId, validParents = _ref2.validParents, validOrganizationTypes = _ref2.validOrganizationTypes, excludeOrganizations = _ref2.excludeOrganizations, otp = _ref2.otp;
              url = "".concat(this.authService, "/v2/authorization/users/register?invitationId=").concat(encodeURIComponent(invitationId));
              _context4.next = 4;
              return this.fetch({
                url: url,
                method: 'POST',
                jwt: this.jwt,
                body: {
                  name: name,
                  familyName: familyName,
                  email: email,
                  password: password,
                  otp: otp,
                  validParents: validParents,
                  validOrganizationTypes: validOrganizationTypes,
                  excludeOrganizations: excludeOrganizations
                }
              });
            case 4:
              response = _context4.sent;
              if (!response.ok) {
                _context4.next = 7;
                break;
              }
              return _context4.abrupt("return", response.json());
            case 7:
              error = undefined;
              _context4.prev = 8;
              _context4.next = 11;
              return response.json();
            case 11:
              error = _context4.sent.error;
              _context4.next = 16;
              break;
            case 14:
              _context4.prev = 14;
              _context4.t0 = _context4["catch"](8);
            case 16:
              if (!(response.status == 401)) {
                _context4.next = 18;
                break;
              }
              throw new DivaError('Login Failed', {
                code: 'CORE_0003'
              });
            case 18:
              if (!(response.status == 404)) {
                _context4.next = 20;
                break;
              }
              throw new DivaError('Resource not found', {
                code: 'CORE_0002'
              });
            case 20:
              throw new DivaError("Error from server while authorizing user. HTTP status: ".concat(response.status), {
                code: 'CORE_0001',
                cause: error,
                custom: {
                  httpStatus: response.status
                }
              });
            case 21:
            case "end":
              return _context4.stop();
          }
        }, _callee4, this, [[8, 14]]);
      }));
      function register(_x5) {
        return _register.apply(this, arguments);
      }
      return register;
    }()
  }, {
    key: "login",
    value: function () {
      var _login = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(_ref3) {
        var organizationId, email, password, simple, validParents, validOrganizationTypes, invitationId, otp, excludeOrganizations, url, queryParams, response, errorResponse, _errorResponse$error;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              organizationId = _ref3.organizationId, email = _ref3.email, password = _ref3.password, simple = _ref3.simple, validParents = _ref3.validParents, validOrganizationTypes = _ref3.validOrganizationTypes, invitationId = _ref3.invitationId, otp = _ref3.otp, excludeOrganizations = _ref3.excludeOrganizations;
              url = "".concat(this.authService, "/v2/authorization/users/login");
              queryParams = [];
              if (organizationId && !otp) {
                queryParams.push("organizationId=".concat(organizationId));
              }
              if (invitationId) {
                queryParams.push("invitationId=".concat(invitationId));
              }
              if (otp) {
                queryParams.push("otp=".concat(otp));
              }
              if (queryParams.length > 0) {
                url = "".concat(url, "?").concat(queryParams.join('&'));
              }
              _context5.next = 9;
              return this.fetch({
                url: url,
                method: 'POST',
                jwt: this.jwt,
                body: {
                  email: email,
                  password: password,
                  simple: simple,
                  validParents: validParents,
                  validOrganizationTypes: validOrganizationTypes,
                  excludeOrganizations: excludeOrganizations
                }
              });
            case 9:
              response = _context5.sent;
              if (!response.ok) {
                _context5.next = 12;
                break;
              }
              return _context5.abrupt("return", response.json());
            case 12:
              errorResponse = undefined;
              _context5.prev = 13;
              _context5.next = 16;
              return response.json();
            case 16:
              errorResponse = _context5.sent;
              _context5.next = 21;
              break;
            case 19:
              _context5.prev = 19;
              _context5.t0 = _context5["catch"](13);
            case 21:
              if (!(response.status == 401)) {
                _context5.next = 23;
                break;
              }
              throw new DivaError('Login Failed', {
                code: 'CORE_0003'
              });
            case 23:
              if (!(response.status == 403)) {
                _context5.next = 27;
                break;
              }
              if (!(errorResponse.errorCode == 'AUTH_0007')) {
                _context5.next = 26;
                break;
              }
              throw new DivaError(errorResponse.error, {
                code: 'CORE_0002'
              });
            case 26:
              throw new DivaError('Login Failed', {
                code: 'CORE_0003'
              });
            case 27:
              if (!(response.status == 404)) {
                _context5.next = 29;
                break;
              }
              throw new DivaError((_errorResponse$error = errorResponse.error) !== null && _errorResponse$error !== void 0 ? _errorResponse$error : 'Resource not found', {
                code: 'CORE_0002'
              });
            case 29:
              throw new DivaError("Error from server while authorizing user. HTTP status: ".concat(response.status), {
                code: 'CORE_0001',
                custom: {
                  httpStatus: response.status
                }
              });
            case 30:
            case "end":
              return _context5.stop();
          }
        }, _callee5, this, [[13, 19]]);
      }));
      function login(_x6) {
        return _login.apply(this, arguments);
      }
      return login;
    }()
  }, {
    key: "logout",
    value: function () {
      var _logout = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(_ref4) {
        var callbackUri, response;
        return _regeneratorRuntime.wrap(function _callee6$(_context6) {
          while (1) switch (_context6.prev = _context6.next) {
            case 0:
              callbackUri = _ref4.callbackUri;
              _context6.prev = 1;
              _context6.next = 4;
              return this.fetch({
                url: "".concat(this.authService, "/v2/authorization/users/logout?callbackUri=").concat(encodeURIComponent(callbackUri)),
                method: 'POST',
                jwt: this.root.storedNToken
              });
            case 4:
              response = _context6.sent;
              if (!response.ok) {
                _context6.next = 7;
                break;
              }
              return _context6.abrupt("return", response.json());
            case 7:
              throw new DivaError('Error from server while logging out', {
                code: 'CORE_0001',
                custom: {
                  httpStatus: response.status
                }
              });
            case 10:
              _context6.prev = 10;
              _context6.t0 = _context6["catch"](1);
              if (!(_context6.t0 instanceof DivaError)) {
                _context6.next = 14;
                break;
              }
              throw _context6.t0;
            case 14:
              throw new DivaError('Error while logging out', {
                code: 'CORE_0001',
                cause: _context6.t0
              });
            case 15:
            case "end":
              return _context6.stop();
          }
        }, _callee6, this, [[1, 10]]);
      }));
      function logout(_x7) {
        return _logout.apply(this, arguments);
      }
      return logout;
    }()
  }, {
    key: "fetchLoginProvider",
    value: function () {
      var _fetchLoginProvider = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee7(_ref5) {
        var email, response;
        return _regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) switch (_context7.prev = _context7.next) {
            case 0:
              email = _ref5.email;
              _context7.prev = 1;
              _context7.next = 4;
              return this.fetch({
                url: "".concat(this.authService, "/v2/provider?email=").concat(encodeURIComponent(email)),
                method: 'GET',
                jwt: this.jwt
              });
            case 4:
              response = _context7.sent;
              if (!response.ok) {
                _context7.next = 7;
                break;
              }
              return _context7.abrupt("return", response.json());
            case 7:
              throw new DivaError('Error from server while loading provider info', {
                code: 'CORE_0001',
                custom: {
                  httpStatus: response.status
                }
              });
            case 10:
              _context7.prev = 10;
              _context7.t0 = _context7["catch"](1);
              if (!(_context7.t0 instanceof DivaError)) {
                _context7.next = 14;
                break;
              }
              throw _context7.t0;
            case 14:
              throw new DivaError('Error while loading provider info', {
                code: 'CORE_0001',
                cause: _context7.t0
              });
            case 15:
            case "end":
              return _context7.stop();
          }
        }, _callee7, this, [[1, 10]]);
      }));
      function fetchLoginProvider(_x8) {
        return _fetchLoginProvider.apply(this, arguments);
      }
      return fetchLoginProvider;
    }()
  }, {
    key: "fetch",
    value: function (_fetch) {
      function fetch(_x) {
        return _fetch.apply(this, arguments);
      }
      fetch.toString = function () {
        return _fetch.toString();
      };
      return fetch;
    }(/*#__PURE__*/function () {
      var _ref7 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee8(_ref6) {
        var url, _ref6$method, method, jwt, body, headers;
        return _regeneratorRuntime.wrap(function _callee8$(_context8) {
          while (1) switch (_context8.prev = _context8.next) {
            case 0:
              url = _ref6.url, _ref6$method = _ref6.method, method = _ref6$method === void 0 ? 'GET' : _ref6$method, jwt = _ref6.jwt, body = _ref6.body;
              headers = {
                'Content-Type': 'application/json',
                'X-Session-Id': DivaUtils.SessionId
              };
              if (jwt) {
                headers.Authorization = "Bearer ".concat(jwt);
              }
              _context8.next = 5;
              return fetch(url, {
                method: method,
                headers: headers,
                body: body ? JSON.stringify(body) : undefined
              });
            case 5:
              return _context8.abrupt("return", _context8.sent);
            case 6:
            case "end":
              return _context8.stop();
          }
        }, _callee8);
      }));
      return function (_x9) {
        return _ref7.apply(this, arguments);
      };
    }())
  }, {
    key: "getInvitationValue",
    value: function () {
      var _getInvitationValue = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee9(what, value) {
        var url, response, resData;
        return _regeneratorRuntime.wrap(function _callee9$(_context9) {
          while (1) switch (_context9.prev = _context9.next) {
            case 0:
              _context9.prev = 0;
              url = "".concat(this.authService, "/invitations/").concat(value, "/").concat(what);
              _context9.next = 4;
              return fetch(url, {
                method: 'GET',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              response = _context9.sent;
              if (!(response.status === 404)) {
                _context9.next = 7;
                break;
              }
              return _context9.abrupt("return", undefined);
            case 7:
              _context9.next = 9;
              return response.json();
            case 9:
              resData = _context9.sent;
              if (!response.ok) {
                _context9.next = 14;
                break;
              }
              return _context9.abrupt("return", resData);
            case 14:
              return _context9.abrupt("return", Promise.reject(resData === null || resData === void 0 ? void 0 : resData.error));
            case 15:
              _context9.next = 20;
              break;
            case 17:
              _context9.prev = 17;
              _context9.t0 = _context9["catch"](0);
              return _context9.abrupt("return", Promise.reject(_context9.t0));
            case 20:
            case "end":
              return _context9.stop();
          }
        }, _callee9, this, [[0, 17]]);
      }));
      function getInvitationValue(_x10, _x11) {
        return _getInvitationValue.apply(this, arguments);
      }
      return getInvitationValue;
    }()
  }, {
    key: "updateUserLanguage",
    value: function () {
      var _updateUserLanguage = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee10(language) {
        var url, patch, response;
        return _regeneratorRuntime.wrap(function _callee10$(_context10) {
          while (1) switch (_context10.prev = _context10.next) {
            case 0:
              _context10.prev = 0;
              url = this.authService + '/v2/users/' + this.userID;
              patch = [{
                op: 'replace',
                path: '/language',
                value: language
              }];
              _context10.next = 5;
              return fetch(url, {
                method: 'PATCH',
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                  patch: patch
                })
              });
            case 5:
              response = _context10.sent;
              if (!(response.status !== 200)) {
                _context10.next = 8;
                break;
              }
              throw new DivaError('Error updating user language');
            case 8:
              _context10.next = 10;
              return response.json();
            case 10:
              return _context10.abrupt("return", _context10.sent);
            case 13:
              _context10.prev = 13;
              _context10.t0 = _context10["catch"](0);
              LOG$5.error(new DivaError('Error updating user language', {
                cause: _context10.t0
              }));
            case 16:
            case "end":
              return _context10.stop();
          }
        }, _callee10, this, [[0, 13]]);
      }));
      function updateUserLanguage(_x12) {
        return _updateUserLanguage.apply(this, arguments);
      }
      return updateUserLanguage;
    }()
  }]);
}();

var ClientArticleHandler = /*#__PURE__*/function () {
  function ClientArticleHandler(root) {
    _classCallCheck(this, ClientArticleHandler);
    this.root = root;
  }
  return _createClass(ClientArticleHandler, [{
    key: "clientArticleService",
    get: function get() {
      return this.root.apiConfig.clientArticleService;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "saveProductsSMArticles",
    value: function () {
      var _saveProductsSMArticles = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(data, serverUrl, organizationId) {
        var fullUrl, response;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              fullUrl = serverUrl + '/v1/pfisterproducts/smarticle?organizationId=' + organizationId;
              _context.prev = 1;
              _context.next = 4;
              return axios.post(fullUrl, JSON.stringify({
                products: data.products,
                removedProductIds: data.removedProductIds,
                parentProductId: data.parentProductId
              }), {
                headers: {
                  Authorization: 'Bearer ' + this.jwt,
                  'Content-Type': 'application/json'
                }
              });
            case 4:
              response = _context.sent;
              if (!(response.status === 200)) {
                _context.next = 9;
                break;
              }
              _context.next = 8;
              return response.data.products;
            case 8:
              return _context.abrupt("return", _context.sent);
            case 9:
              _context.next = 14;
              break;
            case 11:
              _context.prev = 11;
              _context.t0 = _context["catch"](1);
              throw new Error('Unexpected error occurred during saveProductsSMArticles', _context.t0);
            case 14:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[1, 11]]);
      }));
      function saveProductsSMArticles(_x, _x2, _x3) {
        return _saveProductsSMArticles.apply(this, arguments);
      }
      return saveProductsSMArticles;
    }()
  }]);
}();

function ownKeys$7(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$7(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$7(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$7(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOGINMODE_LOCALSTORAGE_KEY = 'diva-login-mode';
var LOG$4 = getLogger('Framework', 'root');
var RootStore = /*#__PURE__*/function () {
  function RootStore(_ref) {
    var _ref2,
      _this = this;
    var components = _ref.components,
      spinnerClass = _ref.spinnerClass,
      language = _ref.language,
      organizationId = _ref.organizationId,
      domain = _ref.domain,
      configProvider = _ref.configUrl,
      defaultApiConfig = _ref.defaultApiConfig,
      component = _ref.currentComponent,
      _ref$identifier = _ref.identifier,
      identifier = _ref$identifier === void 0 ? 'COMPONENT' : _ref$identifier,
      _ref$telemetry = _ref.telemetry,
      telemetry = _ref$telemetry === void 0 ? true : _ref$telemetry,
      onEvent = _ref.onEvent;
    _classCallCheck(this, RootStore);
    _defineProperty(this, "contentStore", void 0);
    _defineProperty(this, "configurationStore", void 0);
    _defineProperty(this, "dataStore", void 0);
    _defineProperty(this, "loadingAndErrorStore", void 0);
    _defineProperty(this, "browserStateStore", void 0);
    _defineProperty(this, "authorizationStore", void 0);
    _defineProperty(this, "_onEvent", void 0);
    _defineProperty(this, "events", []);
    _defineProperty(this, "_initializing", true);
    _defineProperty(this, "_language", 'de');
    _defineProperty(this, "_loginMode", (_ref2 = localStorage.getItem(LOGINMODE_LOCALSTORAGE_KEY)) !== null && _ref2 !== void 0 ? _ref2 : 'offline');
    _defineProperty(this, "_apiHandler", void 0);
    _defineProperty(this, "_productHandler", void 0);
    _defineProperty(this, "_reportHandler", void 0);
    _defineProperty(this, "_organizationHandler", void 0);
    _defineProperty(this, "_mediaHandler", void 0);
    _defineProperty(this, "_adminHandler", void 0);
    _defineProperty(this, "_analyticsHandler", void 0);
    _defineProperty(this, "_supportHandler", void 0);
    _defineProperty(this, "_authorizationHandler", void 0);
    _defineProperty(this, "_clientArticleHandler", void 0);
    _defineProperty(this, "_initalComponent", void 0);
    makeObservable(this, {
      _initializing: observable,
      _language: observable,
      _loginMode: observable,
      language: computed,
      changeLanguage: action,
      changeLoginMode: action,
      initializing: computed
    });
    this._onEvent = onEvent;
    //be compatible with the deprecated configProvider setting
    var apiConfig = defaultApiConfig ? _objectSpread$7({}, defaultApiConfig) : {};
    !apiConfig.adminService && configProvider ? apiConfig.adminService = configProvider : false;
    this.dataStore = new DataStore(this);
    this.authorizationStore = new AuthorizationStore(this);
    this.configurationStore = new ConfigurationStore(this, identifier, apiConfig, domain);
    this.browserStateStore = new BrowserStateStore(this);
    this.loadingAndErrorStore = new _default(this, spinnerClass);
    this.contentStore = new ContentStore(components, this);
    this._apiHandler = new ApiHandler(this);
    this._productHandler = new ProductHandler(this, this.contentStore.openModal.bind(this.contentStore), this.contentStore.closeModal.bind(this.contentStore));
    this._reportHandler = new ReportHandler(this);
    this._organizationHandler = new OrganizationHandler(this);
    this._mediaHandler = new MediaHandler(this);
    this._adminHandler = new AdminHandler(this);
    this._analyticsHandler = new AnalyticsHandler(this);
    this._supportHandler = new SupportHandler(this);
    this._authorizationHandler = new AuthorizationHandler(this);
    this._clientArticleHandler = new ClientArticleHandler(this);

    //every time the organizationId changes call initCache,
    //no idea what it does
    DivaUtils.loginMode = this._loginMode;
    reaction(function () {
      var _this$configurationSt;
      return {
        namespace: (_this$configurationSt = _this.configurationStore.locales) === null || _this$configurationSt === void 0 ? void 0 : _this$configurationSt.namespace
      };
    }, function (value, prev) {
      if (!instance.isInitialized || value.namespace == prev.namespace) return;
      if (value.namespace) changeNamespace(value.namespace);else changeNamespace('default');
    });
    autorun(function () {
      DivaUtils.initPriceFormat(_this.configurationStore.priceFormat);
      if (_this.configurationStore.countryCodesFile) {
        DivaUtils.countryCodeLocation = _this.configurationStore.countryCodesFile;
      }
    });
    DivaUtils.businessMetrics.onOpen();
    window.addEventListener('beforeunload', function () {
      DivaUtils.businessMetrics.onClose();
      flashLoggers();
    });
    this.initialize(telemetry, identifier, organizationId, domain, language, component);
  }

  /**
   * Changes the current language of the application
   * @param lang the new language
   */
  return _createClass(RootStore, [{
    key: "changeLanguage",
    value: function changeLanguage(lang) {
      var _this2 = this;
      this.loadingAndErrorStore.toggleLoading('language');
      instance.changeLanguage(lang, function (err) {
        if (err) {
          LOG$4.error(new DivaError('Could not change language', {
            cause: err,
            code: 'CORE_0007'
          }));
        } else {
          runInAction(function () {
            _this2._language = lang;
            _this2.browserStateStore.setStoredLanguage(_this2._language);
            if (['de', 'en', 'fr', 'it'].includes(_this2._language) && _this2.authorizationStore.loginState !== 'anon') {
              _this2._authorizationHandler.updateUserLanguage(_this2._language);
            }
          });
        }
        _this2.loadingAndErrorStore.toggleLoading('language');
      });
    }

    /**
     * The current language of the application
     */
  }, {
    key: "language",
    get: function get() {
      return this._language;
    }

    /**
     * Changes the current userMode
     * @param mode the new mode
     */
  }, {
    key: "changeLoginMode",
    value: function changeLoginMode(loginMode) {
      if (loginMode && this._loginMode && this._loginMode !== loginMode) {
        this.dataStore.clearSessionGuids();
      }
      this._loginMode = loginMode;
      DivaUtils.loginMode = loginMode;
      if (loginMode !== localStorage.getItem(LOGINMODE_LOCALSTORAGE_KEY)) {
        localStorage.setItem(LOGINMODE_LOCALSTORAGE_KEY, loginMode);
      }
    }
    /**
     * The current mode of the application
     */
  }, {
    key: "loginMode",
    get: function get() {
      return this._loginMode;
    }

    /**
     * The i18n translation function
     */
  }, {
    key: "t",
    get: function get() {
      return instance.t.bind(instance);
    }

    /**
     * The i18n languages
     */
  }, {
    key: "languages",
    get: function get() {
      var _this$configurationSt2, _this$configurationSt3;
      return (_this$configurationSt2 = (_this$configurationSt3 = this.configurationStore.locales) === null || _this$configurationSt3 === void 0 ? void 0 : _this$configurationSt3.available) !== null && _this$configurationSt2 !== void 0 ? _this$configurationSt2 : ['de'];
    }

    /**
     * The eventhandler register by the user of the application or a no-op if non was registered
     */
  }, {
    key: "onEvent",
    get: function get() {
      var _this3 = this;
      return function (event) {
        var _this3$_onEvent;
        (_this3$_onEvent = _this3._onEvent) === null || _this3$_onEvent === void 0 || _this3$_onEvent.call(_this3, event);
        //sends it to the subscribeEvents internally aswell
        _this3.events.forEach(function (fn) {
          return fn(event);
        });
      };
    }

    /**
     * Is true if the application is currently initializing
     */
  }, {
    key: "initializing",
    get: function get() {
      return this._initializing || !this.dataStore.organizationId;
    }

    /**
     * Triggers an event from outside of the application
     * @param event the event
     */
  }, {
    key: "onExternalEvent",
    value: function onExternalEvent(event) {
      this.events.forEach(function (fn) {
        return fn(event);
      });
    }

    /**
     * Subscribe an eventhandler for external events
     * @param fn the eventhandler
     */
  }, {
    key: "subscribeEvents",
    value: function subscribeEvents(fn) {
      this.events.push(fn);
    }

    /**
     * Unsubscribe an eventhandler from external events
     * @param fn the eventhandler
     */
  }, {
    key: "unSubscribeEvents",
    value: function unSubscribeEvents(fn) {
      this.events = this.events.filter(function (ev) {
        return ev !== fn;
      });
    }

    /**
     * get an ApiHandler instance with the current configuration
     */
  }, {
    key: "apiHandler",
    get: function get() {
      return this._apiHandler;
    }

    /**
     * get the productHander instance with the current configuration
     */
  }, {
    key: "productHandler",
    get: function get() {
      return this._productHandler;
    }

    /**
     * get the organizationHandler instance with the current configuration
     */
  }, {
    key: "organizationHandler",
    get: function get() {
      return this._organizationHandler;
    }

    /**
     * get the mediaHandler instance with the current configuration
     */
  }, {
    key: "mediaHandler",
    get: function get() {
      return this._mediaHandler;
    }
  }, {
    key: "adminHandler",
    get: function get() {
      return this._adminHandler;
    }
  }, {
    key: "reportHandler",
    get: function get() {
      return this._reportHandler;
    }
  }, {
    key: "supportHandler",
    get: function get() {
      return this._supportHandler;
    }
  }, {
    key: "analyticsHandler",
    get: function get() {
      return this._analyticsHandler;
    }
  }, {
    key: "clientArticleHandler",
    get: function get() {
      return this._clientArticleHandler;
    }
  }, {
    key: "authorizationHandler",
    get: function get() {
      return this._authorizationHandler;
    }
  }, {
    key: "doShowInitWarnBanner",
    get: function get() {
      return !!this.configurationStore.showInitWarnBanner;
    }
  }, {
    key: "apiConfig",
    get: function get() {
      return this.configurationStore.apiConfig;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.authorizationStore.zToken;
    }
  }, {
    key: "storedNToken",
    get: function get() {
      return this.browserStateStore.getStoredNToken();
    }
  }, {
    key: "user",
    get: function get() {
      return this.dataStore.user;
    }
  }, {
    key: "organization",
    get: function get() {
      return this.dataStore.organization;
    }
  }, {
    key: "allowedOrganizationTypes",
    get: function get() {
      return this.configurationStore.allowedOrganizationTypes;
    }
  }, {
    key: "validOrganizations",
    get: function get() {
      return this.configurationStore.validOrganizations;
    }
  }, {
    key: "excludedOrganizations",
    get: function get() {
      return this.configurationStore.excludedOrganizations;
    }

    /**
     * Initalizes the application
     *
     * @param organizationId the organizationId set via component property
     * @param domain the domain set via component property
     * @param identifier the identifier set via component property
     * @param language the language set via component property
     * @param component the inital component set via component property
     * @param telemetry the telemetry setting via component property
     */
  }, {
    key: "initialize",
    value: (function () {
      var _initialize = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(telemetry, identifier, organizationId, domain, language, component) {
        var _this4 = this;
        var _this$_initalComponen, _this$_initalComponen2, _configuration$pwa, _this$contentStore$cu, urlState, storedLanguage, storedOrganization, initialOrganization, initialLanguage, configuration, initLocalesResult, telemetrySettings, enableApm, disableDivaAnalyticsLocalStorage, disableDivaAnalytics, enableBusinessMetrics, _configuration$enviro5, _configuration$enviro6, myUserAgentInfo, header, manifest, result, warningText, _this$contentStore, verifyEmailToken, authObject, _urlState$component, _initialOrganization, email, _this$contentStore$cu2;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              LOG$4.startTransaction({
                event: 'initCore',
                message: 'Initalizing Core',
                labels: {
                  identifier: identifier,
                  organizationId: organizationId,
                  domain: domain,
                  language: language,
                  component: component === null || component === void 0 ? void 0 : component.type
                },
                eventId: 'INITIALIZE_CORE',
                warningTime: 5000,
                errorTime: 10000
              });
              _context.prev = 1;
              runInAction(function () {
                _this4._initializing = true;
              });
              this.loadingAndErrorStore.toggleLoading('initalize', true);
              LOG$4.successTransaction('UNTIL_INIT');
              _context.next = 7;
              return this.browserStateStore.loadUrlState();
            case 7:
              urlState = _context.sent;
              storedLanguage = this.browserStateStore.getStoredLanguage();
              storedOrganization = this.browserStateStore.getStoredOrganization(); //the inital state is derived in the fallowing order: component params > url > browserstore > configuration
              initialOrganization = organizationId || urlState.organization || storedOrganization;
              initialLanguage = language || urlState.language || storedLanguage;
              LOG$4.startTransaction({
                event: 'onLoadConfig',
                message: 'loading Config',
                eventId: 'LOAD_CONFIG'
              });

              //load core configuration based on initaly available information
              _context.next = 15;
              return this.configurationStore.fetchConfiguration({
                identifier: identifier,
                type: 'FRAMEWORK',
                domain: domain,
                organizationId: initialOrganization
              });
            case 15:
              configuration = _context.sent;
              this.configurationStore.configuration = configuration;
              this._initalComponent = component || urlState.component || this.configurationStore.defaultComponent;
              if (((_this$_initalComponen = this._initalComponent) === null || _this$_initalComponen === void 0 ? void 0 : _this$_initalComponen.route) == '' || ((_this$_initalComponen2 = this._initalComponent) === null || _this$_initalComponen2 === void 0 ? void 0 : _this$_initalComponen2.route) == '/login') {
                //open default route
                this._initalComponent = this.configurationStore.defaultComponent;
              }
              LOG$4.successTransaction('LOAD_CONFIG');
              LOG$4.startTransaction({
                event: 'onLoadServerData',
                message: 'load server data',
                eventId: 'LOAD_SERVER_DATA'
              });

              //async load locales data
              initLocalesResult = init(_objectSpread$7(_objectSpread$7({}, this.configurationStore.locales), {}, {
                defaultLng: initialLanguage,
                apiConfig: this.configurationStore.apiConfig
              }));
              telemetrySettings = this.configurationStore.telemetrySettings;
              enableApm = telemetry && (telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm) != false;
              disableDivaAnalyticsLocalStorage = localStorage.getItem('disableDivaAnalytics');
              disableDivaAnalytics = disableDivaAnalyticsLocalStorage !== undefined && disableDivaAnalyticsLocalStorage !== null && disableDivaAnalyticsLocalStorage === 'true';
              enableBusinessMetrics = telemetrySettings && (telemetrySettings.businessEvents == undefined || (telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.businessEvents)) && telemetry && !disableDivaAnalytics;
              if (telemetry && telemetrySettings !== null && telemetrySettings !== void 0 && telemetrySettings.cookieBotCbid) {
                initCookieBot(telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.cookieBotCbid, function (consent) {
                  if (consent.statistics) {
                    var _configuration$enviro;
                    init$1(enableApm, (_configuration$enviro = configuration.environment) !== null && _configuration$enviro !== void 0 ? _configuration$enviro : 'PROD', configuration.applicationName, typeof (telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm) == 'string' ? telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm : undefined);
                  }
                  if (consent.necessary && enableBusinessMetrics) {
                    var _configuration$enviro2;
                    var myUserAgentInfo = getUserAgentInfo();
                    DivaUtils.businessMetrics.init("production" != 'development', // true, - to local test on PETERPC
                    (_configuration$enviro2 = configuration.environment) !== null && _configuration$enviro2 !== void 0 ? _configuration$enviro2 : 'PROD', window.DIVA_VERSION, _this4.apiConfig.analyticsService, _this4.jwt, telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.personalData, myUserAgentInfo.family, myUserAgentInfo.os, myUserAgentInfo.deviceName, myUserAgentInfo.browser, myUserAgentInfo.screenWidth, myUserAgentInfo.screenHeight, myUserAgentInfo.osVersion, configuration.applicationEnvironment, initialLanguage);
                  }
                }, function (reason) {
                  var _configuration$enviro3;
                  LOG$4.error(new DivaError('Cookiebot initialization failed', {
                    code: 'CORE_0009',
                    custom: {
                      reason: reason
                    }
                  }));
                  init$1(enableApm, (_configuration$enviro3 = configuration.environment) !== null && _configuration$enviro3 !== void 0 ? _configuration$enviro3 : 'PROD', configuration.applicationName, typeof (telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm) == 'string' ? telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm : undefined);
                  if (enableBusinessMetrics) {
                    var _configuration$enviro4;
                    var myUserAgentInfo = getUserAgentInfo();
                    DivaUtils.businessMetrics.init("production" != 'development', (_configuration$enviro4 = configuration.environment) !== null && _configuration$enviro4 !== void 0 ? _configuration$enviro4 : 'PROD', window.DIVA_VERSION, _this4.apiConfig.analyticsService, _this4.jwt, telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.personalData, myUserAgentInfo.family, myUserAgentInfo.os, myUserAgentInfo.deviceName, myUserAgentInfo.browser, myUserAgentInfo.screenWidth, myUserAgentInfo.screenHeight, myUserAgentInfo.osVersion, configuration.applicationEnvironment, initialLanguage);
                  }
                });
              } else {
                init$1(enableApm, (_configuration$enviro5 = configuration.environment) !== null && _configuration$enviro5 !== void 0 ? _configuration$enviro5 : 'PROD', configuration.applicationName, typeof (telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm) == 'string' ? telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.apm : undefined);
                if (enableBusinessMetrics) {
                  myUserAgentInfo = getUserAgentInfo();
                  DivaUtils.businessMetrics.init("production" != 'development', // true, - to local test on PETERPC
                  (_configuration$enviro6 = configuration.environment) !== null && _configuration$enviro6 !== void 0 ? _configuration$enviro6 : 'PROD', window.DIVA_VERSION, this.apiConfig.analyticsService, this.jwt, telemetrySettings === null || telemetrySettings === void 0 ? void 0 : telemetrySettings.personalData, myUserAgentInfo.family, myUserAgentInfo.os, myUserAgentInfo.deviceName, myUserAgentInfo.browser, myUserAgentInfo.screenWidth, myUserAgentInfo.screenHeight, myUserAgentInfo.osVersion, configuration.applicationEnvironment, initialLanguage);
                }
              }
              apmIsInitalized();
              if (configuration.cssCustomFile) {
                header = document.getElementsByTagName('HEAD')[0];
                if (header) DivaUtils.loadCSS(configuration.cssCustomFile, header, undefined);
              }
              if ((_configuration$pwa = configuration.pwa) !== null && _configuration$pwa !== void 0 && _configuration$pwa.manifest) {
                manifest = document.createElement('link');
                manifest.rel = 'manifest';
                manifest.href = configuration.pwa.manifest;
                document.head.appendChild(manifest);
              }
              setOnErrorEvent(function (message, errorCode) {
                return _this4.onEvent({
                  type: 'onError',
                  data: {
                    message: message,
                    errorCode: errorCode
                  }
                });
              });

              //wait for all asnyc processes to finish and set the last state data
              _context.next = 34;
              return initLocalesResult;
            case 34:
              result = _context.sent;
              runInAction(function () {
                _this4._language = result;
                _this4.browserStateStore.setStoredLanguage(_this4._language);
              });
              warningText = this.t('init.deploymentwarntext', '');
              if (warningText.trim() !== '' && this.doShowInitWarnBanner) {
                (_this$contentStore = this.contentStore) === null || _this$contentStore === void 0 || _this$contentStore.openBanner({
                  key: 'InitialWarningBanner',
                  type: 'WARNING',
                  title: this.t('modals.warning', 'Warnung'),
                  text: warningText,
                  useLocalStorage: true
                });
              }
              LOG$4.successTransaction('LOAD_SERVER_DATA');
              LOG$4.startTransaction({
                event: 'onLoadUserData',
                message: 'load user data',
                eventId: 'LOAD_USER_DATA'
              });

              //load userdata
              _context.prev = 40;
              if (!urlState.authdata) {
                _context.next = 65;
                break;
              }
              authObject = JSON.parse(atob(urlState.authdata));
              _context.t0 = authObject === null || authObject === void 0 ? void 0 : authObject.path;
              _context.next = _context.t0 === 'openIdCallback' ? 46 : _context.t0 === 'resetPassword' ? 48 : _context.t0 === 'confirmEmail' ? 50 : _context.t0 === 'acceptInvitation' ? 52 : 62;
              break;
            case 46:
              if (authObject.error) {
                LOG$4.errorTransaction('LOAD_USER_DATA', 'CORE_0006', authObject.error);
                this.authorizationStore.showLogin(false, true);
              } else {
                initialOrganization = authObject.organizationId;
                if (urlState !== null && urlState !== void 0 && (_urlState$component = urlState.component) !== null && _urlState$component !== void 0 && (_urlState$component = _urlState$component.parameters) !== null && _urlState$component !== void 0 && _urlState$component.provider) {
                  this.browserStateStore.setStoredLoginMethod(urlState.component.parameters.provider);
                }
                this.browserStateStore.setStoredNToken(authObject.token, authObject.expiresBy);
              }
              return _context.abrupt("break", 63);
            case 48:
              if (authObject.error) {
                LOG$4.errorTransaction('LOAD_USER_DATA', authObject.code, authObject.error);
                this.loadingAndErrorStore.setError(authObject.error);
              } else {
                this.authorizationStore.showChangePassword(authObject.token);
              }
              return _context.abrupt("break", 63);
            case 50:
              if (authObject.error) {
                LOG$4.errorTransaction('LOAD_USER_DATA', authObject.code, authObject.error);
                this.loadingAndErrorStore.setError(authObject.error);
              } else {
                verifyEmailToken = authObject.token;
              }
              return _context.abrupt("break", 63);
            case 52:
              if (!authObject.error) {
                _context.next = 57;
                break;
              }
              LOG$4.errorTransaction('LOAD_INVITATION', authObject.code, authObject.error);
              this.loadingAndErrorStore.setError(authObject.error);
              _context.next = 61;
              break;
            case 57:
              if (!this.browserStateStore.getStoredNToken()) {
                _context.next = 60;
                break;
              }
              _context.next = 60;
              return this.authorizationStore.logout(undefined, undefined, undefined, true);
            case 60:
              this.authorizationStore.showWelcomeScreen(authObject.additionalParams.isNewUser, authObject.token, authObject.additionalParams.invitationOrgId);
            case 61:
              return _context.abrupt("break", 63);
            case 62:
              return _context.abrupt("break", 63);
            case 63:
              _context.next = 65;
              break;
            case 65:
              LOG$4.successTransaction('LOAD_USER_DATA');
              if (!(!this.browserStateStore.getStoredNToken() && this.configurationStore.hasAuthentication)) {
                _context.next = 80;
                break;
              }
              _context.prev = 67;
              _context.next = 70;
              return flowResult(this.authorizationStore.autorize((_initialOrganization = initialOrganization) !== null && _initialOrganization !== void 0 ? _initialOrganization : configuration.organizations[0]));
            case 70:
              _context.next = 77;
              break;
            case 72:
              _context.prev = 72;
              _context.t1 = _context["catch"](67);
              this.loadingAndErrorStore.setError(_context.t1);
              LOG$4.errorTransaction('INITIALIZE_CORE', _context.t1.code, 'Organization Error');
              return _context.abrupt("return");
            case 77:
              //now Login Page opens. The overwritten initComponent params get saved in restrictedComponent. this will later be evaluated in getRedirectUrl
              this.contentStore.restrictedComponent = this._initalComponent;
              this.authorizationStore.showLogin(urlState.debugLogin, false, initialOrganization);
              return _context.abrupt("return");
            case 80:
              //user is either logged in or no authentication is required
              if (!initialOrganization && !this.configurationStore.hasAuthentication) {
                //if no authentication, fallback to first organization in config
                initialOrganization = configuration.organizations[0];
              }
              _context.prev = 81;
              _context.next = 84;
              return flowResult(this.authorizationStore.autorize(initialOrganization, this.browserStateStore.getStoredNToken()));
            case 84:
              initialOrganization = _context.sent;
              _context.next = 92;
              break;
            case 87:
              _context.prev = 87;
              _context.t2 = _context["catch"](81);
              LOG$4.errorTransaction('INITIALIZE_CORE', 'CORE_0002', 'Error initializing Organization');
              this.loadingAndErrorStore.setError(_context.t2, 'CORE_0002', true);
              return _context.abrupt("return");
            case 92:
              _context.prev = 92;
              _context.next = 95;
              return flowResult(this.dataStore.updateOrganizationInternal(initialOrganization));
            case 95:
              _context.next = 102;
              break;
            case 97:
              _context.prev = 97;
              _context.t3 = _context["catch"](92);
              LOG$4.errorTransaction('INITIALIZE_CORE', 'CORE_0002', 'Error updating Organization');
              this.loadingAndErrorStore.setError(_context.t3);
              return _context.abrupt("return");
            case 102:
              if (!verifyEmailToken) {
                _context.next = 108;
                break;
              }
              _context.next = 105;
              return this.apiHandler.verifyEmail({
                token: verifyEmailToken
              });
            case 105:
              email = _context.sent;
              _context.next = 108;
              return flowResult(this.authorizationStore.login(email, undefined, true, initialOrganization));
            case 108:
              _context.next = 113;
              break;
            case 110:
              _context.prev = 110;
              _context.t4 = _context["catch"](40);
              if (_context.t4 instanceof DivaError && _context.t4.name == 'AUTH_0006') {
                LOG$4.errorTransaction('INITIALIZE_CORE', 'AUTH_0006', 'Existing verification token not valid.');
              } else {
                LOG$4.errorTransaction('INITIALIZE_CORE', 'CORE_0006', 'An error occured during initialization.');
              }
            case 113:
              this.initalizeView();
              if (this.jwt) {
                DivaUtils.businessMetrics.jwtSetter = this.jwt;
              } else {
                LOG$4.debug('No JWT available for Loging');
              }
              LOG$4.successTransaction('INITIALIZE_CORE', {
                identifier: identifier,
                organizationId: this.dataStore.organizationId,
                domain: domain,
                language: this._language,
                component: (_this$contentStore$cu = this.contentStore.currentComponent) === null || _this$contentStore$cu === void 0 ? void 0 : _this$contentStore$cu.type
              });
              _context.next = 123;
              break;
            case 118:
              _context.prev = 118;
              _context.t5 = _context["catch"](1);
              this.loadingAndErrorStore.toggleLoading('initalize', false);
              this.loadingAndErrorStore.setError(_context.t5);
              LOG$4.errorTransaction('INITIALIZE_CORE', 'CORE_0000', _context.t5.message, {
                identifier: identifier,
                organizationId: this.dataStore.organizationId,
                domain: domain,
                language: this._language,
                component: (_this$contentStore$cu2 = this.contentStore.currentComponent) === null || _this$contentStore$cu2 === void 0 ? void 0 : _this$contentStore$cu2.type
              });
            case 123:
              _context.prev = 123;
              this.loadingAndErrorStore.toggleLoading('initalize');
              runInAction(function () {
                _this4._initializing = false;
              });
              return _context.finish(123);
            case 127:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[1, 118, 123, 127], [40, 110], [67, 72], [81, 87], [92, 97]]);
      }));
      function initialize(_x, _x2, _x3, _x4, _x5, _x6) {
        return _initialize.apply(this, arguments);
      }
      return initialize;
    }())
  }, {
    key: "initalizeView",
    value: function initalizeView() {
      if (this.contentStore.currentComponent) {
        LOG$4.debug('View is already initialized');
        return;
      }
      if (this._initalComponent) {
        LOG$4.debug("Inital component", JSON.stringify(this._initalComponent, null, 2));
        this.contentStore.openComponent(this._initalComponent);
      } else {
        this.loadingAndErrorStore.setError(new DivaError('No inital component available', {
          code: 'CORE_0008'
        }));
      }
    }
  }, {
    key: "initalComponent",
    get: function get() {
      if (!this.contentStore.currentComponent) {
        return this._initalComponent;
      }
      return undefined;
    }
  }]);
}();

var _excluded$1 = ["children"];
function ownKeys$6(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$6(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$6(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$6(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var coreContext = /*#__PURE__*/createContext(null);
var DivaCoreProvider = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _store$configurationS;
  var children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded$1);
  var store = useMemo(function () {
    return new RootStore(props);
  }, []);
  useImperativeHandle(ref, function () {
    return {
      invoke: function invoke(event) {
        store.onExternalEvent(event);
      }
    };
  });
  var _useState = useState({
      actions: {
        openComponent: function openComponent(action) {
          return flowResult(store.contentStore.openComponent(action));
        },
        closeComponentInFullscreen: store.contentStore.closeComponentInFullscreen.bind(store.contentStore),
        setAbsoluteFullScreen: store.contentStore.setAbsoluteFullScreen.bind(store.contentStore),
        changeLanguage: store.changeLanguage.bind(store),
        changeLoginMode: store.changeLoginMode.bind(store),
        toggleLoading: store.loadingAndErrorStore.toggleLoading.bind(store.loadingAndErrorStore),
        loadModelViewer: store.contentStore.loadModelViewer.bind(store.contentStore),
        openModal: store.contentStore.openModal.bind(store.contentStore),
        closeModal: store.contentStore.closeModal.bind(store.contentStore),
        sendEmail: store.contentStore.sendEmail.bind(store.contentStore),
        onEvent: store.onEvent.bind(store),
        subscribeEvents: store.subscribeEvents.bind(store),
        unSubscribeEvents: store.unSubscribeEvents.bind(store),
        updateCustomLogo: store.contentStore.updateCustomLogo.bind(store.contentStore),
        updateCustomHeaderElement: store.contentStore.updateCustomHeaderElement.bind(store.contentStore),
        updateBreadcrumbs: store.contentStore.updateBreadcrumbs.bind(store.contentStore),
        toggleHidePrices: store.contentStore.toggleHidePrices.bind(store.contentStore),
        toggleHideConfigPricePreview: store.contentStore.toggleHideConfigPricePreview.bind(store.contentStore),
        toggleHideSnow: store.contentStore.toggleHideSnow.bind(store.contentStore),
        setComponentChange: store.contentStore.setComponentChange.bind(store.contentStore),
        setOrganization: store.dataStore.updateOrganization.bind(store.dataStore),
        getSessionGuid: store.dataStore.getSessionGuid.bind(store.dataStore),
        getApi2AuthLoginData: store.dataStore.getApi2AuthLoginData.bind(store.dataStore),
        logout: store.authorizationStore.logout.bind(store.authorizationStore),
        showLoginWindow: store.authorizationStore.showLogin.bind(store.authorizationStore),
        userHasPermission: store.dataStore.userHasPermission.bind(store.dataStore),
        openFullscreen: store.contentStore.openFullscreen.bind(store.contentStore),
        closeFullscreen: store.contentStore.closeFullscreen.bind(store.contentStore),
        openSideMenu: store.contentStore.openSideMenu.bind(store.contentStore),
        closeSideMenu: store.contentStore.closeSideMenu.bind(store.contentStore),
        openBarrier: store.contentStore.openBarrier.bind(store.contentStore),
        updateHeaderInfos: store.contentStore.updateHeaderInfos.bind(store.contentStore),
        openBanner: store.contentStore.openBanner.bind(store.contentStore),
        closeBanner: store.contentStore.closeBanner.bind(store.contentStore),
        resolveComponent: store.contentStore.resolveComponent.bind(store.contentStore),
        openSnackBar: store.contentStore.openSnackBar.bind(store.contentStore),
        fetchConfiguration: store.configurationStore.fetchConfiguration.bind(store.configurationStore),
        getSubConfiguration: store.contentStore.getSubConfiguration.bind(store.contentStore)
      },
      state: toJS({
        isMobile: store.dataStore.isMobile,
        isFirefox: store.dataStore.isFirefox,
        availableComponents: store.contentStore.availableComponentList,
        availableLanguages: ((_store$configurationS = store.configurationStore.locales) === null || _store$configurationS === void 0 ? void 0 : _store$configurationS.available) || [],
        organization: store.dataStore.organization,
        organizationHierarchy: store.dataStore.organizationHirarchy,
        user: store.dataStore.user,
        jwt: store.authorizationStore.zToken,
        nToken: store.authorizationStore.nToken,
        navigationConfiguration: _objectSpread$6(_objectSpread$6({}, store.configurationStore.navigation), {}, {
          buttons: store.contentStore.availableButtons || [],
          customHeaderElement: store.contentStore.customHeaderComponent,
          customLogo: store.contentStore.customLogo,
          breadcrumbs: store.contentStore.breadcrumbs,
          showFooter: store.contentStore.showFooter,
          allowHidePrices: store.contentStore.allowHidePrices,
          showLogin: store.configurationStore.hasAuthentication
        }),
        initializing: store.initializing,
        loginMode: store.loginMode,
        loading: store.loadingAndErrorStore.isLoading,
        hidePrices: store.contentStore.hidePrices,
        hideConfigPricePreview: store.contentStore.hideConfigPricePreview,
        hideSnow: store.contentStore.hideSnow,
        componentChange: store.contentStore.componentChange,
        dimensions: store.contentStore.containerDimensions,
        headerInfos: store.contentStore.headerInfos,
        apiConfig: store.configurationStore.apiConfig,
        theme: store.configurationStore.theme,
        applicationEnvironment: store.configurationStore.applicationEnvironment,
        isFullscreenComponent: store.contentStore.isFullscreenComponentDefined,
        enableSupport: !!store.configurationStore.enableSupport,
        googleMapsConfig: store.configurationStore.googleMapsconfig,
        cometChatConfig: store.configurationStore.cometchatConfig,
        defaultComponent: store.configurationStore.defaultComponent,
        currentComponent: store.contentStore.currentComponent
      }),
      handler: {
        productHandler: store.productHandler,
        organizationHandler: store.organizationHandler,
        mediaHandler: store.mediaHandler,
        adminHandler: store.adminHandler,
        analyticsHandler: store.analyticsHandler,
        reportHandler: store.reportHandler,
        supportHandler: store.supportHandler,
        authorizationHandler: store.authorizationHandler,
        clientArticleHandler: store.clientArticleHandler
      }
    }),
    _useState2 = _slicedToArray(_useState, 2),
    context = _useState2[0],
    setState = _useState2[1];
  useEffect(function () {
    var stop = autorun(function () {
      var _store$configurationS2;
      setState({
        actions: {
          openComponent: function openComponent(action) {
            return flowResult(store.contentStore.openComponent(action));
          },
          closeComponentInFullscreen: store.contentStore.closeComponentInFullscreen.bind(store.contentStore),
          setAbsoluteFullScreen: store.contentStore.setAbsoluteFullScreen.bind(store.contentStore),
          changeLanguage: store.changeLanguage.bind(store),
          changeLoginMode: store.changeLoginMode.bind(store),
          toggleLoading: store.loadingAndErrorStore.toggleLoading.bind(store.loadingAndErrorStore),
          loadModelViewer: store.contentStore.loadModelViewer.bind(store.contentStore),
          openModal: store.contentStore.openModal.bind(store.contentStore),
          closeModal: store.contentStore.closeModal.bind(store.contentStore),
          sendEmail: store.contentStore.sendEmail.bind(store.contentStore),
          onEvent: store.onEvent.bind(store),
          subscribeEvents: store.subscribeEvents.bind(store),
          unSubscribeEvents: store.unSubscribeEvents.bind(store),
          updateCustomLogo: store.contentStore.updateCustomLogo.bind(store.contentStore),
          updateCustomHeaderElement: store.contentStore.updateCustomHeaderElement.bind(store.contentStore),
          updateBreadcrumbs: store.contentStore.updateBreadcrumbs.bind(store.contentStore),
          toggleHidePrices: store.contentStore.toggleHidePrices.bind(store.contentStore),
          toggleHideConfigPricePreview: store.contentStore.toggleHideConfigPricePreview.bind(store.contentStore),
          toggleHideSnow: store.contentStore.toggleHideSnow.bind(store.contentStore),
          setComponentChange: store.contentStore.setComponentChange.bind(store.contentStore),
          setOrganization: store.dataStore.updateOrganization.bind(store.dataStore),
          getSessionGuid: store.dataStore.getSessionGuid.bind(store.dataStore),
          getApi2AuthLoginData: store.dataStore.getApi2AuthLoginData.bind(store.dataStore),
          logout: store.authorizationStore.logout.bind(store.authorizationStore),
          showLoginWindow: store.authorizationStore.showLogin.bind(store.authorizationStore),
          userHasPermission: store.dataStore.userHasPermission.bind(store.dataStore),
          openFullscreen: store.contentStore.openFullscreen.bind(store.contentStore),
          closeFullscreen: store.contentStore.closeFullscreen.bind(store.contentStore),
          openSideMenu: store.contentStore.openSideMenu.bind(store.contentStore),
          closeSideMenu: store.contentStore.closeSideMenu.bind(store.contentStore),
          openBarrier: store.contentStore.openBarrier.bind(store.contentStore),
          updateHeaderInfos: store.contentStore.updateHeaderInfos.bind(store.contentStore),
          openBanner: store.contentStore.openBanner.bind(store.contentStore),
          closeBanner: store.contentStore.closeBanner.bind(store.contentStore),
          resolveComponent: store.contentStore.resolveComponent.bind(store.contentStore),
          openSnackBar: store.contentStore.openSnackBar.bind(store.contentStore),
          fetchConfiguration: store.configurationStore.fetchConfiguration.bind(store.configurationStore),
          getSubConfiguration: store.contentStore.getSubConfiguration.bind(store.contentStore)
        },
        state: toJS({
          availableComponents: store.contentStore.availableComponentList,
          availableLanguages: ((_store$configurationS2 = store.configurationStore.locales) === null || _store$configurationS2 === void 0 ? void 0 : _store$configurationS2.available) || [],
          organization: store.dataStore.organization,
          organizationHierarchy: store.dataStore.organizationHirarchy,
          user: store.dataStore.user,
          jwt: store.authorizationStore.zToken,
          nToken: store.authorizationStore.nToken,
          isMobile: store.dataStore.isMobile,
          isFirefox: store.dataStore.isFirefox,
          googleMapsConfig: store.configurationStore.googleMapsconfig,
          cometChatConfig: store.configurationStore.cometchatConfig,
          navigationConfiguration: _objectSpread$6(_objectSpread$6({}, store.configurationStore.navigation), {}, {
            buttons: store.contentStore.availableButtons || [],
            customLogo: store.contentStore.customLogo,
            customHeaderElement: store.contentStore.customHeaderComponent,
            breadcrumbs: store.contentStore.breadcrumbs,
            showFooter: store.contentStore.showFooter,
            allowHidePrices: store.contentStore.allowHidePrices,
            showLogin: store.configurationStore.hasAuthentication
          }),
          initializing: store.initializing,
          loginMode: store.loginMode,
          loading: store.loadingAndErrorStore.isLoading,
          hidePrices: store.contentStore.hidePrices,
          hideConfigPricePreview: store.contentStore.hideConfigPricePreview,
          hideSnow: store.contentStore.hideSnow,
          componentChange: store.contentStore.componentChange,
          dimensions: store.contentStore.containerDimensions,
          headerInfos: store.contentStore.headerInfos,
          apiConfig: store.configurationStore.apiConfig,
          theme: store.configurationStore.theme,
          applicationEnvironment: store.configurationStore.applicationEnvironment,
          isFullscreenComponent: store.contentStore.isFullscreenComponentDefined,
          enableSupport: !!store.configurationStore.enableSupport,
          defaultComponent: store.configurationStore.defaultComponent,
          currentComponent: store.contentStore.currentComponent
        }),
        handler: {
          productHandler: store.productHandler,
          organizationHandler: store.organizationHandler,
          mediaHandler: store.mediaHandler,
          adminHandler: store.adminHandler,
          analyticsHandler: store.analyticsHandler,
          reportHandler: store.reportHandler,
          supportHandler: store.supportHandler,
          authorizationHandler: store.authorizationHandler,
          clientArticleHandler: store.clientArticleHandler
        }
      });
    }, {
      name: 'divaCoreState'
    });
    return function () {
      return stop();
    };
  }, []);
  var _useState3 = useState(),
    _useState4 = _slicedToArray(_useState3, 2),
    intervalId = _useState4[0],
    setIntervalId = _useState4[1];
  useEffect(function () {
    //if the component is change from outside update the content store
    if (!store.initializing && props.currentComponent) {
      store.contentStore.openComponent(props.currentComponent);
    }
  }, [props.currentComponent]);
  useEffect(function () {
    return function () {
      var _element$;
      if (intervalId) clearInterval(intervalId);
      var element = document.getElementsByTagName('html');
      var toDelete = [];
      (_element$ = element[0]) === null || _element$ === void 0 || _element$.classList.forEach(function (classname) {
        if (classname.startsWith('diva-component-')) {
          toDelete.push(classname);
        }
      });
      toDelete.map(function (classname) {
        var _element$2;
        return (_element$2 = element[0]) === null || _element$2 === void 0 ? void 0 : _element$2.classList.remove(classname);
      });
    };
  }, []);
  useEffect(function () {
    //if the language is change from outside update the content store
    if (!store.initializing && props.language) {
      store.changeLanguage(props.language);
    }
  }, [props.language]);
  var logState = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(interval) {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return context.handler.authorizationHandler.setOnlineState(interval);
          case 2:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function logState(_x) {
      return _ref2.apply(this, arguments);
    };
  }();
  useEffect(function () {
    _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      var logOnlineState, tempIntervalId;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) switch (_context3.prev = _context3.next) {
          case 0:
            if (!(store.configurationStore.configuration && store.dataStore.user)) {
              _context3.next = 7;
              break;
            }
            logOnlineState = store.configurationStore.configuration.logOnlineState;
            if (!(logOnlineState !== null && logOnlineState !== void 0 && logOnlineState.log)) {
              _context3.next = 7;
              break;
            }
            _context3.next = 5;
            return logState(logOnlineState.intervalMS);
          case 5:
            tempIntervalId = setInterval(/*#__PURE__*/_asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
              return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                while (1) switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return logState(logOnlineState.intervalMS);
                  case 2:
                  case "end":
                    return _context2.stop();
                }
              }, _callee2);
            })), logOnlineState.intervalMS);
            setIntervalId(tempIntervalId);
          case 7:
          case "end":
            return _context3.stop();
        }
      }, _callee3);
    }))();
  }, [store.configurationStore.configuration, store.dataStore.user]);
  return /*#__PURE__*/jsx(coreContext.Provider, {
    value: {
      store: store,
      context: context
    },
    children: children
  });
});
var useDivaCoreContext = function useDivaCoreContext() {
  var context = React.useContext(coreContext);
  if (!(context !== null && context !== void 0 && context.store)) {
    throw new Error('useDivaCoreContext must be used within a DivaCoreProvider.');
  }
  return context.store;
};
var useDivaCore = function useDivaCore() {
  var context = React.useContext(coreContext);
  if (!context) {
    throw new Error('useDivaCore must be used within Diva.');
  }
  return context.context;
};

var overlay$1 = "overlay-X3zhH";
var loading = "loading-kAuhm";
var css_248z$5 = ".overlay-X3zhH {\n  height: 100%;\n  width: 100%;\n  display: flex;\n  background-color: rgba(255, 255, 255, 0.6);\n  z-index: 1000;\n  justify-content: center;\n  align-items: center;\n  position: absolute;\n}\n\n.loading-kAuhm {\n  margin: 0 auto;\n  display: inline-block;\n  position: relative;\n  width: 80px;\n  height: 80px;\n}\n.loading-kAuhm div {\n  box-sizing: border-box;\n  display: block;\n  position: absolute;\n  width: 64px;\n  height: 64px;\n  margin: 8px;\n  border: 8px solid #b6b6b6;\n  border-radius: 50%;\n  animation: loading-kAuhm 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;\n  border-color: #b6b6b6 transparent transparent transparent;\n}\n.loading-kAuhm div:nth-child(1) {\n  animation-delay: -0.45s;\n}\n.loading-kAuhm div:nth-child(2) {\n  animation-delay: -0.3s;\n}\n.loading-kAuhm div:nth-child(3) {\n  animation-delay: -0.15s;\n}\n@keyframes loading-kAuhm {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n";
styleInject(css_248z$5);

var LOG$3 = getLogger('Framework', 'loadDependency');
function loadDependency(_x) {
  return _loadDependency.apply(this, arguments);
}
function _loadDependency() {
  _loadDependency = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var ref, id, url, type, _ref$invalidateCache, invalidateCache;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          ref = _ref.ref, id = _ref.id, url = _ref.url, type = _ref.type, _ref$invalidateCache = _ref.invalidateCache, invalidateCache = _ref$invalidateCache === void 0 ? false : _ref$invalidateCache;
          return _context.abrupt("return", new Promise(function (resolve, rejects) {
            var parent = ref === null || ref === void 0 ? void 0 : ref.current;
            if (!parent) {
              parent = document.head;
            }
            if (parent.getElementsByClassName(id).length) {
              resolve(id);
              return;
            }
            var elem;
            if (type === 'style') {
              elem = document.createElement('link');
              elem.className = id;
              elem.rel = 'stylesheet';
              elem.crossOrigin = 'anonymous';
              elem.href = url + (invalidateCache ? "?v=".concat(getCacheStamp()) : '');
            } else if (type === 'script') {
              elem = document.createElement('script');
              elem.className = id;
              elem.type = 'text/javascript';
              elem.crossOrigin = 'anonymous';
              elem.src = url + (invalidateCache ? "?v=".concat(getCacheStamp()) : '');
            } else {
              rejects('Unkown dependency type');
              return;
            }
            elem.onload = function () {
              resolve(id);
            };
            elem.onerror = function (e) {
              LOG$3.error(new DivaError('Failed to load dependency: ' + type, {
                cause: e
              }));
              resolve(id);
            };
            parent.appendChild(elem);
          }));
        case 2:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return _loadDependency.apply(this, arguments);
}
function getCacheStamp() {
  var date = new Date();
  return new Date(date.getFullYear(), date.getMonth(), date.getDate()).getTime();
}

function Spinner() {
  var _useDivaCoreContext = useDivaCoreContext(),
    loadingAndErrorStore = _useDivaCoreContext.loadingAndErrorStore;
  var throttleRef = useRef(null);
  var _useState = useState(function () {
      var _loadingAndErrorStore, _loadingAndErrorStore2, _loadingAndErrorStore3;
      return (_loadingAndErrorStore = loadingAndErrorStore.customLoader) !== null && _loadingAndErrorStore !== void 0 && _loadingAndErrorStore.spinnerClass && !((_loadingAndErrorStore2 = loadingAndErrorStore.customLoader) !== null && _loadingAndErrorStore2 !== void 0 && _loadingAndErrorStore2.cssFile) ? (_loadingAndErrorStore3 = loadingAndErrorStore.customLoader) === null || _loadingAndErrorStore3 === void 0 ? void 0 : _loadingAndErrorStore3.spinnerClass : loading;
    }),
    _useState2 = _slicedToArray(_useState, 2),
    className = _useState2[0],
    setClassName = _useState2[1];
  var _useState3 = useState(false),
    _useState4 = _slicedToArray(_useState3, 2),
    showSpinner = _useState4[0],
    setShowSpinner = _useState4[1];
  useEffect(function () {
    var _loadingAndErrorStore4, _loadingAndErrorStore5;
    if ((_loadingAndErrorStore4 = loadingAndErrorStore.customLoader) !== null && _loadingAndErrorStore4 !== void 0 && _loadingAndErrorStore4.cssFile) {
      loadDependency({
        id: 'diva-custom-loader',
        type: 'style',
        url: loadingAndErrorStore.customLoader.cssFile
      }).then(function () {
        setClassName(loadingAndErrorStore.customLoader.spinnerClass);
      });
    } else if ((_loadingAndErrorStore5 = loadingAndErrorStore.customLoader) !== null && _loadingAndErrorStore5 !== void 0 && _loadingAndErrorStore5.spinnerClass) {
      setClassName(loadingAndErrorStore.customLoader.spinnerClass);
    }
  }, [loadingAndErrorStore.customLoader.cssFile, loadingAndErrorStore.customLoader.spinnerClass]);
  useEffect(function () {
    if (loadingAndErrorStore.isLoading && throttleRef.current === null) {
      throttleRef.current = setTimeout(function () {
        return setShowSpinner(true);
      }, 350);
    } else if (!loadingAndErrorStore.isLoading) {
      if (throttleRef.current) clearTimeout(throttleRef.current);
      throttleRef.current = null;
      setShowSpinner(false);
    }
  }, [loadingAndErrorStore.isLoading]);
  if (!showSpinner) {
    return /*#__PURE__*/jsx(Fragment, {});
  }
  return /*#__PURE__*/jsx("div", {
    className: overlay$1,
    id: "diva-loader",
    children: /*#__PURE__*/jsxs("div", {
      className: className,
      children: [/*#__PURE__*/jsx("div", {}), /*#__PURE__*/jsx("div", {}), /*#__PURE__*/jsx("div", {}), /*#__PURE__*/jsx("div", {})]
    })
  });
}
var Spinner$1 = observer(Spinner);

var overlay = "overlay-34l68";
var absoluteOverlay = "absolute-overlay-cG7uO";
var closeIcon$1 = "close-icon-1kDyU";
var css_248z$4 = ".overlay-34l68 {\n  height: 100%;\n  width: 100%;\n  display: flex;\n  background-color: #fff;\n  z-index: 999;\n  justify-content: center;\n  align-items: center;\n  position: absolute;\n}\n\n.absolute-overlay-cG7uO {\n  height: 100% !important;\n}\n\n.absolute-overlay-cG7uO {\n  background-color: #fff;\n  position: fixed;\n  top: 0px;\n  right: 0px;\n  bottom: 0px;\n  left: 0px;\n  overflow: hidden;\n  z-index: 1000000;\n  display: block;\n  width: 100vw;\n}\n\n.diva-pseudo-fullscreen body {\n  height: auto !important;\n}\n.diva-pseudo-fullscreen, .diva-pseudo-fullscreen body {\n  overflow: hidden !important;\n}\n\n.close-icon-1kDyU {\n  position: absolute;\n  right: 32px;\n  top: 32px;\n  width: 50px;\n  height: 40px;\n  opacity: 0.3;\n  z-index: 700;\n  cursor: pointer;\n}\n\n.close-icon-1kDyU:before {\n  transform: rotate(45deg);\n}\n\n.close-icon-1kDyU:after {\n  transform: rotate(-45deg);\n}\n\n.close-icon-1kDyU:before,\n.close-icon-1kDyU:after {\n  position: absolute;\n  left: 23px;\n  top: 5px;\n  content: ' ';\n  height: 33px;\n  width: 3px;\n  background-color: #4b4b4b;\n}\n\n.close-icon-1kDyU:hover {\n  opacity: 0.8;\n  transition: opacity 0.2s ease-in-out;\n}\n";
styleInject(css_248z$4);

var sideMenu = "side-menu-2Fgdm";
var leftSideMenu = "left-side-menu-L42L3";
var rightSideMenu = "right-side-menu-Akk-Y";
var wrapper$1 = "wrapper-jJaXo";
var scroller = "scroller-ZnoJy";
var title$1 = "title-WOjYJ";
var hideLeft = "hide-left-4bzTL";
var hideRight = "hide-right-IOmlC";
var show = "show-Z8M2h";
var closeIcon = "close-icon-NJkeP";
var mobileBcGroup = "mobile-bc-group-6v8wI";
var css_248z$3 = ".side-menu-2Fgdm {\n  width: 100%;\n  max-width: 400px;\n  height: 100%;\n  background-color: #f2f2f2;\n  position: absolute;\n  bottom: 0;\n  transition: transform 0.3s cubic-bezier(0, 0.52, 0, 1);\n  box-sizing: border-box;\n}\n\n.left-side-menu-L42L3 {\n  left: 0px;\n}\n\n.right-side-menu-Akk-Y {\n  right: 0px;\n}\n\n.wrapper-jJaXo {\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n\n.scroller-ZnoJy {\n  height: 100%;\n}\n\n.title-WOjYJ {\n  font-size: 22px;\n  margin: 20px;\n}\n\n.hide-left-4bzTL {\n  transform: translate(-960px, 0);\n}\n.hide-right-IOmlC {\n  transform: translate(960px, 0);\n}\n\n.show-Z8M2h {\n  transform: translate(0, 0);\n  overflow: hidden;\n}\n\n.close-icon-NJkeP {\n  position: absolute;\n  top: 16px;\n  right: 16px;\n  opacity: 0.3;\n  width: 32px;\n  height: 32px;\n  z-index: 300;\n  width: 50px;\n  height: 40px;\n  cursor: pointer;\n}\n\n.close-icon-NJkeP:before {\n  transform: rotate(45deg);\n}\n\n.close-icon-NJkeP:after {\n  transform: rotate(-45deg);\n}\n\n.close-icon-NJkeP:before,\n.close-icon-NJkeP:after {\n  position: absolute;\n  right: 15px;\n  content: ' ';\n  height: 33px;\n  width: 3px;\n  background-color: #4b4b4b;\n}\n\n.close-icon-NJkeP:hover {\n  opacity: 0.8;\n  transition: opacity 0.2s ease-in-out;\n}\n\n.mobile-bc-group-6v8wI {\n  display: flex;\n  border-top: 0.8px solid #b6b6b7;\n  padding: 12px 16px;\n  border-bottom: 0.8px solid #b6b6b7;\n  margin-top: 40px;\n  overflow: auto;\n  -ms-overflow-style: none; /* IE and Edge */\n  scrollbar-width: none; /* Firefox */\n}\n\n.mobile-bc-group-6v8wI::-webkit-scrollbar {\n  display: none;\n}\n";
styleInject(css_248z$3);

function ownKeys$5(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$5(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$5(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$5(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var SideMenu = function SideMenu() {
  var _contentStore$sideMen, _contentStore$sideMen5, _contentStore$sideMen6, _contentStore$headerI, _contentStore$headerI2, _contentStore$sideMen7, _contentStore$sideMen8, _contentStore$sideMen9, _contentStore$sideMen10;
  var _useDivaCoreContext = useDivaCoreContext(),
    contentStore = _useDivaCoreContext.contentStore;
  var _useState = useState(!((_contentStore$sideMen = contentStore.sideMenu) !== null && _contentStore$sideMen !== void 0 && _contentStore$sideMen.open)),
    _useState2 = _slicedToArray(_useState, 2),
    hiddenDelayed = _useState2[0],
    setHiddenDelayed = _useState2[1];
  useEffect(function () {
    var _contentStore$sideMen2;
    if (!((_contentStore$sideMen2 = contentStore.sideMenu) !== null && _contentStore$sideMen2 !== void 0 && _contentStore$sideMen2.open)) {
      setTimeout(function () {
        var _contentStore$sideMen3;
        return setHiddenDelayed(!((_contentStore$sideMen3 = contentStore.sideMenu) !== null && _contentStore$sideMen3 !== void 0 && _contentStore$sideMen3.open));
      }, 500);
    } else {
      var _contentStore$sideMen4;
      setHiddenDelayed(!((_contentStore$sideMen4 = contentStore.sideMenu) !== null && _contentStore$sideMen4 !== void 0 && _contentStore$sideMen4.open));
    }
  }, [(_contentStore$sideMen5 = contentStore.sideMenu) === null || _contentStore$sideMen5 === void 0 ? void 0 : _contentStore$sideMen5.open]);
  var swipeHandler = useSwipeable({
    onSwipedLeft: function onSwipedLeft(e) {
      var _e$event$path;
      // do not swipe if the event is triggered withing the breadcrumbs

      var allElements = [];
      _getAllParents(e.event.target, allElements);
      if (contentStore.sideMenu && contentStore.sideMenu.swipeable != false && !((_e$event$path = e.event.path) !== null && _e$event$path !== void 0 && _e$event$path.find(function (p) {
        return p.className == mobileBcGroup || p.className == 'diva-stop-swipe-detection';
      })) && !allElements.find(function (e) {
        return e.className == mobileBcGroup || e.className == 'diva-stop-swipe-detection';
      })) contentStore.closeSideMenu();
    },
    trackMouse: true
  });
  var _getAllParents = function getAllParents(element, allElements) {
    if (element.parentElement && element.nodeName != 'BODY') {
      allElements.push(element.parentElement);
      _getAllParents(element.parentElement, allElements);
    }
  };
  var hide = ((_contentStore$sideMen6 = contentStore.sideMenu) === null || _contentStore$sideMen6 === void 0 ? void 0 : _contentStore$sideMen6.side) == 'right' ? hideRight : hideLeft;
  if (!contentStore.sideMenu) return /*#__PURE__*/jsx(Fragment, {});
  var height = (_contentStore$headerI = (_contentStore$headerI2 = contentStore.headerInfos.HeaderElement) === null || _contentStore$headerI2 === void 0 ? void 0 : _contentStore$headerI2.getBoundingClientRect().height) !== null && _contentStore$headerI !== void 0 ? _contentStore$headerI : 0;
  return /*#__PURE__*/jsxs("div", _objectSpread$5(_objectSpread$5({}, swipeHandler), {}, {
    style: _objectSpread$5(_objectSpread$5({}, contentStore.sideMenu.style), {}, {
      width: hiddenDelayed ? '0px' : undefined,
      backgroundColor: contentStore.sideMenu.backgroundColor,
      height: (_contentStore$sideMen7 = contentStore.sideMenu) !== null && _contentStore$sideMen7 !== void 0 && _contentStore$sideMen7.showCoreHeader ? 'calc(100% - ' + height + 'px)' : undefined,
      zIndex: 2000000,
      position: contentStore.isAbsoluteFullscreenComponent ? 'fixed' : contentStore === null || contentStore === void 0 || (_contentStore$sideMen8 = contentStore.sideMenu) === null || _contentStore$sideMen8 === void 0 || (_contentStore$sideMen8 = _contentStore$sideMen8.style) === null || _contentStore$sideMen8 === void 0 ? void 0 : _contentStore$sideMen8.position
    }),
    className: classnames(sideMenu, contentStore.sideMenu.side == 'right' ? rightSideMenu : leftSideMenu, (_contentStore$sideMen9 = contentStore.sideMenu) !== null && _contentStore$sideMen9 !== void 0 && _contentStore$sideMen9.open ? show : hide),
    children: [/*#__PURE__*/jsx("div", {
      className: closeIcon,
      onClick: (_contentStore$sideMen10 = contentStore.sideMenu) === null || _contentStore$sideMen10 === void 0 ? void 0 : _contentStore$sideMen10.onClose
    }), /*#__PURE__*/jsxs("div", {
      className: wrapper$1,
      children: [!!contentStore.sideMenu.title && /*#__PURE__*/jsx("div", {
        className: title$1,
        children: contentStore.sideMenu.title
      }), contentStore.sideMenu.content && /*#__PURE__*/jsx("div", {
        className: scroller,
        children: contentStore.sideMenu.content
      })]
    })]
  }));
};
var SideMenu$1 = observer(SideMenu);

function ownKeys$4(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$4(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$4(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$4(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LazyModals$1 = /*#__PURE__*/React.lazy(function () {
  return import('./ModalsWrapper-afce575b.js');
});
function Fullscreen(_ref) {
  var inAbsoluteFullscreen = _ref.inAbsoluteFullscreen;
  var _useDivaCoreContext = useDivaCoreContext(),
    contentStore = _useDivaCoreContext.contentStore,
    configurationStore = _useDivaCoreContext.configurationStore;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    onEsc = _useState2[0],
    setOnEsc = _useState2[1];
  var _useDivaCore = useDivaCore(),
    isMobile = _useDivaCore.state.dimensions.isMobile,
    _useDivaCore$actions = _useDivaCore.actions,
    openModal = _useDivaCore$actions.openModal,
    subscribeEvents = _useDivaCore$actions.subscribeEvents,
    unSubscribeEvents = _useDivaCore$actions.unSubscribeEvents;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  useEffect(function () {
    if (onEsc) {
      onCloseComponent(true);
      setOnEsc(false);
    }
  }, [onEsc]);
  var onClose = function onClose() {
    var _contentStore$fullscr;
    contentStore.closeFullscreen();
    if ((_contentStore$fullscr = contentStore.fullscreen) !== null && _contentStore$fullscr !== void 0 && _contentStore$fullscr.onClose) {
      contentStore.fullscreen.onClose();
    }
  };
  var onCloseComponent = function onCloseComponent(ask) {
    if (ask) {
      openModal({
        title: t('modals.close'),
        accept: true,
        reject: true,
        text: t('modals.are_you_sure_to_close'),
        callback: function callback(accepted) {
          if (accepted) contentStore.closeComponentInFullscreen();
        }
      });
    } else {
      contentStore.closeComponentInFullscreen();
    }
  };
  var escFunction = useCallback(function (e) {
    if (!contentStore.isFullscreenComponentDefined && !contentStore.fullscreen) return;
    if (e.key === 'ESC' || e.key === 'Escape') {
      if (contentStore.isFullscreenComponentDefined) {
        setOnEsc(true);
        e.preventDefault();
      } else if (contentStore.fullscreen) {
        onClose();
        e.preventDefault();
      }
    }
  }, []);
  useEffect(function () {
    document.addEventListener('keydown', escFunction, false);
    subscribeEvents(onEventCalled);
    return function () {
      document.removeEventListener('keydown', escFunction, false);
      unSubscribeEvents(onEventCalled);
    };
  }, []);
  var onEventCalled = function onEventCalled(event) {
    if (event.type == 'onFullscreenClose') {
      onCloseComponent();
    }
  };
  useEffect(function () {
    var _contentStore$fullscr2;
    if (contentStore.isFullscreenComponentDefined && (_contentStore$fullscr2 = contentStore.fullscreenComponent) !== null && _contentStore$fullscr2 !== void 0 && (_contentStore$fullscr2 = _contentStore$fullscr2.state) !== null && _contentStore$fullscr2 !== void 0 && _contentStore$fullscr2.absoluteFullscreen) {
      var _element$;
      var element = document.getElementsByTagName('html');
      if (element[0] && !element[0].classList.contains('diva-pseudo-fullscreen')) (_element$ = element[0]) === null || _element$ === void 0 || _element$.classList.add('diva-pseudo-fullscreen');
    }
    return function () {
      var _element$2;
      var element = document.getElementsByTagName('html');
      (_element$2 = element[0]) === null || _element$2 === void 0 || _element$2.classList.remove('diva-pseudo-fullscreen');
    };
  }, [contentStore.isFullscreenComponentDefined]);
  if (!contentStore.isFullscreenComponentDefined && !contentStore.fullscreen) return /*#__PURE__*/jsx(Fragment, {});
  if ((!contentStore.fullscreen || contentStore.isFullscreenComponentDefined) && !inAbsoluteFullscreen) {
    var _c$state$absoluteFull, _c$state$absoluteFull2;
    var c = contentStore.fullscreenComponent;
    var C = c.component;
    return /*#__PURE__*/jsxs("div", {
      id: "DivaCore",
      className: classnames('diva-fullscreen', c.state.absoluteFullscreen ? absoluteOverlay : overlay),
      style: isMobile ? (_c$state$absoluteFull = c.state.absoluteFullscreenStyle) === null || _c$state$absoluteFull === void 0 ? void 0 : _c$state$absoluteFull.mobile : (_c$state$absoluteFull2 = c.state.absoluteFullscreenStyle) === null || _c$state$absoluteFull2 === void 0 ? void 0 : _c$state$absoluteFull2.desktop,
      children: [/*#__PURE__*/jsx(Fullscreen, {
        inAbsoluteFullscreen: true
      }), /*#__PURE__*/jsx(Spinner$1, {}), /*#__PURE__*/jsx(SideMenu$1, {}), configurationStore.enableModals && /*#__PURE__*/jsx(LazyModals$1, {}), /*#__PURE__*/jsx(Suspense, {
        fallback: /*#__PURE__*/jsx(Fallback, {}),
        children: /*#__PURE__*/jsx(C, _objectSpread$4({}, c.state))
      })]
    });
  }
  if (!contentStore.fullscreen) return /*#__PURE__*/jsx(Fragment, {});
  return /*#__PURE__*/jsxs("div", {
    className: classnames('diva-fullscreen', contentStore.fullscreen.absoluteFullscreen ? absoluteOverlay : overlay),
    "data-test-id": "plannerFullscreen",
    style: {
      zIndex: contentStore.fullscreen.overwrittenZIndex
    },
    children: [!contentStore.fullscreen.hideSpinner && /*#__PURE__*/jsx(Spinner$1, {}), /*#__PURE__*/jsx(SideMenu$1, {}), configurationStore.enableModals && /*#__PURE__*/jsx(LazyModals$1, {}), !contentStore.fullscreen.hideClose && /*#__PURE__*/jsx("div", {
      className: closeIcon$1,
      onClick: onClose,
      "data-test-id": "closeFullscreenBtn",
      style: {
        zIndex: contentStore.fullscreen.overwrittenZIndex
      }
    }), contentStore.fullscreen.content]
  });
}
var Fullscreen$1 = observer(Fullscreen);

var wrapper = "wrapper-W1xSq";
var textWrapper = "textWrapper-T2nhQ";
var title = "title-s0Vfz";
var icon = "icon-AodEu";
var css_248z$2 = ".wrapper-W1xSq {\n  position: relative;\n  display: flex;\n  align-items: center;\n  gap: 25px;\n  flex-direction: row;\n  justify-content: flex-start;\n  color: black;\n}\n.textWrapper-T2nhQ {\n  display: flex;\n  flex-direction: column;\n}\n.title-s0Vfz {\n  font-weight: 600;\n  margin: 0px 0px 4px 0px;\n  font-size: 22px;\n}\n.icon-AodEu {\n  height: 48px;\n  margin-left: 12px;\n}\n";
styleInject(css_248z$2);

var WarningOutlined = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20aria-hidden%3D%22true%22%20role%3D%22img%22%20width%3D%221em%22%20height%3D%221em%22%20preserveAspectRatio%3D%22xMidYMid%20meet%22%20viewBox%3D%220%200%201024%201024%22%3E%3Cpath%20fill%3D%22currentColor%22%20d%3D%22M464%20720a48%2048%200%201%200%2096%200a48%2048%200%201%200-96%200zm16-304v184c0%204.4%203.6%208%208%208h48c4.4%200%208-3.6%208-8V416c0-4.4-3.6-8-8-8h-48c-4.4%200-8%203.6-8%208zm475.7%20440l-416-720c-6.2-10.7-16.9-16-27.7-16s-21.6%205.3-27.7%2016l-416%20720C56%20877.4%2071.4%20904%2096%20904h832c24.6%200%2040-26.6%2027.7-48zm-783.5-27.9L512%20239.9l339.8%20588.2H172.2z%22%2F%3E%3C%2Fsvg%3E";

var InfoCircleOutlined = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20aria-hidden%3D%22true%22%20role%3D%22img%22%20width%3D%221em%22%20height%3D%221em%22%20preserveAspectRatio%3D%22xMidYMid%20meet%22%20viewBox%3D%220%200%201024%201024%22%3E%3Cpath%20fill%3D%22currentColor%22%20d%3D%22M512%2064C264.6%2064%2064%20264.6%2064%20512s200.6%20448%20448%20448s448-200.6%20448-448S759.4%2064%20512%2064zm0%20820c-205.4%200-372-166.6-372-372s166.6-372%20372-372s372%20166.6%20372%20372s-166.6%20372-372%20372z%22%2F%3E%3Cpath%20fill%3D%22currentColor%22%20d%3D%22M464%20336a48%2048%200%201%200%2096%200a48%2048%200%201%200-96%200zm72%20112h-48c-4.4%200-8%203.6-8%208v272c0%204.4%203.6%208%208%208h48c4.4%200%208-3.6%208-8V456c0-4.4-3.6-8-8-8z%22%2F%3E%3C%2Fsvg%3E";

var ExclamationCircleOutlined = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20aria-hidden%3D%22true%22%20role%3D%22img%22%20width%3D%221em%22%20height%3D%221em%22%20preserveAspectRatio%3D%22xMidYMid%20meet%22%20viewBox%3D%220%200%201024%201024%22%3E%3Cpath%20fill%3D%22currentColor%22%20d%3D%22M512%2064C264.6%2064%2064%20264.6%2064%20512s200.6%20448%20448%20448s448-200.6%20448-448S759.4%2064%20512%2064zm0%20820c-205.4%200-372-166.6-372-372s166.6-372%20372-372s372%20166.6%20372%20372s-166.6%20372-372%20372z%22%2F%3E%3Cpath%20fill%3D%22currentColor%22%20d%3D%22M464%20688a48%2048%200%201%200%2096%200a48%2048%200%201%200-96%200zm24-112h48c4.4%200%208-3.6%208-8V296c0-4.4-3.6-8-8-8h-48c-4.4%200-8%203.6-8%208v272c0%204.4%203.6%208%208%208z%22%2F%3E%3C%2Fsvg%3E";

function Banner() {
  var _contentStore$banner2;
  var _useDivaCoreContext = useDivaCoreContext(),
    contentStore = _useDivaCoreContext.contentStore;
  var onClose = function onClose() {
    var _contentStore$banner;
    contentStore.closeBanner();
    if ((_contentStore$banner = contentStore.banner) !== null && _contentStore$banner !== void 0 && _contentStore$banner.onClose) {
      contentStore.banner.onClose();
    }
  };
  if (!contentStore.banner || contentStore.banner.useLocalStorage && contentStore.bannerInLocalStorage(contentStore.banner)) {
    return /*#__PURE__*/jsx(Fragment, {});
  }
  if ((_contentStore$banner2 = contentStore.banner) !== null && _contentStore$banner2 !== void 0 && _contentStore$banner2.autoHideInSeconds) {
    setTimeout(function () {
    }, contentStore.banner.autoHideInSeconds * 1000);
  }

  //const iconSize = '48px';
  var backgroundcolor = '#2BA6CB'; //INFO
  var iconjsx = /*#__PURE__*/jsx("img", {
    className: icon,
    src: InfoCircleOutlined
  });
  switch (contentStore.banner.type) {
    case 'WARNING':
      backgroundcolor = '#E3B000';
      iconjsx = /*#__PURE__*/jsx("img", {
        className: icon,
        src: WarningOutlined
      });
      break;
    case 'ERROR':
      backgroundcolor = '#C60F13';
      iconjsx = /*#__PURE__*/jsx("img", {
        className: icon,
        src: ExclamationCircleOutlined
      });
      break;
  }
  var bannercontent = /*#__PURE__*/jsxs("div", {
    className: wrapper,
    children: [/*#__PURE__*/jsx("div", {
      children: iconjsx
    }), /*#__PURE__*/jsxs("div", {
      className: textWrapper,
      children: [/*#__PURE__*/jsx("p", {
        className: title,
        children: contentStore.banner.title
      }), /*#__PURE__*/jsx("span", {
        children: contentStore.banner.text
      })]
    })]
  });
  return /*#__PURE__*/jsx("div", {
    style: {
      padding: '20px 10px 10px 10px'
    },
    children: /*#__PURE__*/jsx(ContentBoxComponent, {
      onClose: onClose,
      settings: {
        contentBoxProps: {
          type: 'CloseButtonContainer',
          hideCloseIcon: contentStore.banner.hideClose,
          style: {
            height: 90,
            width: '100%',
            border: "2px solid ".concat(backgroundcolor),
            borderRadius: '12px',
            boxSizing: 'border-box',
            alignItems: 'center',
            zIndex: 0
          },
          content: bannercontent
        }
      }
    })
  });
}
var Banner$1 = observer(Banner);

var errorDisplay = "errorDisplay-Va5ll";
var errorContainer = "errorContainer-Ioiwn";
var errorContainerItem = "errorContainerItem-NhznQ";
var errorContainerItemCenter = "errorContainerItemCenter-D9mu7";
var errorImage = "errorImage-Ci2Mq";
var errorTitle = "errorTitle-Ffg4d";
var errorMessage = "errorMessage-tdIAi";
var errorTechnicalDetailMessage = "errorTechnicalDetailMessage-QAB5A";
var errorDetailMessage = "errorDetailMessage-5gqi7";
var actionButtons = "actionButtons-feOFT";
var css_248z$1 = ".errorDisplay-Va5ll {\n  background-color: #fff;\n  height: 100%;\n  width: 100%;\n}\n\n.errorContainer-Ioiwn {\n  display: flex;\n  height: 100%;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n}\n\n.errorContainerItem-NhznQ {\n  flex: 1;\n}\n\n.errorContainerItemCenter-D9mu7 {\n  flex: 1;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n}\n\n.errorImage-Ci2Mq {\n  height: 500px;\n}\n\n.errorTitle-Ffg4d {\n  font-size: 96px;\n  font-weight: bolder;\n  margin-top: 0;\n  margin-bottom: 0;\n}\n\n.errorMessage-tdIAi {\n  font-size: 32px;\n  width: 80%;\n}\n.errorTechnicalDetailMessage-QAB5A {\n  margin-top: 20px;\n  color: #999;\n  font-size: 0.9em;\n  margin-bottom: 20px;\n}\n\n.errorDetailMessage-5gqi7 {\n  font-size: 20px;\n  width: 80%;\n}\n.actionButtons-feOFT {\n  display: flex;\n  gap: 10px;\n}\n\n/* Responsive layout - makes a one column layout instead of a two-column layout */\n@media (max-width: 800px) {\n  .errorContainer-Ioiwn {\n    flex-direction: column;\n  }\n  .errorTitle-Ffg4d {\n    font-size: 48px;\n  }\n  .errorImage-Ci2Mq {\n    height: 250px;\n  }\n  .errorContainerItem-NhznQ {\n    text-align: center;\n    margin-left: 10px;\n    margin-right: 10px;\n  }\n  .errorMessage-tdIAi {\n    font-size: 18px;\n    width: 100%;\n  }\n  .errorDetailMessage-5gqi7 {\n    font-size: 14px;\n    width: 100%;\n  }\n  .errorTechnicalDetailMessage-QAB5A {\n    font-size: 0.7em;\n  }\n  .actionButtons-feOFT {\n    flex-direction: column;\n    gap: 5px;\n  }\n}\n";
styleInject(css_248z$1);

function ErrorDisplay() {
  var _useDivaCoreContext = useDivaCoreContext(),
    loadingAndErrorStore = _useDivaCoreContext.loadingAndErrorStore,
    contentStore = _useDivaCoreContext.contentStore,
    authorizationStore = _useDivaCoreContext.authorizationStore,
    configurationStore = _useDivaCoreContext.configurationStore;
  var _React$useState = React.useState(false),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    showReload = _React$useState2[0],
    setShowReload = _React$useState2[1];
  var _useTranslation = useTranslation$1(),
    t = _useTranslation.t;
  var _useDivaCore = useDivaCore$1(),
    apiConfig = _useDivaCore.state.apiConfig;
  var defaultErrorMsg = t('portal.error.default');
  useEffect(function () {
    setShowReload(loadingAndErrorStore.userFriendlyErrorMsg == undefined);
  }, [loadingAndErrorStore.userFriendlyErrorMsg]);
  if (loadingAndErrorStore.error) {
    var _loadingAndErrorStore, _loadingAndErrorStore5;
    return /*#__PURE__*/jsx("div", {
      className: errorDisplay,
      children: /*#__PURE__*/jsxs("div", {
        className: errorContainer,
        children: [/*#__PURE__*/jsx("div", {
          className: errorContainerItemCenter,
          children: /*#__PURE__*/jsx("img", {
            className: errorImage,
            src: loadingAndErrorStore.divaErrorCode == 'CORE_0005' || loadingAndErrorStore.divaErrorCode == 'CORE_0002' ? apiConfig.baseCdnUrl + '/static/images/error/error404.png' : apiConfig.baseCdnUrl + '/static/images/error/error500.png'
          })
        }), /*#__PURE__*/jsxs("div", {
          className: errorContainerItem,
          children: [/*#__PURE__*/jsx("p", {
            className: errorTitle,
            children: "Oops!"
          }), /*#__PURE__*/jsx("p", {
            className: errorMessage,
            children: (_loadingAndErrorStore = loadingAndErrorStore.userFriendlyErrorMsg) !== null && _loadingAndErrorStore !== void 0 ? _loadingAndErrorStore : defaultErrorMsg
          }), loadingAndErrorStore.detailErrorMsg && /*#__PURE__*/jsx("p", {
            className: errorDetailMessage,
            children: loadingAndErrorStore.detailErrorMsg
          }), /*#__PURE__*/jsxs("p", {
            className: errorTechnicalDetailMessage,
            children: [loadingAndErrorStore.divaErrorCode ? loadingAndErrorStore.divaErrorCode + ': ' : '', " ", loadingAndErrorStore.error]
          }), /*#__PURE__*/jsxs("div", {
            className: actionButtons,
            children: [loadingAndErrorStore.fallbackModule && /*#__PURE__*/jsx(Button$1, {
              color: "primary",
              variant: "contained",
              onClick: function onClick() {
                var _loadingAndErrorStore2, _loadingAndErrorStore3, _loadingAndErrorStore4;
                return contentStore.openComponent({
                  url: window.location.origin + ((_loadingAndErrorStore2 = loadingAndErrorStore.fallbackModule) === null || _loadingAndErrorStore2 === void 0 ? void 0 : _loadingAndErrorStore2.route.toLowerCase()) + ((_loadingAndErrorStore3 = loadingAndErrorStore.fallbackModule) !== null && _loadingAndErrorStore3 !== void 0 && _loadingAndErrorStore3.organizationId ? '?organizationId=' + ((_loadingAndErrorStore4 = loadingAndErrorStore.fallbackModule) === null || _loadingAndErrorStore4 === void 0 ? void 0 : _loadingAndErrorStore4.organizationId) : '')
                });
              },
              children: (_loadingAndErrorStore5 = loadingAndErrorStore.fallbackModule.text) !== null && _loadingAndErrorStore5 !== void 0 ? _loadingAndErrorStore5 : t('portal.error.gotodefaultmodule') + ' (' + loadingAndErrorStore.fallbackModule.route.replace('/', '') + ')'
            }), configurationStore.applicationEnvironment !== 'WEB' && loadingAndErrorStore.showLogout && /*#__PURE__*/jsx(Button$1, {
              color: "primary",
              variant: "contained",
              onClick: function onClick() {
                return authorizationStore.logout();
              },
              children: "Logout"
            }), showReload && /*#__PURE__*/jsx(Button$1, {
              color: "primary",
              variant: "contained",
              onClick: function onClick() {
                return location.reload();
              },
              children: "Seite neu laden"
            })]
          })]
        })]
      })
    });
  }
  return /*#__PURE__*/jsx(Fragment, {});
}
var ErrorDisplay$1 = observer(ErrorDisplay);

var snackbar = "snackbar-bkInm";
var clickable = "clickable-34rh-";
var css_248z = "@media (min-width: 600px) {\n  .snackbar-bkInm.MuiSnackbar-anchorOriginBottomRight {\n    bottom: 37px;\n  }\n\n  .snackbar-bkInm .MuiCardHeader-root {\n    padding: 8px 8px 0 8px;\n  }\n  .snackbar-bkInm .MuiCardContent-root {\n    padding: 8px;\n  }\n}\n\n.clickable-34rh- {\n  cursor: pointer;\n}\n";
styleInject(css_248z);

function DivaSnackBar() {
  var _useDivaCoreContext = useDivaCoreContext(),
    contentStore = _useDivaCoreContext.contentStore;
  return /*#__PURE__*/jsx(Fragment, {
    children: contentStore.snackBars.map(function (sb) {
      switch (sb.data.type) {
        case 'classic':
          return /*#__PURE__*/jsx(ClassicSnackBarComponent, {
            sbKey: sb.key,
            data: sb.data,
            deleteFromStore: function deleteFromStore() {
              return contentStore.closeSnackBar(sb.key);
            }
          }, sb.key);
        case 'big':
          return /*#__PURE__*/jsx(BigSnackBarComponent, {
            sbKey: sb.key,
            data: sb.data,
            deleteFromStore: function deleteFromStore() {
              return contentStore.closeSnackBar(sb.key);
            }
          }, sb.key);
        default:
          return /*#__PURE__*/jsx(Fragment, {});
      }
    })
  });
}
function ClassicSnackBarComponent(_ref) {
  var sbKey = _ref.sbKey,
    data = _ref.data,
    deleteFromStore = _ref.deleteFromStore;
  var _useState = useState(true),
    _useState2 = _slicedToArray(_useState, 2),
    open = _useState2[0],
    setOpen = _useState2[1];
  var _onClose = function onClose() {
    setOpen(false);
    //to get the close effect, we wait 5 sec bevor we remove it from the store
    setTimeout(function () {
      return deleteFromStore();
    }, 5000);
  };
  return /*#__PURE__*/jsx(Snackbar, {
    className: snackbar,
    color: "secondary",
    autoHideDuration: data.autoHideDuration,
    open: open,
    anchorOrigin: {
      vertical: 'bottom',
      horizontal: 'right'
    },
    onClose: function onClose(_, r) {
      return r == 'timeout' ? _onClose() : false;
    },
    children: /*#__PURE__*/jsx(Fragment, {
      children: /*#__PURE__*/jsx(SnackbarContent, {
        message: data.message,
        action: /*#__PURE__*/jsxs(Fragment, {
          children: [data.action, /*#__PURE__*/jsx(IconButton, {
            size: "small",
            "aria-label": "close",
            color: "inherit",
            onClick: function onClick() {
              return _onClose();
            },
            children: /*#__PURE__*/jsx(CloseIcon, {
              fontSize: "small"
            })
          })]
        })
      })
    })
  }, sbKey);
}
function BigSnackBarComponent(_ref2) {
  var sbKey = _ref2.sbKey,
    data = _ref2.data,
    deleteFromStore = _ref2.deleteFromStore;
  var _useState3 = useState(true),
    _useState4 = _slicedToArray(_useState3, 2),
    open = _useState4[0],
    setOpen = _useState4[1];
  var _onClose2 = function onClose() {
    setOpen(false);
    //to get the close effect, we wait 5 sec bevor we remove it from the store
    setTimeout(function () {
      return deleteFromStore();
    }, 5000);
  };
  return /*#__PURE__*/jsx(Snackbar, {
    open: open,
    className: snackbar,
    autoHideDuration: data.autoHideDuration,
    color: "secondary",
    anchorOrigin: {
      vertical: 'bottom',
      horizontal: 'right'
    },
    onClose: function onClose(_, r) {
      return r == 'timeout' ? _onClose2() : false;
    },
    children: /*#__PURE__*/jsxs(Card, {
      style: {
        backgroundColor: 'var(--diva-theme-palette-secondary-dark)',
        color: 'var(--diva-theme-palette-secondary-contrast-text)'
      },
      children: [/*#__PURE__*/jsx(CardHeader, {
        action: /*#__PURE__*/jsx(IconButton, {
          size: "small",
          "aria-label": "close",
          color: "inherit",
          onClick: function onClick() {
            return _onClose2();
          },
          children: /*#__PURE__*/jsx(CloseIcon, {
            fontSize: "small"
          })
        }),
        title: data.message,
        titleTypographyProps: {
          variant: 'h6'
        }
      }), data.qrCode && /*#__PURE__*/jsx(CardContent, {
        className: data.clickable ? clickable : undefined,
        onClick: function onClick() {
          if (data.clickable && data.qrCode) window.open(data.qrCode, '_blank');
        },
        children: /*#__PURE__*/jsx(QRCode, {
          size: data.qrCodeSize,
          value: data.qrCode,
          bgColor: 'var(--diva-theme-palette-secondary-dark)',
          fgColor: 'var(--diva-theme-palette-secondary-contrast-text)'
        })
      })]
    })
  }, sbKey);
}
var SnackBar = observer(DivaSnackBar);

function ownKeys$3(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$3(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$3(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$3(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var LOG$2 = getLogger('Framework', 'Root');
var LazyAuth = /*#__PURE__*/React.lazy(function () {
  return import('./index-83515d70.js');
});
var LazyModals = /*#__PURE__*/React.lazy(function () {
  return import('./ModalsWrapper-afce575b.js');
});
function ContentComponent() {
  var context = useDivaCoreContext();
  useEffect(function () {
    LOG$2.debug('Initial render of content wrapper');
  }, []);
  return /*#__PURE__*/jsxs(Fragment, {
    children: [/*#__PURE__*/jsxs(Suspense, {
      fallback: /*#__PURE__*/jsx(Fragment, {}),
      children: [context.configurationStore.hasAuthentication && /*#__PURE__*/jsx(LazyAuth, {}), context.configurationStore.enableModals && !context.contentStore.fullscreen && !context.contentStore.isFullscreenComponentDefined && /*#__PURE__*/jsx(LazyModals, {})]
    }), /*#__PURE__*/jsx(Banner$1, {}), /*#__PURE__*/jsx(Fullscreen$1, {}), /*#__PURE__*/jsx(SnackBar, {}), !context.contentStore.isFullscreenComponentDefined && /*#__PURE__*/jsx(SideMenu$1, {}), /*#__PURE__*/jsxs("div", {
      style: {
        position: 'relative',
        width: '100%',
        zIndex: 0,
        height: '100%',
        overflow: 'auto'
      },
      id: "Diva-content-wrapper",
      children: [/*#__PURE__*/jsx(Spinner$1, {}), /*#__PURE__*/jsx(ErrorDisplay$1, {}), context.contentStore.components.map(function (c) {
        var C = c.component;
        return /*#__PURE__*/jsx("div", {
          hidden: !context.contentStore.isVisible(c.name),
          style: {
            position: 'relative',
            width: '100%',
            zIndex: 0,
            height: '100%',
            overflow: 'auto'
          },
          id: "Diva-component-wrapper",
          children: /*#__PURE__*/jsx(Suspense, {
            fallback: /*#__PURE__*/jsx(Fallback, {}),
            children: /*#__PURE__*/jsx(C, _objectSpread$3({}, context.contentStore.getState(c.name)))
          })
        }, c.name);
      })]
    })]
  });
}
var Content = observer(ContentComponent);

var _excluded = ["refs"];
function ownKeys$2(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$2(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$2(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$2(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
var LOG$1 = getLogger('Framework', 'ProductHandler');
var ProductHandler = /*#__PURE__*/function (_ProductHandlerAbstra) {
  function ProductHandler(root, openModal, closeModal) {
    var _this;
    _classCallCheck(this, ProductHandler);
    _this = _callSuper(this, ProductHandler, [LOG$1, root.t, openModal, closeModal]);
    _this.root = root;
    return _this;
  }
  _inherits(ProductHandler, _ProductHandlerAbstra);
  return _createClass(ProductHandler, [{
    key: "catalogService",
    get: function get() {
      return this.root.apiConfig.catalogService;
    }
  }, {
    key: "mediaService",
    get: function get() {
      return this.root.apiConfig.mediaService;
    }
  }, {
    key: "basketService",
    get: function get() {
      return this.root.apiConfig.basketService;
    }
  }, {
    key: "api2",
    get: function get() {
      return this.root.apiConfig.api2["default"];
    }
  }, {
    key: "sessionGuid",
    get: function get() {
      return this.root.dataStore.getSessionGuid('V');
    }
  }, {
    key: "organization",
    get: function get() {
      return this.root.organization;
    }
  }, {
    key: "user",
    get: function get() {
      return this.root.user;
    }
  }, {
    key: "langs",
    get: function get() {
      return this.root.languages;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.root.jwt;
    }
  }, {
    key: "saveProductMedia",
    value: function () {
      var _saveProductMedia = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(productmedia, organizationId, refCount, refIds) {
        var file, refs;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (!productmedia.file) {
                _context.next = 7;
                break;
              }
              file = productmedia.file;
              if (!file) {
                _context.next = 7;
                break;
              }
              _context.next = 5;
              return file.save({
                organizationId: organizationId,
                refCount: refCount,
                refIds: refIds
              });
            case 5:
              refs = _context.sent;
              return _context.abrupt("return", {
                url: refs.ref ? refs.ref.url : file.url,
                thumbnail: file.thumbnail,
                ref: file.ref,
                mediaType: file.mediaType,
                functionType: file.functionType,
                description: file.description,
                name: file.fileName,
                "class": productmedia["class"],
                refs: refs.ids ? refs.ids : refs
              });
            case 7:
              return _context.abrupt("return", undefined);
            case 8:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function saveProductMedia(_x, _x2, _x3, _x4) {
        return _saveProductMedia.apply(this, arguments);
      }
      return saveProductMedia;
    }()
  }, {
    key: "saveMedias",
    value: function () {
      var _saveMedias = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(mediasToSave, organizationId) {
        var groupedMedias, mediasForProduct, _loop, i, _i, group, saved, media, refs, tmpRefs, tmpMedia, j, _refs, productId;
        return _regeneratorRuntime.wrap(function _callee2$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              groupedMedias = [];
              mediasForProduct = {};
              _loop = /*#__PURE__*/_regeneratorRuntime.mark(function _loop() {
                var toSave, group;
                return _regeneratorRuntime.wrap(function _loop$(_context2) {
                  while (1) switch (_context2.prev = _context2.next) {
                    case 0:
                      toSave = mediasToSave[i];
                      group = toSave.media.url && groupedMedias.find(function (m) {
                        var _toSave$media$file, _m$media$file;
                        return m.media.url === toSave.media.url && ((_toSave$media$file = toSave.media.file) === null || _toSave$media$file === void 0 ? void 0 : _toSave$media$file.state) == ((_m$media$file = m.media.file) === null || _m$media$file === void 0 ? void 0 : _m$media$file.state);
                      });
                      if (group) {
                        group.ids.push(toSave.id);
                        if (group.refIds && toSave.media.ref) group.refIds.push(toSave.media.ref);
                      } else {
                        groupedMedias.push({
                          ids: [toSave.id],
                          media: toSave.media,
                          refIds: toSave.media.ref ? [toSave.media.ref] : undefined
                        });
                      }
                    case 3:
                    case "end":
                      return _context2.stop();
                  }
                }, _loop);
              });
              i = 0;
            case 4:
              if (!(i < mediasToSave.length)) {
                _context3.next = 9;
                break;
              }
              return _context3.delegateYield(_loop(), "t0", 6);
            case 6:
              i++;
              _context3.next = 4;
              break;
            case 9:
              _i = 0;
            case 10:
              if (!(_i < groupedMedias.length)) {
                _context3.next = 22;
                break;
              }
              group = groupedMedias[_i];
              _context3.next = 14;
              return this.saveProductMedia(group.media, organizationId, group.ids.length, group.refIds);
            case 14:
              saved = _context3.sent;
              media = void 0;
              refs = void 0;
              if (!saved) {
                media = group.media;
                refs = group.refIds;
              } else {
                tmpRefs = saved.refs, tmpMedia = _objectWithoutProperties(saved, _excluded);
                refs = tmpRefs;
                media = tmpMedia;
              }
              for (j = 0; j < group.ids.length; j++) {
                productId = group.ids[j];
                if (!mediasForProduct[productId]) mediasForProduct[productId] = {
                  medias: []
                };
                mediasForProduct[productId].medias.push(_objectSpread$2(_objectSpread$2({}, media), {}, {
                  ref: (_refs = refs) === null || _refs === void 0 ? void 0 : _refs[j]
                }));
              }
            case 19:
              _i++;
              _context3.next = 10;
              break;
            case 22:
              return _context3.abrupt("return", mediasForProduct);
            case 23:
            case "end":
              return _context3.stop();
          }
        }, _callee2, this);
      }));
      function saveMedias(_x5, _x6) {
        return _saveMedias.apply(this, arguments);
      }
      return saveMedias;
    }()
  }]);
}(ProductHandlerAbstract);

function HelpButton(_ref) {
  var link = _ref.link,
    title = _ref.title;
  var _useDivaCore = useDivaCore(),
    openModal = _useDivaCore.actions.openModal;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  return /*#__PURE__*/jsx(IconButton$1, {
    onClick: function onClick() {
      return openModal({
        iFrame: link,
        rejectByIcon: true,
        width: '80%',
        height: '80%',
        title: t(title !== null && title !== void 0 ? title : 'modal.help.title'),
        dontRenderForm: true
      });
    },
    size: "large",
    children: /*#__PURE__*/jsx(HelpOutline, {})
  });
}

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var actionFunctions = ['openComponent', 'closeComponentInFullscreen', 'setAbsoluteFullScreen', 'updateBreadcrumbs', 'openModal', 'closeModal', 'sendEmail', 'updateCustomLogo', 'updateCustomHeaderElement', 'toggleHidePrices', 'toggleHideConfigPricePreview', 'toggleLoading', 'changeLanguage', 'changeLoginMode', 'onEvent', 'subscribeEvents', 'unSubscribeEvents', 'setOrganization', 'getSessionGuid', 'getApi2AuthLoginData', 'logout', 'showLoginWindow', 'userHasPermission', 'openFullscreen', 'closeFullscreen', 'openSideMenu', 'closeSideMenu', 'openBarrier', 'updateHeaderInfos', 'openBanner', 'closeBanner', 'resolveComponent', 'openSnackBar', 'setComponentChange'];
function getRender(C) {
  return function (args) {
    return /*#__PURE__*/jsx(DivaMockProvider, {
      state: args.state,
      actions: actions.apply(void 0, actionFunctions),
      children: /*#__PURE__*/jsx(C, _objectSpread$1({}, args))
    });
  };
}
var argTypes = {
  divaParams: {
    control: {
      name: 'Overwrite Diva State',
      control: 'object'
    }
  }
};
var storyBookCoreMock = {
  getRender: getRender,
  argTypes: argTypes
};

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var DivaMockProvider = observer(function (_ref) {
  var children = _ref.children,
    state = _ref.state,
    actions = _ref.actions;
  var _React$useState = React.useState(false),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    initalized = _React$useState2[0],
    setInitalized = _React$useState2[1];
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    store = _useState2[0],
    setStore = _useState2[1];
  var _useState3 = useState(null),
    _useState4 = _slicedToArray(_useState3, 2),
    resizeObserver = _useState4[0],
    setResizeObserver = _useState4[1];
  var ref = useCallback(function (node) {
    if (node !== null) {
      var newStore = new MockedRootStore(state, actions, node, function () {
        return setInitalized(true);
      });
      setStore(newStore);
      if (resizeObserver) {
        resizeObserver.disconnect();
      }
      registerResizeObserver(node, newStore.onResize.bind(newStore)).then(function (observer) {
        setResizeObserver(observer);
      });
    }
  }, [state, actions]);
  var isMobile = !!(store !== null && store !== void 0 && store.dimensions.isMobile);
  var isPortrait = !!(store !== null && store !== void 0 && store.dimensions.isPortrait);
  return /*#__PURE__*/jsxs("div", {
    ref: ref,
    id: "DivaCore",
    style: {
      position: 'relative',
      height: '100%',
      overflow: 'hidden'
    },
    className: (isPortrait ? ' portrait' : '') + (isMobile ? '  mobile' : '') + (isMobile && !isPortrait ? '  landscape' : ''),
    children: [initalized && !!store && /*#__PURE__*/jsx(coreContext.Provider, {
      value: {
        context: store.state
      },
      children: /*#__PURE__*/jsx(I18nextProvider, {
        i18n: instance,
        children: /*#__PURE__*/jsx(Suspense, {
          fallback: /*#__PURE__*/jsx("div", {
            children: "Loading..."
          }),
          children: children
        })
      })
    }), (!initalized || !store) && /*#__PURE__*/jsx("div", {
      children: "Loading..."
    })]
  });
});
var MockedRootStore = /*#__PURE__*/function () {
  function MockedRootStore() {
    var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var actions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var container = arguments.length > 2 ? arguments[2] : undefined;
    var initalized = arguments.length > 3 ? arguments[3] : undefined;
    _classCallCheck(this, MockedRootStore);
    this.data = data;
    this.actions = actions;
    this.container = container;
    this.initalized = initalized;
    _defineProperty(this, "handlers", void 0);
    _defineProperty(this, "_apiHandler", void 0);
    _defineProperty(this, "_dimensions", {
      isMobile: false,
      isPortrait: false,
      isTablet: false,
      width: 0,
      height: 0
    });
    _defineProperty(this, "_language", 'de');
    _defineProperty(this, "dataStore", {});
    _defineProperty(this, "excludedOrganizations", void 0);
    _defineProperty(this, "t", instance.t.bind(instance));
    this._apiHandler = new ApiHandler(this);
    this.handlers = mockCoreHandlers(this);
    this.initialize();
    makeObservable(this, {
      dimensions: computed,
      _dimensions: observable.shallow,
      onResize: action
    });
  }
  return _createClass(MockedRootStore, [{
    key: "onResize",
    value: function onResize(width, height) {
      this._dimensions = calculateDimensions(width, height);
      console.log('new dimensions', this._dimensions);
    }
  }, {
    key: "initialize",
    value: function () {
      var _initialize = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var _this$data$language;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (this.data.priceFormat) DivaUtils.initPriceFormat(this.data.priceFormat);
              updateCssThemeVariables(this.container, this.theme);
              _context.next = 4;
              return init(_objectSpread(_objectSpread({}, this.data.locales), {}, {
                apiConfig: this.apiConfig,
                defaultLng: (_this$data$language = this.data.language) !== null && _this$data$language !== void 0 ? _this$data$language : this.language
              }));
            case 4:
              this._language = _context.sent;
              this.initalized();
            case 6:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function initialize() {
        return _initialize.apply(this, arguments);
      }
      return initialize;
    }()
  }, {
    key: "changeLanguage",
    value: function changeLanguage(lang) {
      var _this = this;
      instance.changeLanguage(lang, function (err) {
        if (err) {
          throw new Error('Could not change language', {
            cause: err
          });
        } else {
          _this._language = lang;
        }
      });
    }
  }, {
    key: "changeLoginMode",
    value: function changeLoginMode(loginMode) {
      if (this.actions.changeLoginMode) {
        this.actions.changeLoginMode(loginMode);
      } else {
        throw new Error('Method not implemented.');
      }
    }
  }, {
    key: "onExternalEvent",
    value: function onExternalEvent(event) {
      if (this.actions.onEvent) {
        this.actions.onEvent(event);
      } else {
        throw new Error('Method not implemented.');
      }
    }
  }, {
    key: "subscribeEvents",
    value: function subscribeEvents(fn) {
      if (this.actions.subscribeEvents) {
        this.actions.subscribeEvents(fn);
      } else {
        throw new Error('Method not implemented.');
      }
    }
  }, {
    key: "unSubscribeEvents",
    value: function unSubscribeEvents(fn) {
      if (this.actions.unSubscribeEvents) {
        this.actions.unSubscribeEvents(fn);
      } else {
        throw new Error('Method not implemented.');
      }
    }
  }, {
    key: "onEvent",
    value: function onEvent(event) {
      if (this.actions.onEvent) {
        this.actions.onEvent(event);
      } else {
        throw new Error('Method not implemented.');
      }
    }
  }, {
    key: "language",
    get: function get() {
      return this._language;
    }
  }, {
    key: "loginMode",
    get: function get() {
      var _this$data$loginMode;
      return (_this$data$loginMode = this.data.loginMode) !== null && _this$data$loginMode !== void 0 ? _this$data$loginMode : 'offline';
    }
  }, {
    key: "languages",
    get: function get() {
      var _this$data$availableL;
      return (_this$data$availableL = this.data.availableLanguages) !== null && _this$data$availableL !== void 0 ? _this$data$availableL : ['de', 'en', 'fr', 'it'];
    }
  }, {
    key: "initializing",
    get: function get() {
      var _this$data$initializi;
      return (_this$data$initializi = this.data.initializing) !== null && _this$data$initializi !== void 0 ? _this$data$initializi : false;
    }
  }, {
    key: "aviailableComponents",
    get: function get() {
      var _this$data$availableC;
      return (_this$data$availableC = this.data.availableComponents) !== null && _this$data$availableC !== void 0 ? _this$data$availableC : [];
    }
  }, {
    key: "apiConfig",
    get: function get() {
      return parseApiConfig(this.data.apiConfig, {
        baseUrl: 'https://api-dev.diva-portal.com'
      }, this.organization);
    }
  }, {
    key: "navigationConfiguration",
    get: function get() {
      var _this$data$navigation;
      return (_this$data$navigation = this.data.navigationConfiguration) !== null && _this$data$navigation !== void 0 ? _this$data$navigation : {
        showFooter: true,
        allowHidePrices: true,
        showLogin: true,
        buttons: []
      };
    }
  }, {
    key: "apiHandler",
    get: function get() {
      return this._apiHandler;
    }
  }, {
    key: "productHandler",
    get: function get() {
      return this.handlers.productHandler;
    }
  }, {
    key: "organizationHandler",
    get: function get() {
      return this.handlers.organizationHandler;
    }
  }, {
    key: "mediaHandler",
    get: function get() {
      return this.handlers.mediaHandler;
    }
  }, {
    key: "adminHandler",
    get: function get() {
      return this.handlers.adminHandler;
    }
  }, {
    key: "authorizationHandler",
    get: function get() {
      return this.handlers.authorizationHandler;
    }
  }, {
    key: "analyticsHandler",
    get: function get() {
      return this.handlers.analyticsHandler;
    }
  }, {
    key: "reportHandler",
    get: function get() {
      return this.handlers.reportHandler;
    }
  }, {
    key: "supportHandler",
    get: function get() {
      return this.handlers.supportHandler;
    }
  }, {
    key: "clientArticleHandler",
    get: function get() {
      return this.handlers.clientArticleHandler;
    }
  }, {
    key: "doShowInitWarnBanner",
    get: function get() {
      return false;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this.data.jwt;
    }
  }, {
    key: "storedNToken",
    get: function get() {
      return this.data.nToken;
    }
  }, {
    key: "user",
    get: function get() {
      return this.data.user;
    }
  }, {
    key: "organization",
    get: function get() {
      var _this$data$organizati;
      return (_this$data$organizati = this.data.organization) !== null && _this$data$organizati !== void 0 ? _this$data$organizati : {
        _id: 'test',
        street: 'Teststreet',
        city: 'Testcity',
        region: 'Testregion',
        zipCode: '1234',
        countryCode: 'IT',
        phone: '000',
        email: 'test@example.com',
        settings: {
          defaultCurrency: 'EUR',
          useCatalogTranslations: 'DEFAULT'
        }
      };
    }
  }, {
    key: "organizationHierarchy",
    get: function get() {
      var _this$data$organizati2;
      return (_this$data$organizati2 = this.data.organizationHierarchy) !== null && _this$data$organizati2 !== void 0 ? _this$data$organizati2 : [];
    }
  }, {
    key: "allowedOrganizationTypes",
    get: function get() {
      return ['RETAILER'];
    }
  }, {
    key: "validOrganizations",
    get: function get() {
      return undefined;
    }
  }, {
    key: "dimensions",
    get: function get() {
      var _this$data$dimensions;
      return (_this$data$dimensions = this.data.dimensions) !== null && _this$data$dimensions !== void 0 ? _this$data$dimensions : this._dimensions;
    }
  }, {
    key: "headerInfos",
    get: function get() {
      var _this$data$headerInfo;
      return (_this$data$headerInfo = this.data.headerInfos) !== null && _this$data$headerInfo !== void 0 ? _this$data$headerInfo : {
        visible: false
      };
    }
  }, {
    key: "theme",
    get: function get() {
      var _this$data$theme$pale, _this$data$theme, _this$data$theme$pale2, _this$data$theme2, _this$data$theme$pale3, _this$data$theme3, _this$data$theme$pale4, _this$data$theme4, _ref2, _this$data$theme$pale5, _this$data$theme5, _this$data$theme6, _ref3, _this$data$theme$pale6, _this$data$theme7, _this$data$theme8, _ref4, _this$data$theme$pale7, _this$data$theme9, _this$data$theme10, _ref5, _this$data$theme$pale8, _this$data$theme11, _this$data$theme12, _this$data$theme$pale9, _this$data$theme13, _this$data$theme$pale10, _this$data$theme14, _this$data$theme$typo, _this$data$theme15, _this$data$theme$comp, _this$data$theme16;
      return {
        palette: {
          primary: {
            main: (_this$data$theme$pale = (_this$data$theme = this.data.theme) === null || _this$data$theme === void 0 || (_this$data$theme = _this$data$theme.palette) === null || _this$data$theme === void 0 || (_this$data$theme = _this$data$theme.primary) === null || _this$data$theme === void 0 ? void 0 : _this$data$theme.main) !== null && _this$data$theme$pale !== void 0 ? _this$data$theme$pale : defaultTheme.palette.primary.main,
            light: (_this$data$theme$pale2 = (_this$data$theme2 = this.data.theme) === null || _this$data$theme2 === void 0 || (_this$data$theme2 = _this$data$theme2.palette) === null || _this$data$theme2 === void 0 || (_this$data$theme2 = _this$data$theme2.primary) === null || _this$data$theme2 === void 0 ? void 0 : _this$data$theme2.light) !== null && _this$data$theme$pale2 !== void 0 ? _this$data$theme$pale2 : defaultTheme.palette.primary.light,
            dark: (_this$data$theme$pale3 = (_this$data$theme3 = this.data.theme) === null || _this$data$theme3 === void 0 || (_this$data$theme3 = _this$data$theme3.palette) === null || _this$data$theme3 === void 0 || (_this$data$theme3 = _this$data$theme3.primary) === null || _this$data$theme3 === void 0 ? void 0 : _this$data$theme3.dark) !== null && _this$data$theme$pale3 !== void 0 ? _this$data$theme$pale3 : defaultTheme.palette.primary.dark,
            contrastText: (_this$data$theme$pale4 = (_this$data$theme4 = this.data.theme) === null || _this$data$theme4 === void 0 || (_this$data$theme4 = _this$data$theme4.palette) === null || _this$data$theme4 === void 0 || (_this$data$theme4 = _this$data$theme4.primary) === null || _this$data$theme4 === void 0 ? void 0 : _this$data$theme4.contrastText) !== null && _this$data$theme$pale4 !== void 0 ? _this$data$theme$pale4 : defaultTheme.palette.primary.contrastText
          },
          secondary: {
            main: (_ref2 = (_this$data$theme$pale5 = (_this$data$theme5 = this.data.theme) === null || _this$data$theme5 === void 0 || (_this$data$theme5 = _this$data$theme5.palette) === null || _this$data$theme5 === void 0 || (_this$data$theme5 = _this$data$theme5.secondary) === null || _this$data$theme5 === void 0 ? void 0 : _this$data$theme5.main) !== null && _this$data$theme$pale5 !== void 0 ? _this$data$theme$pale5 : (_this$data$theme6 = this.data.theme) === null || _this$data$theme6 === void 0 || (_this$data$theme6 = _this$data$theme6.palette) === null || _this$data$theme6 === void 0 || (_this$data$theme6 = _this$data$theme6.primary) === null || _this$data$theme6 === void 0 ? void 0 : _this$data$theme6.main) !== null && _ref2 !== void 0 ? _ref2 : defaultTheme.palette.secondary.main,
            light: (_ref3 = (_this$data$theme$pale6 = (_this$data$theme7 = this.data.theme) === null || _this$data$theme7 === void 0 || (_this$data$theme7 = _this$data$theme7.palette) === null || _this$data$theme7 === void 0 || (_this$data$theme7 = _this$data$theme7.secondary) === null || _this$data$theme7 === void 0 ? void 0 : _this$data$theme7.light) !== null && _this$data$theme$pale6 !== void 0 ? _this$data$theme$pale6 : (_this$data$theme8 = this.data.theme) === null || _this$data$theme8 === void 0 || (_this$data$theme8 = _this$data$theme8.palette) === null || _this$data$theme8 === void 0 || (_this$data$theme8 = _this$data$theme8.primary) === null || _this$data$theme8 === void 0 ? void 0 : _this$data$theme8.light) !== null && _ref3 !== void 0 ? _ref3 : defaultTheme.palette.secondary.light,
            dark: (_ref4 = (_this$data$theme$pale7 = (_this$data$theme9 = this.data.theme) === null || _this$data$theme9 === void 0 || (_this$data$theme9 = _this$data$theme9.palette) === null || _this$data$theme9 === void 0 || (_this$data$theme9 = _this$data$theme9.secondary) === null || _this$data$theme9 === void 0 ? void 0 : _this$data$theme9.dark) !== null && _this$data$theme$pale7 !== void 0 ? _this$data$theme$pale7 : (_this$data$theme10 = this.data.theme) === null || _this$data$theme10 === void 0 || (_this$data$theme10 = _this$data$theme10.palette) === null || _this$data$theme10 === void 0 || (_this$data$theme10 = _this$data$theme10.primary) === null || _this$data$theme10 === void 0 ? void 0 : _this$data$theme10.dark) !== null && _ref4 !== void 0 ? _ref4 : defaultTheme.palette.secondary.dark,
            contrastText: (_ref5 = (_this$data$theme$pale8 = (_this$data$theme11 = this.data.theme) === null || _this$data$theme11 === void 0 || (_this$data$theme11 = _this$data$theme11.palette) === null || _this$data$theme11 === void 0 || (_this$data$theme11 = _this$data$theme11.secondary) === null || _this$data$theme11 === void 0 ? void 0 : _this$data$theme11.contrastText) !== null && _this$data$theme$pale8 !== void 0 ? _this$data$theme$pale8 : (_this$data$theme12 = this.data.theme) === null || _this$data$theme12 === void 0 || (_this$data$theme12 = _this$data$theme12.palette) === null || _this$data$theme12 === void 0 || (_this$data$theme12 = _this$data$theme12.primary) === null || _this$data$theme12 === void 0 ? void 0 : _this$data$theme12.contrastText) !== null && _ref5 !== void 0 ? _ref5 : defaultTheme.palette.secondary.contrastText
          },
          text: {
            primary: (_this$data$theme$pale9 = (_this$data$theme13 = this.data.theme) === null || _this$data$theme13 === void 0 || (_this$data$theme13 = _this$data$theme13.palette) === null || _this$data$theme13 === void 0 || (_this$data$theme13 = _this$data$theme13.text) === null || _this$data$theme13 === void 0 ? void 0 : _this$data$theme13.primary) !== null && _this$data$theme$pale9 !== void 0 ? _this$data$theme$pale9 : defaultTheme.palette.text.primary,
            secondary: (_this$data$theme$pale10 = (_this$data$theme14 = this.data.theme) === null || _this$data$theme14 === void 0 || (_this$data$theme14 = _this$data$theme14.palette) === null || _this$data$theme14 === void 0 || (_this$data$theme14 = _this$data$theme14.text) === null || _this$data$theme14 === void 0 ? void 0 : _this$data$theme14.secondary) !== null && _this$data$theme$pale10 !== void 0 ? _this$data$theme$pale10 : defaultTheme.palette.text.secondary
          }
        },
        typography: {
          fontFamily: (_this$data$theme$typo = (_this$data$theme15 = this.data.theme) === null || _this$data$theme15 === void 0 || (_this$data$theme15 = _this$data$theme15.typography) === null || _this$data$theme15 === void 0 ? void 0 : _this$data$theme15.fontFamily) !== null && _this$data$theme$typo !== void 0 ? _this$data$theme$typo : defaultTheme.typography.fontFamily
        },
        components: (_this$data$theme$comp = (_this$data$theme16 = this.data.theme) === null || _this$data$theme16 === void 0 ? void 0 : _this$data$theme16.components) !== null && _this$data$theme$comp !== void 0 ? _this$data$theme$comp : defaultTheme.components
      };
    }
  }, {
    key: "state",
    get: function get() {
      var _this2 = this,
        _this$data$loading,
        _this$data$hidePrices,
        _this$data$hideConfig,
        _this$data$applicatio,
        _this$data$isFullscre,
        _this$data$enableSupp;
      return {
        actions: {
          changeLanguage: this.changeLanguage.bind(this),
          changeLoginMode: this.changeLoginMode.bind(this),
          subscribeEvents: this.subscribeEvents.bind(this),
          unSubscribeEvents: this.unSubscribeEvents.bind(this),
          toggleHideSnow: function toggleHideSnow() {},
          onEvent: this.onEvent.bind(this),
          openComponent: function openComponent(data) {
            if (_this2.actions.openComponent) {
              return _this2.actions.openComponent(data);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          closeComponentInFullscreen: function closeComponentInFullscreen() {
            if (_this2.actions.closeComponentInFullscreen) {
              _this2.actions.closeComponentInFullscreen();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          setAbsoluteFullScreen: function setAbsoluteFullScreen(val) {
            if (_this2.actions.setAbsoluteFullScreen) {
              _this2.actions.setAbsoluteFullScreen(val);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          updateBreadcrumbs: function updateBreadcrumbs(params) {
            if (_this2.actions.updateBreadcrumbs) {
              _this2.actions.updateBreadcrumbs(params);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openModal: function openModal(data) {
            if (_this2.actions.openModal) {
              _this2.actions.openModal(data);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          closeModal: function closeModal() {
            if (_this2.actions.closeModal) {
              _this2.actions.closeModal();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          sendEmail: function sendEmail(data) {
            if (_this2.actions.sendEmail) {
              _this2.actions.sendEmail(data);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          updateCustomLogo: function updateCustomLogo(components, logo) {
            if (_this2.actions.updateCustomLogo) {
              _this2.actions.updateCustomLogo(components, logo);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          updateCustomHeaderElement: function updateCustomHeaderElement(components, element) {
            if (_this2.actions.updateCustomHeaderElement) {
              _this2.actions.updateCustomHeaderElement(components, element);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          toggleHidePrices: function toggleHidePrices() {
            if (_this2.actions.toggleHidePrices) {
              _this2.actions.toggleHidePrices();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          toggleHideConfigPricePreview: function toggleHideConfigPricePreview() {
            if (_this2.actions.toggleHideConfigPricePreview) {
              _this2.actions.toggleHideConfigPricePreview();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          toggleLoading: function toggleLoading(id, hidden, toggle) {
            if (_this2.actions.toggleLoading) {
              _this2.actions.toggleLoading(id, hidden, toggle);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          loadModelViewer: function loadModelViewer() {
            if (_this2.actions.loadModelViewer) {
              _this2.actions.loadModelViewer();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          setOrganization: function setOrganization(organizationId) {
            if (_this2.actions.setOrganization) {
              _this2.actions.setOrganization(organizationId);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          getSessionGuid: function getSessionGuid(userRole, loginMode, organizationId, api2Location) {
            if (_this2.actions.getSessionGuid) {
              return _this2.actions.getSessionGuid(userRole, loginMode, organizationId, api2Location);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          getApi2AuthLoginData: function getApi2AuthLoginData(userRole, loginMode, organizationId, api2Location) {
            if (_this2.actions.getApi2AuthLoginData) {
              return _this2.actions.getApi2AuthLoginData(userRole, loginMode, organizationId, api2Location);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          logout: function logout() {
            if (_this2.actions.logout) {
              _this2.actions.logout();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          showLoginWindow: function showLoginWindow() {
            if (_this2.actions.showLoginWindow) {
              _this2.actions.showLoginWindow();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          userHasPermission: function userHasPermission(permission) {
            if (_this2.actions.userHasPermission) {
              return _this2.actions.userHasPermission(permission);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openFullscreen: function openFullscreen(fullscreen) {
            if (_this2.actions.openFullscreen) {
              _this2.actions.openFullscreen(fullscreen);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          closeFullscreen: function closeFullscreen() {
            if (_this2.actions.closeFullscreen) {
              _this2.actions.closeFullscreen();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openSideMenu: function openSideMenu(sideMenu) {
            if (_this2.actions.openSideMenu) {
              _this2.actions.openSideMenu(sideMenu);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          closeSideMenu: function closeSideMenu() {
            if (_this2.actions.closeSideMenu) {
              _this2.actions.closeSideMenu();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openBarrier: function openBarrier(barrier) {
            if (_this2.actions.openBarrier) {
              _this2.actions.openBarrier(barrier);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          updateHeaderInfos: function updateHeaderInfos(headerInfos) {
            if (_this2.actions.updateHeaderInfos) {
              _this2.actions.updateHeaderInfos(headerInfos);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openBanner: function openBanner(banner) {
            if (_this2.actions.openBanner) {
              _this2.actions.openBanner(banner);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          closeBanner: function closeBanner() {
            if (_this2.actions.closeBanner) {
              _this2.actions.closeBanner();
            } else {
              throw new Error('Method not implemented.');
            }
          },
          resolveComponent: function resolveComponent(action) {
            if (_this2.actions.resolveComponent) {
              return _this2.actions.resolveComponent(action);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          openSnackBar: function openSnackBar(data) {
            if (_this2.actions.openSnackBar) {
              _this2.actions.openSnackBar(data);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          setComponentChange: function setComponentChange(value) {
            if (_this2.actions.setComponentChange) {
              _this2.actions.setComponentChange(value);
            } else {
              throw new Error('Method not implemented.');
            }
          },
          fetchConfiguration: function fetchConfiguration(_ref6) {
            var identifier = _ref6.identifier,
              type = _ref6.type,
              domain = _ref6.domain,
              organizationId = _ref6.organizationId;
            if (_this2.actions.fetchConfiguration) {
              _this2.actions.fetchConfiguration({
                identifier: identifier,
                type: type,
                domain: domain,
                organizationId: organizationId
              });
            } else {
              throw new Error('Method not implemented.');
            }
          },
          getSubConfiguration: function getSubConfiguration(type) {
            if (_this2.actions.getSubConfiguration) {
              return _this2.actions.getSubConfiguration(type);
            } else {
              throw new Error('Method not implemented.');
            }
          }
        },
        state: _objectSpread(_objectSpread({}, this.data), {}, {
          hideSnow: false,
          apiConfig: this.apiConfig,
          availableLanguages: this.languages,
          loginMode: this.loginMode,
          availableComponents: this.aviailableComponents,
          initializing: this.initializing,
          organization: this.organization,
          organizationHierarchy: this.organizationHierarchy,
          navigationConfiguration: this.navigationConfiguration,
          loading: (_this$data$loading = this.data.loading) !== null && _this$data$loading !== void 0 ? _this$data$loading : false,
          hidePrices: (_this$data$hidePrices = this.data.hidePrices) !== null && _this$data$hidePrices !== void 0 ? _this$data$hidePrices : false,
          hideConfigPricePreview: (_this$data$hideConfig = this.data.hideConfigPricePreview) !== null && _this$data$hideConfig !== void 0 ? _this$data$hideConfig : false,
          dimensions: this.dimensions,
          isMobile: userAgentIsMobile(),
          isFirefox: !!this.data.isFirefox,
          headerInfos: this.headerInfos,
          theme: this.theme,
          applicationEnvironment: (_this$data$applicatio = this.data.applicationEnvironment) !== null && _this$data$applicatio !== void 0 ? _this$data$applicatio : 'WEB',
          isFullscreenComponent: (_this$data$isFullscre = this.data.isFullscreenComponent) !== null && _this$data$isFullscre !== void 0 ? _this$data$isFullscre : false,
          enableSupport: (_this$data$enableSupp = this.data.enableSupport) !== null && _this$data$enableSupp !== void 0 ? _this$data$enableSupp : false
        }),
        handler: this.handlers
      };
    }
  }]);
}();
function mockCoreHandlers(root) {
  return {
    productHandler: new ProductHandler(root),
    organizationHandler: new OrganizationHandler(root),
    mediaHandler: new MediaHandler(root),
    adminHandler: new AdminHandler(root),
    authorizationHandler: new AuthorizationHandler(root),
    analyticsHandler: new AnalyticsHandler(root),
    reportHandler: new ReportHandler(root),
    supportHandler: new SupportHandler(root),
    clientArticleHandler: new ClientArticleHandler(root)
  };
}

var LOG = getLogger('Framework', 'root');
LOG.startTransaction({
  event: 'unitInit',
  message: 'Until initalization starts',
  eventId: 'UNTIL_INIT',
  errorTime: 6000,
  warningTime: 4000
});
LOG.startTransaction({
  event: 'untilRender',
  message: 'Until first render',
  eventId: 'UNTIL_RENDER',
  errorTime: 6000,
  warningTime: 4000
});
window.DIVA_VERSION = "v".concat(process.env.VERSION);

export { AuthButton as A, Content as C, DivaCore as D, HelpButton as H, Input as I, ONE_DAY_UNIX as O, ProductHandler as P, RequestStatus as R, SupportHandler as S, getLogger as a, separator as b, success as c, auth as d, error as e, loginBox as f, google as g, logoContainer as h, styleInject as i, useDivaCore as j, AuthorizationHandler as k, link as l, microsoft as m, AnalyticsHandler as n, OrganizationHandler as o, ClientArticleHandler as p, DivaMockProvider as q, storyBookCoreMock as r, socialButton as s, titlecontainer as t, useDivaCoreContext as u };
